@@ -13,8 +13,7 @@ from ansible_collections.ansible.netcommon.plugins.module_utils.network.common.n
 
 
 class CliParserTemplate(NetworkTemplate):
-    """ The parser template base class
-    """
+    """The parser template base class"""
 
     def __init__(self, lines=None):
         super(CliParserTemplate, self).__init__(lines=lines, tmplt=self)
