@@ -10,6 +10,7 @@ module: guest_type_email
 short_description: Resource module for Guest Type Email
 description:
 - Manage operation update of the resource Guest Type Email.
+- This API allows the client to update a guest type email by ID.
 version_added: '1.0.0'
 extends_documentation_fragment:
   - cisco.ise.module
@@ -17,6 +18,7 @@ author: Rafael Campos (@racampos)
 options:
   additionalData:
     description: Guest Type Email's additionalData.
+    elements: dict
     suboptions:
       name:
         description: Guest Type Email's name.
@@ -25,14 +27,19 @@ options:
         description: Guest Type Email's value.
         type: str
     type: list
+  id:
+    description: Id path parameter.
+    type: str
 requirements:
-- ciscoisesdk >= 1.1.0
+- ciscoisesdk >= 2.0.3
 - python >= 3.5
-seealso:
-# Reference by Internet resource
-- name: Guest Type Email reference
-  description: Complete reference of the Guest Type Email object model.
-  link: https://ciscoisesdk.readthedocs.io/en/latest/api/api.html#v3-0-0-summary
+notes:
+  - SDK Method used are
+    guest_type.GuestType.update_guest_type_email,
+
+  - Paths used are
+    put /ers/config/guesttype/email/{id},
+
 """
 
 EXAMPLES = r"""
