@@ -2,7 +2,8 @@
 # -*- coding: utf-8 -*-
 #
 # Copyright (c) 2015 CenturyLink
-# GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
+# GNU General Public License v3.0+ (see LICENSES/GPL-3.0-or-later.txt or https://www.gnu.org/licenses/gpl-3.0.txt)
+# SPDX-License-Identifier: GPL-3.0-or-later
 
 from __future__ import absolute_import, division, print_function
 __metaclass__ = type
@@ -24,7 +25,7 @@ options:
     description:
       - Whether to add a public ip to the server
     type: bool
-    default: 'no'
+    default: false
   alias:
     description:
       - The account alias to provision the servers under.
@@ -95,8 +96,8 @@ options:
     description:
       - Whether to create the server as 'Managed' or not.
     type: bool
-    default: 'no'
-    required: False
+    default: false
+    required: false
   memory:
     description:
       - Memory in GB.
@@ -193,7 +194,7 @@ options:
     description:
       - Whether to wait for the provisioning tasks to finish before returning.
     type: bool
-    default: 'yes'
+    default: true
 requirements:
     - python = 2.7
     - requests >= 2.5.0
@@ -567,31 +568,31 @@ class ClcServer:
             template=dict(),
             group=dict(default='Default Group'),
             network_id=dict(),
-            location=dict(default=None),
+            location=dict(),
             cpu=dict(default=1, type='int'),
             memory=dict(default=1, type='int'),
-            alias=dict(default=None),
-            password=dict(default=None, no_log=True),
-            ip_address=dict(default=None),
+            alias=dict(),
+            password=dict(no_log=True),
+            ip_address=dict(),
             storage_type=dict(
                 default='standard',
                 choices=[
                     'standard',
                     'hyperscale']),
             type=dict(default='standard', choices=['standard', 'hyperscale', 'bareMetal']),
-            primary_dns=dict(default=None),
-            secondary_dns=dict(default=None),
+            primary_dns=dict(),
+            secondary_dns=dict(),
             additional_disks=dict(type='list', default=[], elements='dict'),
             custom_fields=dict(type='list', default=[], elements='dict'),
-            ttl=dict(default=None),
+            ttl=dict(),
             managed_os=dict(type='bool', default=False),
-            description=dict(default=None),
-            source_server_password=dict(default=None, no_log=True),
-            cpu_autoscale_policy_id=dict(default=None),
-            anti_affinity_policy_id=dict(default=None),
-            anti_affinity_policy_name=dict(default=None),
-            alert_policy_id=dict(default=None),
-            alert_policy_name=dict(default=None),
+            description=dict(),
+            source_server_password=dict(no_log=True),
+            cpu_autoscale_policy_id=dict(),
+            anti_affinity_policy_id=dict(),
+            anti_affinity_policy_name=dict(),
+            alert_policy_id=dict(),
+            alert_policy_name=dict(),
             packages=dict(type='list', default=[], elements='dict'),
             state=dict(
                 default='present',
@@ -601,7 +602,7 @@ class ClcServer:
                     'started',
                     'stopped']),
             count=dict(type='int', default=1),
-            exact_count=dict(type='int', default=None),
+            exact_count=dict(type='int', ),
             count_group=dict(),
             server_ids=dict(type='list', default=[], elements='str'),
             add_public_ip=dict(type='bool', default=False),
@@ -612,14 +613,13 @@ class ClcServer:
                     'UDP',
                     'ICMP']),
             public_ip_ports=dict(type='list', default=[], elements='dict'),
-            configuration_id=dict(default=None),
-            os_type=dict(default=None,
-                         choices=[
-                             'redHat6_64Bit',
-                             'centOS6_64Bit',
-                             'windows2012R2Standard_64Bit',
-                             'ubuntu14_64Bit'
-                         ]),
+            configuration_id=dict(),
+            os_type=dict(choices=[
+                'redHat6_64Bit',
+                'centOS6_64Bit',
+                'windows2012R2Standard_64Bit',
+                'ubuntu14_64Bit'
+            ]),
             wait=dict(type='bool', default=True))
 
         mutually_exclusive = [
