@@ -1,8 +1,10 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
+
 # Copyright: (c) 2018, Ansible Project
 # Copyright: (c) 2018, Abhijeet Kasurde <akasurde@redhat.com>
-# GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
+# GNU General Public License v3.0+ (see LICENSES/GPL-3.0-or-later.txt or https://www.gnu.org/licenses/gpl-3.0.txt)
+# SPDX-License-Identifier: GPL-3.0-or-later
 
 from __future__ import absolute_import, division, print_function
 __metaclass__ = type
@@ -19,11 +21,6 @@ description:
     - Be careful while removing disk specified as this may lead to data loss.
 author:
     - Abhijeet Kasurde (@Akasurde) <akasurde@redhat.com>
-notes:
-    - Tested on vSphere 6.0 and 6.5
-requirements:
-    - "python >= 2.6"
-    - PyVmomi
 options:
    name:
      description:
@@ -94,8 +91,9 @@ options:
          description:
          - The type of disk, if not specified then use C(thick) type for new disk, no eagerzero.
          - The disk type C(rdm) is added in version 1.13.0.
+         - The disk type C(vpmemdisk) is added in version 2.7.0.
          type: str
-         choices: ['thin', 'eagerzeroedthick', 'thick', 'rdm' ]
+         choices: ['thin', 'eagerzeroedthick', 'thick', 'rdm', 'vpmemdisk']
        disk_mode:
          description:
            - Type of disk mode. If not specified then use C(persistent) mode for new disk.
@@ -103,31 +101,42 @@ options:
            - If set to 'independent_persistent' mode, same as persistent, but not affected by snapshots.
            - If set to 'independent_nonpersistent' mode, changes to virtual disk are made to a redo log and discarded
              at power off, but not affected by snapshots.
+           - Not applicable when disk C(type) is set to C(vpmemdisk).
          type: str
          choices: ['persistent', 'independent_persistent', 'independent_nonpersistent']
        rdm_path:
          description:
          - Path of LUN for Raw Device Mapping required for disk type C(rdm).
-         - Only valid is C(type) is set to C(rdm).
+         - Only valid if C(type) is set to C(rdm).
          type: str
-         version_added: '1.12.0'
+       cluster_disk:
+         description:
+           - This value allows for the sharing of an RDM between two machines.
+           - The primary machine holding the RDM uses the default C(False).
+           - The secondary machine holding the RDM uses C(True).
+         type: bool
+         default: False
+         version_added: '1.17.0'
        compatibility_mode:
-         description: Compatibility mode for raw devices. Required for disk type 'rdm'
+         description: Compatibility mode for raw devices. Required when disk type C(type) is set to C(rdm).
          type: str
          choices: ['physicalMode','virtualMode']
        sharing:
          description:
-           - This parameter is not available for Raw Device Mapping(RDM).
            - The sharing mode of the virtual disk.
            - Setting sharing means that multiple virtual machines can write to the virtual disk.
-           - Sharing can only be set if C(type) is set to C(eagerzeroedthick).
+           - Sharing can only be set if C(type) is set to C(eagerzeroedthick) or C(rdm).
          type: bool
          default: False
        datastore:
-         description: Name of datastore or datastore cluster to be used for the disk.
+         description:
+           - Name of datastore or datastore cluster to be used for the disk.
+           - Not applicable when disk C(type) is set to C(vpmemdisk).
          type: str
        autoselect_datastore:
-         description: Select the less used datastore. Specify only if C(datastore) is not specified.
+         description:
+           - Select the less used datastore. Specify only if C(datastore) is not specified.
+           - Not applicable when disk C(type) is set to C(vpmemdisk).
          type: bool
        scsi_controller:
          description:
@@ -135,10 +144,19 @@ options:
            - Care should be taken while specifying 'scsi_controller' is 0 and 'unit_number' as 0 as this disk may contain OS.
          type: int
          choices: [0, 1, 2, 3]
+       bus_sharing:
+         description:
+           - Only functions with Paravirtual SCSI Controller.
+           - Allows for the sharing of the scsi bus between two virtual machines.
+         type: str
+         choices: ['noSharing', 'physicalSharing', 'virtualSharing']
+         default: 'noSharing'
+         version_added: '1.17.0'
        unit_number:
          description:
            - Disk Unit Number.
            - Valid value range from 0 to 15, except 7 for SCSI Controller.
+           - Valid value range from 0 to 64, except 7 for Paravirtual SCSI Controller on Virtual Hardware version 14 or higher
            - Valid value range from 0 to 29 for SATA controller.
            - Valid value range from 0 to 14 for NVME controller.
          type: int
@@ -157,6 +175,7 @@ options:
          description:
            - Existing disk image to be used. Filename must already exist on the datastore.
            - Specify filename string in C([datastore_name] path/to/file.vmdk) format. Added in version 2.10.
+           - Not applicable when disk C(type) is set to C(vpmemdisk).
          type: str
        state:
          description:
@@ -178,7 +197,9 @@ options:
          type: int
          choices: [0, 1, 2, 3]
        iolimit:
-         description: Section specifies the shares and limit for storage I/O resource.
+         description:
+           - Section specifies the shares and limit for storage I/O resource.
+           - Not applicable when disk C(type) is set to C(vpmemdisk).
          suboptions:
            limit:
              description: Section specifies values for limit where the utilization of a virtual machine will not exceed, even if there are available resources.
@@ -196,7 +217,9 @@ options:
              type: dict
          type: dict
        shares:
-         description: Section for iolimit section tells about what are all different types of shares user can add for disk.
+         description:
+           - Section for iolimit section tells about what are all different types of shares user can add for disk.
+           - Not applicable when disk C(type) is set to C(vpmemdisk).
          suboptions:
            level:
              description: Tells about different level for the shares section.
@@ -303,6 +326,42 @@ EXAMPLES = r'''
         compatibility_mode: 'virtualMode'
         disk_mode: 'persistent'
 
+- name: Add raw device mapping to virtual machine with Physical bus sharing
+  community.vmware.vmware_guest_disk:
+    hostname: "{{ vcenter_hostname }}"
+    username: "{{ vcenter_username }}"
+    password: "{{ vcenter_password }}"
+    datacenter: "{{ datacenter_name }}"
+    validate_certs: no
+    name: "Test_VM"
+    disk:
+      - type: rdm
+        state: present
+        scsi_controller: 1
+        unit_number: 5
+        rdm_path: /vmfs/devices/disks/naa.060000003b1234efb453
+        compatibility_mode: 'virtualMode'
+        disk_mode: 'persistent'
+        bus_sharing: physicalSharing
+
+- name: Add raw device mapping to virtual machine with Physical bus sharing and clustered disk
+  community.vmware.vmware_guest_disk:
+    hostname: "{{ vcenter_hostname }}"
+    username: "{{ vcenter_username }}"
+    password: "{{ vcenter_password }}"
+    datacenter: "{{ datacenter_name }}"
+    validate_certs: no
+    name: "Test_VM"
+    disk:
+      - type: rdm
+        state: present
+        scsi_controller: 1
+        unit_number: 5
+        compatibility_mode: 'virtualMode'
+        disk_mode: 'persistent'
+        bus_sharing: physicalSharing
+        filename: "[datastore1] path/to/rdm/disk-marker.vmdk"
+
 - name: create new disk with custom IO limits and shares in IO Limits
   community.vmware.vmware_guest_disk:
     hostname: "{{ vcenter_hostname }}"
@@ -394,6 +453,24 @@ EXAMPLES = r'''
         disk_mode: 'independent_persistent'
   delegate_to: localhost
   register: disk_facts
+
+- name: Add a new vPMem disk to virtual machine to SATA controller
+  community.vmware.vmware_guest_disk:
+    hostname: "{{ vcenter_hostname }}"
+    username: "{{ vcenter_username }}"
+    password: "{{ vcenter_password }}"
+    datacenter: "{{ datacenter_name }}"
+    validate_certs: no
+    name: VM_226
+    disk:
+      - type: vpmemdisk
+        size_gb: 1
+        state: present
+        controller_type: sata
+        controller_number: 1
+        unit_number: 2
+  delegate_to: localhost
+  register: disk_facts
 '''
 
 RETURN = r'''
@@ -477,19 +554,23 @@ class PyVmomiHelper(PyVmomi):
             disk_spec.device.backing = vim.vm.device.VirtualDisk.RawDiskMappingVer1BackingInfo()
             disk_spec.device.backing.deviceName = disk['rdm_path']
             disk_spec.device.backing.compatibilityMode = disk['compatibility_mode']
+        elif disk['disk_type'] == 'vpmemdisk':
+            disk_spec.device.backing = vim.vm.device.VirtualDisk.LocalPMemBackingInfo()
         else:
             disk_spec.device.backing = vim.vm.device.VirtualDisk.FlatVer2BackingInfo()
 
-        disk_spec.device.backing.diskMode = disk['disk_mode']
-        disk_spec.device.backing.sharing = disk['sharing']
+        if disk['disk_type'] != 'vpmemdisk':
+            disk_spec.device.backing.diskMode = disk['disk_mode']
+            disk_spec.device.backing.sharing = disk['sharing']
+
+            if disk['disk_type'] == 'thin':
+                disk_spec.device.backing.thinProvisioned = True
+            elif disk['disk_type'] == 'eagerzeroedthick':
+                disk_spec.device.backing.eagerlyScrub = True
+
         disk_spec.device.controllerKey = ctl_key
         disk_spec.device.unitNumber = disk['disk_unit_number']
 
-        if disk['disk_type'] == 'thin':
-            disk_spec.device.backing.thinProvisioned = True
-        elif disk['disk_type'] == 'eagerzeroedthick':
-            disk_spec.device.backing.eagerlyScrub = True
-
         return disk_spec
 
     def reconfigure_vm(self, config_spec, device_type):
@@ -510,7 +591,7 @@ class PyVmomiHelper(PyVmomi):
         except vim.fault.InvalidDeviceSpec as invalid_device_spec:
             self.module.fail_json(msg="Failed to manage '%s' on given virtual machine due to invalid"
                                       " device spec : %s" % (device_type, to_native(invalid_device_spec.msg)),
-                                  details="Please check ESXi server logs for more details.")
+                                      details="Please check ESXi server logs for more details.")
         except vim.fault.RestrictedVersion as e:
             self.module.fail_json(msg="Failed to reconfigure virtual machine due to"
                                       " product versioning restrictions: %s" % to_native(e.msg))
@@ -552,7 +633,7 @@ class PyVmomiHelper(PyVmomi):
         sharing = disk.get('sharing')
         if sharing and disk_type != 'eagerzeroedthick' and disk_type != 'rdm':
             self.module.fail_json(msg="Invalid 'sharing' mode specified for disk index [%s]. 'disk_mode'"
-                                      " must be 'eagerzeroedthick' when 'sharing'." % disk_index)
+                                      " must be 'eagerzeroedthick' or 'rdm' when 'sharing'." % disk_index)
         if sharing:
             sharing_mode = 'sharingMultiWriter'
         else:
@@ -595,7 +676,7 @@ class PyVmomiHelper(PyVmomi):
             if not ctl_found and disk['state'] == 'present':
                 # Create new controller
                 if disk['controller_type'] in self.device_helper.scsi_device_type.keys():
-                    ctl_spec = self.device_helper.create_scsi_controller(disk['controller_type'], disk['controller_number'])
+                    ctl_spec = self.device_helper.create_scsi_controller(disk['controller_type'], disk['controller_number'], disk['bus_sharing'])
                 elif disk['controller_type'] == 'sata':
                     ctl_spec = self.device_helper.create_sata_controller(disk['controller_number'])
                 elif disk['controller_type'] == 'nvme':
@@ -636,7 +717,8 @@ class PyVmomiHelper(PyVmomi):
                                                                       disk_spec.device.capacityInKB))
                                     if disk['size'] != disk_spec.device.capacityInKB:
                                         disk_spec.operation = vim.vm.device.VirtualDeviceSpec.Operation.edit
-                                        disk_spec = self.get_ioandshares_diskconfig(disk_spec, disk)
+                                        if disk['disk_type'] != 'vpmemdisk':
+                                            disk_spec = self.get_ioandshares_diskconfig(disk_spec, disk)
                                         disk_spec.device.capacityInKB = disk['size']
                                         self.config_spec.deviceChange.append(disk_spec)
                                         disk_change = True
@@ -663,9 +745,13 @@ class PyVmomiHelper(PyVmomi):
                         disk_spec = self.create_disk(device.key, disk)
                         # get Storage DRS recommended datastore from the datastore cluster
                         if disk['disk_type'] == 'rdm':
-                            # RDM still requires a creation operation but adding filename and datastore seem to break it.
-                            # So let VMWare handle it for now.
-                            disk_spec.fileOperation = vim.vm.device.VirtualDeviceSpec.FileOperation.create
+                            # Since RDMs can be shared between two machines cluster_disk with rdm will
+                            # invoke a copy of the existing disk instead of trying to create a new one which causes
+                            # file lock issues in VSphere. This ensures we dont add a "create" operation.
+                            if disk['filename'] is not None and disk['cluster_disk'] is True:
+                                disk_spec.device.backing.fileName = disk['filename']
+                            else:
+                                disk_spec.fileOperation = vim.vm.device.VirtualDeviceSpec.FileOperation.create
                         else:
                             if disk['filename'] is None:
                                 if disk['datastore_cluster'] is not None:
@@ -700,7 +786,6 @@ class PyVmomiHelper(PyVmomi):
             if disk_change:
                 # Adding multiple disks in a single attempt raises weird errors
                 # So adding single disk at a time.
-
                 self.reconfigure_vm(self.config_spec, 'disks')
                 self.config_spec = vim.vm.ConfigSpec()
                 self.config_spec.deviceChange = []
@@ -734,7 +819,21 @@ class PyVmomiHelper(PyVmomi):
                                 controller_number=0,
                                 disk_mode='persistent',
                                 disk_type='thick',
-                                sharing=False)
+                                sharing=False,
+                                bus_sharing='noSharing',
+                                cluster_disk=False)
+            # Type of Disk
+            if disk['type'] is not None:
+                current_disk['disk_type'] = disk['type']
+            if current_disk['disk_type'] == 'vpmemdisk':
+                if self.vm.runtime.powerState != vim.VirtualMachinePowerState.poweredOff:
+                    self.module.fail_json(msg="Please make sure VM is in powered off state before doing vPMem disk"
+                                              " reconfiguration.")
+                disk['datastore'] = None
+                disk['autoselect_datastore'] = None
+                disk['filename'] = None
+                disk['disk_mode'] = None
+
             # Check state
             if disk['state'] is not None:
                 current_disk['state'] = disk['state']
@@ -772,14 +871,28 @@ class PyVmomiHelper(PyVmomi):
                 self.module.fail_json(msg="Invalid Disk unit number ID '%s' specified at index [%s]."
                                           % (disk['unit_number'], disk_index))
             if current_disk['controller_type'] in self.device_helper.scsi_device_type.keys():
-                if temp_disk_unit_number not in range(0, 16):
-                    self.module.fail_json(msg="Invalid Disk unit number ID specified for disk [%s] at index [%s],"
-                                              " please specify value between 0 to 15 only (excluding 7)."
-                                              % (temp_disk_unit_number, disk_index))
-                if temp_disk_unit_number == 7:
-                    self.module.fail_json(msg="Invalid Disk unit number ID specified for disk at index [%s], please"
-                                              " specify value other than 7 as it is reserved for SCSI Controller."
-                                              % disk_index)
+                # the Paravirtual SCSI Controller Supports up to 64 disks in vSphere 6.7. Using hardware
+                # version 14 or higher from the vm config should catch this appropriately.
+                hw_version = int(self.vm.config.version.split('-')[1])
+                if current_disk['controller_type'] == 'paravirtual' and hw_version >= 14:
+                    if temp_disk_unit_number not in range(0, 64):
+                        self.module.fail_json(msg="Invalid Disk unit number ID specified for disk [%s] at index [%s],"
+                                                  " please specify value between 0 to 64 only (excluding 7)."
+                                                  % (temp_disk_unit_number, disk_index))
+                    if temp_disk_unit_number == 7:
+                        self.module.fail_json(msg="Invalid Disk unit number ID specified for disk at index [%s], please"
+                                                  " specify value other than 7 as it is reserved for SCSI Controller."
+                                                  % disk_index)
+
+                else:
+                    if temp_disk_unit_number not in range(0, 16):
+                        self.module.fail_json(msg="Invalid Disk unit number ID specified for disk [%s] at index [%s],"
+                                                  " please specify value between 0 to 15 only (excluding 7)."
+                                                  % (temp_disk_unit_number, disk_index))
+                    if temp_disk_unit_number == 7:
+                        self.module.fail_json(msg="Invalid Disk unit number ID specified for disk at index [%s], please"
+                                                  " specify value other than 7 as it is reserved for SCSI Controller."
+                                                  % disk_index)
             elif current_disk['controller_type'] == 'sata' and temp_disk_unit_number not in range(0, 30):
                 self.module.fail_json(msg="Invalid Disk unit number ID specified for SATA disk [%s] at index [%s],"
                                           " please specify value between 0 to 29" % (temp_disk_unit_number, disk_index))
@@ -829,6 +942,10 @@ class PyVmomiHelper(PyVmomi):
                             datastore = ds
                             datastore_freespace = ds.summary.freeSpace
                     current_disk['datastore'] = datastore
+                else:
+                    if current_disk['disk_type'] == 'vpmemdisk':
+                        current_disk['datastore'] = None
+                        current_disk['autoselect_datastore'] = False
 
                 if disk['filename'] is not None:
                     current_disk['filename'] = disk['filename']
@@ -885,24 +1002,23 @@ class PyVmomiHelper(PyVmomi):
                     else:
                         self.module.fail_json(msg="%s is not a supported unit for disk size for disk index [%s]."
                                                   " Supported units are ['%s']." % (unit, disk_index, "', '".join(disk_units.keys())))
-                elif current_disk['filename'] is None and disk.get('type') != 'rdm':
-                    # No size found but disk, fail
+                elif current_disk['filename'] is None and disk['type'] != 'rdm':
+                    # No size found but disk, fail. Excepting RDMs because the cluster_disk will need a filename.
                     self.module.fail_json(msg="No size, size_kb, size_mb, size_gb or size_tb"
                                               " attribute found into disk index [%s] configuration." % disk_index)
 
-                # Type of Disk
-                if disk['type'] is not None:
-                    current_disk['disk_type'] = disk['type']
                 # Mode of Disk
                 if disk['disk_mode'] is not None:
                     current_disk['disk_mode'] = disk['disk_mode']
-                # Sharing mode of disk
-                current_disk['sharing'] = self.get_sharing(disk, current_disk['disk_type'], disk_index)
 
-                if disk['shares'] is not None:
-                    current_disk['shares'] = disk['shares']
-                if disk['iolimit'] is not None:
-                    current_disk['iolimit'] = disk['iolimit']
+                if current_disk['disk_type'] != 'vpmemdisk':
+                    # Sharing mode of disk
+                    current_disk['sharing'] = self.get_sharing(disk, current_disk['disk_type'], disk_index)
+
+                    if disk['shares'] is not None:
+                        current_disk['shares'] = disk['shares']
+                    if disk['iolimit'] is not None:
+                        current_disk['iolimit'] = disk['iolimit']
 
                 # Deal with RDM disk needs. RDMS require some different values compared to Virtual Disks
                 if disk['type'] == 'rdm':
@@ -913,12 +1029,29 @@ class PyVmomiHelper(PyVmomi):
                     current_disk['compatibility_mode'] = compatibility_mode
 
                     # RDMs need a path
-                    if 'rdm_path' not in disk:
-                        self.module.fail_json(msg="rdm_path needs must be specified when using disk type 'rdm' for disk index [%s]" % disk_index)
+                    if 'rdm_path' not in disk and 'filename' not in disk:
+                        self.module.fail_json(msg="rdm_path and/or 'filename' needs must be specified when using disk type 'rdm'"
+                                              "for disk index [%s]" % disk_index)
                     else:
                         current_disk['rdm_path'] = disk.get('rdm_path')
 
+                    if disk['filename'] and disk['rdm_path'] is None and disk['cluster_disk'] is False:
+                        self.module.fail_json(msg=" 'filename' requires setting 'cluster_disk' to True when using disk type 'rdm' without a"
+                                              "'rdm_path' for disk index [%s]" % disk_index)
+                    else:
+                        current_disk['cluster_disk'] = disk.get('cluster_disk')
+
+                # Enable Physical or virtual SCSI Bus Sharing
+                if disk['bus_sharing']:
+                    bus_sharing = disk.get('bus_sharing', 'noSharing')
+                    if bus_sharing not in ['noSharing', 'physicalSharing', 'virtualSharing']:
+                        self.module.fail_json(msg="Invalid SCSI 'bus_sharing' specied for disk index [%s]. Please "
+                                                  "specify 'bus_sharing' value from "
+                                                  "['noSharing', 'physicalSharing', 'virtualSharing']." % disk_index)
+                    current_disk['bus_sharing'] = bus_sharing
+
             disks_data.append(current_disk)
+
         return disks_data
 
     def get_recommended_datastore(self, datastore_cluster_obj, disk_spec_obj):
@@ -959,6 +1092,8 @@ class PyVmomiHelper(PyVmomi):
         datastore = None
         datastore_freespace = 0
         for ds in datastore_cluster_obj.childEntity:
+            if ds.summary.maintenanceMode == "inMaintenance":
+                continue
             if ds.summary.freeSpace > datastore_freespace:
                 # If datastore field is provided, filter destination datastores
                 datastore = ds
@@ -998,7 +1133,7 @@ class PyVmomiHelper(PyVmomi):
                     backing_filename=disk.backing.fileName,
                     backing_datastore=disk.backing.datastore.name,
                     backing_disk_mode=disk.backing.diskMode,
-                    backing_sharing=disk.backing.sharing,
+                    backing_sharing=disk.backing.sharing if hasattr(disk.backing, 'sharing') else None,
                     backing_uuid=disk.backing.uuid,
                     controller_key=disk.controllerKey,
                     unit_number=disk.unitNumber,
@@ -1014,7 +1149,7 @@ class PyVmomiHelper(PyVmomi):
                     disks_facts[disk_index].update(backing_devicename=disk.backing.deviceName,
                                                    backing_compatibility_mode=disk.backing.compatibilityMode)
 
-                else:
+                elif not isinstance(disk.backing, vim.vm.device.VirtualDisk.LocalPMemBackingInfo):
                     disks_facts[disk_index].update(backing_writethrough=disk.backing.writeThrough,
                                                    backing_thinprovisioned=disk.backing.thinProvisioned,
                                                    backing_eagerlyscrub=bool(disk.backing.eagerlyScrub))
@@ -1041,7 +1176,7 @@ def main():
                 size_mb=dict(type='int'),
                 size_gb=dict(type='int'),
                 size_tb=dict(type='int'),
-                type=dict(type='str', choices=['thin', 'eagerzeroedthick', 'thick', 'rdm']),
+                type=dict(type='str', choices=['thin', 'eagerzeroedthick', 'thick', 'rdm', 'vpmemdisk']),
                 disk_mode=dict(type='str', choices=['persistent', 'independent_persistent', 'independent_nonpersistent']),
                 compatibility_mode=dict(type='str', choices=['physicalMode', 'virtualMode']),
                 rdm_path=dict(type='str'),
@@ -1056,6 +1191,8 @@ def main():
                 state=dict(type='str', default='present', choices=['present', 'absent']),
                 controller_type=dict(type='str', choices=['buslogic', 'lsilogic', 'paravirtual', 'lsilogicsas', 'sata', 'nvme']),
                 controller_number=dict(type='int', choices=[0, 1, 2, 3]),
+                bus_sharing=dict(type='str', choices=['noSharing', 'physicalSharing', 'virtualSharing'], default='noSharing'),
+                cluster_disk=dict(type='bool', default=False),
                 iolimit=dict(
                     type='dict',
                     options=dict(
