@@ -41,6 +41,7 @@ options:
     host_groups:
         description:
             - List of host groups the host is part of.
+            - Make sure the Zabbix user used for Ansible can read these groups.
         type: list
         elements: str
     link_templates:
@@ -220,7 +221,6 @@ options:
             - Specifies what encryption to use for outgoing connections.
             - Possible values, 1 (no encryption), 2 (PSK), 4 (certificate).
             - Works only with >= Zabbix 3.0
-        default: 1
         type: int
     tls_accept:
         description:
@@ -229,19 +229,20 @@ options:
             - Possible values, 1 (no encryption), 2 (PSK), 4 (certificate).
             - Values can be combined.
             - Works only with >= Zabbix 3.0
-        default: 1
         type: int
     tls_psk_identity:
         description:
             - It is a unique name by which this specific PSK is referred to by Zabbix components
             - Do not put sensitive information in the PSK identity string, it is transmitted over the network unencrypted.
             - Works only with >= Zabbix 3.0
+            - Using this parameter with Zabbix >= 5.4 makes this module non-idempotent.
         type: str
     tls_psk:
         description:
             - PSK value is a hard to guess string of hexadecimal digits.
             - The preshared key, at least 32 hex digits. Required if either I(tls_connect) or I(tls_accept) has PSK enabled.
             - Works only with >= Zabbix 3.0
+            - Using this parameter with Zabbix >= 5.4 makes this module non-idempotent.
         type: str
     ca_cert:
         description:
@@ -426,10 +427,11 @@ EXAMPLES = r'''
 
 import copy
 
-from distutils.version import LooseVersion
 from ansible.module_utils.basic import AnsibleModule
 
 from ansible_collections.community.zabbix.plugins.module_utils.base import ZabbixBase
+from ansible_collections.community.zabbix.plugins.module_utils.version import LooseVersion
+
 import ansible_collections.community.zabbix.plugins.module_utils.helpers as zabbix_utils
 
 
@@ -466,12 +468,15 @@ class Host(ZabbixBase):
         try:
             if self._module.check_mode:
                 self._module.exit_json(changed=True)
-            parameters = {'host': host_name, 'interfaces': interfaces, 'groups': group_ids, 'status': status,
-                          'tls_connect': tls_connect, 'tls_accept': tls_accept}
+            parameters = {'host': host_name, 'interfaces': interfaces, 'groups': group_ids, 'status': status}
             if proxy_id:
                 parameters['proxy_hostid'] = proxy_id
             if visible_name:
                 parameters['name'] = visible_name
+            if tls_connect:
+                parameters['tls_connect'] = tls_connect
+            if tls_accept:
+                parameters['tls_accept'] = tls_accept
             if tls_psk_identity is not None:
                 parameters['tls_psk_identity'] = tls_psk_identity
             if tls_psk is not None:
@@ -507,12 +512,15 @@ class Host(ZabbixBase):
         try:
             if self._module.check_mode:
                 self._module.exit_json(changed=True)
-            parameters = {'hostid': host_id, 'groups': group_ids, 'status': status, 'tls_connect': tls_connect,
-                          'tls_accept': tls_accept}
+            parameters = {'hostid': host_id, 'groups': group_ids, 'status': status}
             if proxy_id >= 0:
                 parameters['proxy_hostid'] = proxy_id
             if visible_name:
                 parameters['name'] = visible_name
+            if tls_connect:
+                parameters['tls_connect'] = tls_connect
+            if tls_accept:
+                parameters['tls_accept'] = tls_accept
             if tls_psk_identity:
                 parameters['tls_psk_identity'] = tls_psk_identity
             if tls_psk:
@@ -535,34 +543,10 @@ class Host(ZabbixBase):
                 parameters['macros'] = macros
             if tags is not None:
                 parameters['tags'] = tags
+            if interfaces:
+                parameters['interfaces'] = interfaces
 
             self._zapi.host.update(parameters)
-            interface_list_copy = exist_interface_list
-            if interfaces:
-                for interface in interfaces:
-                    flag = False
-                    interface_str = interface
-                    for exist_interface in exist_interface_list:
-                        interface_type = int(interface['type'])
-                        exist_interface_type = int(exist_interface['type'])
-                        if interface_type == exist_interface_type:
-                            # update
-                            interface_str['interfaceid'] = exist_interface['interfaceid']
-                            self._zapi.hostinterface.update(interface_str)
-                            flag = True
-                            interface_list_copy.remove(exist_interface)
-                            break
-                    if not flag:
-                        # add
-                        interface_str['hostid'] = host_id
-                        self._zapi.hostinterface.create(interface_str)
-                        # remove
-                remove_interface_ids = []
-                for remove_interface in interface_list_copy:
-                    interface_id = remove_interface['interfaceid']
-                    remove_interface_ids.append(interface_id)
-                if len(remove_interface_ids) > 0:
-                    self._zapi.hostinterface.delete(remove_interface_ids)
         except Exception as e:
             self._module.fail_json(msg="Failed to update host %s: %s" % (host_name, e))
 
@@ -586,7 +570,7 @@ class Host(ZabbixBase):
         }
 
         if LooseVersion(self._zbx_api_version) >= LooseVersion('4.2.0'):
-            params.update({'selectTags': 'extend'})
+            params.update({'selectTags': ['tag', 'value']})
 
         if LooseVersion(self._zbx_api_version) >= LooseVersion('5.4.0'):
             params.update({
@@ -637,11 +621,11 @@ class Host(ZabbixBase):
     # get group ids by group names
     def get_group_ids_by_group_names(self, group_names):
         if self.check_host_group_exist(group_names):
-            return self._zapi.hostgroup.get({'output': 'groupid', 'filter': {'name': group_names}})
+            return self._zapi.hostgroup.get({'output': 'extend', 'filter': {'name': group_names}})
 
     # get host groups ids by host id
     def get_group_ids_by_host_id(self, host_id):
-        return self._zapi.hostgroup.get({'output': 'groupid', 'hostids': host_id})
+        return self._zapi.hostgroup.get({'output': 'extend', 'hostids': host_id})
 
     # get host templates by host id
     def get_host_templates_by_host_id(self, host_id):
@@ -674,6 +658,10 @@ class Host(ZabbixBase):
             if interface['type'] == 1:
                 ip = interface.get('ip', '')
 
+            for key in ['ip', 'dns']:
+                if key not in interface or interface[key] is None:
+                    interface[key] = ''
+
             if 'port' not in interface or interface['port'] is None:
                 interface['port'] = type_to_port.get(interface['type'], '')
 
@@ -702,65 +690,21 @@ class Host(ZabbixBase):
 
     # check the exist_interfaces whether it equals the interfaces or not
     def check_interface_properties(self, exist_interfaces, interfaces):
-        # hostinterface.details looks different based on the version of SNMP currently configured
-        snmp_ver_keys = {
-            1: ['version', 'bulk', 'community'],
-            2: ['version', 'bulk', 'community'],
-            3: [
-                'version', 'bulk', 'securityname', 'securitylevel', 'authprotocol',
-                'authpassphrase', 'privprotocol', 'privpassphrase', 'contextname'
-            ]
-        }
-
-        i_ports = []
-        for interface in interfaces:
-            i_ports.append(interface['port'])
-
-        exist_i_ports = []
-        for interface in exist_interfaces:
-            exist_i_ports.append(interface['port'])
-
-        if sorted(i_ports) != sorted(exist_i_ports):
+        # Find already configured interfaces in requested interfaces
+        if len(exist_interfaces) != len(interfaces):
             return True
 
-        _matched_intfs = []
+        for iface in interfaces:
+            found = False
+            for e_int in exist_interfaces:
+                diff_dict = {}
+                zabbix_utils.helper_cleanup_data(zabbix_utils.helper_compare_dictionaries(iface, e_int, diff_dict))
+                if diff_dict == {}:
+                    found = True
+                    break
 
-        for exist_interface in exist_interfaces:
-            exist_interface_port = str(exist_interface['port'])
-
-            # Zabbix API should return empty dictionary instead of list, workaround:
-            if 'details' in exist_interface and not exist_interface['details']:
-                exist_interface['details'] = {}
-
-            for interface in interfaces:
-                # ensure one interface is not matched multiple times
-                if interface in _matched_intfs:
-                    continue
-
-                if str(interface['port']) == exist_interface_port:
-                    for key in interface.keys():
-                        # since 5.0, zabbix API returns details for each host interface, but only SNMP is not empty
-                        if key == 'details':
-                            if interface['details']:
-                                # only data relevant to a particular version are returned and rest should be filtered
-                                snmp_ver = int(interface['details']['version'])
-                                for dkey in list(interface['details'].keys()):
-                                    if dkey not in snmp_ver_keys[snmp_ver]:
-                                        interface['details'].pop(dkey)
-                                    else:
-                                        interface['details'][dkey] = str(interface['details'][dkey])
-
-                            # either compare empty or filtered dictionaries
-                            if interface['details'] != exist_interface['details']:
-                                return True
-
-                        elif str(exist_interface[key]) != str(interface[key]):
-                            return True
-
-                # if the code got here, that means interfaces did match, remove the one matched and break loop for
-                # current intf, otherwise it would start comparing to next intf of the same type and not match
-                _matched_intfs.append(interface)
-                break
+        if not found:
+            return True
 
         return False
 
@@ -827,15 +771,17 @@ class Host(ZabbixBase):
             if int(host['tls_accept']) != tls_accept:
                 return True
 
-        if LooseVersion(self._zbx_api_version) <= LooseVersion('5.4.0'):
+        if LooseVersion(self._zbx_api_version) < LooseVersion('5.4'):
             if tls_psk_identity is not None and 'tls_psk_identity' in host:
                 if host['tls_psk_identity'] != tls_psk_identity:
                     return True
-
-        if LooseVersion(self._zbx_api_version) <= LooseVersion('5.4.0'):
             if tls_psk is not None and 'tls_psk' in host:
                 if host['tls_psk'] != tls_psk:
                     return True
+        else:
+            # in Zabbix >= 5.4 these parameters are write-only and are not returned in host.get response
+            if tls_psk_identity is not None or tls_psk is not None:
+                return True
 
         if tls_issuer is not None and 'tls_issuer' in host:
             if host['tls_issuer'] != tls_issuer:
@@ -864,20 +810,13 @@ class Host(ZabbixBase):
         # hostmacroid and hostid are present in every item of host['macros'] and need to be removed
         if macros is not None and 'macros' in host:
             t_macros = copy.deepcopy(macros)  # make copy to prevent change in original data
-            existing_macros = sorted(host['macros'], key=lambda k: k['macro'])
-            for macro in existing_macros:
+            for macro in host['macros']:
                 macro.pop('hostid', False)
                 macro.pop('hostmacroid', False)
-                if 'type' in macro:
-                    macro['type'] = int(macro['type'])
 
-            # 'secret' type macros don't return 'value' from API
-            if LooseVersion(self._zbx_api_version) >= LooseVersion('5.0'):
-                for macro in t_macros:
-                    if macro['type'] == 1:
-                        macro.pop('value', False)
-
-            if sorted(t_macros, key=lambda k: k['macro']) != existing_macros:
+            diff = []
+            zabbix_utils.helper_compare_lists(t_macros, host['macros'], diff)
+            if diff != []:
                 return True
 
         if tags is not None and 'tags' in host:
@@ -900,8 +839,11 @@ class Host(ZabbixBase):
         templates_clear = exist_template_ids.difference(template_ids)
         templates_clear_list = list(templates_clear)
         request_str = {'hostid': host_id, 'templates': template_id_list, 'templates_clear': templates_clear_list,
-                       'tls_connect': tls_connect, 'tls_accept': tls_accept, 'ipmi_authtype': ipmi_authtype,
-                       'ipmi_privilege': ipmi_privilege, 'ipmi_username': ipmi_username, 'ipmi_password': ipmi_password}
+                       'ipmi_authtype': ipmi_authtype, 'ipmi_privilege': ipmi_privilege, 'ipmi_username': ipmi_username, 'ipmi_password': ipmi_password}
+        if tls_connect:
+            request_str['tls_connect'] = tls_connect
+        if tls_accept:
+            request_str['tls_accept'] = tls_accept
         if tls_psk_identity is not None:
             request_str['tls_psk_identity'] = tls_psk_identity
         if tls_psk is not None:
@@ -958,6 +900,40 @@ class Host(ZabbixBase):
             self._module.fail_json(msg="Failed to set inventory to host: %s" % e)
 
 
+# Add all default values to all missing parameters for existing interfaces
+def update_exist_interfaces_with_defaults(exist_interfaces):
+
+    new_exist_interfaces = []
+    default_interface = {
+        'main': '0',
+        'useip': '0',
+        'ip': '',
+        'dns': '',
+        'port': ''
+    }
+    default_interface_details = {
+        'version': 2,
+        'bulk': 1,
+        'community': '',
+        'securityname': '',
+        'contextname': '',
+        'securitylevel': 0,
+        'authprotocol': 0,
+        'authpassphrase': '',
+        'privprotocol': 0,
+        'privpassphrase': ''
+    }
+    for interface in exist_interfaces:
+        new_interface = default_interface.copy()
+        new_interface.update(interface)
+        new_interface['details'] = default_interface_details.copy()
+        if 'details' in interface:
+            new_interface['details'].update(interface['details'])
+        new_exist_interfaces.append(new_interface)
+
+    return new_exist_interfaces
+
+
 def normalize_macro_name(macro_name):
     # Zabbix handles macro names in upper case characters
     if ':' in macro_name:
@@ -987,8 +963,8 @@ def main():
         ipmi_privilege=dict(type='int', default=None),
         ipmi_username=dict(type='str', required=False, default=None),
         ipmi_password=dict(type='str', required=False, default=None, no_log=True),
-        tls_connect=dict(type='int', default=1),
-        tls_accept=dict(type='int', default=1),
+        tls_connect=dict(type='int', required=False),
+        tls_accept=dict(type='int', required=False),
         tls_psk_identity=dict(type='str', required=False),
         tls_psk=dict(type='str', required=False),
         ca_cert=dict(type='str', required=False, aliases=['tls_issuer']),
@@ -1002,8 +978,8 @@ def main():
                 type=dict(type='str', required=True, choices=['agent', '1', 'snmp', '2', 'ipmi', '3', 'jmx', '4']),
                 main=dict(type='int', choices=[0, 1], default=0),
                 useip=dict(type='int', choices=[0, 1], default=0),
-                ip=dict(type='str', default=''),
-                dns=dict(type='str', default=''),
+                ip=dict(type='str'),
+                dns=dict(type='str'),
                 port=dict(type='str'),
                 bulk=dict(type='int', choices=[0, 1], default=1),
                 details=dict(
@@ -1012,7 +988,7 @@ def main():
                     options=dict(
                         version=dict(type='int', choices=[1, 2, 3], default=2),
                         bulk=dict(type='int', choices=[0, 1], default=1),
-                        community=dict(type='str'),
+                        community=dict(type='str', default=''),
                         securityname=dict(type='str', default=''),
                         contextname=dict(type='str', default=''),
                         securitylevel=dict(type='int', choices=[0, 1, 2], default=0),
@@ -1113,9 +1089,9 @@ def main():
                     macro.pop('type')
                 else:
                     if macro['type'] == 'text':
-                        macro['type'] = 0
+                        macro['type'] = '0'
                     elif macro['type'] == 'secret':
-                        macro['type'] = 1
+                        macro['type'] = '1'
 
     # Use proxy specified, or set to 0
     if proxy:
@@ -1148,25 +1124,59 @@ def main():
             # get existing host's interfaces
             exist_interfaces = host._zapi.hostinterface.get({'output': 'extend', 'hostids': host_id})
             exist_interfaces.sort(key=lambda x: int(x['interfaceid']))
+            exist_interfaces = update_exist_interfaces_with_defaults(exist_interfaces)
 
-            # When force=no is specified, append existing interfaces to interfaces to update. When
-            # no interfaces have been specified, copy existing interfaces as specified from the API.
-            # Do the same with templates and host groups.
-            if not force or not interfaces:
-                for interface in copy.deepcopy(exist_interfaces):
-                    # remove values not used during hostinterface.add/update calls
-                    for key in tuple(interface.keys()):
-                        if key in ['interfaceid', 'hostid']:
-                            interface.pop(key, None)
+            # Convert integer parameters from strings to ints
+            for idx, interface in enumerate(copy.deepcopy(exist_interfaces)):
+                for key in tuple(interface.keys()):
+                    # fix values for properties
+                    if key in ['useip', 'main', 'type', 'bulk']:
+                        exist_interfaces[idx][key] = int(interface[key])
+                    elif key == 'details':
+                        if not interface[key]:
+                            exist_interfaces[idx][key] = {}
+                        else:
+                            for d_key in interface[key].keys():
+                                if d_key in ['version', 'bulk', 'securitylevel', 'authprotocol', 'privprotocol']:
+                                    exist_interfaces[idx][key][d_key] = int(interface[key][d_key])
 
-                    for index in interface.keys():
-                        if index in ['useip', 'main', 'type', 'bulk']:
-                            interface[index] = int(interface[index])
-                        elif index == 'details' and not interface[index]:
-                            interface[index] = {}
+            interfaces_copy = copy.deepcopy(interfaces)
+            found_in_interfaces = []
+            for idx, interface in enumerate(copy.deepcopy(exist_interfaces)):
+                interfaceid = interface['interfaceid']
+                hostid = interface['hostid']
 
-                    if interface not in interfaces:
+                if not interfaces_copy:
+                    # Whe no interfaces specified, copy existing interfaces
+                    interfaces.append(interface)
+                    continue
+
+                # Find already configured interfaces in requested interfaces and compile final list of
+                # interfaces in 'interfaces' variable. Every element of the list defines one interface.
+                # If an element has 'interfaceid' field then Zabbix will update existing interface otherwise
+                # a new interface will be added.
+                found = False
+                for idx1, iface in enumerate(interfaces_copy):
+                    diff_dict = {}
+                    zabbix_utils.helper_cleanup_data(zabbix_utils.helper_compare_dictionaries(iface, interface, diff_dict))
+                    if diff_dict == {}:
+                        found = True
+                        found_in_interfaces.append(iface)
+                        interfaces[idx1]['interfaceid'] = interfaceid
+                        interfaces[idx1]['hostid'] = hostid
+                        break
+
+                if not found:
+                    if not force:
                         interfaces.append(interface)
+                    else:
+                        # if force == True overwrite existing interfaces with provided interfaces with the same type
+                        for idx1, iface in enumerate(interfaces_copy):
+                            if interface['type'] == iface['type'] and iface not in found_in_interfaces:
+                                found_in_interfaces.append(iface)
+                                interfaces[idx1]['interfaceid'] = interfaceid
+                                interfaces[idx1]['hostid'] = hostid
+                                break
 
             if not force or link_templates is None:
                 template_ids = list(set(template_ids + host.get_host_templates_by_host_id(host_id)))
@@ -1178,10 +1188,21 @@ def main():
 
                 # Macros not present in host.update will be removed if we dont copy them when force=no
                 if macros is not None and 'macros' in zabbix_host_obj.keys():
-                    provided_macros = [m['macro'] for m in macros]
                     existing_macros = zabbix_host_obj['macros']
                     for macro in existing_macros:
-                        if macro['macro'] not in provided_macros:
+                        macro.pop('hostmacroid', None)
+                        macro.pop('hostid', None)
+                        macro.pop('automatic', None)
+                        found = False
+                        for idx1, prov_macro in enumerate(macros):
+                            diff_dict = {}
+                            zabbix_utils.helper_compare_dictionaries(prov_macro, macro, diff_dict)
+                            if diff_dict == {}:
+                                found = True
+                                break
+                        if found:
+                            macros[idx1] = macro
+                        else:
                             macros.append(macro)
 
                 # Tags not present in host.update will be removed if we dont copy them when force=no
