@@ -14,15 +14,15 @@ short_description: Fetches a UCS file from remote nodes
 description:
    - This module is used for fetching UCS files from remote machines and
      storing them locally in a file tree, organized by hostname. This module
-     is written to create and transfer UCS files that might not be present,
+     was written to create and transfer UCS files that might not be present,
      it does not require UCS file to be pre-created. So a missing remote UCS
      is not an error unless C(fail_on_missing) is set to 'yes'.
 version_added: "1.0.0"
 options:
   backup:
     description:
-      - Create a backup file including the timestamp information so you can
-        get the original file back if you somehow overwrote it incorrectly.
+      - Creates a backup file including the timestamp information so you can
+        get the original file back if you overwrote it incorrectly.
     type: bool
     default: no
   create_on_missing:
@@ -34,8 +34,8 @@ options:
   dest:
     description:
       - A directory to save the UCS file into.
+      - This option is mandatory when C(only_create_file) is set to C(no).
     type: path
-    required: True
   encryption_password:
     description:
       - Password to use to encrypt the UCS file if desired.
@@ -47,21 +47,32 @@ options:
     default: no
   force:
     description:
-      - If C(no), the file will only be transferred if the destination does not
+      - If C(no), the file is only transferred if the destination does not
         exist.
     type: bool
     default: yes
   src:
     description:
-      - The name of the UCS file to create on the remote server for downloading. The file will be retrieved or created in /var/local/ucs/.
+      - The name of the UCS file to create on the remote server for downloading.
+      - The file is retrieved or created in /var/local/ucs/.
+      - This option is mandatory when C(only_create_file) is set to C(yes).
     type: str
   async_timeout:
     description:
-      - Parameter used when creating new UCS file on device.
-      - The amount of time in seconds to wait for the API async interface to complete its task.
+      - Parameter used when creating new UCS file on a device.
+      - The amount of time to wait for the API async interface to complete its task, in seconds.
       - The accepted value range is between C(150) and C(1800) seconds.
     type: int
     default: 150
+  only_create_file:
+    description:
+      - If C(yes), the file is created on device and not downloaded. If the UCS archive exists on device,
+        no change is made and file is not be downloaded.
+      - To recreate UCS files left on the device, remove them with C(bigip_ucs) module before running this module with
+        C(only_create_file) set to C(yes).
+    type: bool
+    default: no
+    version_added: "1.12.0"
 notes:
   - BIG-IP provides no way to get a checksum of the UCS files on the system
     via any interface with the possible exception of logging in directly to the box (which
@@ -89,6 +100,36 @@ EXAMPLES = r'''
       user: admin
       password: secret
   delegate_to: localhost
+
+- name: Only create new UCS, no download
+  bigip_ucs_fetch:
+    src: cs_backup.ucs
+    only_create_file: yes
+    provider:
+      server: lb.mydomain.com
+      user: admin
+      password: secret
+  delegate_to: localhost
+
+- name: Recreate UCS file left on device - remove file first
+  bigip_ucs:
+    ucs: cs_backup.ucs
+    state: absent
+    provider:
+      server: lb.mydomain.com
+      user: admin
+      password: secret
+  delegate_to: localhost
+
+- name: Recreate UCS file left on device - create new file
+  bigip_ucs_fetch:
+    src: cs_backup.ucs
+    only_create_file: yes
+    provider:
+      server: lb.mydomain.com
+      user: admin
+      password: secret
+  delegate_to: localhost
 '''
 
 RETURN = r'''
@@ -105,12 +146,12 @@ dest:
 src:
   description:
     - Name of the UCS file on the remote BIG-IP to download. If not
-      specified, this will be a randomly generated filename.
+      specified, this is a randomly generated filename.
   returned: changed
   type: str
   sample: cs_backup.ucs
 backup_file:
-  description: Name of backup file.
+  description: Name of the backup file.
   returned: changed and if backup=yes
   type: str
   sample: /path/to/file.txt.2015-02-12@22:09~
@@ -178,10 +219,13 @@ class Parameters(AnsibleF5Parameters):
         'src',
         'md5sum',
         'checksum',
-        'backup_file']
+        'backup_file'
+    ]
     api_attributes = []
     api_map = {}
 
+
+class ModuleParameters(Parameters):
     @property
     def options(self):
         result = []
@@ -213,14 +257,14 @@ class Parameters(AnsibleF5Parameters):
                     # circumstances where the directory does not have
                     # the execute bit for the current user set, in
                     # which case the stat() call will raise an OSError
-                    os.stat(os.path.dirname(result))
+                    os.stat(os.path.dirname(self.dest))
                 except OSError as e:
                     if "permission denied" in str(e).lower():
                         raise F5ModuleError(
-                            "Destination directory {0} is not accessible".format(os.path.dirname(result))
+                            "Destination directory {0} is not accessible".format(os.path.dirname(self.dest))
                         )
                     raise F5ModuleError(
-                        "Destination directory {0} does not exist".format(os.path.dirname(result))
+                        "Destination directory {0} does not exist".format(os.path.dirname(self.dest))
                     )
 
         if not os.access(os.path.dirname(result), os.W_OK):
@@ -303,7 +347,7 @@ class BaseManager(object):
     def __init__(self, *args, **kwargs):
         self.module = kwargs.get('module', None)
         self.client = F5RestClient(**self.module.params)
-        self.want = Parameters(params=self.module.params)
+        self.want = ModuleParameters(params=self.module.params)
         self.changes = UsableChanges()
 
     def exec_module(self):
@@ -322,7 +366,8 @@ class BaseManager(object):
 
     def present(self):
         if self.exists():
-            self.update()
+            if not self.want.only_create_file:
+                self.update()
         else:
             self.create()
 
@@ -350,6 +395,9 @@ class BaseManager(object):
             )
         self._set_checksum()
         self._set_md5sum()
+        self.changes.update({'src': self.want.src})
+        self.changes.update({'md5sum': self.want.md5sum})
+        self.changes.update({'checksum': self.want.checksum})
         file_args = self.module.load_file_common_arguments(self.module.params)
         return self.module.set_fs_attributes_if_different(file_args, True)
 
@@ -382,7 +430,8 @@ class BaseManager(object):
             return True
         if self.want.create_on_missing:
             self.create_on_device()
-        self.execute()
+        if not self.want.only_create_file:
+            self.execute()
         return True
 
     def create_on_device(self):
@@ -456,10 +505,13 @@ class BaseManager(object):
                     return True
 
             time.sleep(delay)
-        raise F5ModuleError(
-            "Module timeout reached, state change is unknown, "
-            "please increase the async_timeout parameter for long lived actions."
-        )
+        # at times we time out waiting on task as sometimes task is gone from async queue after services reboot
+        # we are adding existence check here to catch where the file is created but async task is removed.
+        if not self.exists():
+            raise F5ModuleError(
+                "Module timeout reached, state change is unknown, "
+                "please increase the async_timeout parameter for long lived actions."
+            )
 
     def download(self):
         self.download_from_device(self.want.dest)
@@ -635,7 +687,6 @@ class ArgumentSpec(object):
             ),
             encryption_password=dict(no_log=True),
             dest=dict(
-                required=True,
                 type='path'
             ),
             force=dict(
@@ -647,11 +698,19 @@ class ArgumentSpec(object):
                 type='bool'
             ),
             src=dict(),
+            only_create_file=dict(
+                default='no',
+                type='bool'
+            ),
             async_timeout=dict(
                 type='int',
                 default=150
             ),
         )
+        self.required_if = [
+            ['only_create_file', 'no', ['dest']],
+            ['only_create_file', 'yes', ['src']]
+        ]
         self.argument_spec = {}
         self.argument_spec.update(f5_argument_spec)
         self.argument_spec.update(argument_spec)
@@ -664,6 +723,7 @@ def main():
     module = AnsibleModule(
         argument_spec=spec.argument_spec,
         supports_check_mode=spec.supports_check_mode,
+        required_if=spec.required_if,
         add_file_common_args=spec.add_file_common_args
     )
 
