@@ -97,25 +97,25 @@ options:
         suboptions:
             dataplan:
                 type: str
-                description: no description
+                description: 'Dataplan.'
             description:
                 type: str
-                description: no description
+                description: 'Description.'
             modem1_ifname:
                 type: str
-                description: no description
+                description: 'Modem1_Ifname.'
             modem1_sim_profile:
                 type: str
-                description: no description
+                description: 'Modem1_Sim_Profile.'
             modem2_ifname:
                 type: str
-                description: no description
+                description: 'Modem2_Ifname.'
             modem2_sim_profile:
                 type: str
-                description: no description
+                description: 'Modem2_Sim_Profile.'
             name:
                 type: str
-                description: no description
+                description: 'Name.'
 
 '''
 
@@ -193,6 +193,11 @@ def main():
             'required': False,
             'default': False
         },
+        'forticloud_access_token': {
+            'type': 'str',
+            'required': False,
+            'no_log': True
+        },
         'proposed_method': {
             'type': 'str',
             'required': False,
@@ -306,6 +311,8 @@ def main():
     if module._socket_path:
         connection = Connection(module._socket_path)
         connection.set_option('enable_log', module.params['enable_log'] if 'enable_log' in module.params else False)
+        connection.set_option('forticloud_access_token',
+                              module.params['forticloud_access_token'] if 'forticloud_access_token' in module.params else None)
         fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
         fmgr.validate_parameters(params_validation_blob)
         fmgr.process_curd(argument_specs=module_arg_spec)
