@@ -97,90 +97,90 @@ options:
         suboptions:
             _gui_meta:
                 type: str
-                description: no description
+                description: '_Gui_Meta.'
             dynamic_mapping:
-                description: no description
+                description: 'Dynamic_Mapping.'
                 type: list
                 suboptions:
                     _gui_meta:
                         type: str
-                        description: no description
+                        description: '_Gui_Meta.'
                     _scope:
-                        description: no description
+                        description: '_Scope.'
                         type: list
                         suboptions:
                             name:
                                 type: str
-                                description: no description
+                                description: 'Name.'
                             vdom:
                                 type: str
-                                description: no description
+                                description: 'Vdom.'
                     ldap-server:
                         type: str
-                        description: no description
+                        description: 'LDAP server to get group information.'
                     password:
-                        description: no description
+                        description: 'Password of the first FSSO collector agent.'
                         type: str
                     password2:
-                        description: no description
+                        description: 'Password of the second FSSO collector agent.'
                         type: str
                     password3:
-                        description: no description
+                        description: 'Password of the third FSSO collector agent.'
                         type: str
                     password4:
-                        description: no description
+                        description: 'Password of the fourth FSSO collector agent.'
                         type: str
                     password5:
-                        description: no description
+                        description: 'Password of the fifth FSSO collector agent.'
                         type: str
                     port:
                         type: int
-                        description: no description
+                        description: 'Port of the first FSSO collector agent.'
                     port2:
                         type: int
-                        description: no description
+                        description: 'Port of the second FSSO collector agent.'
                     port3:
                         type: int
-                        description: no description
+                        description: 'Port of the third FSSO collector agent.'
                     port4:
                         type: int
-                        description: no description
+                        description: 'Port of the fourth FSSO collector agent.'
                     port5:
                         type: int
-                        description: no description
+                        description: 'Port of the fifth FSSO collector agent.'
                     server:
                         type: str
-                        description: no description
+                        description: 'Domain name or IP address of the first FSSO collector agent.'
                     server2:
                         type: str
-                        description: no description
+                        description: 'Domain name or IP address of the second FSSO collector agent.'
                     server3:
                         type: str
-                        description: no description
+                        description: 'Domain name or IP address of the third FSSO collector agent.'
                     server4:
                         type: str
-                        description: no description
+                        description: 'Domain name or IP address of the fourth FSSO collector agent.'
                     server5:
                         type: str
-                        description: no description
+                        description: 'Domain name or IP address of the fifth FSSO collector agent.'
                     source-ip:
                         type: str
-                        description: no description
+                        description: 'Source IP for communications to FSSO agent.'
                     source-ip6:
                         type: str
-                        description: no description
+                        description: 'IPv6 source for communications to FSSO agent.'
                     ssl:
                         type: str
-                        description: no description
+                        description: 'Enable/disable use of SSL.'
                         choices:
                             - 'disable'
                             - 'enable'
                     ssl-trusted-cert:
                         type: str
-                        description: no description
+                        description: 'Trusted server certificate or CA certificate.'
                     type:
                         type: str
-                        description: no description
+                        description: 'Server type.'
                         choices:
                             - 'default'
                             - 'fortiems'
@@ -188,28 +188,28 @@ options:
                             - 'fortiems-cloud'
                     user-info-server:
                         type: str
-                        description: no description
+                        description: 'LDAP server to get user information.'
                     ldap-poll:
                         type: str
-                        description: no description
+                        description: 'Enable/disable automatic fetching of groups from LDAP server.'
                         choices:
                             - 'disable'
                             - 'enable'
                     ldap-poll-filter:
                         type: str
-                        description: no description
+                        description: 'Filter used to fetch groups.'
                     ldap-poll-interval:
                         type: int
-                        description: no description
+                        description: 'Interval in minutes within to fetch groups from LDAP server.'
                     group-poll-interval:
                         type: int
-                        description: no description
+                        description: 'Interval in minutes within to fetch groups from FSSO server, or unset to disable.'
                     interface:
                         type: str
-                        description: no description
+                        description: 'Specify outgoing interface to reach server.'
                     interface-select-method:
                         type: str
-                        description: no description
+                        description: 'Specify how to select outgoing interface to reach server.'
                         choices:
                             - 'auto'
                             - 'sdwan'
@@ -221,19 +221,19 @@ options:
                 type: str
                 description: 'Name.'
             password:
-                description: no description
+                description: 'Password of the first FSSO collector agent.'
                 type: str
             password2:
-                description: no description
+                description: 'Password of the second FSSO collector agent.'
                 type: str
             password3:
-                description: no description
+                description: 'Password of the third FSSO collector agent.'
                 type: str
             password4:
-                description: no description
+                description: 'Password of the fourth FSSO collector agent.'
                 type: str
             password5:
-                description: no description
+                description: 'Password of the fifth FSSO collector agent.'
                 type: str
             port:
                 type: int
@@ -320,7 +320,26 @@ options:
 '''
 
 EXAMPLES = '''
- - hosts: fortimanager-inventory
+ - name: gathering fortimanager facts
+   hosts: fortimanager00
+   gather_facts: no
+   connection: httpapi
+   collections:
+     - fortinet.fortimanager
+   vars:
+     ansible_httpapi_use_ssl: True
+     ansible_httpapi_validate_certs: False
+     ansible_httpapi_port: 443
+   tasks:
+    - name: retrieve all the Fortinet Single Sign On (FSSO) agents
+      fmgr_fact:
+        facts:
+            selector: 'user_fsso'
+            params:
+                adom: 'ansible'
+                fsso: '' 
+
+ - hosts: fortimanager00
    collections:
      - fortinet.fortimanager
    connection: httpapi
@@ -329,81 +348,16 @@ EXAMPLES = '''
       ansible_httpapi_validate_certs: False
       ansible_httpapi_port: 443
    tasks:
-    - name: Configure Fortinet Single Sign On
+    - name: Configure Fortinet Single Sign On (FSSO) agents.
       fmgr_user_fsso:
          bypass_validation: False
-         workspace_locking_adom: <value in [global, custom adom including root]>
-         workspace_locking_timeout: 300
-         rc_succeeded: [0, -2, -3, ...]
-         rc_failed: [-2, -3, ...]
-         adom: <your own value>
-         state: <value in [present, absent]>
+         adom: ansible
+         state: present
          user_fsso:
-            _gui_meta: <value of string>
-            dynamic_mapping:
-              -
-                  _gui_meta: <value of string>
-                  _scope:
-                    -
-                        name: <value of string>
-                        vdom: <value of string>
-                  ldap-server: <value of string>
-                  password: <value of string>
-                  password2: <value of string>
-                  password3: <value of string>
-                  password4: <value of string>
-                  password5: <value of string>
-                  port: <value of integer>
-                  port2: <value of integer>
-                  port3: <value of integer>
-                  port4: <value of integer>
-                  port5: <value of integer>
-                  server: <value of string>
-                  server2: <value of string>
-                  server3: <value of string>
-                  server4: <value of string>
-                  server5: <value of string>
-                  source-ip: <value of string>
-                  source-ip6: <value of string>
-                  ssl: <value in [disable, enable]>
-                  ssl-trusted-cert: <value of string>
-                  type: <value in [default, fortiems, fortinac, ...]>
-                  user-info-server: <value of string>
-                  ldap-poll: <value in [disable, enable]>
-                  ldap-poll-filter: <value of string>
-                  ldap-poll-interval: <value of integer>
-                  group-poll-interval: <value of integer>
-                  interface: <value of string>
-                  interface-select-method: <value in [auto, sdwan, specify]>
-            ldap-server: <value of string>
-            name: <value of string>
-            password: <value of string>
-            password2: <value of string>
-            password3: <value of string>
-            password4: <value of string>
-            password5: <value of string>
-            port: <value of integer>
-            port2: <value of integer>
-            port3: <value of integer>
-            port4: <value of integer>
-            port5: <value of integer>
-            server: <value of string>
-            server2: <value of string>
-            server3: <value of string>
-            server4: <value of string>
-            server5: <value of string>
-            source-ip: <value of string>
-            source-ip6: <value of string>
-            ldap-poll: <value in [disable, enable]>
-            ldap-poll-filter: <value of string>
-            ldap-poll-interval: <value of integer>
-            ssl: <value in [disable, enable]>
-            ssl-trusted-cert: <value of string>
-            type: <value in [default, fortiems, fortinac, ...]>
-            user-info-server: <value of string>
-            group-poll-interval: <value of integer>
-            interface: <value of string>
-            interface-select-method: <value in [auto, sdwan, specify]>
+            name: ansible-test-fsso
+            password: fortinet
+            port: 9000
+            server: ansible
 
 '''
 
@@ -451,6 +405,11 @@ def main():
             'required': False,
             'default': False
         },
+        'forticloud_access_token': {
+            'type': 'str',
+            'required': False,
+            'no_log': True
+        },
         'proposed_method': {
             'type': 'str',
             'required': False,
@@ -1412,6 +1371,8 @@ def main():
     if module._socket_path:
         connection = Connection(module._socket_path)
         connection.set_option('enable_log', module.params['enable_log'] if 'enable_log' in module.params else False)
+        connection.set_option('forticloud_access_token',
+                              module.params['forticloud_access_token'] if 'forticloud_access_token' in module.params else None)
         fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
         fmgr.validate_parameters(params_validation_blob)
         fmgr.process_curd(argument_specs=module_arg_spec)
