@@ -6,19 +6,16 @@ __metaclass__ = type
 
 DOCUMENTATION = '''
     name: aws_ec2
-    plugin_type: inventory
     short_description: EC2 inventory source
-    requirements:
-        - boto3
-        - botocore
     extends_documentation_fragment:
     - inventory_cache
     - constructed
+    - amazon.aws.aws_boto3
     - amazon.aws.aws_credentials
 
     description:
         - Get inventory hosts from Amazon Web Services EC2.
-        - Uses a YAML configuration file that ends with C(aws_ec2.(yml|yaml)).
+        - Uses a YAML configuration file that ends with C(aws_ec2.{yml|yaml}).
     notes:
         - If no credentials are provided and the control node has an associated IAM instance profile then the
           role will be used for authentication.
@@ -37,14 +34,36 @@ DOCUMENTATION = '''
               - A list of regions in which to describe EC2 instances.
               - If empty (the default) default this will include all regions, except possibly restricted ones like us-gov-west-1 and cn-north-1.
           type: list
+          elements: str
           default: []
         hostnames:
           description:
               - A list in order of precedence for hostname variables.
-              - You can use the options specified in U(http://docs.aws.amazon.com/cli/latest/reference/ec2/describe-instances.html#options).
-              - To use tags as hostnames use the syntax tag:Name=Value to use the hostname Name_Value, or tag:Name to use the value of the Name tag.
           type: list
+          elements: dict
           default: []
+          suboptions:
+            name:
+                description:
+                    - Name of the host.
+                    - Can be one of the options specified in U(http://docs.aws.amazon.com/cli/latest/reference/ec2/describe-instances.html#options).
+                    - To use tags as hostnames use the syntax tag:Name=Value to use the hostname Name_Value, or tag:Name to use the value of the Name tag.
+                    - If value provided does not exist in the above options, it will be used as a literal string.
+                type: str
+                required: True
+            prefix:
+                description:
+                    - Prefix to prepend to I(name). Same options as I(name).
+                    - If I(prefix) is specified, final hostname will be I(prefix) +  I(separator) + I(name).
+                type: str
+                default: ''
+                required: False
+            separator:
+                description:
+                    - Value to separate I(prefix) and I(name) when I(prefix) is specified.
+                type: str
+                default: '_'
+                required: False
         filters:
           description:
               - A dictionary of filter value pairs.
@@ -58,7 +77,9 @@ DOCUMENTATION = '''
               - Every entry in this list triggers a search query. As such, from a performance point of view, it's better to
                 keep the list as short as possible.
           type: list
+          elements: dict
           default: []
+          version_added: 1.5.0
         exclude_filters:
           description:
               - A list of filters. Any instances matching one of the filters are excluded from the result.
@@ -67,7 +88,9 @@ DOCUMENTATION = '''
               - Every entry in this list triggers a search query. As such, from a performance point of view, it's better to
                 keep the list as short as possible.
           type: list
+          elements: dict
           default: []
+          version_added: 1.5.0
         include_extra_api_calls:
           description:
               - Add two additional API calls for every instance to include 'persistent' and 'events' host variables.
@@ -99,6 +122,17 @@ DOCUMENTATION = '''
             - The use of this feature is discouraged and we advise to migrate to the new ``tags`` structure.
           type: bool
           default: False
+          version_added: 1.5.0
+        hostvars_prefix:
+          description:
+            - The prefix for host variables names coming from AWS.
+          type: str
+          version_added: 3.1.0
+        hostvars_suffix:
+          description:
+            - The suffix for host variables names coming from AWS.
+          type: str
+          version_added: 3.1.0
 '''
 
 EXAMPLES = '''
@@ -138,6 +172,9 @@ hostnames:
   - name: 'private-ip-address'
     separator: '_'
     prefix: 'tag:Name'
+  - name: 'test_literal' # Using literal values for hostname
+    separator: '-'       # Hostname will be aws-test_literal
+    prefix: 'aws'
 
 # Example using constructed features to create groups and set ansible_host
 plugin: aws_ec2
@@ -205,6 +242,12 @@ compose:
   ansible_host: public_dns_name
 groups:
   libvpc: vpc_id == 'vpc-####'
+# Define prefix and suffix for host variables coming from AWS.
+plugin: aws_ec2
+regions:
+  - us-east-1
+hostvars_prefix: 'aws_'
+hostvars_suffix: '_ec2'
 '''
 
 import re
@@ -227,6 +270,7 @@ from ansible_collections.amazon.aws.plugins.module_utils.ec2 import HAS_BOTO3
 from ansible_collections.amazon.aws.plugins.module_utils.ec2 import ansible_dict_to_boto3_filter_list
 from ansible_collections.amazon.aws.plugins.module_utils.ec2 import boto3_tag_list_to_ansible_dict
 from ansible_collections.amazon.aws.plugins.module_utils.ec2 import camel_dict_to_snake_dict
+from ansible_collections.amazon.aws.plugins.module_utils.core import is_boto3_error_code
 
 
 # The mappings give an array of keys to get from the filter name to the value
@@ -369,9 +413,11 @@ class InventoryModule(BaseInventoryPlugin, Constructable, Cacheable):
             :param instance: instance dict returned by boto3 ec2 describe_instances()
         '''
         allowed_filters = sorted(list(instance_data_filter_to_boto_attr.keys()) + list(instance_meta_filter_to_boto_attr.keys()))
+
+        # If filter not in allow_filters -> use it as a literal string
         if filter_name not in allowed_filters:
-            raise AnsibleError("Invalid filter '%s' provided; filter must be one of %s." % (filter_name,
-                                                                                            allowed_filters))
+            return filter_name
+
         if filter_name in instance_data_filter_to_boto_attr:
             boto_attr_list = instance_data_filter_to_boto_attr[filter_name]
         else:
@@ -408,7 +454,7 @@ class InventoryModule(BaseInventoryPlugin, Constructable, Cacheable):
                 raise AnsibleError("Insufficient credentials found: %s" % to_native(e))
         return connection
 
-    def _boto3_assume_role(self, credentials, region):
+    def _boto3_assume_role(self, credentials, region=None):
         """
         Assume an IAM role passed by iam_role_arn parameter
 
@@ -447,6 +493,19 @@ class InventoryModule(BaseInventoryPlugin, Constructable, Cacheable):
             except botocore.exceptions.NoRegionError:
                 # above seems to fail depending on boto3 version, ignore and lets try something else
                 pass
+            except is_boto3_error_code('UnauthorizedOperation') as e:  # pylint: disable=duplicate-except
+                if iam_role_arn is not None:
+                    try:
+                        # Describe regions assuming arn role
+                        assumed_credentials = self._boto3_assume_role(credentials)
+                        client = self._get_connection(assumed_credentials)
+                        resp = client.describe_regions()
+                        regions = [x['RegionName'] for x in resp.get('Regions', [])]
+                    except botocore.exceptions.NoRegionError:
+                        # above seems to fail depending on boto3 version, ignore and lets try something else
+                        pass
+                else:
+                    raise AnsibleError("Unauthorized operation: %s" % to_native(e))
 
         # fallback to local list hardcoded in boto3 if still no regions
         if not regions:
@@ -647,8 +706,17 @@ class InventoryModule(BaseInventoryPlugin, Constructable, Cacheable):
             if not hostname:
                 continue
             self.inventory.add_host(hostname, group=group)
+            hostvars_prefix = self.get_option("hostvars_prefix")
+            hostvars_suffix = self.get_option("hostvars_suffix")
+            new_vars = dict()
             for hostvar, hostval in host.items():
+                if hostvars_prefix:
+                    hostvar = hostvars_prefix + hostvar
+                if hostvars_suffix:
+                    hostvar = hostvar + hostvars_suffix
+                new_vars[hostvar] = hostval
                 self.inventory.set_variable(hostname, hostvar, hostval)
+            host.update(new_vars)
 
             # Use constructed if applicable
 
