@@ -193,7 +193,7 @@ def aws_common_argument_spec():
         ec2_url=dict(aliases=['aws_endpoint_url', 'endpoint_url']),
         aws_access_key=dict(aliases=['ec2_access_key', 'access_key'], no_log=False),
         aws_secret_key=dict(aliases=['ec2_secret_key', 'secret_key'], no_log=True),
-        security_token=dict(aliases=['access_token', 'aws_security_token'], no_log=True),
+        security_token=dict(aliases=['access_token', 'aws_security_token', 'session_token', 'aws_session_token'], no_log=True),
         validate_certs=dict(default=True, type='bool'),
         aws_ca_bundle=dict(type='path'),
         profile=dict(aliases=['aws_profile']),
@@ -742,3 +742,16 @@ def normalize_ec2_vpc_dhcp_config(option_config):
                 config_data[option] = [val['Value'] for val in config_item['Values']]
 
     return config_data
+
+
+def is_outposts_arn(input_regex):
+    """
+    Validates the provided regex pattern of outpost arn as per API specification document.
+
+    API Specification Document:
+    https://docs.aws.amazon.com/outposts/latest/APIReference/API_Outpost.html
+    """
+    regex_pattern = r'^arn:aws([a-z-]+)?:outposts:[a-z\d-]+:\d{12}:outpost/op-[a-f0-9]{17}$'
+    if not re.match(regex_pattern, input_regex):
+        return False
+    return True
