@@ -23,6 +23,7 @@ options:
   instance_ids:
     description:
       - If you specify one or more instance IDs, only instances that have the specified IDs are returned.
+      - Mutually exclusive with I(exact_count).
     type: list
     elements: str
   state:
@@ -53,8 +54,23 @@ options:
     description:
       - Instance type to use for the instance, see U(https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/instance-types.html)
         Only required when instance is not already present.
-    default: t2.micro
+      - If not specified, t2.micro will be used.
     type: str
+  count:
+    description:
+      - Number of instances to launch.
+      - Setting this value will result in always launching new instances.
+      - Mutually exclusive with I(exact_count).
+    type: int
+    version_added: 2.2.0
+  exact_count:
+    description:
+      - An integer value which indicates how many instances that match the I(filters) parameter should be running.
+      - Instances are either created or terminated based on this value.
+      - If termination takes place, least recently created instances will be terminated based on Launch Time.
+      - Mutually exclusive with I(count), I(instance_ids).
+    type: int
+    version_added: 2.2.0
   user_data:
     description:
       - Opaque blob of data which is made available to the ec2 instance
@@ -141,6 +157,7 @@ options:
         description:
         - a list of ENI IDs (strings) or a list of objects containing the key I(id).
         type: list
+        elements: str
       assign_public_ip:
         description:
         - when true assigns a public IP address to the interface
@@ -153,6 +170,7 @@ options:
         description:
         - a list of IPv6 addresses to assign to the network interface
         type: list
+        elements: str
       source_dest_check:
         description:
         - controls whether source/destination checking is enabled on the interface
@@ -165,6 +183,7 @@ options:
         description:
         - a list of IPv4 addresses to assign to the network interface
         type: list
+        elements: str
       subnet_id:
         description:
         - the subnet to connect the network interface to
@@ -182,6 +201,7 @@ options:
         description:
         - a list of security group IDs to attach to the interface
         type: list
+        elements: str
   volumes:
     description:
     - A list of block device mappings, by default this will always use the AMI root device so the volumes option is primarily for adding more storage.
@@ -415,6 +435,7 @@ EXAMPLES = '''
     tags:
       Env: "eni_on"
     instance_type: t2.micro
+
 - name: start an instance with metadata options
   amazon.aws.ec2_instance:
     name: "public-metadataoptions-instance"
@@ -426,6 +447,35 @@ EXAMPLES = '''
     metadata_options:
       http_endpoint: enabled
       http_tokens: optional
+
+# ensure number of instances running with a tag matches exact_count
+- name: start multiple instances
+  amazon.aws.ec2_instance:
+    instance_type: t3.small
+    image_id: ami-123456
+    exact_count: 5
+    region: us-east-2
+    vpc_subnet_id: subnet-0123456
+    network:
+      assign_public_ip: yes
+      security_group: default
+    tags:
+      foo: bar
+
+# launches multiple instances - specific number of instances
+- name: start specific number of multiple instances
+  amazon.aws.ec2_instance:
+    instance_type: t3.small
+    image_id: ami-123456
+    count: 3
+    region: us-east-2
+    network:
+      assign_public_ip: yes
+      security_group: default
+      vpc_subnet_id: subnet-0123456
+    state: present
+    tags:
+      foo: bar
 '''
 
 RETURN = '''
@@ -848,6 +898,7 @@ try:
 except ImportError:
     pass  # caught by AnsibleAWSModule
 
+
 from ansible.module_utils._text import to_native
 from ansible.module_utils.common.dict_transformations import camel_dict_to_snake_dict
 from ansible.module_utils.common.dict_transformations import snake_dict_to_camel_dict
@@ -857,6 +908,7 @@ from ansible.module_utils.six.moves.urllib import parse as urlparse
 from ansible_collections.amazon.aws.plugins.module_utils.core import AnsibleAWSModule
 from ansible_collections.amazon.aws.plugins.module_utils.core import is_boto3_error_code
 from ansible_collections.amazon.aws.plugins.module_utils.core import is_boto3_error_message
+from ansible_collections.amazon.aws.plugins.module_utils.core import parse_aws_arn
 from ansible_collections.amazon.aws.plugins.module_utils.ec2 import AWSRetry
 from ansible_collections.amazon.aws.plugins.module_utils.ec2 import ansible_dict_to_boto3_filter_list
 from ansible_collections.amazon.aws.plugins.module_utils.ec2 import ensure_ec2_tags
@@ -1185,7 +1237,7 @@ def build_top_level_options(params):
 
     if params.get('launch_template') is not None:
         spec['LaunchTemplate'] = {}
-        if not params.get('launch_template').get('id') or params.get('launch_template').get('name'):
+        if not params.get('launch_template').get('id') and not params.get('launch_template').get('name'):
             module.fail_json(msg="Could not create instance with launch template. Either launch_template.name or launch_template.id parameters are required")
 
         if params.get('launch_template').get('id') is not None:
@@ -1250,7 +1302,20 @@ def build_run_instance_spec(params):
     if params.get('instance_role'):
         spec['IamInstanceProfile'] = dict(Arn=determine_iam_role(params.get('instance_role')))
 
-    spec['InstanceType'] = params['instance_type']
+    if module.params.get('exact_count'):
+        spec['MaxCount'] = module.params.get('to_launch')
+        spec['MinCount'] = module.params.get('to_launch')
+
+    if module.params.get('count'):
+        spec['MaxCount'] = module.params.get('count')
+        spec['MinCount'] = module.params.get('count')
+
+    if not module.params.get('launch_template'):
+        spec['InstanceType'] = params['instance_type'] if module.params.get('instance_type') else 't2.micro'
+
+    if module.params.get('launch_template') and module.params.get('instance_type'):
+        spec['InstanceType'] = params['instance_type']
+
     return spec
 
 
@@ -1402,6 +1467,8 @@ def change_network_attachments(instance, params):
 
 def find_instances(ids=None, filters=None):
     paginator = client.get_paginator('describe_instances')
+    sanitized_filters = dict()
+
     if ids:
         params = dict(InstanceIds=ids)
     elif filters is None:
@@ -1409,13 +1476,16 @@ def find_instances(ids=None, filters=None):
     else:
         for key in list(filters.keys()):
             if not key.startswith("tag:"):
-                filters[key.replace("_", "-")] = filters.pop(key)
-        params = dict(Filters=ansible_dict_to_boto3_filter_list(filters))
+                sanitized_filters[key.replace("_", "-")] = filters[key]
+            else:
+                sanitized_filters[key] = filters[key]
+        params = dict(Filters=ansible_dict_to_boto3_filter_list(sanitized_filters))
 
     try:
         results = _describe_instances(**params)
     except (botocore.exceptions.BotoCoreError, botocore.exceptions.ClientError) as e:
         module.fail_json_aws(e, msg="Could not describe instances")
+
     retval = list(results)
     return retval
 
@@ -1648,7 +1718,8 @@ def pretty_instance(i):
 
 
 def determine_iam_role(name_or_arn):
-    if re.match(r'^arn:aws:iam::\d+:instance-profile/[\w+=/,.@-]+$', name_or_arn):
+    result = parse_aws_arn(name_or_arn)
+    if result and result['service'] == 'iam' and result['resource'].startswith('instance-profile/'):
         return name_or_arn
     iam = module.client('iam', retry_decorator=AWSRetry.jittered_backoff())
     try:
@@ -1699,6 +1770,52 @@ def handle_existing(existing_matches, state):
     return result
 
 
+def enforce_count(existing_matches, module, desired_module_state):
+    exact_count = module.params.get('exact_count')
+
+    try:
+        current_count = len(existing_matches)
+        if current_count == exact_count:
+            module.exit_json(
+                changed=False,
+                msg='{0} instances already running, nothing to do.'.format(exact_count)
+            )
+
+        elif current_count < exact_count:
+            to_launch = exact_count - current_count
+            module.params['to_launch'] = to_launch
+            # launch instances
+            try:
+                ensure_present(existing_matches=existing_matches, desired_module_state=desired_module_state)
+            except botocore.exceptions.ClientError as e:
+                module.fail_json(e, msg='Unable to launch instances')
+        elif current_count > exact_count:
+            to_terminate = current_count - exact_count
+            # sort the instances from least recent to most recent based on launch time
+            existing_matches = sorted(existing_matches, key=lambda inst: inst['LaunchTime'])
+            # get the instance ids of instances with the count tag on them
+            all_instance_ids = [x['InstanceId'] for x in existing_matches]
+            terminate_ids = all_instance_ids[0:to_terminate]
+            if module.check_mode:
+                module.exit_json(changed=True, msg='Would have terminated following instances if not in check mode {0}'.format(terminate_ids))
+            # terminate instances
+            try:
+                result = client.terminate_instances(aws_retry=True, InstanceIds=terminate_ids)
+                await_instances(terminate_ids, desired_module_state='terminated', force_wait=True)
+            except is_boto3_error_code('InvalidInstanceID.NotFound'):
+                pass
+            except botocore.exceptions.ClientError as e:  # pylint: disable=duplicate-except
+                module.fail_json(e, msg='Unable to terminate instances')
+            module.exit_json(
+                changed=True,
+                msg='Successfully terminated instances.',
+                terminated_ids=terminate_ids,
+            )
+
+    except (botocore.exceptions.BotoCoreError, botocore.exceptions.ClientError) as e:
+        module.fail_json_aws(e, msg="Failed to enforce instance count")
+
+
 def ensure_present(existing_matches, desired_module_state):
     tags = dict(module.params.get('tags') or {})
     name = module.params.get('name')
@@ -1712,6 +1829,7 @@ def ensure_present(existing_matches, desired_module_state):
             module.exit_json(
                 changed=True,
                 spec=instance_spec,
+                msg='Would have launched instances if not in check_mode.',
             )
         instance_response = run_instances(**instance_spec)
         instances = instance_response['Instances']
@@ -1762,12 +1880,12 @@ def ensure_present(existing_matches, desired_module_state):
 
 def run_instances(**instance_spec):
     try:
-        return client.run_instances(**instance_spec)
+        return client.run_instances(aws_retry=True, **instance_spec)
     except is_boto3_error_message('Invalid IAM Instance Profile ARN'):
         # If the instance profile has just been created, it takes some time to be visible by ec2
         # So we wait 10 second and retry the run_instances
         time.sleep(10)
-        return client.run_instances(**instance_spec)
+        return client.run_instances(aws_retry=True, **instance_spec)
 
 
 def build_filters():
@@ -1817,10 +1935,11 @@ def main():
         state=dict(default='present', choices=['present', 'started', 'running', 'stopped', 'restarted', 'rebooted', 'terminated', 'absent']),
         wait=dict(default=True, type='bool'),
         wait_timeout=dict(default=600, type='int'),
-        # count=dict(default=1, type='int'),
+        count=dict(type='int'),
+        exact_count=dict(type='int'),
         image=dict(type='dict'),
         image_id=dict(type='str'),
-        instance_type=dict(default='t2.micro', type='str'),
+        instance_type=dict(type='str'),
         user_data=dict(type='str'),
         tower_callback=dict(type='dict'),
         ebs_optimized=dict(type='bool'),
@@ -1861,9 +1980,15 @@ def main():
             ['availability_zone', 'vpc_subnet_id'],
             ['tower_callback', 'user_data'],
             ['image_id', 'image'],
+            ['exact_count', 'count'],
+            ['exact_count', 'instance_ids'],
         ],
         supports_check_mode=True
     )
+
+    if not module.params.get('instance_type') and not module.params.get('launch_template') and module.params.get('state') != 'absent':
+        module.deprecate("Default value instance_type has been deprecated, in the future you must set an instance_type or a launch_template",
+                         date='2023-01-01', collection_name='amazon.aws')
     result = dict()
 
     if module.params.get('network'):
@@ -1895,7 +2020,9 @@ def main():
                 msg='No matching instances found',
                 changed=False,
             )
-    elif existing_matches:
+    elif module.params.get('exact_count'):
+        enforce_count(existing_matches, module, desired_module_state=state)
+    elif existing_matches and not module.params.get('count'):
         for match in existing_matches:
             warn_if_public_ip_assignment_changed(match)
             warn_if_cpu_options_changed(match)
