@@ -43,7 +43,6 @@ options:
   iops:
     description:
       - The provisioned IOPs you want to associate with this volume (integer).
-      - By default AWS will set this to 100.
     type: int
   encrypted:
     description:
@@ -93,7 +92,7 @@ options:
     version_added: 1.5.0
   modify_volume:
     description:
-      - The volume won't be modify unless this key is C(true).
+      - The volume won't be modified unless this key is C(true).
     type: bool
     default: false
     version_added: 1.4.0
@@ -102,14 +101,26 @@ options:
       - Volume throughput in MB/s.
       - This parameter is only valid for gp3 volumes.
       - Valid range is from 125 to 1000.
+      - Requires at least botocore version 1.19.27.
     type: int
     version_added: 1.4.0
+  multi_attach:
+    description:
+      - If set to C(yes), Multi-Attach will be enabled when creating the volume.
+      - When you create a new volume, Multi-Attach is disabled by default.
+      - This parameter is supported with io1 and io2 volumes only.
+    type: bool
+    version_added: 2.0.0
+  outpost_arn:
+    description:
+      - The Amazon Resource Name (ARN) of the Outpost.
+      - If set, allows to create volume in an Outpost.
+    type: str
+    version_added: 3.1.0
 author: "Lester Wade (@lwade)"
 extends_documentation_fragment:
 - amazon.aws.aws
 - amazon.aws.ec2
-
-requirements: [ boto3>=1.16.33 ]
 '''
 
 EXAMPLES = '''
@@ -149,7 +160,6 @@ EXAMPLES = '''
 # Example: Launch an instance and then add a volume if not already attached
 #   * Volume will be created with the given name if not already created.
 #   * Nothing will happen if the volume is already attached.
-#   * Requires Ansible 2.0
 
 - amazon.aws.ec2:
     keypair: "{{ keypair }}"
@@ -191,6 +201,14 @@ EXAMPLES = '''
     volume_type: gp2
     device_name: /dev/xvdf
 
+# Create new volume with multi-attach enabled
+- amazon.aws.ec2_vol:
+    zone: XXXXXX
+    multi_attach: true
+    volume_size: 4
+    volume_type: io1
+    iops: 102
+
 # Attach an existing volume to instance. The volume will be deleted upon instance termination.
 - amazon.aws.ec2_vol:
     instance: XXXXXX
@@ -220,13 +238,13 @@ volume:
     returned: when success
     type: str
     sample: {
-        "attachment_set": {
+        "attachment_set": [{
             "attach_time": "2015-10-23T00:22:29.000Z",
             "deleteOnTermination": "false",
             "device": "/dev/sdf",
             "instance_id": "i-8356263c",
             "status": "attached"
-        },
+        }],
         "create_time": "2015-10-21T14:36:08.870Z",
         "encrypted": false,
         "id": "vol-35b333d9",
@@ -248,12 +266,13 @@ from ..module_utils.core import AnsibleAWSModule
 from ..module_utils.ec2 import camel_dict_to_snake_dict
 from ..module_utils.ec2 import boto3_tag_list_to_ansible_dict
 from ..module_utils.ec2 import ansible_dict_to_boto3_filter_list
-from ..module_utils.ec2 import ansible_dict_to_boto3_tag_list
-from ..module_utils.ec2 import compare_aws_tags
 from ..module_utils.ec2 import describe_ec2_tags
 from ..module_utils.ec2 import ensure_ec2_tags
+from ..module_utils.ec2 import is_outposts_arn
 from ..module_utils.ec2 import AWSRetry
 from ..module_utils.core import is_boto3_error_code
+from ..module_utils.tagging import boto3_tag_specifications
+
 
 try:
     import botocore
@@ -358,14 +377,34 @@ def update_volume(module, ec2_conn, volume):
     req_obj = {'VolumeId': volume['volume_id']}
 
     if module.params.get('modify_volume'):
+        target_type = module.params.get('volume_type')
+        original_type = None
+        type_changed = False
+        if target_type:
+            original_type = volume['volume_type']
+            if target_type != original_type:
+                type_changed = True
+                req_obj['VolumeType'] = target_type
+
         iops_changed = False
-        if volume['volume_type'] != 'standard':
-            target_iops = module.params.get('iops')
-            if target_iops:
-                original_iops = volume['iops']
-                if target_iops != original_iops:
+        target_iops = module.params.get('iops')
+        original_iops = volume.get('iops')
+        if target_iops:
+            if target_iops != original_iops:
+                iops_changed = True
+                req_obj['Iops'] = target_iops
+            else:
+                req_obj['Iops'] = original_iops
+        else:
+            # If no IOPS value is specified and there was a volume_type update to gp3,
+            # the existing value is retained, unless a volume type is modified that supports different values,
+            # otherwise, the default iops value is applied.
+            if type_changed and target_type == 'gp3':
+                if (
+                    (original_iops and (int(original_iops) < 3000 or int(original_iops) > 16000)) or not original_iops
+                ):
+                    req_obj['Iops'] = 3000
                     iops_changed = True
-                    req_obj['iops'] = target_iops
 
         target_size = module.params.get('volume_size')
         size_changed = False
@@ -373,7 +412,7 @@ def update_volume(module, ec2_conn, volume):
             original_size = volume['size']
             if target_size != original_size:
                 size_changed = True
-                req_obj['size'] = target_size
+                req_obj['Size'] = target_size
 
         target_type = module.params.get('volume_type')
         original_type = None
@@ -386,22 +425,33 @@ def update_volume(module, ec2_conn, volume):
 
         target_throughput = module.params.get('throughput')
         throughput_changed = False
-        if 'gp3' in [target_type, original_type]:
-            if target_throughput:
-                original_throughput = volume.get('throughput')
-                if target_throughput != original_throughput:
-                    throughput_changed = True
-                    req_obj['Throughput'] = target_throughput
+        if target_throughput:
+            original_throughput = volume.get('throughput')
+            if target_throughput != original_throughput:
+                throughput_changed = True
+                req_obj['Throughput'] = target_throughput
 
-        changed = iops_changed or size_changed or type_changed or throughput_changed
+        target_multi_attach = module.params.get('multi_attach')
+        multi_attach_changed = False
+        if target_multi_attach is not None:
+            original_multi_attach = volume['multi_attach_enabled']
+            if target_multi_attach != original_multi_attach:
+                multi_attach_changed = True
+                req_obj['MultiAttachEnabled'] = target_multi_attach
+
+        changed = iops_changed or size_changed or type_changed or throughput_changed or multi_attach_changed
 
         if changed:
+            if module.check_mode:
+                module.exit_json(changed=True, msg='Would have updated volume if not in check mode.')
             response = ec2_conn.modify_volume(**req_obj)
 
             volume['size'] = response.get('VolumeModification').get('TargetSize')
             volume['volume_type'] = response.get('VolumeModification').get('TargetVolumeType')
             volume['iops'] = response.get('VolumeModification').get('TargetIops')
-            volume['throughput'] = response.get('VolumeModification').get('TargetThroughput')
+            volume['multi_attach_enabled'] = response.get('VolumeModification').get('TargetMultiAttachEnabled')
+            if module.botocore_at_least("1.19.27"):
+                volume['throughput'] = response.get('VolumeModification').get('TargetThroughput')
 
     return volume, changed
 
@@ -415,12 +465,16 @@ def create_volume(module, ec2_conn, zone):
     volume_type = module.params.get('volume_type')
     snapshot = module.params.get('snapshot')
     throughput = module.params.get('throughput')
-    # If custom iops is defined we use volume_type "io1" rather than the default of "standard"
-    if iops:
-        volume_type = 'io1'
+    multi_attach = module.params.get('multi_attach')
+    outpost_arn = module.params.get('outpost_arn')
+    tags = module.params.get('tags')
+    name = module.params.get('name')
 
     volume = get_volume(module, ec2_conn)
 
+    if module.check_mode:
+        module.exit_json(changed=True, msg='Would have created a volume if not in check mode.')
+
     if volume is None:
 
         try:
@@ -439,9 +493,28 @@ def create_volume(module, ec2_conn, zone):
             if iops:
                 additional_params['Iops'] = int(iops)
 
+            # Use the default value if any iops has been specified when volume_type=gp3
+            if volume_type == 'gp3' and not iops:
+                additional_params['Iops'] = 3000
+
             if throughput:
                 additional_params['Throughput'] = int(throughput)
 
+            if multi_attach:
+                additional_params['MultiAttachEnabled'] = True
+
+            if outpost_arn:
+                if is_outposts_arn(outpost_arn):
+                    additional_params['OutpostArn'] = outpost_arn
+                else:
+                    module.fail_json('OutpostArn does not match the pattern specified in API specifications.')
+
+            if name:
+                tags['Name'] = name
+
+            if tags:
+                additional_params['TagSpecifications'] = boto3_tag_specifications(tags, types=['volume'])
+
             create_vol_response = ec2_conn.create_volume(
                 aws_retry=True,
                 AvailabilityZone=zone,
@@ -472,13 +545,21 @@ def attach_volume(module, ec2_conn, volume_dict, instance_dict, device_name):
 
     attachment_data = get_attachment_data(volume_dict, wanted_state='attached')
     if attachment_data:
-        if attachment_data.get('instance_id', None) != instance_dict['instance_id']:
-            module.fail_json(msg="Volume {0} is already attached to another instance: {1}".format(volume_dict['volume_id'],
-                             attachment_data.get('instance_id', None)))
-        else:
-            return volume_dict, changed
+        if module.check_mode:
+            if attachment_data[0].get('status') in ['attached', 'attaching']:
+                module.exit_json(changed=False, msg='IN CHECK MODE - volume already attached to instance: {0}.'.format(
+                                 attachment_data[0].get('instance_id', None)))
+        if not volume_dict['multi_attach_enabled']:
+            # volumes without MultiAttach Enabled can be attached to 1 instance only
+            if attachment_data[0].get('instance_id', None) != instance_dict['instance_id']:
+                module.fail_json(msg="Volume {0} is already attached to another instance: {1}."
+                                 .format(volume_dict['volume_id'], attachment_data[0].get('instance_id', None)))
+            else:
+                return volume_dict, changed
 
     try:
+        if module.check_mode:
+            module.exit_json(changed=True, msg='Would have attached volume if not in check mode.')
         attach_response = ec2_conn.attach_volume(aws_retry=True, Device=device_name,
                                                  InstanceId=instance_dict['instance_id'],
                                                  VolumeId=volume_dict['volume_id'])
@@ -493,6 +574,7 @@ def attach_volume(module, ec2_conn, volume_dict, instance_dict, device_name):
     modify_dot_attribute(module, ec2_conn, instance_dict, device_name)
 
     volume = get_volume(module, ec2_conn, vol_id=volume_dict['volume_id'])
+
     return volume, changed
 
 
@@ -539,17 +621,22 @@ def modify_dot_attribute(module, ec2_conn, instance_dict, device_name):
 def get_attachment_data(volume_dict, wanted_state=None):
     changed = False
 
-    attachment_data = {}
+    attachment_data = []
     if not volume_dict:
         return attachment_data
-    for data in volume_dict.get('attachments', []):
-        if wanted_state and wanted_state == data['state']:
-            attachment_data = data
-            break
-        else:
-            # No filter, return first
-            attachment_data = data
-            break
+    resource = volume_dict.get('attachments', [])
+    if wanted_state:
+        # filter 'state', return attachment matching wanted state
+        resource = [data for data in resource if data['state'] == wanted_state]
+
+    for data in resource:
+        attachment_data.append({
+            'attach_time': data.get('attach_time', None),
+            'device': data.get('device', None),
+            'instance_id': data.get('instance_id', None),
+            'status': data.get('state', None),
+            'delete_on_termination': data.get('delete_on_termination', None)
+        })
 
     return attachment_data
 
@@ -558,8 +645,11 @@ def detach_volume(module, ec2_conn, volume_dict):
     changed = False
 
     attachment_data = get_attachment_data(volume_dict, wanted_state='attached')
-    if attachment_data:
-        ec2_conn.detach_volume(aws_retry=True, VolumeId=volume_dict['volume_id'])
+    # The ID of the instance must be specified if you are detaching a Multi-Attach enabled volume.
+    for attachment in attachment_data:
+        if module.check_mode:
+            module.exit_json(changed=True, msg='Would have detached volume if not in check mode.')
+        ec2_conn.detach_volume(aws_retry=True, InstanceId=attachment['instance_id'], VolumeId=volume_dict['volume_id'])
         waiter = ec2_conn.get_waiter('volume_available')
         waiter.wait(
             VolumeIds=[volume_dict['volume_id']],
@@ -570,7 +660,7 @@ def detach_volume(module, ec2_conn, volume_dict):
     return volume_dict, changed
 
 
-def get_volume_info(volume, tags=None):
+def get_volume_info(module, volume, tags=None):
     if not tags:
         tags = boto3_tag_list_to_ansible_dict(volume.get('tags'))
     attachment_data = get_attachment_data(volume)
@@ -584,17 +674,14 @@ def get_volume_info(volume, tags=None):
         'status': volume.get('state'),
         'type': volume.get('volume_type'),
         'zone': volume.get('availability_zone'),
-        'throughput': volume.get('throughput'),
-        'attachment_set': {
-            'attach_time': attachment_data.get('attach_time', None),
-            'device': attachment_data.get('device', None),
-            'instance_id': attachment_data.get('instance_id', None),
-            'status': attachment_data.get('state', None),
-            'deleteOnTermination': attachment_data.get('delete_on_termination', None)
-        },
+        'attachment_set': attachment_data,
+        'multi_attach_enabled': volume.get('multi_attach_enabled'),
         'tags': tags
     }
 
+    if module.botocore_at_least("1.19.27"):
+        volume_info['throughput'] = volume.get('throughput')
+
     return volume_info
 
 
@@ -614,6 +701,8 @@ def get_mapped_block_device(instance_dict=None, device_name=None):
 
 
 def ensure_tags(module, connection, res_id, res_type, tags, purge_tags):
+    if module.check_mode:
+        return {}, True
     changed = ensure_ec2_tags(connection, module, res_id, res_type, tags, purge_tags, ['InvalidVolume.NotFound'])
     final_tags = describe_ec2_tags(connection, module, res_id, res_type)
 
@@ -638,10 +727,19 @@ def main():
         tags=dict(default={}, type='dict'),
         modify_volume=dict(default=False, type='bool'),
         throughput=dict(type='int'),
+        outpost_arn=dict(type='str'),
         purge_tags=dict(type='bool', default=False),
+        multi_attach=dict(type='bool'),
     )
 
-    module = AnsibleAWSModule(argument_spec=argument_spec)
+    module = AnsibleAWSModule(
+        argument_spec=argument_spec,
+        required_if=[
+            ['volume_type', 'io1', ['iops']],
+            ['volume_type', 'io2', ['iops']],
+        ],
+        supports_check_mode=True,
+    )
 
     param_id = module.params.get('id')
     name = module.params.get('name')
@@ -652,11 +750,18 @@ def main():
     snapshot = module.params.get('snapshot')
     state = module.params.get('state')
     tags = module.params.get('tags')
+    iops = module.params.get('iops')
+    volume_type = module.params.get('volume_type')
+    throughput = module.params.get('throughput')
+    multi_attach = module.params.get('multi_attach')
 
     if state == 'list':
         module.deprecate(
             'Using the "list" state has been deprecated.  Please use the ec2_vol_info module instead', date='2022-06-01', collection_name='amazon.aws')
 
+    if module.params.get('throughput'):
+        module.require_botocore_at_least('1.19.27', reason='to set the throughput for a volume')
+
     # Ensure we have the zone or can get the zone
     if instance is None and zone is None and state == 'present':
         module.fail_json(msg="You must specify either instance or zone")
@@ -668,6 +773,25 @@ def main():
     else:
         detach_vol_flag = False
 
+    if iops:
+        if volume_type in ('gp2', 'st1', 'sc1', 'standard'):
+            module.fail_json(msg='IOPS is not supported for gp2, st1, sc1, or standard volumes.')
+
+        if volume_type == 'gp3' and (int(iops) < 3000 or int(iops) > 16000):
+            module.fail_json(msg='For a gp3 volume type, IOPS values must be between 3000 and 16000.')
+
+        if volume_type in ('io1', 'io2') and (int(iops) < 100 or int(iops) > 64000):
+            module.fail_json(msg='For io1 and io2 volume types, IOPS values must be between 100 and 64000.')
+
+    if throughput:
+        if volume_type != 'gp3':
+            module.fail_json(msg='Throughput is only supported for gp3 volume.')
+        if throughput < 125 or throughput > 1000:
+            module.fail_json(msg='Throughput values must be between 125 and 1000.')
+
+    if multi_attach is True and volume_type not in ('io1', 'io2'):
+        module.fail_json(msg='multi_attach is only supported for io1 and io2 volumes.')
+
     # Set changed flag
     changed = False
 
@@ -678,7 +802,7 @@ def main():
         vols = get_volumes(module, ec2_conn)
 
         for v in vols:
-            returned_volumes.append(get_volume_info(v))
+            returned_volumes.append(get_volume_info(module, v))
 
         module.exit_json(changed=False, volumes=returned_volumes)
 
@@ -728,34 +852,38 @@ def main():
                         changed=False
                     )
 
-        attach_state_changed = False
+        final_tags = None
+        tags_changed = False
 
         if volume:
             volume, changed = update_volume(module, ec2_conn, volume)
+            if name:
+                tags['Name'] = name
+            final_tags, tags_changed = ensure_tags(module, ec2_conn, volume['volume_id'], 'volume', tags, module.params.get('purge_tags'))
         else:
             volume, changed = create_volume(module, ec2_conn, zone=zone)
 
-        if name:
-            tags['Name'] = name
-        final_tags, tags_changed = ensure_tags(module, ec2_conn, volume['volume_id'], 'volume', tags, module.params.get('purge_tags'))
-
         if detach_vol_flag:
-            volume, changed = detach_volume(module, ec2_conn, volume_dict=volume)
+            volume, attach_changed = detach_volume(module, ec2_conn, volume_dict=volume)
         elif inst is not None:
-            volume, changed = attach_volume(module, ec2_conn, volume_dict=volume, instance_dict=inst, device_name=device_name)
+            volume, attach_changed = attach_volume(module, ec2_conn, volume_dict=volume, instance_dict=inst, device_name=device_name)
+        else:
+            attach_changed = False
 
         # Add device, volume_id and volume_type parameters separately to maintain backward compatibility
-        volume_info = get_volume_info(volume, tags=final_tags)
+        volume_info = get_volume_info(module, volume, tags=final_tags)
 
-        if tags_changed:
+        if tags_changed or attach_changed:
             changed = True
 
-        module.exit_json(changed=changed, volume=volume_info, device=volume_info['attachment_set']['device'],
+        module.exit_json(changed=changed, volume=volume_info, device=device_name,
                          volume_id=volume_info['id'], volume_type=volume_info['type'])
     elif state == 'absent':
         if not name and not param_id:
             module.fail_json('A volume name or id is required for deletion')
         if volume:
+            if module.check_mode:
+                module.exit_json(changed=True, msg='Would have deleted volume if not in check mode.')
             detach_volume(module, ec2_conn, volume_dict=volume)
             changed = delete_volume(module, ec2_conn, volume_id=volume['volume_id'])
         module.exit_json(changed=changed)
