@@ -7,8 +7,9 @@ from __future__ import absolute_import, division, print_function
 __metaclass__ = type
 
 DOCUMENTATION = """
-author: Ansible Networking Team
-connection: network_cli
+author:
+ - Ansible Networking Team (@ansible-network)
+name: network_cli
 short_description: Use network_cli to run command on network appliances
 description:
 - This connection plugin provides a connection to remote devices over the SSH and
@@ -26,6 +27,7 @@ options:
       to.
     default: inventory_hostname
     vars:
+    - name: inventory_hostname
     - name: ansible_host
   port:
     type: int
@@ -108,6 +110,19 @@ options:
     - name: ansible_network_become_errors
     default: fail
     choices: ["ignore", "warn", "fail"]
+  terminal_errors:
+    type: str
+    description:
+    - This option determines how failures while setting terminal parameters
+      are handled.
+    - When set to C(ignore), the errors are silently ignored.
+      When set to C(warn), a warning message is displayed.
+      The default option C(fail), triggers a failure and halts execution.
+    vars:
+    - name: ansible_network_terminal_errors
+    default: fail
+    choices: ["ignore", "warn", "fail"]
+    version_added: 3.1.0
   become_method:
     description:
     - This option allows the become method to be specified in for handling privilege
@@ -121,24 +136,6 @@ options:
     - name: ANSIBLE_BECOME_METHOD
     vars:
     - name: ansible_become_method
-  import_modules:
-    type: boolean
-    description:
-    - Reduce CPU usage and network module execution time
-      by enabling direct execution. Instead of the module being packaged
-      and executed by the shell, it will be directly executed by the Ansible
-      control node using the same python interpreter as the Ansible process.
-      Note- Incompatible with C(asynchronous mode).
-      Note- Python 3 and Ansible 2.9.16 or greater required.
-      Note- With Ansible 2.9.x fully qualified modules names are required in tasks.
-    default: false
-    ini:
-    - section: ansible_network
-      key: import_modules
-    env:
-    - name: ANSIBLE_NETWORK_IMPORT_MODULES
-    vars:
-    - name: ansible_network_import_modules
   host_key_auto_add:
     type: boolean
     description:
@@ -195,6 +192,7 @@ options:
     - name: ansible_terminal_stderr_re
   terminal_initial_prompt:
     type: list
+    elements: string
     description:
     - A single regex pattern or a sequence of patterns to evaluate the expected prompt
       at the time of initial login to the remote host.
@@ -202,6 +200,7 @@ options:
     - name: ansible_terminal_initial_prompt
   terminal_initial_answer:
     type: list
+    elements: string
     description:
     - The answer to reply with if the C(terminal_initial_prompt) is matched. The value
       can be a single answer or a list of answers for multiple terminal_initial_prompt.
@@ -248,10 +247,12 @@ options:
     - name: ansible_network_cli_retries
   ssh_type:
     description:
-      - The type of the transport used by C(network_cli) connection plugin to connection to remote host.
-        Valid value is either I(paramiko) or I(libssh)
-      - In order to use I(libssh), the ansible-pylibssh package needs to be installed
-    default: paramiko
+      - The python package that will be used by the C(network_cli) connection plugin to create a SSH connection to remote host.
+      - I(libssh) will use the ansible-pylibssh package, which needs to be installed in order to work.
+      - I(paramiko) will instead use the paramiko package to manage the SSH connection.
+      - I(auto) will use ansible-pylibssh if that package is installed, otherwise will fallback to paramiko.
+    default: auto
+    choices: ["libssh", "paramiko", "auto"]
     env:
         - name: ANSIBLE_NETWORK_CLI_SSH_TYPE
     ini:
@@ -288,30 +289,33 @@ options:
     - name: ansible_network_single_user_mode
 """
 
-from functools import wraps
 import getpass
 import json
 import logging
-import re
 import os
+import re
 import signal
 import socket
 import time
 import traceback
+from functools import wraps
 from io import BytesIO
 
 from ansible.errors import AnsibleConnectionFailure, AnsibleError
+from ansible.module_utils._text import to_bytes, to_text
 from ansible.module_utils.basic import missing_required_lib
 from ansible.module_utils.six import PY3
 from ansible.module_utils.six.moves import cPickle
-from ansible.module_utils._text import to_bytes, to_text
 from ansible.playbook.play_context import PlayContext
 from ansible.plugins.loader import (
+    cache_loader,
     cliconf_loader,
-    terminal_loader,
     connection_loader,
+    terminal_loader,
+)
+from ansible_collections.ansible.netcommon.plugins.connection.libssh import (
+    HAS_PYLIBSSH,
 )
-from ansible.plugins.loader import cache_loader
 from ansible_collections.ansible.netcommon.plugins.module_utils.network.common.utils import (
     to_list,
 )
@@ -343,7 +347,7 @@ class AnsibleCmdRespRecv(Exception):
 
 
 class Connection(NetworkConnectionBase):
-    """ CLI (shell) SSH connections on Paramiko """
+    """CLI (shell) SSH connections on Paramiko"""
 
     transport = "ansible.netcommon.network_cli"
     has_pipelining = True
@@ -411,27 +415,56 @@ class Connection(NetworkConnectionBase):
             )
         self.queue_message("log", "network_os is set to %s" % self._network_os)
 
+    @property
+    def ssh_type(self):
+        if self._ssh_type is None:
+            self._ssh_type = self.get_option("ssh_type")
+            self.queue_message(
+                "vvvv", "ssh type is set to %s" % self._ssh_type
+            )
+            # Support autodetection of supported library
+            if self._ssh_type == "auto":
+                self.queue_message("vvvv", "autodetecting ssh_type")
+                if HAS_PYLIBSSH:
+                    self._ssh_type = "libssh"
+                else:
+                    self.queue_message(
+                        "warning",
+                        "ansible-pylibssh not installed, falling back to paramiko",
+                    )
+                    self._ssh_type = "paramiko"
+                self.queue_message(
+                    "vvvv", "ssh type is now set to %s" % self._ssh_type
+                )
+
+        if self._ssh_type not in ["paramiko", "libssh"]:
+            raise AnsibleConnectionFailure(
+                "Invalid value '%s' set for ssh_type option."
+                " Expected value is either 'libssh' or 'paramiko'"
+                % self._ssh_type
+            )
+
+        return self._ssh_type
+
     @property
     def ssh_type_conn(self):
-        self._ssh_type = self.get_option("ssh_type")
         if self._ssh_type_conn is None:
-            if self._ssh_type not in ["paramiko", "libssh"]:
+            if self.ssh_type == "libssh":
+                connection_plugin = "ansible.netcommon.libssh"
+            elif self.ssh_type == "paramiko":
+                # NOTE: This MUST be paramiko or things will break
+                connection_plugin = "paramiko"
+            else:
                 raise AnsibleConnectionFailure(
                     "Invalid value '%s' set for ssh_type option."
                     " Expected value is either 'libssh' or 'paramiko'"
                     % self._ssh_type
                 )
 
-            # TODO: Remove this check if/when libssh connection plugin is moved to ansible-base
-            if self._ssh_type == "libssh":
-                self._ssh_type = "ansible.netcommon.libssh"
-
             self._ssh_type_conn = connection_loader.get(
-                self._ssh_type, self._play_context, "/dev/null"
-            )
-            self.queue_message(
-                "vvvv", "ssh type is set to %s" % self.get_option("ssh_type")
+                connection_plugin, self._play_context, "/dev/null"
             )
+
         return self._ssh_type_conn
 
     # To maintain backward compatibility
@@ -441,7 +474,7 @@ class Connection(NetworkConnectionBase):
 
     def _get_log_channel(self):
         name = "p=%s u=%s | " % (os.getpid(), getpass.getuser())
-        name += "%s [%s]" % (self._ssh_type, self._play_context.remote_addr)
+        name += "%s [%s]" % (self.ssh_type, self._play_context.remote_addr)
         return name
 
     @ensure_connect
@@ -569,10 +602,10 @@ class Connection(NetworkConnectionBase):
         Connects to the remote device and starts the terminal
         """
         if self._play_context.verbosity > 3:
-            logging.getLogger(self._ssh_type).setLevel(logging.DEBUG)
+            logging.getLogger(self.ssh_type).setLevel(logging.DEBUG)
 
         self.queue_message(
-            "vvvv", "invoked shell using ssh_type: %s" % self._ssh_type
+            "vvvv", "invoked shell using ssh_type: %s" % self.ssh_type
         )
 
         self._single_user_mode = self.get_option("single_user_mode")
@@ -605,8 +638,8 @@ class Connection(NetworkConnectionBase):
                         )
                     else:
                         msg = (
-                            u"network_cli_retry: attempt: %d, caught exception(%s), "
-                            u"pausing for %d seconds"
+                            "network_cli_retry: attempt: %d, caught exception(%s), "
+                            "pausing for %d seconds"
                             % (
                                 attempt + 1,
                                 to_text(e, errors="surrogate_or_strict"),
@@ -623,7 +656,7 @@ class Connection(NetworkConnectionBase):
             self._connected = True
 
             self._ssh_shell = ssh.ssh.invoke_shell()
-            if self._ssh_type == "paramiko":
+            if self.ssh_type == "paramiko":
                 self._ssh_shell.settimeout(command_timeout)
 
             self.queue_message(
@@ -660,7 +693,7 @@ class Connection(NetworkConnectionBase):
                 self._on_become(become_pass=auth_pass)
 
             self.queue_message("vvvv", "firing event: on_open_shell()")
-            self._terminal.on_open_shell()
+            self._on_open_shell()
 
             self.queue_message(
                 "vvvv", "ssh connection has completed successfully"
@@ -686,6 +719,25 @@ class Connection(NetworkConnectionBase):
             else:
                 raise
 
+    def _on_open_shell(self):
+        """
+        Wraps terminal.on_open_shell() to handle
+        terminal setting failures based on user preference
+        """
+        on_terminal_error = self.get_option("terminal_errors")
+        try:
+            self._terminal.on_open_shell()
+        except AnsibleConnectionFailure:
+            if on_terminal_error == "ignore":
+                pass
+            elif on_terminal_error == "warn":
+                self.queue_message(
+                    "warning",
+                    "on_open_shell: failed to set terminal parameters",
+                )
+            else:
+                raise
+
     def close(self):
         """
         Close the active connection to the device
@@ -720,10 +772,12 @@ class Connection(NetworkConnectionBase):
         newline=True,
         prompt_retry_check=False,
         check_all=False,
+        strip_prompt=True,
     ):
 
         recv = BytesIO()
-        cache_socket_timeout = self._ssh_shell.gettimeout()
+        cache_socket_timeout = self.get_option("persistent_command_timeout")
+        self._ssh_shell.settimeout(cache_socket_timeout)
         command_prompt_matched = False
         handled = False
         errored_response = None
@@ -753,7 +807,6 @@ class Connection(NetworkConnectionBase):
 
                 except AnsibleCmdRespRecv:
                     # reset socket timeout to global timeout
-                    self._ssh_shell.settimeout(cache_socket_timeout)
                     return self._command_response
             else:
                 data = self._ssh_shell.recv(256)
@@ -809,10 +862,11 @@ class Connection(NetworkConnectionBase):
                     raise AnsibleConnectionFailure(errored_response)
                 self._last_response = recv.getvalue()
                 resp = self._strip(self._last_response)
-                self._command_response = self._sanitize(resp, command)
+                self._command_response = self._sanitize(
+                    resp, command, strip_prompt
+                )
                 if self._buffer_read_timeout == 0.0:
                     # reset socket timeout to global timeout
-                    self._ssh_shell.settimeout(cache_socket_timeout)
                     return self._command_response
                 else:
                     command_prompt_matched = True
@@ -825,6 +879,7 @@ class Connection(NetworkConnectionBase):
         newline=True,
         prompt_retry_check=False,
         check_all=False,
+        strip_prompt=True,
     ):
         self._command_response = resp = b""
         command_prompt_matched = False
@@ -891,7 +946,9 @@ class Connection(NetworkConnectionBase):
                 if errored_response:
                     raise AnsibleConnectionFailure(errored_response)
                 self._last_response = data
-                self._command_response += self._sanitize(resp, command)
+                self._command_response += self._sanitize(
+                    resp, command, strip_prompt
+                )
                 command_prompt_matched = True
 
     def receive(
@@ -902,6 +959,7 @@ class Connection(NetworkConnectionBase):
         newline=True,
         prompt_retry_check=False,
         check_all=False,
+        strip_prompt=True,
     ):
         """
         Handles receiving of output from command
@@ -932,7 +990,7 @@ class Connection(NetworkConnectionBase):
         )
 
         self._log_messages("command: %s" % command)
-        if self._ssh_type == "libssh":
+        if self.ssh_type == "libssh":
             response = self.receive_libssh(
                 command,
                 prompts,
@@ -940,8 +998,9 @@ class Connection(NetworkConnectionBase):
                 newline,
                 prompt_retry_check,
                 check_all,
+                strip_prompt,
             )
-        else:
+        elif self.ssh_type == "paramiko":
             response = self.receive_paramiko(
                 command,
                 prompts,
@@ -949,6 +1008,7 @@ class Connection(NetworkConnectionBase):
                 newline,
                 prompt_retry_check,
                 check_all,
+                strip_prompt,
             )
 
         return response
@@ -963,6 +1023,7 @@ class Connection(NetworkConnectionBase):
         sendonly=False,
         prompt_retry_check=False,
         check_all=False,
+        strip_prompt=True,
     ):
         """
         Sends the command to the device in the opened shell
@@ -992,7 +1053,13 @@ class Connection(NetworkConnectionBase):
             if sendonly:
                 return
             response = self.receive(
-                command, prompt, answer, newline, prompt_retry_check, check_all
+                command,
+                prompt,
+                answer,
+                newline,
+                prompt_retry_check,
+                check_all,
+                strip_prompt,
             )
             response = to_text(response, errors="surrogate_then_replace")
 
@@ -1105,7 +1172,7 @@ class Connection(NetworkConnectionBase):
                 return True
         return False
 
-    def _sanitize(self, resp, command=None):
+    def _sanitize(self, resp, command=None, strip_prompt=True):
         """
         Removes elements from the response before returning to the caller
         """
@@ -1115,15 +1182,15 @@ class Connection(NetworkConnectionBase):
                 continue
 
             for prompt in self._matched_prompt.strip().splitlines():
-                if prompt.strip() in line:
+                if prompt.strip() in line and strip_prompt:
                     break
             else:
                 cleaned.append(line)
+
         return b"\n".join(cleaned).strip()
 
     def _find_error(self, response):
-        """Searches the buffered response for a matching error condition
-        """
+        """Searches the buffered response for a matching error condition"""
         for stderr_regex in self._terminal_stderr_re:
             if stderr_regex.search(response):
                 self._log_messages(
@@ -1140,8 +1207,7 @@ class Connection(NetworkConnectionBase):
         return False
 
     def _find_prompt(self, response):
-        """Searches the buffered response for a matching command prompt
-        """
+        """Searches the buffered response for a matching command prompt"""
         for stdout_regex in self._terminal_stdout_re:
             match = stdout_regex.search(response)
             if match:
@@ -1187,7 +1253,7 @@ class Connection(NetworkConnectionBase):
                         "'pattern' is a required key for option '%s',"
                         " received option value is %s" % (option, item)
                     )
-                pattern = br"%s" % to_bytes(item["pattern"])
+                pattern = rb"%s" % to_bytes(item["pattern"])
                 flag = item.get("flags", 0)
                 if flag:
                     flag = getattr(re, flag.split(".")[1])
@@ -1211,11 +1277,10 @@ class Connection(NetworkConnectionBase):
                         remote host before triggering timeout exception
         :return: None
         """
-        ssh_type = self.get_option("ssh_type")
         ssh = self.ssh_type_conn._connect_uncached()
-        if ssh_type == "libssh":
+        if self.ssh_type == "libssh":
             self.ssh_type_conn.put_file(source, destination, proto=proto)
-        elif ssh_type == "paramiko":
+        elif self.ssh_type == "paramiko":
             if proto == "scp":
                 if not HAS_SCP:
                     raise AnsibleError(missing_required_lib("scp"))
@@ -1233,7 +1298,7 @@ class Connection(NetworkConnectionBase):
                 )
         else:
             raise AnsibleError(
-                "Do not know how to do SCP with ssh_type %s" % ssh_type
+                "Do not know how to do SCP with ssh_type %s" % self.ssh_type
             )
 
     def get_file(self, source=None, destination=None, proto="scp", timeout=30):
@@ -1247,11 +1312,10 @@ class Connection(NetworkConnectionBase):
         :return: None
         """
         """Fetch file over scp/sftp from remote device"""
-        ssh_type = self.get_option("ssh_type")
         ssh = self.ssh_type_conn._connect_uncached()
-        if ssh_type == "libssh":
+        if self.ssh_type == "libssh":
             self.ssh_type_conn.fetch_file(source, destination, proto=proto)
-        elif ssh_type == "paramiko":
+        elif self.ssh_type == "paramiko":
             if proto == "scp":
                 if not HAS_SCP:
                     raise AnsibleError(missing_required_lib("scp"))
@@ -1273,7 +1337,7 @@ class Connection(NetworkConnectionBase):
                 )
         else:
             raise AnsibleError(
-                "Do not know how to do SCP with ssh_type %s" % ssh_type
+                "Do not know how to do SCP with ssh_type %s" % self.ssh_type
             )
 
     def get_cache(self):
