@@ -689,6 +689,7 @@ class ActionModule(ActionBase):
         'category_names',
         'log_path',
         'reboot',
+        'skip_optional',
         'reboot_timeout',
         'reject_list', 'blacklist',
         'server_selection',
@@ -776,11 +777,11 @@ class ActionModule(ActionBase):
             result['found_update_count'] = 0
             result['failed_update_count'] = 0
             result['installed_update_count'] = 0
-            result['updates'] = []
-            result['filtered_updates'] = []
+            result['updates'] = {}
+            result['filtered_updates'] = {}
             for update_id in self._selected_updates:
                 update_info = self._get_update_info(update_id)
-                result['updates'].append(update_info)
+                result['updates'][update_id] = update_info
                 result['found_update_count'] += 1
 
                 if 'failure_hresult_code' in update_info:
@@ -803,7 +804,7 @@ class ActionModule(ActionBase):
 
                 update_info['filtered_reasons'] = reasons
 
-                result['filtered_updates'].append(update_info)
+                result['filtered_updates'][update_id] = update_info
 
         if self._invocation and 'invocation' not in result:
             result['invocation'] = self._invocation
@@ -923,8 +924,7 @@ class ActionModule(ActionBase):
         except Exception as e:
             # Try our best to cancel the update task on an unknown failure.
             display.warning("Unknown failure when polling update result - attempting to cancel task: %s" % to_text(e))
-            cmd = '&%s -CancelId %s -TaskPid %d' % (quote_pwsh(cancel_script_path), quote_pwsh(cancel_id), task_pid)
-            self._execute_command(cmd)
+            self._execute_script(cancel_script_path, {"CancelId": cancel_id, "TaskPid": task_pid})
 
             raise
 
@@ -954,8 +954,7 @@ class ActionModule(ActionBase):
 
     def _poll_result(self, script_path, output_path, offset):  # type: (str, str, int) -> Tuple[List[Dict], int]
         """Reads the update scheduled task output results path and returns any new results."""
-        cmd = '&%s -OutputPath %s -Offset %d' % (quote_pwsh(script_path), quote_pwsh(output_path), offset)
-        rc, stdout, stderr = self._execute_command(cmd)
+        rc, stdout, stderr = self._execute_script(script_path, {'OutputPath': output_path, 'Offset': offset})
 
         if rc != 0:
             msg = "Failed to poll update task, see rc, stdout, stderr for more info"
@@ -973,6 +972,16 @@ class ActionModule(ActionBase):
 
         return entries, offset
 
+    def _execute_script(self, script, parameters):  # typing: (str, typing.Dict) -> Tuple[int, str, str]
+        # The script is read from a file and executed as a scriptblock to avoid any execution policy shenanigans
+        encoded_parameters = ' '.join(
+            '-%s %s' % (k, v if isinstance(v, int) else quote_pwsh(v))
+            for k, v in parameters.items()
+        )
+        cmd = '$cmd = Get-Content -LiteralPath %s -Raw; &([ScriptBlock]::Create($cmd)) %s' \
+              % (quote_pwsh(script), encoded_parameters)
+        return self._execute_command(cmd)
+
     def _execute_command(self, command):  # type: (str) -> Tuple[int, str, str]
         """Runs a command on the Windows host and returned the result"""
         # Need to wrap the command in our PowerShell encoded wrapper. This is done to align the command input to a
