@@ -123,7 +123,7 @@ EXAMPLES = r'''
           $Force
       )
 
-      New-Item -Path $Path -ItemType Direcotry -Force:$Force
+      New-Item -Path $Path -ItemType Directory -Force:$Force
     parameters:
       Path: C:\temp
       Force: true
@@ -318,7 +318,9 @@ error:
       description:
       - The object which the error occured.
       - May be null if no object was specified when the record was created.
-      type: str
+      - Type type of this object depends on the error record itself.
+      - If the value is a complex type, it will follow the C(depth) limit specified.
+      type: raw
       returned: always
       sample: C:\Windows
     category_info:
