@@ -125,13 +125,12 @@ def _tmplt_bgp_params(config_data):
             **config_data["bgp_params"]
         )
     elif config_data["bgp_params"].get("listen"):
-        command += " listen"
+        # from eos 4.23 , 'bgp listen limit ' is replaced by 'dynamic peer max'.
+        command = "dynamic peer max "
         if config_data["bgp_params"]["listen"].get("limit"):
-            command += " limit {limit}".format(
-                **config_data["bgp_params"]["listen"]
-            )
+            command += "{limit}".format(**config_data["bgp_params"]["listen"])
         else:
-            command += " range {address} peer-group".format(
+            command += " range {address} peer group".format(
                 **config_data["bgp_params"]["listen"]["range"]
             )
             if config_data["bgp_params"]["listen"]["range"]["peer_group"].get(
@@ -225,15 +224,13 @@ def _tmplt_bgp_graceful_restart_helper(config_data):
 
 
 def _tmplt_bgp_access_group(config_data):
-    if config_data["access_group"].get("afi") == "ipv4":
+    if config_data.get("afi") == "ipv4":
         afi = "ip"
     else:
         afi = "ipv6"
-    command = afi + " access-group {acl_name}".format(
-        **config_data["access_group"]
-    )
-    if config_data["access_group"].get("direction"):
-        command += " {direction}".format(**config_data["access_group"])
+    command = afi + " access-group {acl_name}".format(**config_data)
+    if config_data.get("direction"):
+        command += " {direction}".format(**config_data)
     return command
 
 
@@ -241,7 +238,7 @@ def _tmplt_bgp_maximum_paths(config_data):
     command = "maximum-paths {max_equal_cost_paths}".format(
         **config_data["maximum_paths"]
     )
-    if config_data.get("max_installed_ecmp_paths"):
+    if config_data["maximum_paths"].get("max_installed_ecmp_paths"):
         command += " ecmp {max_installed_ecmp_paths}".format(
             **config_data["maximum_paths"]
         )
@@ -263,7 +260,7 @@ def _tmplt_bgp_monitoring(config_data):
 
 
 def _tmplt_bgp_neighbor(config_data):
-    command = "neighbor {peer}".format(**config_data["neighbor"])
+    command = "neighbor {neighbor_address}".format(**config_data["neighbor"])
     if config_data["neighbor"].get("additional_paths"):
         command += " additional-paths {additional_paths}".format(
             **config_data["neighbor"]
@@ -271,7 +268,7 @@ def _tmplt_bgp_neighbor(config_data):
         if config_data["neighbor"]["additional_paths"] == "send":
             command += "any"
     elif config_data["neighbor"].get("peer_group"):
-        command += " peer-group"
+        command += " peer group"
         if (
             config_data["neighbor"]["peer_group"]
             != config_data["neighbor"]["peer_group"]
@@ -285,6 +282,10 @@ def _tmplt_bgp_neighbor(config_data):
             )
     elif config_data["neighbor"].get("auto_local_addr"):
         command += " auto-local-addr"
+    elif config_data["neighbor"].get("bfd"):
+        command += " bfd"
+        if config_data["neighbor"]["bfd"] == "c_bit":
+            command += " c-bit"
     elif config_data["neighbor"].get("default_originate"):
         command += " default-originate"
         if config_data["neighbor"]["default_originate"].get("route_map"):
@@ -492,9 +493,16 @@ def _tmplt_bgp_network(config_data):
 
 
 def _tmplt_bgp_route_target(config_data):
-    command = "route-target {action} {target}".format(
-        **config_data["route_target"]
-    )
+    command = "route-target {action}".format(**config_data["route_target"])
+    if config_data["route_target"].get("type"):
+        command += " {type}".format(**config_data["route_target"])
+    if config_data["route_target"].get("route_map"):
+        command += " {route_map}".format(**config_data["route_target"])
+    if config_data["route_target"].get("imported_route"):
+        command += " imported-route"
+    if config_data["route_target"].get("target"):
+        command += " {target}".format(**config_data["route_target"])
+
     return command
 
 
@@ -1096,9 +1104,7 @@ class Bgp_globalTemplate(NetworkTemplate):
             "name": "bgp_params.listen_limit",
             "getval": re.compile(
                 r"""
-                \s*bgp
-                \s+listen
-                \s+limit
+                \s*dynamic\speer\smax
                 \s+(?P<limit>\d+)
                 *$""",
                 re.VERBOSE,
@@ -1125,7 +1131,7 @@ class Bgp_globalTemplate(NetworkTemplate):
                 \s+listen
                 \s+range
                 \s+(?P<address>\S+)
-                \s+peer-group
+                \s+peer\sgroup
                 \s+(?P<group>\S+)
                 \s*(?P<filter>peer-filter \S+)*
                 \s*(?P<remote_as>remote-as \S+)*
@@ -1455,7 +1461,7 @@ class Bgp_globalTemplate(NetworkTemplate):
             },
         },
         {
-            "name": "acccess_group",
+            "name": "access_group",
             "getval": re.compile(
                 r"""
                 \s*(?P<afi>ip|ipv6)
@@ -1470,11 +1476,13 @@ class Bgp_globalTemplate(NetworkTemplate):
             "result": {
                 "vrfs": {
                     '{{ "vrf_" + vrf|d() }}': {
-                        "access_group": {
-                            "afi": "{{ ipv4 if afi == 'ip'  else afi }}",
-                            "acl_name": "{{ acl_name }}",
-                            "direction": "{{ direction }}",
-                        }
+                        "access_group": [
+                            {
+                                "afi": "{{ ipv4 if afi == 'ip'  else afi }}",
+                                "acl_name": "{{ acl_name }}",
+                                "direction": "{{ direction }}",
+                            }
+                        ]
                     }
                 }
             },
@@ -1548,7 +1556,7 @@ class Bgp_globalTemplate(NetworkTemplate):
                     '{{ "vrf_" + vrf|d() }}': {
                         "neighbor": {
                             "{{ peer }}": {
-                                "peer": "{{ peer }}",
+                                "neighbor_address": "{{ peer }}",
                                 "additional_paths": "{{ action }}",
                             }
                         }
@@ -1574,7 +1582,7 @@ class Bgp_globalTemplate(NetworkTemplate):
                     '{{ "vrf_" + vrf|d() }}': {
                         "neighbor": {
                             "{{ peer }}": {
-                                "peer": "{{ peer }}",
+                                "neighbor_address": "{{ peer }}",
                                 "allowas_in": {
                                     "set": "{{ True if count is undefined }}",
                                     "count": "{{ count }}"
@@ -1602,7 +1610,7 @@ class Bgp_globalTemplate(NetworkTemplate):
                     '{{ "vrf_" + vrf|d() }}': {
                         "neighbor": {
                             "{{ peer }}": {
-                                "peer": "{{ peer }}",
+                                "neighbor_address": "{{ peer }}",
                                 "auto_local_addr": "{{ True }}",
                             }
                         }
@@ -1610,6 +1618,32 @@ class Bgp_globalTemplate(NetworkTemplate):
                 }
             },
         },
+        {
+            "name": "neighbor.bfd",
+            "getval": re.compile(
+                r"""
+                \s*neighbor
+                \s+(?P<peer>\S+)
+                \s+bfd
+                \s*(?P<cbit>c-bit)
+                *$""",
+                re.VERBOSE,
+            ),
+            "setval": _tmplt_bgp_neighbor,
+            "compval": "neighbor.bfd",
+            "result": {
+                "vrfs": {
+                    '{{ "vrf_" + vrf|d() }}': {
+                        "neighbor": {
+                            "{{ peer }}": {
+                                "neighbor_address": "{{ peer }}",
+                                "bfd": "{{ 'c_bit' if cbit is defined else 'enable' }}",
+                            }
+                        }
+                    }
+                }
+            },
+        },
         {
             "name": "neighbor.default_originate",
             "getval": re.compile(
@@ -1629,7 +1663,7 @@ class Bgp_globalTemplate(NetworkTemplate):
                     '{{ "vrf_" + vrf|d() }}': {
                         "neighbor": {
                             "{{ peer }}": {
-                                "peer": "{{ peer }}",
+                                "neighbor_address": "{{ peer }}",
                                 "default_originate": {
                                     "route_map": "{{ route_map.split(" ")[1] }}",
                                     "always": "{{ True if always is defined }}"
@@ -1658,7 +1692,7 @@ class Bgp_globalTemplate(NetworkTemplate):
                     '{{ "vrf_" + vrf|d() }}': {
                         "neighbor": {
                             "{{ peer }}": {
-                                "peer": "{{ peer }}",
+                                "neighbor_address": "{{ peer }}",
                                 "description": "{{ desc }}",
                             }
                         }
@@ -1683,7 +1717,7 @@ class Bgp_globalTemplate(NetworkTemplate):
                     '{{ "vrf_" + vrf|d() }}': {
                         "neighbor": {
                             "{{ peer }}": {
-                                "peer": "{{ peer }}",
+                                "neighbor_address": "{{ peer }}",
                                 "dont_capability_negotiate": "{{ True }}",
                             }
                         }
@@ -1709,9 +1743,9 @@ class Bgp_globalTemplate(NetworkTemplate):
                     '{{ "vrf_" + vrf|d() }}': {
                         "neighbor": {
                             "{{ peer }}": {
-                                "peer": "{{ peer }}",
+                                "neighbor_address": "{{ peer }}",
                                 "ebgp_multihop": {
-                                    "set": "{{ True if ttl is not set }}",
+                                    "set": "{{ True if ttl is not defined }}",
                                     "ttl": "{{ ttl }}"
                                 }
                             }
@@ -1737,7 +1771,7 @@ class Bgp_globalTemplate(NetworkTemplate):
                     '{{ "vrf_" + vrf|d() }}': {
                         "neighbor": {
                             "{{ peer }}": {
-                                "peer": "{{ peer }}",
+                                "neighbor_address": "{{ peer }}",
                                 "enforce_first_as": "{{ True }}",
                             }
                         }
@@ -1763,7 +1797,7 @@ class Bgp_globalTemplate(NetworkTemplate):
                     '{{ "vrf_" + vrf|d() }}': {
                         "neighbor": {
                             "{{ peer }}": {
-                                "peer": "{{ peer }}",
+                                "neighbor_address": "{{ peer }}",
                                 "export_localpref": "{{ pref }}",
                             }
                         }
@@ -1789,7 +1823,7 @@ class Bgp_globalTemplate(NetworkTemplate):
                     '{{ "vrf_" + vrf|d() }}': {
                         "neighbor": {
                             "{{ peer }}": {
-                                "peer": "{{ peer }}",
+                                "neighbor_address": "{{ peer }}",
                                 "fall_over": "{{ True }}",
                             }
                         }
@@ -1815,7 +1849,7 @@ class Bgp_globalTemplate(NetworkTemplate):
                     '{{ "vrf_" + vrf|d() }}': {
                         "neighbor": {
                             "{{ peer }}": {
-                                "peer": "{{ peer }}",
+                                "neighbor_address": "{{ peer }}",
                                 "graceful_restart": "{{ True }}",
                             }
                         }
@@ -1840,7 +1874,7 @@ class Bgp_globalTemplate(NetworkTemplate):
                     '{{ "vrf_" + vrf|d() }}': {
                         "neighbor": {
                             "{{ peer }}": {
-                                "peer": "{{ peer }}",
+                                "neighbor_address": "{{ peer }}",
                                 "graceful_restart_helper": "{{ True }}",
                             }
                         }
@@ -1866,7 +1900,7 @@ class Bgp_globalTemplate(NetworkTemplate):
                     '{{ "vrf_" + vrf|d() }}': {
                         "neighbor": {
                             "{{ peer }}": {
-                                "peer": "{{ peer }}",
+                                "neighbor_address": "{{ peer }}",
                                 "idle_restart_timer": "{{ time }}",
                             }
                         }
@@ -1892,7 +1926,7 @@ class Bgp_globalTemplate(NetworkTemplate):
                     '{{ "vrf_" + vrf|d() }}': {
                         "neighbor": {
                             "{{ peer }}": {
-                                "peer": "{{ peer }}",
+                                "neighbor_address": "{{ peer }}",
                                 "import_localpref": "{{ pref }}",
                             }
                         }
@@ -1920,7 +1954,7 @@ class Bgp_globalTemplate(NetworkTemplate):
                     '{{ "vrf_" + vrf|d() }}': {
                         "neighbor": {
                             "{{ peer }}": {
-                                "peer": "{{ peer }}",
+                                "neighbor_address": "{{ peer }}",
                                 "link_bandwidth": {
                                     "set": "{{ True }}",
                                     "auto": "{{ True if auto is defined }}",
@@ -1954,7 +1988,7 @@ class Bgp_globalTemplate(NetworkTemplate):
                     '{{ "vrf_" + vrf|d() }}': {
                         "neighbor": {
                             "{{ peer }}": {
-                                "peer": "{{ peer }}",
+                                "neighbor_address": "{{ peer }}",
                                 "local_as": {
                                     "as_number": "{{ num }}",
                                     "fallback": "{{ True if fallback is defined }}"
@@ -1983,7 +2017,7 @@ class Bgp_globalTemplate(NetworkTemplate):
                     '{{ "vrf_" + vrf|d() }}': {
                         "neighbor": {
                             "{{ peer }}": {
-                                "peer": "{{ peer }}",
+                                "neighbor_address": "{{ peer }}",
                                 "local_v6_addr": "{{ addr }}",
                             }
                         }
@@ -2011,7 +2045,7 @@ class Bgp_globalTemplate(NetworkTemplate):
                     '{{ "vrf_" + vrf|d() }}': {
                         "neighbor": {
                             "{{ peer }}": {
-                                "peer": "{{ peer }}",
+                                "neighbor_address": "{{ peer }}",
                                 "maximum_accepted_routes": {
                                     "count": "{{ count }}",
                                     "warning_limit": "{{ limit }}"
@@ -2044,7 +2078,7 @@ class Bgp_globalTemplate(NetworkTemplate):
                     '{{ "vrf_" + vrf|d() }}': {
                         "neighbor": {
                             "{{ peer }}": {
-                                "peer": "{{ peer }}",
+                                "neighbor_address": "{{ peer }}",
                                 "maximum_received_routes": {
                                     "count": "{{ count }}",
                                     "warning_limit": {
@@ -2077,7 +2111,7 @@ class Bgp_globalTemplate(NetworkTemplate):
                     '{{ "vrf_" + vrf|d() }}': {
                         "neighbor": {
                             "{{ peer }}": {
-                                "peer": "{{ peer }}",
+                                "neighbor_address": "{{ peer }}",
                                 "metric_out": "{{ metric }}",
                             }
                         }
@@ -2102,7 +2136,7 @@ class Bgp_globalTemplate(NetworkTemplate):
                     '{{ "vrf_" + vrf|d() }}': {
                         "neighbor": {
                             "{{ peer }}": {
-                                "peer": "{{ peer }}",
+                                "neighbor_address": "{{ peer }}",
                                 "monitoring": "{{ True }}",
                             }
                         }
@@ -2127,7 +2161,7 @@ class Bgp_globalTemplate(NetworkTemplate):
                     '{{ "vrf_" + vrf|d() }}': {
                         "neighbor": {
                             "{{ peer }}": {
-                                "peer": "{{ peer }}",
+                                "neighbor_address": "{{ peer }}",
                                 "next_hop_self": "{{ True }}",
                             }
                         }
@@ -2152,7 +2186,7 @@ class Bgp_globalTemplate(NetworkTemplate):
                     '{{ "vrf_" + vrf|d() }}': {
                         "neighbor": {
                             "{{ peer }}": {
-                                "peer": "{{ peer }}",
+                                "neighbor_address": "{{ peer }}",
                                 "next_hop_unchanged": "{{ True }}",
                             }
                         }
@@ -2179,7 +2213,7 @@ class Bgp_globalTemplate(NetworkTemplate):
                     '{{ "vrf_" + vrf|d() }}': {
                         "neighbor": {
                             "{{ peer }}": {
-                                "peer": "{{ peer }}",
+                                "neighbor_address": "{{ peer }}",
                                 "next_hop_v6_address": "{{ addr }}",
                             }
                         }
@@ -2205,7 +2239,7 @@ class Bgp_globalTemplate(NetworkTemplate):
                     '{{ "vrf_" + vrf|d() }}': {
                         "neighbor": {
                             "{{ peer }}": {
-                                "peer": "{{ peer }}",
+                                "neighbor_address": "{{ peer }}",
                                 "out_delay": "{{ delay }}",
                             }
                         }
@@ -2231,7 +2265,7 @@ class Bgp_globalTemplate(NetworkTemplate):
                     '{{ "vrf_" + vrf|d() }}': {
                         "neighbor": {
                             "{{ peer }}": {
-                                "peer": "{{ peer }}",
+                                "neighbor_address": "{{ peer }}",
                                 "remote_as": "{{ num }}",
                             }
                         }
@@ -2258,7 +2292,7 @@ class Bgp_globalTemplate(NetworkTemplate):
                     '{{ "vrf_" + vrf|d() }}': {
                         "neighbor": {
                             "{{ peer }}": {
-                                "peer": "{{ peer }}",
+                                "neighbor_address": "{{ peer }}",
                                 "remove_private_as": {
                                     "set": "{{ True if all is undefined and replace is undefined }}",
                                     "all": "{{ True if all is defined }}",
@@ -2276,7 +2310,7 @@ class Bgp_globalTemplate(NetworkTemplate):
                 r"""
                 \s*neighbor
                 \s+(?P<peer>\S+)
-                \s+peer-group
+                \s+peer\sgroup
                 \s*(?P<name>\S+)
                 *$""",
                 re.VERBOSE,
@@ -2288,7 +2322,7 @@ class Bgp_globalTemplate(NetworkTemplate):
                     '{{ "vrf_" + vrf|d() }}': {
                         "neighbor": {
                             "{{ peer }}": {
-                                "peer": "{{ peer }}",
+                                "neighbor_address": "{{ peer }}",
                                 "peer_group": "{{ name if name is defined else peer}}",
                             }
                         }
@@ -2315,7 +2349,7 @@ class Bgp_globalTemplate(NetworkTemplate):
                     '{{ "vrf_" + vrf|d() }}': {
                         "neighbor": {
                             "{{ peer }}": {
-                                "peer": "{{ peer }}",
+                                "neighbor_address": "{{ peer }}",
                                 "prefix_list": {
                                     "name": "{{ name }}",
                                     "direction": "{{ dir }}"
@@ -2345,7 +2379,7 @@ class Bgp_globalTemplate(NetworkTemplate):
                     '{{ "vrf_" + vrf|d() }}': {
                         "neighbor": {
                             "{{ peer }}": {
-                                "peer": "{{ peer }}",
+                                "neighbor_address": "{{ peer }}",
                                 "route_map": {
                                     "name": "{{ name }}",
                                     "direction": "{{ dir }}"
@@ -2373,7 +2407,7 @@ class Bgp_globalTemplate(NetworkTemplate):
                     '{{ "vrf_" + vrf|d() }}': {
                         "neighbor": {
                             "{{ peer }}": {
-                                "peer": "{{ peer }}",
+                                "neighbor_address": "{{ peer }}",
                                 "route_reflector_client": "{{ True }}",
                             }
                         }
@@ -2398,7 +2432,7 @@ class Bgp_globalTemplate(NetworkTemplate):
                     '{{ "vrf_" + vrf|d() }}': {
                         "neighbor": {
                             "{{ peer }}": {
-                                "peer": "{{ peer }}",
+                                "neighbor_address": "{{ peer }}",
                                 "route_to_peer": "{{ True }}",
                             }
                         }
@@ -2413,7 +2447,7 @@ class Bgp_globalTemplate(NetworkTemplate):
                 \s*neighbor
                 \s+(?P<peer>\S+)
                 \s+send-community
-                \s+(?P<comm>add|extended|link-bandwidth|remove|standard)*
+                \s*(?P<comm>add|extended|link-bandwidth|remove|standard)*
                 \s*(?P<attr>extended|link-bandwidth|standard)*
                 \s*(?P<link>aggregate|divide)*
                 \s*(?P<div>equal|ratio)*
@@ -2428,7 +2462,7 @@ class Bgp_globalTemplate(NetworkTemplate):
                     '{{ "vrf_" + vrf|d() }}': {
                         "neighbor": {
                             "{{ peer }}": {
-                                "peer": "{{ peer }}",
+                                "neighbor_address": "{{ peer }}",
                                 "send_community": {
                                     "set": "{{ True if comm is not defined }}",
                                     "community_attribute": "{{ comm }}",
@@ -2460,7 +2494,7 @@ class Bgp_globalTemplate(NetworkTemplate):
                     '{{ "vrf_" + vrf|d() }}': {
                         "neighbor": {
                             "{{ peer }}": {
-                                "peer": "{{ peer }}",
+                                "neighbor_address": "{{ peer }}",
                                 "shutdown": "{{ True }}",
                             }
                         }
@@ -2487,7 +2521,7 @@ class Bgp_globalTemplate(NetworkTemplate):
                     '{{ "vrf_" + vrf|d() }}': {
                         "neighbor": {
                             "{{ peer }}": {
-                                "peer": "{{ peer }}",
+                                "neighbor_address": "{{ peer }}",
                                 "soft_reconfiguration": "{{ 'all' if all is defined else 'None' }}",
                             }
                         }
@@ -2515,7 +2549,7 @@ class Bgp_globalTemplate(NetworkTemplate):
                     '{{ "vrf_" + vrf|d() }}': {
                         "neighbor": {
                             "{{ peer }}": {
-                                "peer": "{{ peer }}",
+                                "neighbor_address": "{{ peer }}",
                                 "transport": {
                                     "connection_mode": "{{ mode }}",
                                     "remote_port": "{{ port if port is defined }}"
@@ -2545,7 +2579,7 @@ class Bgp_globalTemplate(NetworkTemplate):
                     '{{ "vrf_" + vrf|d() }}': {
                         "neighbor": {
                             "{{ peer }}": {
-                                "peer": "{{ peer }}",
+                                "neighbor_address": "{{ peer }}",
                                 "timers": {
                                     "keepalive": "{{ keepalive }}",
                                     "holdtime": "{{ holdtime }}"
@@ -2575,7 +2609,7 @@ class Bgp_globalTemplate(NetworkTemplate):
                     '{{ "vrf_" + vrf|d() }}': {
                         "neighbor": {
                             "{{ peer }}": {
-                                "peer": "{{ peer }}",
+                                "neighbor_address": "{{ peer }}",
                                 "ttl": "{{ hop }}",
                             }
                         }
@@ -2601,7 +2635,7 @@ class Bgp_globalTemplate(NetworkTemplate):
                     '{{ "vrf_" + vrf|d() }}': {
                         "neighbor": {
                             "{{ peer }}": {
-                                "peer": "{{ peer }}",
+                                "neighbor_address": "{{ peer }}",
                                 "update_source": "{{ src }}",
                             }
                         }
@@ -2627,7 +2661,7 @@ class Bgp_globalTemplate(NetworkTemplate):
                     '{{ "vrf_" + vrf|d() }}': {
                         "neighbor": {
                             "{{ peer }}": {
-                                "peer": "{{ peer }}",
+                                "neighbor_address": "{{ peer }}",
                                 "weight": "{{ val }}",
                             }
                         }
@@ -2667,7 +2701,10 @@ class Bgp_globalTemplate(NetworkTemplate):
                 r"""
                 \s*route-target
                 \s+(?P<action>\S+)
-                \s+(?P<target>\S+)
+                \s*(?P<type>evpn|vpn-ipv4|vpn-ipv6)*
+                \s*(?P<map>route-map\s\S+)*
+                \s*(?P<imp>imported-route)*
+                \s*(?P<target>\S+)
                 *$""",
                 re.VERBOSE,
             ),
@@ -2678,6 +2715,9 @@ class Bgp_globalTemplate(NetworkTemplate):
                     '{{ "vrf_" + vrf|d() }}': {
                         "route_target": {
                             "action": "{{ action }}",
+                            "type": "{{ type }}",
+                            "route_map": "{{ map.split(" ")[1] }}",
+                            "imported_route": "{{ True if imp is defined }}",
                             "target": "{{ target }}",
                         }
                     }
