@@ -228,7 +228,7 @@ import re
 from ansible_collections.azure.azcollection.plugins.module_utils.azure_rm_common import AzureRMModuleBase
 try:
     from msrestazure.tools import parse_resource_id
-    from msrestazure.azure_exceptions import CloudError
+    from azure.core.exceptions import ResourceNotFoundError
 except ImportError:
     # This is handled in azure_rm_common
     pass
@@ -424,7 +424,7 @@ class AzureRMManagedDisk(AzureRMModuleBase):
 
     def _update_vm(self, name, params):
         try:
-            poller = self.compute_client.virtual_machines.create_or_update(self.resource_group, name, params)
+            poller = self.compute_client.virtual_machines.begin_create_or_update(self.resource_group, name, params)
             self.get_poller_result(poller)
         except Exception as exc:
             self.fail("Error updating virtual machine {0} - {1}".format(name, str(exc)))
@@ -455,11 +455,7 @@ class AzureRMManagedDisk(AzureRMModuleBase):
             creation_data['create_option'] = self.compute_models.DiskCreateOption.copy
             creation_data['source_resource_id'] = self.source_uri
         if self.os_type:
-            typecon = {
-                'linux': self.compute_models.OperatingSystemTypes.linux,
-                'windows': self.compute_models.OperatingSystemTypes.windows
-            }
-            disk_params['os_type'] = typecon[self.os_type]
+            disk_params['os_type'] = self.compute_models.OperatingSystemTypes(self.os_type.capitalize())
         else:
             disk_params['os_type'] = None
         disk_params['creation_data'] = creation_data
@@ -467,13 +463,12 @@ class AzureRMManagedDisk(AzureRMModuleBase):
 
     def create_or_update_managed_disk(self, parameter):
         try:
-            poller = self.compute_client.disks.create_or_update(
-                self.resource_group,
-                self.name,
-                parameter)
+            poller = self.compute_client.disks.begin_create_or_update(self.resource_group,
+                                                                      self.name,
+                                                                      parameter)
             aux = self.get_poller_result(poller)
             return managed_disk_to_dict(aux)
-        except CloudError as e:
+        except Exception as e:
             self.fail("Error creating the managed disk: {0}".format(str(e)))
 
     # This method accounts for the difference in structure between the
@@ -484,7 +479,7 @@ class AzureRMManagedDisk(AzureRMModuleBase):
             if not found_disk['disk_size_gb'] == new_disk['disk_size_gb']:
                 resp = True
         if new_disk.get('os_type'):
-            if not found_disk['os_type'] == new_disk['os_type']:
+            if found_disk['os_type'] is None or not self.compute_models.OperatingSystemTypes(found_disk['os_type'].capitalize()) == new_disk['os_type']:
                 resp = True
         if new_disk.get('sku'):
             if not found_disk['storage_account_type'] == new_disk['sku'].name:
@@ -500,11 +495,10 @@ class AzureRMManagedDisk(AzureRMModuleBase):
 
     def delete_managed_disk(self):
         try:
-            poller = self.compute_client.disks.delete(
-                self.resource_group,
-                self.name)
+            poller = self.compute_client.disks.begin_delete(self.resource_group,
+                                                            self.name)
             return self.get_poller_result(poller)
-        except CloudError as e:
+        except Exception as e:
             self.fail("Error deleting the managed disk: {0}".format(str(e)))
 
     def get_managed_disk(self):
@@ -513,7 +507,7 @@ class AzureRMManagedDisk(AzureRMModuleBase):
                 self.resource_group,
                 self.name)
             return managed_disk_to_dict(resp)
-        except CloudError as e:
+        except ResourceNotFoundError as e:
             self.log('Did not find managed disk')
 
     def is_attach_caching_option_different(self, vm_name, disk):
@@ -521,9 +515,10 @@ class AzureRMManagedDisk(AzureRMModuleBase):
         if vm_name:
             vm = self._get_vm(vm_name)
             correspondence = next((d for d in vm.storage_profile.data_disks if d.name.lower() == disk.get('name').lower()), None)
-            if correspondence and correspondence.caching.name != self.attach_caching:
+            caching_options = self.compute_models.CachingTypes[self.attach_caching] if self.attach_caching and self.attach_caching != '' else None
+            if correspondence and correspondence.caching != caching_options:
                 resp = True
-                if correspondence.caching.name == 'none' and self.attach_caching == '':
+                if correspondence.caching == 'none' and (self.attach_caching == '' or self.attach_caching is None):
                     resp = False
         return resp
 
