@@ -31,6 +31,8 @@ options:
     tags:
         description:
             - Limit results by providing a list of tags. Format tags as 'key' or 'key:value'.
+        type: list
+        elements: str
 
 extends_documentation_fragment:
     - azure.azcollection.azure
@@ -272,8 +274,8 @@ vms:
 '''
 
 try:
-    from msrestazure.azure_exceptions import CloudError
     from msrestazure.tools import parse_resource_id
+    from azure.core.exceptions import ResourceNotFoundError
 except Exception:
     # This is handled in azure_rm_common
     pass
@@ -295,7 +297,7 @@ class AzureRMVirtualMachineInfo(AzureRMModuleBase):
         self.module_arg_spec = dict(
             resource_group=dict(type='str'),
             name=dict(type='str'),
-            tags=dict(type='list')
+            tags=dict(type='list', elements='str')
         )
 
         self.results = dict(
@@ -347,7 +349,7 @@ class AzureRMVirtualMachineInfo(AzureRMModuleBase):
         self.log('List all items')
         try:
             items = self.compute_client.virtual_machines.list(self.resource_group)
-        except CloudError as exc:
+        except ResourceNotFoundError as exc:
             self.fail("Failed to list all items - {0}".format(str(exc)))
 
         results = []
@@ -360,7 +362,7 @@ class AzureRMVirtualMachineInfo(AzureRMModuleBase):
         self.log('List all items')
         try:
             items = self.compute_client.virtual_machines.list_all()
-        except CloudError as exc:
+        except ResourceNotFoundError as exc:
             self.fail("Failed to list all items - {0}".format(str(exc)))
 
         results = []
@@ -378,7 +380,7 @@ class AzureRMVirtualMachineInfo(AzureRMModuleBase):
         try:
             vm = self.compute_client.virtual_machines.get(resource_group, name, expand='instanceview')
             return self.serialize_vm(vm)
-        except Exception as exc:
+        except ResourceNotFoundError as exc:
             self.fail("Error getting virtual machine {0} - {1}".format(self.name, str(exc)))
 
     def serialize_vm(self, vm):
@@ -409,6 +411,10 @@ class AzureRMVirtualMachineInfo(AzureRMModuleBase):
                 display_status = instance['statuses'][index]['displayStatus']
                 power_state = 'generalized'
                 break
+            elif code[0] == 'ProvisioningState' and code[1] == 'failed':
+                display_status = instance['statuses'][index]['displayStatus']
+                power_state = ''
+                break
 
         new_result = {}
         new_result['power_state'] = power_state
