@@ -73,6 +73,7 @@ options:
                 description:
                     - A list of address blocks reserved for this virtual network in CIDR notation.
                 type: list
+                elements: str
     bgp_properties:
         description:
             - The set of bgp properties.
@@ -94,6 +95,7 @@ options:
                 description:
                     - BGP peering address with IP configuration ID for virtual network gateway.
                 type: list
+                elements: dict
                 suboptions:
                     ipconfiguration_id:
                         description:
@@ -103,14 +105,17 @@ options:
                         description:
                             - The list of default BGP peering addresses which belong to IP configuration.
                         type: list
+                        elements: str
                     custom_bgp_ip_addresses:
                         description:
                             - The list of custom BGP peering addresses which belong to IP configuration.
                         type: list
+                        elements: str
                     tunnel_ip_addresses:
                         description:
                             - The list of tunnel public IP addresses which belong to IP configuration.
                         type: list
+                        elements: str
     is_security_site:
         description:
             - IsSecuritySite flag.
@@ -119,6 +124,7 @@ options:
         description:
             - List of all vpn site links.
         type: list
+        elements: dict
         suboptions:
             name:
                 description:
@@ -294,9 +300,9 @@ state:
 
 from ansible_collections.azure.azcollection.plugins.module_utils.azure_rm_common_ext import AzureRMModuleBaseExt
 try:
-    from msrestazure.azure_exceptions import CloudError
     from msrestazure.azure_operation import AzureOperationPoller
-    from msrest.polling import LROPoller
+    from azure.core.exceptions import ResourceNotFoundError
+    from azure.core.polling import LROPoller
 except ImportError:
     # This is handled in azure_rm_common
     pass
@@ -563,21 +569,21 @@ class AzureRMVpnSite(AzureRMModuleBaseExt):
 
     def create_update_resource(self):
         try:
-            response = self.network_client.vpn_sites.create_or_update(resource_group_name=self.resource_group,
-                                                                      vpn_site_name=self.name,
-                                                                      vpn_site_parameters=self.body)
+            response = self.network_client.vpn_sites.begin_create_or_update(resource_group_name=self.resource_group,
+                                                                            vpn_site_name=self.name,
+                                                                            vpn_site_parameters=self.body)
             if isinstance(response, AzureOperationPoller) or isinstance(response, LROPoller):
                 response = self.get_poller_result(response)
-        except CloudError as exc:
+        except Exception as exc:
             self.log('Error attempting to create the VpnSite instance.')
             self.fail('Error creating the VpnSite instance: {0}'.format(str(exc)))
         return response.as_dict()
 
     def delete_resource(self):
         try:
-            response = self.network_client.vpn_sites.delete(resource_group_name=self.resource_group,
-                                                            vpn_site_name=self.name)
-        except CloudError as e:
+            response = self.network_client.vpn_sites.begin_delete(resource_group_name=self.resource_group,
+                                                                  vpn_site_name=self.name)
+        except Exception as e:
             self.log('Error attempting to delete the VpnSite instance.')
             self.fail('Error deleting the VpnSite instance: {0}'.format(str(e)))
 
@@ -587,7 +593,7 @@ class AzureRMVpnSite(AzureRMModuleBaseExt):
         try:
             response = self.network_client.vpn_sites.get(resource_group_name=self.resource_group,
                                                          vpn_site_name=self.name)
-        except CloudError as e:
+        except ResourceNotFoundError as e:
             return False
         return response.as_dict()
 
