@@ -122,9 +122,9 @@ options:
             - The minimum TLS encryption version required for the app.
         type: str
         choices:
-            - 1.0
-            - 1.1
-            - 1.2
+            - '1.0'
+            - '1.1'
+            - '1.2'
 
     ftps_state:
         description:
@@ -320,7 +320,7 @@ EXAMPLES = '''
 '''
 
 RETURN = '''
-azure_webapp:
+id:
     description:
         - ID of current web app.
     returned: always
