@@ -18,6 +18,7 @@
 #
 from __future__ import absolute_import, division, print_function
 
+
 __metaclass__ = type
 
 DOCUMENTATION = """
@@ -38,14 +39,15 @@ options:
       to the device is present in this list, the existing cache is invalidated.
     version_added: 2.0.0
     type: list
+    elements: str
     default: []
     vars:
     - name: ansible_ios_config_commands
 """
 
+import json
 import re
 import time
-import json
 
 from ansible.errors import AnsibleConnectionFailure
 from ansible.module_utils._text import to_text
@@ -55,10 +57,11 @@ from ansible_collections.ansible.netcommon.plugins.module_utils.network.common.c
     NetworkConfig,
     dumps,
 )
-from ansible_collections.ansible.netcommon.plugins.module_utils.network.common.utils import (
-    to_list,
+from ansible_collections.ansible.netcommon.plugins.module_utils.network.common.utils import to_list
+from ansible_collections.ansible.netcommon.plugins.plugin_utils.cliconf_base import (
+    CliconfBase,
+    enable_mode,
 )
-from ansible.plugins.cliconf import CliconfBase, enable_mode
 
 
 class Cliconf(CliconfBase):
@@ -70,12 +73,12 @@ class Cliconf(CliconfBase):
     def get_config(self, source="running", flags=None, format=None):
         if source not in ("running", "startup"):
             raise ValueError(
-                "fetching configuration from %s is not supported" % source
+                "fetching configuration from %s is not supported" % source,
             )
 
         if format:
             raise ValueError(
-                "'format' value %s is not supported for get_config" % format
+                "'format' value %s is not supported for get_config" % format,
             )
 
         if not flags:
@@ -138,19 +141,19 @@ class Cliconf(CliconfBase):
 
         if candidate is None and device_operations["supports_generate_diff"]:
             raise ValueError(
-                "candidate configuration is required to generate diff"
+                "candidate configuration is required to generate diff",
             )
 
         if diff_match not in option_values["diff_match"]:
             raise ValueError(
                 "'match' value %s in invalid, valid values are %s"
-                % (diff_match, ", ".join(option_values["diff_match"]))
+                % (diff_match, ", ".join(option_values["diff_match"])),
             )
 
         if diff_replace not in option_values["diff_replace"]:
             raise ValueError(
                 "'replace' value %s in invalid, valid values are %s"
-                % (diff_replace, ", ".join(option_values["diff_replace"]))
+                % (diff_replace, ", ".join(option_values["diff_replace"])),
             )
 
         # prepare candidate configuration
@@ -162,31 +165,42 @@ class Cliconf(CliconfBase):
             # running configuration
             have_src, have_banners = self._extract_banners(running)
             running_obj = NetworkConfig(
-                indent=1, contents=have_src, ignore_lines=diff_ignore_lines
+                indent=1,
+                contents=have_src,
+                ignore_lines=diff_ignore_lines,
             )
             configdiffobjs = candidate_obj.difference(
-                running_obj, path=path, match=diff_match, replace=diff_replace
+                running_obj,
+                path=path,
+                match=diff_match,
+                replace=diff_replace,
             )
 
         else:
             configdiffobjs = candidate_obj.items
             have_banners = {}
 
-        diff["config_diff"] = (
-            dumps(configdiffobjs, "commands") if configdiffobjs else ""
-        )
+        diff["config_diff"] = dumps(configdiffobjs, "commands") if configdiffobjs else ""
         banners = self._diff_banners(want_banners, have_banners)
         diff["banner_diff"] = banners if banners else {}
         return diff
 
     @enable_mode
     def edit_config(
-        self, candidate=None, commit=True, replace=None, comment=None
+        self,
+        candidate=None,
+        commit=True,
+        replace=None,
+        comment=None,
     ):
         resp = {}
         operations = self.get_device_operations()
         self.check_edit_config_capability(
-            operations, candidate, commit, replace, comment
+            operations,
+            candidate,
+            commit,
+            replace,
+            comment,
         )
 
         results = []
@@ -211,7 +225,11 @@ class Cliconf(CliconfBase):
         return resp
 
     def edit_macro(
-        self, candidate=None, commit=True, replace=None, comment=None
+        self,
+        candidate=None,
+        commit=True,
+        replace=None,
+        comment=None,
     ):
         """
         ios_config:
@@ -224,7 +242,11 @@ class Cliconf(CliconfBase):
         resp = {}
         operations = self.get_device_operations()
         self.check_edit_config_capability(
-            operations, candidate, commit, replace, comment
+            operations,
+            candidate,
+            commit,
+            replace,
+            comment,
         )
 
         results = []
@@ -267,7 +289,7 @@ class Cliconf(CliconfBase):
             raise ValueError("must provide value of command to execute")
         if output:
             raise ValueError(
-                "'output' value %s is not supported for get" % output
+                "'output' value %s is not supported for get" % output,
             )
 
         return self.send_command(
@@ -357,7 +379,10 @@ class Cliconf(CliconfBase):
         return json.dumps(result)
 
     def edit_banner(
-        self, candidate=None, multiline_delimiter="@", commit=True
+        self,
+        candidate=None,
+        multiline_delimiter="@",
+        commit=True,
     ):
         """
         Edit banner on remote device
@@ -405,8 +430,7 @@ class Cliconf(CliconfBase):
             output = cmd.pop("output", None)
             if output:
                 raise ValueError(
-                    "'output' value %s is not supported for run_commands"
-                    % output
+                    "'output' value %s is not supported for run_commands" % output,
                 )
 
             try:
@@ -449,9 +473,8 @@ class Cliconf(CliconfBase):
 
             if out is None:
                 raise AnsibleConnectionFailure(
-                    message=u"cli prompt is not identified from the last received"
-                    u" response window: %s"
-                    % self._connection._last_recv_window
+                    message="cli prompt is not identified from the last received"
+                    " response window: %s" % self._connection._last_recv_window,
                 )
 
             if re.search(
@@ -459,7 +482,8 @@ class Cliconf(CliconfBase):
                 to_text(out, errors="surrogate_then_replace").strip(),
             ):
                 self._connection.queue_message(
-                    "vvvv", "wrong context, sending end to device"
+                    "vvvv",
+                    "wrong context, sending end to device",
                 )
                 self._connection.send_command("end")
 
