@@ -7,6 +7,7 @@
 
 from __future__ import absolute_import, division, print_function
 
+
 __metaclass__ = type
 
 """
@@ -18,15 +19,14 @@ created.
 """
 
 from ansible.module_utils.six import iteritems
-from ansible_collections.ansible.netcommon.plugins.module_utils.network.common.utils import (
-    dict_merge,
-)
 from ansible_collections.ansible.netcommon.plugins.module_utils.network.common.resource_module import (
     ResourceModule,
 )
-from ansible_collections.cisco.ios.plugins.module_utils.network.ios.facts.facts import (
-    Facts,
+from ansible_collections.ansible.netcommon.plugins.module_utils.network.common.utils import (
+    dict_merge,
 )
+
+from ansible_collections.cisco.ios.plugins.module_utils.network.ios.facts.facts import Facts
 from ansible_collections.cisco.ios.plugins.module_utils.network.ios.rm_templates.bgp_global import (
     Bgp_globalTemplate,
 )
@@ -134,7 +134,7 @@ class Bgp_global(ResourceModule):
         )
 
     def execute_module(self):
-        """ Execute the module
+        """Execute the module
 
         :rtype: A dictionary
         :returns: The result from module execution
@@ -145,8 +145,8 @@ class Bgp_global(ResourceModule):
         return self.result
 
     def generate_commands(self):
-        """ Generate configuration commands to send based on
-            want, have and desired state.
+        """Generate configuration commands to send based on
+        want, have and desired state.
         """
         if self.state in ["merged", "replaced"]:
             w_asn = self.want.get("as_number")
@@ -156,7 +156,7 @@ class Bgp_global(ResourceModule):
                 self._module.fail_json(
                     msg="BGP is already configured with ASN {0}. "
                     "Please remove it with state: purged before "
-                    "configuring new ASN".format(h_asn)
+                    "configuring new ASN".format(h_asn),
                 )
 
         if self.want:
@@ -167,16 +167,12 @@ class Bgp_global(ResourceModule):
 
         if self.state == "deleted":
             # deleted, clean up global params
-            if not self.want or (
-                self.have.get("as_number") == self.want.get("as_number")
-            ):
+            if not self.want or (self.have.get("as_number") == self.want.get("as_number")):
                 self._compare(want={}, have=self.have)
 
         elif self.state == "purged":
             # delete as_number takes down whole bgp config
-            if not self.want or (
-                self.have.get("as_number") == self.want.get("as_number")
-            ):
+            if not self.want or (self.have.get("as_number") == self.want.get("as_number")):
                 self.addcmd(self.have or {}, "as_number", True)
 
         else:
@@ -189,9 +185,9 @@ class Bgp_global(ResourceModule):
 
     def _compare(self, want, have):
         """Leverages the base class `compare()` method and
-           populates the list of commands to be run by comparing
-           the `want` and `have` data with the `parsers` defined
-           for the Bgp_global network resource.
+        populates the list of commands to be run by comparing
+        the `want` and `have` data with the `parsers` defined
+        for the Bgp_global network resource.
         """
         self.generic_list_parsers = [
             "distributes",
@@ -215,23 +211,28 @@ class Bgp_global(ResourceModule):
                 )
             else:
                 self._compare_generic_lists(
-                    want.get(_parse, {}), have.get(_parse, {}), _parse
+                    want.get(_parse, {}),
+                    have.get(_parse, {}),
+                    _parse,
                 )
 
         # for neighbors
         self._compare_neighbor_lists(
-            want.get("neighbors", {}), have.get("neighbors", {})
+            want.get("neighbors", {}),
+            have.get("neighbors", {}),
         )
 
         # for redistribute
         self._compare_redistribute_lists(
-            want.get("redistribute", {}), have.get("redistribute", {})
+            want.get("redistribute", {}),
+            have.get("redistribute", {}),
         )
 
         # add as_number in the begining fo command set if commands generated
         if len(self.commands) != cmd_len or (not have and want):
             self.commands.insert(
-                0, self._tmplt.render(want or have, "as_number", False)
+                0,
+                self._tmplt.render(want or have, "as_number", False),
             )
 
     def _has_bgp_inject_maps(self, want):
@@ -348,11 +349,11 @@ class Bgp_global(ResourceModule):
                 for k_rmps, w_rmps in want_route.items():
                     have_rmps = have_route.pop(k_rmps, {})
                     w_rmps["neighbor_address"] = w_neighbor.get(
-                        "neighbor_address"
+                        "neighbor_address",
                     )
                     if have_rmps:
                         have_rmps["neighbor_address"] = have_nbr.get(
-                            "neighbor_address"
+                            "neighbor_address",
                         )
                         have_rmps = {"route_maps": have_rmps}
                     self.compare(
@@ -364,8 +365,7 @@ class Bgp_global(ResourceModule):
             self.compare(parsers="neighbor_address", want={}, have=h_neighbor)
 
     def _compare_generic_lists(self, w_attr, h_attr, parser):
-        """Handling of gereric list options.
-        """
+        """Handling of gereric list options."""
         for wkey, wentry in iteritems(w_attr):
             if wentry != h_attr.pop(wkey, {}):
                 self.addcmd(wentry, parser, False)
@@ -406,19 +406,14 @@ class Bgp_global(ResourceModule):
                         neb = self._bgp_global_list_to_dict(neb)
                 tmp_data[k] = {str(i[p_key[k]]): i for i in tmp_data[k]}
             elif tmp_data.get("distributes") and k == "distributes":
-                tmp_data[k] = {
-                    str("".join([i.get(j, "") for j in _v])): i
-                    for i in tmp_data[k]
-                }
+                tmp_data[k] = {str("".join([i.get(j, "") for j in _v])): i for i in tmp_data[k]}
             elif tmp_data.get("redistribute") and k == "redistribute":
                 tmp_data[k] = {
                     str(
                         [
-                            ky + vl.get("name", "") + vl.get("process_id", "")
-                            if ky in _v
-                            else ky
+                            ky + vl.get("name", "") + vl.get("process_id", "") if ky in _v else ky
                             for ky, vl in i.items()
-                        ][0]
+                        ][0],
                     ): i
                     for i in tmp_data[k]
                 }
@@ -447,11 +442,11 @@ class Bgp_global(ResourceModule):
             if want.get("aggregate_address"):
                 if want.get("aggregate_addresses"):
                     want["aggregate_addresses"].append(
-                        want.pop("aggregate_address")
+                        want.pop("aggregate_address"),
                     )
                 else:
                     want["aggregate_addresses"] = [
-                        want.pop("aggregate_address")
+                        want.pop("aggregate_address"),
                     ]
             if want.get("bgp"):
                 _want_bgp = want.get("bgp", {})
@@ -468,32 +463,24 @@ class Bgp_global(ResourceModule):
                 if _want_bgp.get("inject_map"):
                     if _want_bgp.get("inject_maps"):
                         _want_bgp["inject_maps"].append(
-                            _want_bgp.pop("inject_map")
+                            _want_bgp.pop("inject_map"),
                         )
                     else:
                         _want_bgp["inject_maps"] = [
-                            _want_bgp.pop("inject_map")
+                            _want_bgp.pop("inject_map"),
                         ]
                 if _want_bgp.get("listen", {}).get("range"):
-                    if (
-                        _want_bgp.get("listen")
-                        .get("range")
-                        .get("ipv4_with_subnet")
-                    ):
-                        _want_bgp["listen"]["range"][
-                            "host_with_subnet"
-                        ] = _want_bgp["listen"]["range"].pop(
-                            "ipv4_with_subnet"
+                    if _want_bgp.get("listen").get("range").get("ipv4_with_subnet"):
+                        _want_bgp["listen"]["range"]["host_with_subnet"] = _want_bgp["listen"][
+                            "range"
+                        ].pop(
+                            "ipv4_with_subnet",
                         )
-                    elif (
-                        _want_bgp.get("listen")
-                        .get("range")
-                        .get("ipv6_with_subnet")
-                    ):
-                        _want_bgp["listen"]["range"][
-                            "host_with_subnet"
-                        ] = _want_bgp["listen"]["range"].pop(
-                            "ipv6_with_subnet"
+                    elif _want_bgp.get("listen").get("range").get("ipv6_with_subnet"):
+                        _want_bgp["listen"]["range"]["host_with_subnet"] = _want_bgp["listen"][
+                            "range"
+                        ].pop(
+                            "ipv6_with_subnet",
                         )
             if want.get("distribute_list"):
                 if want.get("distributes"):
