@@ -12,6 +12,7 @@ created
 
 from __future__ import absolute_import, division, print_function
 
+
 __metaclass__ = type
 
 
@@ -19,21 +20,17 @@ from ansible_collections.ansible.netcommon.plugins.module_utils.network.common.c
     ConfigBase,
 )
 from ansible_collections.ansible.netcommon.plugins.module_utils.network.common.utils import (
+    remove_empties,
     to_list,
 )
-from ansible_collections.cisco.ios.plugins.module_utils.network.ios.facts.facts import (
-    Facts,
-)
+
+from ansible_collections.cisco.ios.plugins.module_utils.network.ios.facts.facts import Facts
 from ansible_collections.cisco.ios.plugins.module_utils.network.ios.utils.utils import (
-    dict_to_set,
-    normalize_interface,
-)
-from ansible_collections.cisco.ios.plugins.module_utils.network.ios.utils.utils import (
-    remove_command_from_config_list,
     add_command_to_config_list,
-)
-from ansible_collections.cisco.ios.plugins.module_utils.network.ios.utils.utils import (
+    dict_to_set,
     filter_dict_having_none_value,
+    normalize_interface,
+    remove_command_from_config_list,
     remove_duplicate_interface,
 )
 
@@ -59,15 +56,17 @@ class L2_Interfaces(ConfigBase):
     }
 
     def get_l2_interfaces_facts(self, data=None):
-        """ Get the 'facts' (the current configuration)
+        """Get the 'facts' (the current configuration)
         :rtype: A dictionary
         :returns: The current configuration as a dictionary
         """
         facts, _warnings = Facts(self._module).get_facts(
-            self.gather_subset, self.gather_network_resources, data=data
+            self.gather_subset,
+            self.gather_network_resources,
+            data=data,
         )
         l2_interfaces_facts = facts["ansible_network_resources"].get(
-            "l2_interfaces"
+            "l2_interfaces",
         )
         if not l2_interfaces_facts:
             return []
@@ -75,7 +74,7 @@ class L2_Interfaces(ConfigBase):
         return l2_interfaces_facts
 
     def execute_module(self):
-        """ Execute the module
+        """Execute the module
         :rtype: A dictionary
         :returns: The result from module execution
         """
@@ -104,10 +103,10 @@ class L2_Interfaces(ConfigBase):
             running_config = self._module.params["running_config"]
             if not running_config:
                 self._module.fail_json(
-                    msg="value of running_config parameter must not be empty for state parsed"
+                    msg="value of running_config parameter must not be empty for state parsed",
                 )
             result["parsed"] = self.get_l2_interfaces_facts(
-                data=running_config
+                data=running_config,
             )
         else:
             changed_l2_interfaces_facts = []
@@ -123,7 +122,7 @@ class L2_Interfaces(ConfigBase):
         return result
 
     def set_config(self, existing_facts):
-        """ Collect the configuration from the args passed to the module,
+        """Collect the configuration from the args passed to the module,
             collect the current configuration (as a dict from facts)
         :rtype: A list
         :returns: the commands necessary to migrate the current configuration
@@ -142,7 +141,7 @@ class L2_Interfaces(ConfigBase):
         return to_list(resp)
 
     def set_state(self, want, have):
-        """ Select the appropriate function based on the state provided
+        """Select the appropriate function based on the state provided
         :param want: the desired configuration as a dictionary
         :param have: the current configuration as a dictionary
         :rtype: A list
@@ -151,16 +150,18 @@ class L2_Interfaces(ConfigBase):
         """
         commands = []
 
-        if (
-            self.state in ("overridden", "merged", "replaced", "rendered")
-            and not want
-        ):
+        if self.state in ("overridden", "merged", "replaced", "rendered") and not want:
             self._module.fail_json(
                 msg="value of config parameter must not be empty for state {0}".format(
-                    self.state
-                )
+                    self.state,
+                ),
             )
-
+        if want:
+            for each in want:
+                if each.get("access"):
+                    each["access"] = remove_empties(each.get("access"))
+                if each.get("voice"):
+                    each["voice"] = remove_empties(each.get("voice"))
         if self.state == "overridden":
             commands = self._state_overridden(want, have, self._module)
         elif self.state == "deleted":
@@ -173,7 +174,7 @@ class L2_Interfaces(ConfigBase):
         return commands
 
     def _state_replaced(self, want, have, module):
-        """ The command generator when state is replaced
+        """The command generator when state is replaced
         :param want: the desired configuration as a dictionary
         :param have: the current configuration as a dictionary
         :param interface_type: interface type
@@ -198,7 +199,7 @@ class L2_Interfaces(ConfigBase):
         return commands
 
     def _state_overridden(self, want, have, module):
-        """ The command generator when state is overridden
+        """The command generator when state is overridden
         :param want: the desired configuration as a dictionary
         :param obj_in_have: the current configuration as a dictionary
         :rtype: A list
@@ -227,7 +228,7 @@ class L2_Interfaces(ConfigBase):
         return commands
 
     def _state_merged(self, want, have, module):
-        """ The command generator when state is merged
+        """The command generator when state is merged
         :param want: the additive configuration as a dictionary
         :param obj_in_have: the current configuration as a dictionary
         :rtype: A list
@@ -249,7 +250,7 @@ class L2_Interfaces(ConfigBase):
         return commands
 
     def _state_deleted(self, want, have):
-        """ The command generator when state is deleted
+        """The command generator when state is deleted
         :param want: the objects from which the configuration should be removed
         :param obj_in_have: the current configuration as a dictionary
         :param interface_type: interface type
@@ -285,7 +286,7 @@ class L2_Interfaces(ConfigBase):
                 else:
                     module.fail_json(
                         msg="Command rejected: Bad VLAN list - end of range not larger than the"
-                        " start of range!"
+                        " start of range!",
                     )
             else:
                 return True
@@ -313,16 +314,14 @@ class L2_Interfaces(ConfigBase):
         if have.get("trunk") and want.get("trunk"):
             for each in ["allowed_vlans", "pruning_vlans"]:
                 if have["trunk"].get(each) and want["trunk"].get(each):
-                    check, want["trunk"][
-                        each
-                    ] = self._expand_vlan_range_if_any(
-                        "want", want["trunk"][each]
+                    (check, want["trunk"][each]) = self._expand_vlan_range_if_any(
+                        "want",
+                        want["trunk"][each],
                     )
                     if not check:
-                        check, have["trunk"][
-                            each
-                        ] = self._expand_vlan_range_if_any(
-                            "have", have["trunk"][each]
+                        (check, have["trunk"][each]) = self._expand_vlan_range_if_any(
+                            "have",
+                            have["trunk"][each],
                         )
 
         # Get the diff b/w want and have
@@ -333,7 +332,7 @@ class L2_Interfaces(ConfigBase):
         have_trunk = dict(have_dict).get("trunk")
         if want_trunk and have_trunk:
             diff = set(tuple(dict(want_dict).get("trunk"))) - set(
-                tuple(dict(have_dict).get("trunk"))
+                tuple(dict(have_dict).get("trunk")),
             )
             _want_dict = dict(want_dict)
             _have_dict = dict(have_dict)
@@ -354,13 +353,21 @@ class L2_Interfaces(ConfigBase):
             trunk = diff.get("trunk")
 
             if access:
-                cmd = "switchport access vlan {0}".format(access[0][1])
+                if access[0][0] == "vlan":
+                    cmd = "switchport access vlan {0}".format(access[0][1])
+                if access[0][0] == "vlan_name":
+                    cmd = "switchport access vlan name {0}".format(access[0][1])
                 add_command_to_config_list(interface, cmd, commands)
 
             if diff.get("voice"):
-                cmd = "switchport voice vlan {0}".format(
-                    diff.get("voice")[0][1]
-                )
+                if diff.get("voice")[0][0] == "vlan" or diff.get("voice")[0][0] == "vlan_tag":
+                    cmd = "switchport voice vlan {0}".format(
+                        diff.get("voice")[0][1],
+                    )
+                if diff.get("voice")[0][0] == "vlan_name":
+                    cmd = "switchport voice vlan name {0}".format(
+                        diff.get("voice")[0][1],
+                    )
                 add_command_to_config_list(interface, cmd, commands)
 
             if want_trunk:
@@ -368,30 +375,31 @@ class L2_Interfaces(ConfigBase):
                     diff = dict(trunk)
                 if diff.get("encapsulation"):
                     cmd = self.trunk_cmds["encapsulation"] + " {0}".format(
-                        diff.get("encapsulation")
+                        diff.get("encapsulation"),
                     )
                     add_command_to_config_list(interface, cmd, commands)
                 if diff.get("native_vlan"):
                     cmd = self.trunk_cmds["native_vlan"] + " {0}".format(
-                        diff.get("native_vlan")
+                        diff.get("native_vlan"),
                     )
                     add_command_to_config_list(interface, cmd, commands)
                 allowed_vlans = diff.get("allowed_vlans")
                 pruning_vlans = diff.get("pruning_vlans")
 
                 if allowed_vlans and self._check_for_correct_vlan_range(
-                    allowed_vlans, module
+                    allowed_vlans,
+                    module,
                 ):
                     diff = None
                     if self.state == "merged":
                         have_trunk = have.get("trunk")
                         if have_trunk and have_trunk.get("allowed_vlans"):
                             have_allowed_vlans = have_trunk.get(
-                                "allowed_vlans"
+                                "allowed_vlans",
                             )
                             allowed_vlans = list(allowed_vlans)
                             diff = set(allowed_vlans).difference(
-                                set(have_allowed_vlans)
+                                set(have_allowed_vlans),
                             )
                             allowed_vlans = list(diff) if diff else tuple()
                     allowed_vlans = ",".join(allowed_vlans)
@@ -404,18 +412,19 @@ class L2_Interfaces(ConfigBase):
                         cmd = trunk_cmd + " {0}".format(allowed_vlans)
                         add_command_to_config_list(interface, cmd, commands)
                 if pruning_vlans and self._check_for_correct_vlan_range(
-                    pruning_vlans, module
+                    pruning_vlans,
+                    module,
                 ):
                     diff = None
                     if self.state == "merged":
                         have_trunk = have.get("trunk")
                         if have_trunk and have_trunk.get("pruning_vlans"):
                             have_pruning_vlans = have_trunk.get(
-                                "pruning_vlans"
+                                "pruning_vlans",
                             )
                             pruning_vlans = list(pruning_vlans)
                             diff = set(pruning_vlans).difference(
-                                set(have_pruning_vlans)
+                                set(have_pruning_vlans),
                             )
                             pruning_vlans = list(diff) if diff else tuple()
                     pruning_vlans = ",".join(pruning_vlans)
@@ -443,16 +452,20 @@ class L2_Interfaces(ConfigBase):
 
         if have.get("mode") or want.get("mode"):
             remove_command_from_config_list(
-                interface, "switchport mode", commands
+                interface,
+                "switchport mode",
+                commands,
             )
 
         if have.get("access") and want.get("access") is None:
             remove_command_from_config_list(
-                interface, L2_Interfaces.access_cmds["access_vlan"], commands
+                interface,
+                L2_Interfaces.access_cmds["access_vlan"],
+                commands,
             )
         elif have.get("access") and want.get("access"):
             if have.get("access").get("vlan") != want.get("access").get(
-                "vlan"
+                "vlan",
             ):
                 remove_command_from_config_list(
                     interface,
@@ -462,57 +475,77 @@ class L2_Interfaces(ConfigBase):
 
         if have.get("voice") and want.get("voice") is None:
             remove_command_from_config_list(
-                interface, L2_Interfaces.voice_cmds["voice_vlan"], commands
+                interface,
+                L2_Interfaces.voice_cmds["voice_vlan"],
+                commands,
             )
         elif have.get("voice") and want.get("voice"):
             if have.get("voice").get("vlan") != want.get("voice").get("vlan"):
                 remove_command_from_config_list(
-                    interface, L2_Interfaces.voice_cmds["voice_vlan"], commands
+                    interface,
+                    L2_Interfaces.voice_cmds["voice_vlan"],
+                    commands,
                 )
 
         if have.get("trunk") and want.get("trunk") is None:
             # Check when no config is passed
             if have.get("trunk").get("encapsulation"):
                 remove_command_from_config_list(
-                    interface, self.trunk_cmds["encapsulation"], commands
+                    interface,
+                    self.trunk_cmds["encapsulation"],
+                    commands,
                 )
             if have.get("trunk").get("native_vlan"):
                 remove_command_from_config_list(
-                    interface, self.trunk_cmds["native_vlan"], commands
+                    interface,
+                    self.trunk_cmds["native_vlan"],
+                    commands,
                 )
             if have.get("trunk").get("allowed_vlans"):
                 remove_command_from_config_list(
-                    interface, self.trunk_cmds["allowed_vlans"], commands
+                    interface,
+                    self.trunk_cmds["allowed_vlans"],
+                    commands,
                 )
             if have.get("trunk").get("pruning_vlans"):
                 remove_command_from_config_list(
-                    interface, self.trunk_cmds["pruning_vlans"], commands
+                    interface,
+                    self.trunk_cmds["pruning_vlans"],
+                    commands,
                 )
         elif have.get("trunk") and want.get("trunk"):
             # Check when config is passed, also used in replaced and override state
-            if have.get("trunk").get("encapsulation") and have.get(
-                "trunk"
-            ).get("encapsulation") != want.get("trunk").get("encapsulation"):
+            if have.get("trunk").get("encapsulation") and have.get("trunk").get(
+                "encapsulation",
+            ) != want.get("trunk").get("encapsulation"):
                 remove_command_from_config_list(
-                    interface, self.trunk_cmds["encapsulation"], commands
+                    interface,
+                    self.trunk_cmds["encapsulation"],
+                    commands,
                 )
             if have.get("trunk").get("native_vlan") and have.get("trunk").get(
-                "native_vlan"
+                "native_vlan",
             ) != want.get("trunk").get("native_vlan"):
                 remove_command_from_config_list(
-                    interface, self.trunk_cmds["native_vlan"], commands
+                    interface,
+                    self.trunk_cmds["native_vlan"],
+                    commands,
                 )
-            if have.get("trunk").get("allowed_vlans") and have.get(
-                "trunk"
-            ).get("allowed_vlans") != want.get("trunk").get("allowed_vlans"):
+            if have.get("trunk").get("allowed_vlans") and have.get("trunk").get(
+                "allowed_vlans",
+            ) != want.get("trunk").get("allowed_vlans"):
                 remove_command_from_config_list(
-                    interface, self.trunk_cmds["allowed_vlans"], commands
+                    interface,
+                    self.trunk_cmds["allowed_vlans"],
+                    commands,
                 )
-            if have.get("trunk").get("pruning_vlans") and have.get(
-                "trunk"
-            ).get("pruning_vlans") != want.get("trunk").get("pruning_vlans"):
+            if have.get("trunk").get("pruning_vlans") and have.get("trunk").get(
+                "pruning_vlans",
+            ) != want.get("trunk").get("pruning_vlans"):
                 remove_command_from_config_list(
-                    interface, self.trunk_cmds["pruning_vlans"], commands
+                    interface,
+                    self.trunk_cmds["pruning_vlans"],
+                    commands,
                 )
 
         return commands
