@@ -7,6 +7,7 @@
 
 from __future__ import absolute_import, division, print_function
 
+
 __metaclass__ = type
 
 """
@@ -21,12 +22,11 @@ from ansible.module_utils.six import iteritems
 from ansible_collections.ansible.netcommon.plugins.module_utils.network.common.resource_module import (
     ResourceModule,
 )
-from ansible_collections.cisco.ios.plugins.module_utils.network.ios.facts.facts import (
-    Facts,
-)
 from ansible_collections.ansible.netcommon.plugins.module_utils.network.common.utils import (
     dict_merge,
 )
+
+from ansible_collections.cisco.ios.plugins.module_utils.network.ios.facts.facts import Facts
 from ansible_collections.cisco.ios.plugins.module_utils.network.ios.rm_templates.route_maps import (
     Route_mapsTemplate,
 )
@@ -49,7 +49,7 @@ class Route_maps(ResourceModule):
         )
 
     def execute_module(self):
-        """ Execute the module
+        """Execute the module
 
         :rtype: A dictionary
         :returns: The result from module execution
@@ -60,8 +60,8 @@ class Route_maps(ResourceModule):
         return self.result
 
     def generate_commands(self):
-        """ Generate configuration commands to send based on
-            want, have and desired state.
+        """Generate configuration commands to send based on
+        want, have and desired state.
         """
 
         if self.want:
@@ -83,9 +83,7 @@ class Route_maps(ResourceModule):
 
         # if state is deleted, empty out wantd and set haved to wantd
         if self.state == "deleted":
-            haved = {
-                k: v for k, v in iteritems(haved) if k in wantd or not wantd
-            }
+            haved = {k: v for k, v in iteritems(haved) if k in wantd or not wantd}
             wantd = {}
 
         # remove superfluous config for overridden and deleted
@@ -100,9 +98,9 @@ class Route_maps(ResourceModule):
 
     def _compare(self, want, have):
         """Leverages the base class `compare()` method and
-           populates the list of commands to be run by comparing
-           the `want` and `have` data with the `parsers` defined
-           for the Route_maps network resource.
+        populates the list of commands to be run by comparing
+        the `want` and `have` data with the `parsers` defined
+        for the Route_maps network resource.
         """
         if want != have and self.state != "deleted":
             self.entries_compare(want, have)
@@ -117,10 +115,7 @@ class Route_maps(ResourceModule):
                         # description gets merged with existing description, so explicit delete is required
                         # replaced and overridden state
                         if (
-                            (
-                                self.state == "replaced"
-                                or self.state == "overridden"
-                            )
+                            (self.state == "replaced" or self.state == "overridden")
                             and have_entry.get("description")
                             and have_entry.get("description")
                             != want["entries"][k].get("description")
@@ -139,32 +134,36 @@ class Route_maps(ResourceModule):
                         want_match = v.get("match")
                         if have_match and want_match:
                             self.list_type_compare(
-                                "match", want=want_match, have=have_match
+                                "match",
+                                want=want_match,
+                                have=have_match,
                             )
                         elif not have_match and want_match:
                             self.list_type_compare(
-                                "match", want=want_match, have=dict()
+                                "match",
+                                want=want_match,
+                                have=dict(),
                             )
                         have_set = have_entry.get("set")
                         want_set = v.get("set")
                         if have_set and want_set:
                             self.list_type_compare(
-                                "set", want=want_set, have=have_set
+                                "set",
+                                want=want_set,
+                                have=have_set,
                             )
                         elif not have_set and want_set:
                             self.list_type_compare(
-                                "set", want=want_set, have=dict()
+                                "set",
+                                want=want_set,
+                                have=dict(),
                             )
                     if cmd_len != len(self.commands):
                         route_map_cmd = "route-map {route_map}".format(**want)
                         if want["entries"][k].get("action"):
-                            route_map_cmd += " {action}".format(
-                                **want["entries"][k]
-                            )
+                            route_map_cmd += " {action}".format(**want["entries"][k])
                         if want["entries"][k].get("sequence"):
-                            route_map_cmd += " {sequence}".format(
-                                **want["entries"][k]
-                            )
+                            route_map_cmd += " {sequence}".format(**want["entries"][k])
                         self.commands.insert(cmd_len, route_map_cmd)
                         cmd_len = len(self.commands)
             else:
@@ -177,28 +176,26 @@ class Route_maps(ResourceModule):
                     want_match = v.get("match")
                     if want_match:
                         self.list_type_compare(
-                            "match", want=want_match, have=dict()
+                            "match",
+                            want=want_match,
+                            have=dict(),
                         )
                     want_set = v.get("set")
                     if want_set:
                         self.list_type_compare(
-                            "set", want=want_set, have=dict()
+                            "set",
+                            want=want_set,
+                            have=dict(),
                         )
                     if cmd_len != len(self.commands):
                         route_map_cmd = "route-map {route_map}".format(**want)
                         if want["entries"][k].get("action"):
-                            route_map_cmd += " {action}".format(
-                                **want["entries"][k]
-                            )
+                            route_map_cmd += " {action}".format(**want["entries"][k])
                         if want["entries"][k].get("sequence"):
-                            route_map_cmd += " {sequence}".format(
-                                **want["entries"][k]
-                            )
+                            route_map_cmd += " {sequence}".format(**want["entries"][k])
                         self.commands.insert(cmd_len, route_map_cmd)
                         cmd_len = len(self.commands)
-        if (
-            self.state == "replaced" or self.state == "overridden"
-        ) and have.get("entries"):
+        if (self.state == "replaced" or self.state == "overridden") and have.get("entries"):
             cmd_len = len(self.commands)
             for k, v in iteritems(have["entries"]):
                 route_map_cmd = "no route-map {route_map}".format(**have)
@@ -234,10 +231,7 @@ class Route_maps(ResourceModule):
                     have_val = have_v.pop(key, {})
                     if val != have_val:
                         if have_val:
-                            if (
-                                self.state == "overridden"
-                                or self.state == "replaced"
-                            ):
+                            if self.state == "overridden" or self.state == "replaced":
                                 self.compare(
                                     parsers=parsers,
                                     want=dict(),
@@ -254,9 +248,7 @@ class Route_maps(ResourceModule):
                                 want={compare_type: {k: {key: val}}},
                                 have=dict(),
                             )
-                if (
-                    self.state == "overridden" or self.state == "replaced"
-                ) and have_v:
+                if (self.state == "overridden" or self.state == "replaced") and have_v:
                     for key, val in iteritems(have_v):
                         self.compare(
                             parsers=parsers,
@@ -296,24 +288,28 @@ class Route_maps(ResourceModule):
                         match = every.get("match")
                         if match:
                             if match.get("as_path") and match.get(
-                                "as_path"
+                                "as_path",
                             ).get("acls"):
                                 match["as_path"]["acls"] = convert_to_dict(
-                                    match["as_path"]["acls"], "acl"
+                                    match["as_path"]["acls"],
+                                    "acl",
                                 )
                             if match.get("community") and match.get(
-                                "community"
+                                "community",
                             ).get("name"):
                                 match["community"]["name"] = convert_to_dict(
-                                    match["community"]["name"], "name"
+                                    match["community"]["name"],
+                                    "name",
                                 )
                             if match.get("extcommunity"):
                                 match["extcommunity"] = convert_to_dict(
-                                    match["extcommunity"], "num"
+                                    match["extcommunity"],
+                                    "num",
                                 )
                             if match.get("interfaces"):
                                 match["interfaces"] = convert_to_dict(
-                                    match["interfaces"], "interface"
+                                    match["interfaces"],
+                                    "interface",
                                 )
                             if match.get("ip"):
                                 for each_ip_param in [
@@ -325,67 +321,59 @@ class Route_maps(ResourceModule):
                                 ]:
                                     if match["ip"].get(each_ip_param):
                                         if match["ip"][each_ip_param].get(
-                                            "acls"
+                                            "acls",
                                         ):
-                                            match["ip"][each_ip_param][
-                                                "acls"
-                                            ] = convert_to_dict(
-                                                match["ip"][each_ip_param][
-                                                    "acls"
-                                                ],
+                                            match["ip"][each_ip_param]["acls"] = convert_to_dict(
+                                                match["ip"][each_ip_param]["acls"],
                                                 "acl",
                                             )
                                         elif match["ip"][each_ip_param].get(
-                                            "prefix_lists"
+                                            "prefix_lists",
                                         ):
                                             match["ip"][each_ip_param][
                                                 "prefix_lists"
                                             ] = convert_to_dict(
-                                                match["ip"][each_ip_param][
-                                                    "prefix_lists"
-                                                ],
+                                                match["ip"][each_ip_param]["prefix_lists"],
                                                 "prefix_list",
                                             )
                             if match.get("local_preference") and match.get(
-                                "local_preference"
+                                "local_preference",
                             ).get("value"):
-                                match["local_preference"][
-                                    "value"
-                                ] = convert_to_dict(
-                                    match["local_preference"]["value"], "value"
+                                match["local_preference"]["value"] = convert_to_dict(
+                                    match["local_preference"]["value"],
+                                    "value",
                                 )
                             if match.get("mdt_group") and match.get(
-                                "mdt_group"
+                                "mdt_group",
                             ).get("acls"):
                                 match["mdt_group"]["acls"] = convert_to_dict(
-                                    match["mdt_group"]["acls"], "acl"
+                                    match["mdt_group"]["acls"],
+                                    "acl",
                                 )
                             if match.get("policy_lists"):
                                 match["policy_lists"] = convert_to_dict(
-                                    match["policy_lists"], "policy"
+                                    match["policy_lists"],
+                                    "policy",
                                 )
                             if match.get("security_group"):
                                 for each_sg_param in ["source", "destination"]:
                                     if match.get("security_group").get(
-                                        each_sg_param
+                                        each_sg_param,
                                     ):
-                                        match["security_group"][
-                                            each_sg_param
-                                        ] = convert_to_dict(
-                                            match["security_group"][
-                                                each_sg_param
-                                            ],
+                                        match["security_group"][each_sg_param] = convert_to_dict(
+                                            match["security_group"][each_sg_param],
                                             each_sg_param,
                                         )
                         set = every.get("set")
                         if set:
                             if set.get("interfaces"):
                                 set["interfaces"] = convert_to_dict(
-                                    set["interfaces"], "interface"
+                                    set["interfaces"],
+                                    "interface",
                                 )
                         action = every.get("action")
                         sequence = every.get("sequence")
                         temp_entries.update(
-                            {action + "_" + str(sequence): every}
+                            {action + "_" + str(sequence): every},
                         )
                     val["entries"] = temp_entries
