@@ -12,27 +12,27 @@ based on the configuration.
 
 from __future__ import absolute_import, division, print_function
 
+
 __metaclass__ = type
 
 import re
+
 from ansible.module_utils.six import iteritems
-from ansible_collections.ansible.netcommon.plugins.module_utils.network.common import (
-    utils,
+from ansible_collections.ansible.netcommon.plugins.module_utils.network.common import utils
+from ansible_collections.ansible.netcommon.plugins.module_utils.network.common.network_template import (
+    NetworkTemplate,
 )
+
 from ansible_collections.cisco.ios.plugins.module_utils.network.ios.argspec.acls.acls import (
     AclsArgs,
 )
 from ansible_collections.cisco.ios.plugins.module_utils.network.ios.rm_templates.acls import (
     AclsTemplate,
 )
-from ansible_collections.ansible.netcommon.plugins.module_utils.network.common.network_template import (
-    NetworkTemplate,
-)
 
 
 class AclsFacts(object):
-    """ The ios_acls fact class
-    """
+    """The ios_acls fact class"""
 
     def __init__(self, module, subspec="config", options="options"):
 
@@ -46,16 +46,17 @@ class AclsFacts(object):
         # and incomplete ACLs are not viewed correctly
         _acl_data = connection.get("show access-list")
         _remarks_data = connection.get(
-            "show running-config | include ip(v6)* access-list|remark"
+            "show running-config | include ip(v6)* access-list|remark",
         )
         if _remarks_data:
             _acl_data += "\n" + _remarks_data
         return _acl_data
 
     def sanitize_data(self, data):
+        """removes matches or extra config info that is added on acl match"""
         re_data = ""
         for da in data.split("\n"):
-            if "matches" in da:
+            if "match" in da:
                 mod_da = re.sub(r"\([^()]*\)", "", da)
                 re_data += mod_da[:-1] + "\n"
             else:
@@ -63,7 +64,7 @@ class AclsFacts(object):
         return re_data
 
     def populate_facts(self, connection, ansible_facts, data=None):
-        """ Populate the facts for acls
+        """Populate the facts for acls
         :param connection: the device connection
         :param ansible_facts: Facts dictionary
         :param data: previously collected conf
@@ -101,6 +102,11 @@ class AclsFacts(object):
             def process_protocol_options(each):
                 for each_ace in each.get("aces"):
                     if each_ace.get("source"):
+                        if len(each_ace.get("source")) == 1 and each_ace.get(
+                            "source",
+                            {},
+                        ).get("address"):
+                            each_ace["source"]["host"] = each_ace["source"].pop("address")
                         if each_ace.get("source", {}).get("address"):
                             addr = each_ace.get("source", {}).get("address")
                             if addr[-1] == ",":
@@ -109,23 +115,37 @@ class AclsFacts(object):
                         each_ace["protocol_options"] = {
                             each_ace["protocol"]: {
                                 each_ace.pop("icmp_igmp_tcp_protocol").replace(
-                                    "-", "_"
-                                ): True
-                            }
+                                    "-",
+                                    "_",
+                                ): True,
+                            },
                         }
                     if each_ace.get("protocol_number"):
                         each_ace["protocol_options"] = {
-                            "protocol_number": each_ace.pop("protocol_number")
+                            "protocol_number": each_ace.pop("protocol_number"),
                         }
 
+            def collect_remarks(aces):
+                """makes remarks list per ace"""
+                ace_entry = []
+                rem = []
+                for i in aces:
+                    if i.get("remarks"):
+                        rem.append(i.pop("remarks"))
+                    else:
+                        ace_entry.append(i)
+                if rem:
+                    ace_entry.append({"remarks": rem})
+                return ace_entry
+
             for each in temp_v4:
-                aces_ipv4 = each.get("aces")
-                if aces_ipv4:
+                if each.get("aces"):
+                    each["aces"] = collect_remarks(each.get("aces"))
                     process_protocol_options(each)
 
             for each in temp_v6:
-                aces_ipv6 = each.get("aces")
-                if aces_ipv6:
+                if each.get("aces"):
+                    each["aces"] = collect_remarks(each.get("aces"))
                     process_protocol_options(each)
 
         objs = []
@@ -138,7 +158,8 @@ class AclsFacts(object):
         if objs:
             facts["acls"] = []
             params = utils.validate_config(
-                self.argument_spec, {"config": objs}
+                self.argument_spec,
+                {"config": objs},
             )
             for cfg in params["config"]:
                 facts["acls"].append(utils.remove_empties(cfg))
