@@ -11,29 +11,48 @@ calls the appropriate facts gathering function
 
 from __future__ import absolute_import, division, print_function
 
+
 __metaclass__ = type
 
 
 from ansible_collections.ansible.netcommon.plugins.module_utils.network.common.facts.facts import (
     FactsBase,
 )
+
+from ansible_collections.cisco.ios.plugins.module_utils.network.ios.facts.acl_interfaces.acl_interfaces import (
+    Acl_interfacesFacts,
+)
+from ansible_collections.cisco.ios.plugins.module_utils.network.ios.facts.acls.acls import AclsFacts
+from ansible_collections.cisco.ios.plugins.module_utils.network.ios.facts.bgp_address_family.bgp_address_family import (
+    Bgp_address_familyFacts,
+)
+from ansible_collections.cisco.ios.plugins.module_utils.network.ios.facts.bgp_global.bgp_global import (
+    Bgp_globalFacts,
+)
+from ansible_collections.cisco.ios.plugins.module_utils.network.ios.facts.hostname.hostname import (
+    HostnameFacts,
+)
 from ansible_collections.cisco.ios.plugins.module_utils.network.ios.facts.interfaces.interfaces import (
     InterfacesFacts,
 )
 from ansible_collections.cisco.ios.plugins.module_utils.network.ios.facts.l2_interfaces.l2_interfaces import (
     L2_InterfacesFacts,
 )
-from ansible_collections.cisco.ios.plugins.module_utils.network.ios.facts.vlans.vlans import (
-    VlansFacts,
+from ansible_collections.cisco.ios.plugins.module_utils.network.ios.facts.l3_interfaces.l3_interfaces import (
+    L3_InterfacesFacts,
+)
+from ansible_collections.cisco.ios.plugins.module_utils.network.ios.facts.lacp.lacp import LacpFacts
+from ansible_collections.cisco.ios.plugins.module_utils.network.ios.facts.lacp_interfaces.lacp_interfaces import (
+    Lacp_InterfacesFacts,
 )
 from ansible_collections.cisco.ios.plugins.module_utils.network.ios.facts.lag_interfaces.lag_interfaces import (
     Lag_interfacesFacts,
 )
-from ansible_collections.cisco.ios.plugins.module_utils.network.ios.facts.lacp.lacp import (
-    LacpFacts,
-)
-from ansible_collections.cisco.ios.plugins.module_utils.network.ios.facts.lacp_interfaces.lacp_interfaces import (
-    Lacp_InterfacesFacts,
+from ansible_collections.cisco.ios.plugins.module_utils.network.ios.facts.legacy.base import (
+    Config,
+    Default,
+    Hardware,
+    Interfaces,
 )
 from ansible_collections.cisco.ios.plugins.module_utils.network.ios.facts.lldp_global.lldp_global import (
     Lldp_globalFacts,
@@ -41,17 +60,14 @@ from ansible_collections.cisco.ios.plugins.module_utils.network.ios.facts.lldp_g
 from ansible_collections.cisco.ios.plugins.module_utils.network.ios.facts.lldp_interfaces.lldp_interfaces import (
     Lldp_InterfacesFacts,
 )
-from ansible_collections.cisco.ios.plugins.module_utils.network.ios.facts.l3_interfaces.l3_interfaces import (
-    L3_InterfacesFacts,
+from ansible_collections.cisco.ios.plugins.module_utils.network.ios.facts.logging_global.logging_global import (
+    Logging_globalFacts,
 )
-from ansible_collections.cisco.ios.plugins.module_utils.network.ios.facts.acl_interfaces.acl_interfaces import (
-    Acl_InterfacesFacts,
+from ansible_collections.cisco.ios.plugins.module_utils.network.ios.facts.ntp_global.ntp_global import (
+    Ntp_globalFacts,
 )
-from ansible_collections.cisco.ios.plugins.module_utils.network.ios.facts.static_routes.static_routes import (
-    Static_RoutesFacts,
-)
-from ansible_collections.cisco.ios.plugins.module_utils.network.ios.facts.acls.acls import (
-    AclsFacts,
+from ansible_collections.cisco.ios.plugins.module_utils.network.ios.facts.ospf_interfaces.ospf_interfaces import (
+    Ospf_InterfacesFacts,
 )
 from ansible_collections.cisco.ios.plugins.module_utils.network.ios.facts.ospfv2.ospfv2 import (
     Ospfv2Facts,
@@ -59,43 +75,28 @@ from ansible_collections.cisco.ios.plugins.module_utils.network.ios.facts.ospfv2
 from ansible_collections.cisco.ios.plugins.module_utils.network.ios.facts.ospfv3.ospfv3 import (
     Ospfv3Facts,
 )
-from ansible_collections.cisco.ios.plugins.module_utils.network.ios.facts.ospf_interfaces.ospf_interfaces import (
-    Ospf_InterfacesFacts,
-)
-from ansible_collections.cisco.ios.plugins.module_utils.network.ios.facts.bgp_global.bgp_global import (
-    Bgp_globalFacts,
-)
-from ansible_collections.cisco.ios.plugins.module_utils.network.ios.facts.bgp_address_family.bgp_address_family import (
-    Bgp_address_familyFacts,
-)
-from ansible_collections.cisco.ios.plugins.module_utils.network.ios.facts.logging_global.logging_global import (
-    Logging_globalFacts,
+from ansible_collections.cisco.ios.plugins.module_utils.network.ios.facts.prefix_lists.prefix_lists import (
+    Prefix_listsFacts,
 )
 from ansible_collections.cisco.ios.plugins.module_utils.network.ios.facts.route_maps.route_maps import (
     Route_mapsFacts,
 )
-from ansible_collections.cisco.ios.plugins.module_utils.network.ios.facts.prefix_lists.prefix_lists import (
-    Prefix_listsFacts,
-)
-from ansible_collections.cisco.ios.plugins.module_utils.network.ios.facts.ntp_global.ntp_global import (
-    Ntp_globalFacts,
-)
 from ansible_collections.cisco.ios.plugins.module_utils.network.ios.facts.snmp_server.snmp_server import (
     Snmp_serverFacts,
 )
-from ansible_collections.cisco.ios.plugins.module_utils.network.ios.facts.hostname.hostname import (
-    HostnameFacts,
+from ansible_collections.cisco.ios.plugins.module_utils.network.ios.facts.static_routes.static_routes import (
+    Static_RoutesFacts,
 )
-from ansible_collections.cisco.ios.plugins.module_utils.network.ios.facts.legacy.base import (
-    Default,
-    Hardware,
-    Interfaces,
-    Config,
+from ansible_collections.cisco.ios.plugins.module_utils.network.ios.facts.vlans.vlans import (
+    VlansFacts,
 )
 
 
 FACT_LEGACY_SUBSETS = dict(
-    default=Default, hardware=Hardware, interfaces=Interfaces, config=Config
+    default=Default,
+    hardware=Hardware,
+    interfaces=Interfaces,
+    config=Config,
 )
 
 FACT_RESOURCE_SUBSETS = dict(
@@ -108,7 +109,7 @@ FACT_RESOURCE_SUBSETS = dict(
     lldp_global=Lldp_globalFacts,
     lldp_interfaces=Lldp_InterfacesFacts,
     l3_interfaces=L3_InterfacesFacts,
-    acl_interfaces=Acl_InterfacesFacts,
+    acl_interfaces=Acl_interfacesFacts,
     static_routes=Static_RoutesFacts,
     acls=AclsFacts,
     ospfv2=Ospfv2Facts,
@@ -126,8 +127,7 @@ FACT_RESOURCE_SUBSETS = dict(
 
 
 class Facts(FactsBase):
-    """ The fact class for ios
-    """
+    """The fact class for ios"""
 
     VALID_LEGACY_GATHER_SUBSETS = frozenset(FACT_LEGACY_SUBSETS.keys())
     VALID_RESOURCE_SUBSETS = frozenset(FACT_RESOURCE_SUBSETS.keys())
@@ -136,9 +136,12 @@ class Facts(FactsBase):
         super(Facts, self).__init__(module)
 
     def get_facts(
-        self, legacy_facts_type=None, resource_facts_type=None, data=None
+        self,
+        legacy_facts_type=None,
+        resource_facts_type=None,
+        data=None,
     ):
-        """ Collect the facts for ios
+        """Collect the facts for ios
         :param legacy_facts_type: List of legacy facts types
         :param resource_facts_type: List of resource fact types
         :param data: previously collected conf
@@ -147,12 +150,15 @@ class Facts(FactsBase):
         """
         if self.VALID_RESOURCE_SUBSETS:
             self.get_network_resources_facts(
-                FACT_RESOURCE_SUBSETS, resource_facts_type, data
+                FACT_RESOURCE_SUBSETS,
+                resource_facts_type,
+                data,
             )
 
         if self.VALID_LEGACY_GATHER_SUBSETS:
             self.get_network_legacy_facts(
-                FACT_LEGACY_SUBSETS, legacy_facts_type
+                FACT_LEGACY_SUBSETS,
+                legacy_facts_type,
             )
 
         return self.ansible_facts, self._warnings
