@@ -10,28 +10,29 @@ based on the configuration.
 """
 from __future__ import absolute_import, division, print_function
 
+
 __metaclass__ = type
 
 import re
+
 from copy import deepcopy
+
 from ansible.module_utils.six import iteritems
-from ansible_collections.ansible.netcommon.plugins.module_utils.network.common import (
-    utils,
+from ansible_collections.ansible.netcommon.plugins.module_utils.network.common import utils
+from ansible_collections.ansible.netcommon.plugins.module_utils.network.common.network_template import (
+    NetworkTemplate,
 )
+
 from ansible_collections.cisco.ios.plugins.module_utils.network.ios.argspec.ospfv3.ospfv3 import (
     Ospfv3Args,
 )
 from ansible_collections.cisco.ios.plugins.module_utils.network.ios.rm_templates.ospfv3 import (
     Ospfv3Template,
 )
-from ansible_collections.ansible.netcommon.plugins.module_utils.network.common.network_template import (
-    NetworkTemplate,
-)
 
 
 class Ospfv3Facts(object):
-    """ The ios ospfv3 fact class
-    """
+    """The ios ospfv3 fact class"""
 
     def __init__(self, module, subspec="config", options="options"):
         self._module = module
@@ -41,8 +42,7 @@ class Ospfv3Facts(object):
         return connection.get("show running-config | section ^router ospfv3")
 
     def parse(self, net_template_obj):
-        """ Overrided network template parse
-        """
+        """Overrided network template parse"""
         result = {}
         shared = {}
         temp_pid = None
@@ -58,25 +58,20 @@ class Ospfv3Facts(object):
                     capdict = temp
                     if "address-family" in line:
                         capdict.update({"id": temp_pid})
-                    if (
-                        "manet" in line
-                        and "pid" not in shared
-                        and shared.get("unicast")
-                    ):
+                    if "manet" in line and "pid" not in shared and shared.get("unicast"):
                         del shared["unicast"]
 
                     if "router ospfv3" in line:
                         temp_pid = None
                     if parser.get("shared"):
                         shared = capdict
-                    if not temp_pid and (
-                        shared.get("pid") or shared.get("id")
-                    ):
+                    if not temp_pid and (shared.get("pid") or shared.get("id")):
                         temp_pid = shared.get("pid") or shared.get("id")
                     vals = utils.dict_merge(capdict, shared)
                     try:
                         res = net_template_obj._deepformat(
-                            deepcopy(parser["result"]), vals
+                            deepcopy(parser["result"]),
+                            vals,
                         )
                     except Exception:
                         continue
@@ -85,8 +80,7 @@ class Ospfv3Facts(object):
         return result
 
     def parse_for_address_family(self, current):
-        """ Parsing and Fishing out address family contents
-        """
+        """Parsing and Fishing out address family contents"""
         pid_addr_family_dict = {}
         temp_dict = {}
         temp_pid = None
@@ -118,7 +112,7 @@ class Ospfv3Facts(object):
         return pid_addr_family_dict
 
     def populate_facts(self, connection, ansible_facts, data=None):
-        """ Populate the facts for ospfv3
+        """Populate the facts for ospfv3
         :param connection: the device connection
         :param ansible_facts: Facts dictionary
         :param data: previously collected conf
@@ -145,14 +139,16 @@ class Ospfv3Facts(object):
             if key in current and current[key]:
                 current[key] = current[key].values()
                 current[key] = sorted(
-                    current[key], key=lambda k, sk=sortv: k[sk]
+                    current[key],
+                    key=lambda k, sk=sortv: k[sk],
                 )
 
         for process in current.get("processes", []):
             if "areas" in process:
                 process["areas"] = list(process["areas"].values())
                 process["areas"] = sorted(
-                    process["areas"], key=lambda k, sk="area_id": k[sk]
+                    process["areas"],
+                    key=lambda k, sk="area_id": k[sk],
                 )
                 for area in process["areas"]:
                     if "filters" in area:
@@ -162,7 +158,8 @@ class Ospfv3Facts(object):
                     if "areas" in each:
                         each["areas"] = list(each["areas"].values())
                         each["areas"] = sorted(
-                            each["areas"], key=lambda k, sk="area_id": k[sk]
+                            each["areas"],
+                            key=lambda k, sk="area_id": k[sk],
                         )
                         for area in each["areas"]:
                             if "filters" in area:
@@ -173,7 +170,9 @@ class Ospfv3Facts(object):
         facts = {}
         if current:
             params = ospfv3_parser.validate_config(
-                self.argument_spec, {"config": ipv4}, redact=True
+                self.argument_spec,
+                {"config": ipv4},
+                redact=True,
             )
             params = utils.remove_empties(params)
 
