@@ -5,6 +5,7 @@
 
 from __future__ import absolute_import, division, print_function
 
+
 __metaclass__ = type
 
 """
@@ -15,6 +16,7 @@ the given network resource.
 """
 
 import re
+
 from ansible_collections.ansible.netcommon.plugins.module_utils.network.common.network_template import (
     NetworkTemplate,
 )
@@ -26,8 +28,8 @@ def tmplt_host(verb):
     if verb.get("transport"):
         changed = False
     if verb:
-        if verb.get("hostname"):
-            cmd += " {hostname}".format(hostname=verb["hostname"])
+        if verb.get("host"):
+            cmd += " {hostname}".format(hostname=verb["host"])
         if verb.get("ipv6"):
             cmd += " ipv6 {ipv6}".format(ipv6=verb["ipv6"])
         if verb.get("vrf"):
@@ -43,7 +45,7 @@ def tmplt_host(verb):
             changed = True
             if session_id.get("text"):
                 cmd += " session-id string {text}".format(
-                    text=session_id["text"]
+                    text=session_id["text"],
                 )
             elif session_id.get("tag"):
                 cmd += " session-id {tag}".format(tag=session_id["tag"])
@@ -52,12 +54,12 @@ def tmplt_host(verb):
             changed = True
         if verb.get("sequence_num_session"):
             cmd += " {sequence_num_session}".format(
-                sequence_num_session="sequence-num-session"
+                sequence_num_session="sequence-num-session",
             )
             changed = True
         if verb.get("discriminator"):
             cmd += " discriminator {discriminator}".format(
-                discriminator=verb["discriminator"]
+                discriminator=verb["discriminator"],
             )
             changed = True
     if not changed:
@@ -68,8 +70,8 @@ def tmplt_host(verb):
 def tmplt_host_transport(verb):
     cmd = "logging host"
 
-    if verb.get("hostname"):
-        cmd += " {hostname}".format(hostname=verb["hostname"])
+    if verb.get("host"):
+        cmd += " {hostname}".format(hostname=verb["host"])
     if verb.get("ipv6"):
         cmd += " ipv6 {ipv6}".format(ipv6=verb["ipv6"])
     if verb.get("vrf"):
@@ -97,7 +99,7 @@ def tmplt_host_transport(verb):
                 cmd += " {filtered}".format(filtered="filtered")
             if verb.get("discriminator"):
                 cmd += " discriminator {discriminator}".format(
-                    discriminator=verb["discriminator"]
+                    discriminator=verb["discriminator"],
                 )
             if verb.get("stream"):
                 cmd += " stream {stream}".format(stream=verb["stream"])
@@ -105,21 +107,21 @@ def tmplt_host_transport(verb):
                 session_id = verb.get("session_id")
                 if session_id.get("text"):
                     cmd += " session-id string {text}".format(
-                        text=session_id["text"]
+                        text=session_id["text"],
                     )
                 elif session_id.get("tag"):
                     cmd += " session-id {tag}".format(tag=session_id["tag"])
             if verb.get("sequence_num_session"):
                 cmd += " {sequence_num_session}".format(
-                    sequence_num_session="sequence-num-session"
+                    sequence_num_session="sequence-num-session",
                 )
     return cmd
 
 
 def tmplt_host_del(verb):
     cmd = "logging host"
-    if verb.get("hostname"):
-        cmd += " {hostname}".format(hostname=verb["hostname"])
+    if verb.get("host"):
+        cmd += " {hostname}".format(hostname=verb["host"])
     if verb.get("ipv6"):
         cmd += " ipv6 {ipv6}".format(ipv6=verb["ipv6"])
     if verb.get("transport"):
@@ -129,8 +131,8 @@ def tmplt_host_del(verb):
 
 def tmplt_host_transport_del(verb):
     cmd = "logging host"
-    if verb.get("hostname"):
-        cmd += " {hostname}".format(hostname=verb["hostname"])
+    if verb.get("host"):
+        cmd += " {hostname}".format(hostname=verb["host"])
     if verb.get("ipv6"):
         cmd += " ipv6 {ipv6}".format(ipv6=verb["ipv6"])
     return cmd
@@ -180,7 +182,7 @@ def tmplt_message_counter(verb):
 
     if verb.get("message_counter"):
         cmd += " {message_counter}".format(
-            message_counter=verb["message_counter"]
+            message_counter=verb["message_counter"],
         )
     return cmd
 
@@ -215,11 +217,11 @@ def tmplt_common(verb, cmd):
             cmd += " {console}".format(console="console")
         if verb.get("message_limit"):
             cmd += " message-limit {message_limit}".format(
-                message_limit=verb["message_limit"]
+                message_limit=verb["message_limit"],
             )
         if verb.get("discriminator"):
             cmd += " discriminator {discriminator}".format(
-                discriminator=verb.get("discriminator")
+                discriminator=verb.get("discriminator"),
             )
         if verb.get("filtered"):
             cmd += " {filtered}".format(filtered="filtered")
@@ -231,7 +233,7 @@ def tmplt_common(verb, cmd):
             cmd += " {severity}".format(severity=verb["severity"])
         if verb.get("except_severity"):
             cmd += " except {exceptSev}".format(
-                exceptSev=verb["except_severity"]
+                exceptSev=verb["except_severity"],
             )
         if verb.get("tag"):
             cmd += " {tag}".format(tag=verb["tag"])
@@ -270,7 +272,9 @@ def tmplt_persistent(config_data):
 class Logging_globalTemplate(NetworkTemplate):
     def __init__(self, lines=None, module=None):
         super(Logging_globalTemplate, self).__init__(
-            lines=lines, tmplt=self, module=module
+            lines=lines,
+            tmplt=self,
+            module=module,
         )
 
     # fmt: off
@@ -290,12 +294,13 @@ class Logging_globalTemplate(NetworkTemplate):
                 (\ssession-id\sstring\s(?P<text>\S+))?
                 (\s(?P<sequence_num_session>sequence-num-session))?
                 (\sdiscriminator\s(?P<discriminator>.+$))?
-                $""", re.VERBOSE),
+                $""", re.VERBOSE,
+            ),
             "setval": tmplt_host,
             "remval": tmplt_host_del,
             "result": {
                 "hosts": [{
-                    "hostname": "{{ hostname }}",
+                    "host": "{{ hostname }}",
                     "ipv6": "{{ ipv6 }}",
                     "discriminator": "{{ discriminator }}",
                     "vrf": "{{ vrf }}",
@@ -306,8 +311,8 @@ class Logging_globalTemplate(NetworkTemplate):
                     "session_id": {
                         "tag": "{{ tag }}",
                         "text": "{{ text }}",
-                    }
-                }]
+                    },
+                }],
             },
         },
         {
@@ -317,7 +322,7 @@ class Logging_globalTemplate(NetworkTemplate):
                 ^logging\shost
                 (\s(?P<hostname>\S+))?
                 (\sipv6\s(?P<ipv6>\S+))?
-                (\svrf\s(?P<vrf>\w+))?
+                (\svrf\s(?P<vrf>\S+))?
                 (\stransport\s(?P<transport>tcp|udp))?
                 (\sport\s(?P<port>\d+))?
                 (\s(?P<audit>audit))?
@@ -328,12 +333,13 @@ class Logging_globalTemplate(NetworkTemplate):
                 (\ssession-id\s(?P<tag>hostname|ipv4|ipv6))?
                 (\ssession-id\sstring\s(?P<text>\S+))?
                 (\s(?P<sequence_num_session>sequence-num-session))?
-                $""", re.VERBOSE),
+                $""", re.VERBOSE,
+            ),
             "setval": tmplt_host_transport,
             "remval": tmplt_host_transport_del,
             "result": {
                 "hosts": [{
-                    "hostname": "{{ hostname }}",
+                    "host": "{{ hostname }}",
                     "ipv6": "{{ ipv6 }}",
                     "vrf": "{{ vrf if transport is defined }}",
                     "transport": {
@@ -349,9 +355,9 @@ class Logging_globalTemplate(NetworkTemplate):
                             },
                             "filtered": "{{ True if filtered is defined }}",
                             "stream": "{{ stream }}",
-                        }
-                    }
-                }]
+                        },
+                    },
+                }],
             },
         },
         {
@@ -359,12 +365,13 @@ class Logging_globalTemplate(NetworkTemplate):
             "getval": re.compile(
                 r"""
                 ^logging\sbuffered
-                (\sdiscriminator\s(?P<sdiscriminator>.+))?
+                (\sdiscriminator\s(?P<discriminator>.+))?
                 (\s(?P<filtered>filtered))?
                 (\s(?P<xml>xml))?
                 (\s(?P<size>[1-9][0-9]*))?
                 (\s(?P<severity>alerts|critical|debugging|emergencies|errors|informational|notifications|warnings))?
-                $""", re.VERBOSE),
+                $""", re.VERBOSE,
+            ),
             "setval": tmplt_buffered,
             "result": {
                 "buffered": {
@@ -373,7 +380,7 @@ class Logging_globalTemplate(NetworkTemplate):
                     "severity": "{{ severity }}",
                     "size": "{{ size }}",
                     "discriminator": "{{ discriminator }}",
-                }
+                },
             },
         },
         {
@@ -381,10 +388,11 @@ class Logging_globalTemplate(NetworkTemplate):
             "getval": re.compile(
                 r"""
                 ^logging\s(?P<buginf>buginf)
-                $""", re.VERBOSE),
+                $""", re.VERBOSE,
+            ),
             "setval": "logging buginf",
             "result": {
-                "buginf": "{{ True if buginf is defined }}"
+                "buginf": "{{ True if buginf is defined }}",
             },
         },
         {
@@ -393,10 +401,11 @@ class Logging_globalTemplate(NetworkTemplate):
                 r"""
                 ^logging\scns-events
                 (\s(?P<severity>alerts|critical|debugging|emergencies|errors|informational|notifications|warnings))?
-                $""", re.VERBOSE),
+                $""", re.VERBOSE,
+            ),
             "setval": "logging cns-events {{ cns_events }}",
             "result": {
-                "cns_events": "{{ severity }}"
+                "cns_events": "{{ severity }}",
             },
         },
         {
@@ -407,8 +416,9 @@ class Logging_globalTemplate(NetworkTemplate):
                 (\s(?P<filtered>filtered))?
                 (\s(?P<xml>xml))?
                 (\s(?P<severity>alerts|critical|debugging|emergencies|errors|informational|notifications|warnings|guaranteed$))?
-                (\s(?P<discriminator>discriminator\s.+$))?
-                $""", re.VERBOSE),
+                (\sdiscriminator\s(?P<discriminator>.+$))?
+                $""", re.VERBOSE,
+            ),
             "setval": tmplt_console,
             "result": {
                 "console": {
@@ -416,7 +426,7 @@ class Logging_globalTemplate(NetworkTemplate):
                     "discriminator": "{{ discriminator }}",
                     "filtered": "{{ True if filtered is defined }}",
                     "xml": "{{ True if xml is defined }}",
-                }
+                },
             },
         },
         {
@@ -424,10 +434,11 @@ class Logging_globalTemplate(NetworkTemplate):
             "getval": re.compile(
                 r"""
                 ^logging\s(?P<count>count)
-                $""", re.VERBOSE),
+                $""", re.VERBOSE,
+            ),
             "setval": "logging count",
             "result": {
-                "count": "{{ True if count is defined }}"
+                "count": "{{ True if count is defined }}",
             },
         },
         {
@@ -435,12 +446,13 @@ class Logging_globalTemplate(NetworkTemplate):
             "getval": re.compile(
                 r"""
                 ^logging\sdelimiter\s(?P<tcp>tcp)
-                $""", re.VERBOSE),
+                $""", re.VERBOSE,
+            ),
             "setval": "logging delimiter tcp",
             "result": {
                 "delimiter": {
-                    "tcp": "{{ True if tcp is defined }}"
-                }
+                    "tcp": "{{ True if tcp is defined }}",
+                },
             },
         },
         {
@@ -448,10 +460,11 @@ class Logging_globalTemplate(NetworkTemplate):
             "getval": re.compile(
                 r"""
                 ^logging\sdiscriminator\s(?P<discriminator>.+$)
-                $""", re.VERBOSE),
+                $""", re.VERBOSE,
+            ),
             "setval": "logging discriminator {{ discriminator }}",
             "result": {
-                "discriminator": ["{{ discriminator }}", ]
+                "discriminator": ["{{ discriminator }}"],
             },
         },
         {
@@ -460,12 +473,13 @@ class Logging_globalTemplate(NetworkTemplate):
                 r"""
                 ^logging\sdmvpn\srate-limit
                 (\s(?P<rate>\d+))?
-                $""", re.VERBOSE),
+                $""", re.VERBOSE,
+            ),
             "setval": "logging dmvpn rate-limit {{ dmvpn.rate_limit }}",
             "result": {
                 "dmvpn": {
                     "rate_limit": "{{ rate }}",
-                }
+                },
             },
         },
         {
@@ -473,12 +487,13 @@ class Logging_globalTemplate(NetworkTemplate):
             "getval": re.compile(
                 r"""
                 ^logging\sesm\s(?P<config>config)
-                $""", re.VERBOSE),
+                $""", re.VERBOSE,
+            ),
             "setval": "logging esm config",
             "result": {
                 "esm": {
-                    "config": "{{ True if config is defined }}"
-                }
+                    "config": "{{ True if config is defined }}",
+                },
             },
         },
         {
@@ -487,10 +502,11 @@ class Logging_globalTemplate(NetworkTemplate):
                 r"""
                 ^logging\sexception
                 \s(?P<exception>[1-9][0-9]*)
-                $""", re.VERBOSE),
+                $""", re.VERBOSE,
+            ),
             "setval": "logging exception {{ exception }}",
             "result": {
-                "exception": "{{ exception }}"
+                "exception": "{{ exception }}",
             },
         },
         {
@@ -499,10 +515,11 @@ class Logging_globalTemplate(NetworkTemplate):
                 r"""
                 ^logging\sfacility
                 \s(?P<facility>auth|cron|daemon|kern|local0|local1|local2|local3|local4|local5|local6|local7|lpr|mail|news|sys10|sys11|sys12|sys13|sys14|sys9|syslog|user|uucp)
-                $""", re.VERBOSE),
+                $""", re.VERBOSE,
+            ),
             "setval": "logging facility {{ facility }}",
             "result": {
-                "facility": "{{ facility }}"
+                "facility": "{{ facility }}",
             },
         },
         {
@@ -513,14 +530,15 @@ class Logging_globalTemplate(NetworkTemplate):
                 (\s(?P<url>\S+))?
                 (\s(?P<order>\d+))?
                 (\sargs\s(?P<args>.+$))?
-                $""", re.VERBOSE),
+                $""", re.VERBOSE,
+            ),
             "setval": tmplt_filter,
             "result": {
                 "filter": [{
                     "url": "{{ url }}",
                     "order": "{{ order }}",
                     "args": "{{ args }}",
-                }]
+                }],
             },
         },
         {
@@ -530,13 +548,14 @@ class Logging_globalTemplate(NetworkTemplate):
                 ^logging\shistory
                 (\s(?P<size>\d+))?
                 (\s(?P<severity>alerts|critical|debugging|emergencies|errors|informational|notifications|warnings))?
-                $""", re.VERBOSE),
+                $""", re.VERBOSE,
+            ),
             "setval": tmplt_history,
             "result": {
                 "history": {
                     "severity": "{{ severity }}",
                     "size": "{{ size }}",
-                }
+                },
             },
         },
         {
@@ -545,10 +564,11 @@ class Logging_globalTemplate(NetworkTemplate):
                 r"""
                 ^logging\smessage-counter
                 \s(?P<counter>log|debug|syslog)
-                $""", re.VERBOSE),
+                $""", re.VERBOSE,
+            ),
             "setval": tmplt_message_counter,
             "result": {
-                "message_counter": ["{{ counter }}", ]
+                "message_counter": ["{{ counter }}"],
             },
         },
         {
@@ -559,8 +579,9 @@ class Logging_globalTemplate(NetworkTemplate):
                 (\s(?P<filtered>filtered))?
                 (\s(?P<xml>xml))?
                 (\s(?P<severity>alerts|critical|debugging|emergencies|errors|informational|notifications|warnings))?
-                (\s(?P<discriminator>discriminator\s.+$))?
-                $""", re.VERBOSE),
+                (\sdiscriminator\s(?P<discriminator>.+$))?
+                $""", re.VERBOSE,
+            ),
             "setval": tmplt_monitor,
             "result": {
                 "monitor": {
@@ -568,7 +589,7 @@ class Logging_globalTemplate(NetworkTemplate):
                     "xml": "{{ True if xml is defined }}",
                     "severity": "{{ severity }}",
                     "discriminator": "{{ discriminator }}",
-                }
+                },
             },
         },
         {
@@ -578,7 +599,8 @@ class Logging_globalTemplate(NetworkTemplate):
                 ((?P<negate>no))?
                 ((\s|^))?logging
                 (\s(?P<on>on))?
-                $""", re.VERBOSE),
+                $""", re.VERBOSE,
+            ),
             "setval": tmplt_logging_on,
             "remval": "logging on",
             "result": {
@@ -592,13 +614,14 @@ class Logging_globalTemplate(NetworkTemplate):
                 ^logging\sorigin-id
                 (\s(?P<tag>hostname|ip|ipv6))?
                 (\sstring\s(?P<text>.+$))?
-                $""", re.VERBOSE),
+                $""", re.VERBOSE,
+            ),
             "setval": tmplt_origin_id,
             "result": {
                 "origin_id": {
                     "tag": "{{ tag }}",
                     "text": "{{ text }}",
-                }
+                },
             },
         },
         {
@@ -614,7 +637,8 @@ class Logging_globalTemplate(NetworkTemplate):
                 (\s(?P<immediate>immediate))?
                 (\s(?P<protected>protected))?
                 (\s(?P<notify>notify))?
-                $""", re.VERBOSE),
+                $""", re.VERBOSE,
+            ),
             "setval": tmplt_persistent,
             "result": {
                 "persistent": {
@@ -626,7 +650,7 @@ class Logging_globalTemplate(NetworkTemplate):
                     "size": "{{ size }}",
                     "threshold": "{{ threshold }}",
                     "url": "{{ url }}",
-                }
+                },
             },
         },
         {
@@ -635,12 +659,13 @@ class Logging_globalTemplate(NetworkTemplate):
                 r"""
                 ^logging\spolicy-firewall
                 (\srate-limit\s(?P<rate>[1-9][0-9]*))?
-                $""", re.VERBOSE),
+                $""", re.VERBOSE,
+            ),
             "setval": "logging policy-firewall rate-limit {{ policy_firewall.rate_limit }}",
             "result": {
                 "policy_firewall": {
                     "rate_limit": "{{ rate }}",
-                }
+                },
             },
         },
         {
@@ -651,14 +676,15 @@ class Logging_globalTemplate(NetworkTemplate):
                 (\s(?P<size>[1-9][0-9]*))?
                 (\sesm\s(?P<esm>[1-9][0-9]*))?
                 (\strap\s(?P<trap>[1-9][0-9]*))?
-                $""", re.VERBOSE),
+                $""", re.VERBOSE,
+            ),
             "setval": tmplt_queue_limit,
             "result": {
                 "queue_limit": {
                     "size": "{{ size }}",
                     "esm": "{{ esm }}",
                     "trap": "{{ trap }}",
-                }
+                },
             },
         },
         {
@@ -669,7 +695,8 @@ class Logging_globalTemplate(NetworkTemplate):
                 (\s(?P<option>all|console))?
                 (\s(?P<size>[1-9][0-9]*))?
                 (\sexcept\s(?P<except_severity>alerts|critical|debugging|emergencies|errors|informational|notifications|warnings))?
-                $""", re.VERBOSE),
+                $""", re.VERBOSE,
+            ),
             "setval": tmplt_rate_limit,
             "result": {
                 "rate_limit": {
@@ -677,7 +704,7 @@ class Logging_globalTemplate(NetworkTemplate):
                     "all": "{{ True if option == 'all' }}",
                     "console": "{{ True if option == 'console' }}",
                     "except_severity": "{{ except_severity }}",
-                }
+                },
             },
         },
         {
@@ -688,13 +715,14 @@ class Logging_globalTemplate(NetworkTemplate):
                 (\s(?P<reload>reload))?
                 (\smessage-limit\s(?P<message_limit>[1-9][0-9]*))?
                 (\s(?P<severity>alerts|critical|debugging|emergencies|errors|informational|notifications|warnings))?
-                $""", re.VERBOSE),
+                $""", re.VERBOSE,
+            ),
             "setval": tmplt_reload,
             "result": {
                 "reload": {
                     "severity": "{{ severity }}",
                     "message_limit": "{{ message_limit }}",
-                }
+                },
             },
         },
         {
@@ -703,11 +731,12 @@ class Logging_globalTemplate(NetworkTemplate):
                 r"""
                 ^logging
                 \s(?P<server_arp>server-arp)
-                $""", re.VERBOSE),
+                $""", re.VERBOSE,
+            ),
             "setval": "logging server-arp",
             "result": {
-                "server_arp": "{{ True if server_arp is defined }}"
-            }
+                "server_arp": "{{ True if server_arp is defined }}",
+            },
         },
         {
             "name": "snmp_trap",
@@ -715,10 +744,11 @@ class Logging_globalTemplate(NetworkTemplate):
                 r"""
                 ^logging\ssnmp-trap
                 (\s(?P<severity>alerts|critical|debugging|emergencies|errors|informational|notifications|warnings))?
-                $""", re.VERBOSE),
+                $""", re.VERBOSE,
+            ),
             "setval": "logging snmp-trap {{ snmp_trap }}",
             "result": {
-                "snmp_trap": ["{{ severity }}", ]
+                "snmp_trap": ["{{ severity }}"],
             },
         },
         {
@@ -728,13 +758,14 @@ class Logging_globalTemplate(NetworkTemplate):
                 ^logging\ssource-interface
                 (\s(?P<interface>\S+))?
                 (\svrf\s(?P<vrf>\S+))?
-                $""", re.VERBOSE),
+                $""", re.VERBOSE,
+            ),
             "setval": tmplt_source_interface,
             "result": {
                 "source_interface": [{
                     "interface": "{{ interface }}",
                     "vrf": "{{ vrf }}",
-                }]
+                }],
             },
         },
         {
@@ -743,7 +774,8 @@ class Logging_globalTemplate(NetworkTemplate):
                 r"""
                 ^logging\strap
                 \s(?P<severity>alerts|critical|debugging|emergencies|errors|informational|notifications|warnings)
-                $""", re.VERBOSE),
+                $""", re.VERBOSE,
+            ),
             "setval": "logging trap {{ trap }}",
             "result": {
                 "trap": "{{ severity }}",
@@ -754,10 +786,11 @@ class Logging_globalTemplate(NetworkTemplate):
             "getval": re.compile(
                 r"""
                 ^logging\s(?P<userinfo>userinfo)
-                $""", re.VERBOSE),
+                $""", re.VERBOSE,
+            ),
             "setval": "logging userinfo",
             "result": {
-                "userinfo": "{{ True if userinfo is defined }}"
+                "userinfo": "{{ True if userinfo is defined }}",
             },
         },
     ]
