@@ -5,6 +5,7 @@
 
 from __future__ import absolute_import, division, print_function
 
+
 __metaclass__ = type
 
 """
@@ -15,6 +16,7 @@ the given network resource.
 """
 
 import re
+
 from ansible.module_utils.six import iteritems
 from ansible_collections.ansible.netcommon.plugins.module_utils.network.common.network_template import (
     NetworkTemplate,
@@ -34,26 +36,20 @@ def _tmplt_route_map_match(config_data):
             if config_data["match"]["additional_paths"].get("all"):
                 cmd += " all"
             if config_data["match"]["additional_paths"].get("best"):
-                cmd += " best {best}".format(
-                    **config_data["match"]["additional_paths"]
-                )
+                cmd += " best {best}".format(**config_data["match"]["additional_paths"])
             if config_data["match"]["additional_paths"].get("best_range"):
                 cmd += " best-range"
                 if config_data["match"]["additional_paths"]["best_range"].get(
-                    "lower_limit"
+                    "lower_limit",
                 ):
                     cmd += " lower-limit {lower_limit}".format(
-                        **config_data["match"]["additional_paths"][
-                            "best_range"
-                        ]
+                        **config_data["match"]["additional_paths"]["best_range"]
                     )
                 if config_data["match"]["additional_paths"]["best_range"].get(
-                    "upper_limit"
+                    "upper_limit",
                 ):
                     cmd += " upper-limit {upper_limit}".format(
-                        **config_data["match"]["additional_paths"][
-                            "best_range"
-                        ]
+                        **config_data["match"]["additional_paths"]["best_range"]
                     )
             if config_data["match"]["additional_paths"].get("group_best"):
                 cmd += " group-best"
@@ -100,7 +96,7 @@ def _tmplt_route_map_match(config_data):
             command.append(cmd)
         if match.get("length"):
             command.append(
-                "match length {minimum} {maximum}".format(**match["length"])
+                "match length {minimum} {maximum}".format(**match["length"]),
             )
         if match.get("local_preference"):
             cmd = "match local-preference "
@@ -237,11 +233,13 @@ def _tmplt_route_map_match_ip(config_data):
             if config_data["match"]["ip"]["address"].get("prefix_lists"):
                 cmd += " prefix-list"
                 cmd = construct_cmd_from_list(
-                    cmd, config_data["match"]["ip"]["address"]["prefix_lists"]
+                    cmd,
+                    config_data["match"]["ip"]["address"]["prefix_lists"],
                 )
             elif config_data["match"]["ip"]["address"].get("acls"):
                 cmd = construct_cmd_from_list(
-                    cmd, config_data["match"]["ip"]["address"]["acls"]
+                    cmd,
+                    config_data["match"]["ip"]["address"]["acls"],
                 )
         if config_data["match"]["ip"].get("flowspec"):
             cmd += " flowspec"
@@ -252,48 +250,48 @@ def _tmplt_route_map_match_ip(config_data):
             if config_data["match"]["ip"]["flowspec"].get("prefix_lists"):
                 cmd += " prefix-list"
                 cmd = construct_cmd_from_list(
-                    cmd, config_data["match"]["ip"]["flowspec"]["prefix_lists"]
+                    cmd,
+                    config_data["match"]["ip"]["flowspec"]["prefix_lists"],
                 )
             elif config_data["match"]["ip"]["flowspec"].get("acls"):
                 cmd = construct_cmd_from_list(
-                    cmd, config_data["match"]["ip"]["flowspec"]["acls"]
+                    cmd,
+                    config_data["match"]["ip"]["flowspec"]["acls"],
                 )
         if config_data["match"]["ip"].get("next_hop"):
             cmd += " next-hop"
             if config_data["match"]["ip"]["next_hop"].get("prefix_lists"):
                 cmd += " prefix-list"
                 cmd = construct_cmd_from_list(
-                    cmd, config_data["match"]["ip"]["next_hop"]["prefix_lists"]
+                    cmd,
+                    config_data["match"]["ip"]["next_hop"]["prefix_lists"],
                 )
             elif config_data["match"]["ip"]["next_hop"].get("acls"):
                 cmd = construct_cmd_from_list(
-                    cmd, config_data["match"]["ip"]["next_hop"]["acls"]
+                    cmd,
+                    config_data["match"]["ip"]["next_hop"]["acls"],
                 )
         if config_data["match"]["ip"].get("redistribution_source"):
             cmd += " redistribution-source"
             if config_data["match"]["ip"]["redistribution_source"].get(
-                "prefix_lists"
+                "prefix_lists",
             ):
                 cmd += " prefix-list"
                 cmd = construct_cmd_from_list(
                     cmd,
-                    config_data["match"]["ip"]["redistribution_source"][
-                        "prefix_lists"
-                    ],
+                    config_data["match"]["ip"]["redistribution_source"]["prefix_lists"],
                 )
             elif config_data["match"]["ip"]["redistribution_source"].get(
-                "acls"
+                "acls",
             ):
                 cmd = construct_cmd_from_list(
                     cmd,
-                    config_data["match"]["ip"]["redistribution_source"][
-                        "acls"
-                    ],
+                    config_data["match"]["ip"]["redistribution_source"]["acls"],
                 )
         if config_data["match"]["ip"].get("route_source"):
             cmd += " route-source"
             if config_data["match"]["ip"]["route_source"].get(
-                "redistribution_source"
+                "redistribution_source",
             ):
                 cmd += " redistribution-source"
             if config_data["match"]["ip"]["route_source"].get("prefix_lists"):
@@ -304,7 +302,8 @@ def _tmplt_route_map_match_ip(config_data):
                 )
             elif config_data["match"]["ip"]["route_source"].get("acls"):
                 cmd = construct_cmd_from_list(
-                    cmd, config_data["match"]["ip"]["route_source"]["acls"]
+                    cmd,
+                    config_data["match"]["ip"]["route_source"]["acls"],
                 )
         return cmd
 
@@ -319,9 +318,7 @@ def _tmplt_route_map_match_ipv6(config_data):
                     **config_data["match"]["ipv6"]["address"]
                 )
             elif config_data["match"]["ipv6"]["address"].get("acl"):
-                cmd += " {acl}".format(
-                    **config_data["match"]["ipv6"]["address"]
-                )
+                cmd += " {acl}".format(**config_data["match"]["ipv6"]["address"])
         if config_data["match"]["ipv6"].get("flowspec"):
             cmd += " flowspec"
             if config_data["match"]["ipv6"]["flowspec"].get("dest_pfx"):
@@ -333,9 +330,7 @@ def _tmplt_route_map_match_ipv6(config_data):
                     **config_data["match"]["ipv6"]["flowspec"]
                 )
             elif config_data["match"]["ipv6"]["flowspec"].get("acl"):
-                cmd += " {acl}".format(
-                    **config_data["match"]["ipv6"]["flowspec"]
-                )
+                cmd += " {acl}".format(**config_data["match"]["ipv6"]["flowspec"])
         if config_data["match"]["ipv6"].get("next_hop"):
             cmd += " next-hop"
             if config_data["match"]["ipv6"]["next_hop"].get("prefix_list"):
@@ -343,9 +338,7 @@ def _tmplt_route_map_match_ipv6(config_data):
                     **config_data["match"]["ipv6"]["next_hop"]
                 )
             elif config_data["match"]["ipv6"]["next_hop"].get("acl"):
-                cmd += " {acl}".format(
-                    **config_data["match"]["ipv6"]["next_hop"]
-                )
+                cmd += " {acl}".format(**config_data["match"]["ipv6"]["next_hop"])
         if config_data["match"]["ipv6"].get("route_source"):
             cmd += " route-source"
             if config_data["match"]["ipv6"]["route_source"].get("prefix_list"):
@@ -353,9 +346,7 @@ def _tmplt_route_map_match_ipv6(config_data):
                     **config_data["match"]["ipv6"]["route_source"]
                 )
             elif config_data["match"]["ipv6"]["route_source"].get("acl"):
-                cmd += " {acl}".format(
-                    **config_data["match"]["ipv6"]["route_source"]
-                )
+                cmd += " {acl}".format(**config_data["match"]["ipv6"]["route_source"])
         return cmd
 
 
@@ -375,11 +366,11 @@ def _tmplt_route_map_set(config_data):
             if set["as_path"].get("prepend"):
                 cmd += " prepend"
                 if set["as_path"]["prepend"].get("as_number"):
-                    cmd += " {as_number}".format(**set["as_path"]["prepend"])
-                elif set["as_path"]["prepend"].get("last_as"):
-                    cmd += " last-as {last_as}".format(
-                        **set["as_path"]["prepend"]
+                    cmd += " {0}".format(
+                        " ".join(set["as_path"]["prepend"].get("as_number")),
                     )
+                elif set["as_path"]["prepend"].get("last_as"):
+                    cmd += " last-as {last_as}".format(**set["as_path"]["prepend"])
             if set["as_path"].get("tag"):
                 cmd += " tag"
             command.append(cmd)
@@ -412,15 +403,15 @@ def _tmplt_route_map_set(config_data):
             command.append(
                 "set dampening {penalty_half_time} {reuse_route_val} {suppress_route_val} {max_suppress}".format(
                     **set["dampening"]
-                )
+                ),
             )
         if set.get("default"):
             command.append(
-                "set default interface {default}".format(**set["default"])
+                "set default interface {default}".format(**set["default"]),
             )
         if set.get("extcomm_list"):
             command.append(
-                "set extcomm-list {extcomm_list} delete".format(**set)
+                "set extcomm-list {extcomm_list} delete".format(**set),
             )
         if set.get("extcommunity"):
             if set["extcommunity"].get("cost"):
@@ -432,9 +423,7 @@ def _tmplt_route_map_set(config_data):
                 if set["extcommunity"]["cost"].get("id"):
                     cmd += " {id}".format(**set["extcommunity"]["cost"])
                 if set["extcommunity"]["cost"].get("cost_value"):
-                    cmd += " {cost_value}".format(
-                        **set["extcommunity"]["cost"]
-                    )
+                    cmd += " {cost_value}".format(**set["extcommunity"]["cost"])
                 command.append(cmd)
             if set["extcommunity"].get("rt"):
                 cmd = "set extcommunity rt"
@@ -449,7 +438,7 @@ def _tmplt_route_map_set(config_data):
                 command.append(cmd)
             if set["extcommunity"].get("soo"):
                 command.append(
-                    "set extcommunity soo {soo}".format(**set["extcommunity"])
+                    "set extcommunity soo {soo}".format(**set["extcommunity"]),
                 )
             if set["extcommunity"].get("vpn_distinguisher"):
                 cmd = "set extcommunity vpn-distinguisher"
@@ -458,9 +447,7 @@ def _tmplt_route_map_set(config_data):
                         **set["extcommunity"]["vpn_distinguisher"]["range"]
                     )
                 elif set["extcommunity"]["vpn_distinguisher"].get("address"):
-                    cmd += " {address}".format(
-                        **set["extcommunity"]["vpn_distinguisher"]
-                    )
+                    cmd += " {address}".format(**set["extcommunity"]["vpn_distinguisher"])
                 if set["extcommunity"]["vpn_distinguisher"].get("additive"):
                     cmd += " additive"
                 command.append(cmd)
@@ -487,7 +474,7 @@ def _tmplt_route_map_set(config_data):
             command.append("set lisp locator-set {lisp}".format(**set))
         if set.get("local_preference"):
             command.append(
-                "set local-preference {local_preference}".format(**set)
+                "set local-preference {local_preference}".format(**set),
             )
         if set.get("metric"):
             cmd = "set metric"
@@ -495,15 +482,19 @@ def _tmplt_route_map_set(config_data):
                 cmd += " {metric_value}".format(**set["metric"])
                 if set["metric"].get("deviation"):
                     if set["metric"]["deviation"] == "plus":
-                        cmd += " +{eigrp_delay} {metric_reliability} {metric_bandwidth} {mtu}".format(
-                            **set["metric"]
+                        cmd += (
+                            " +{eigrp_delay} {metric_reliability} {metric_bandwidth} {mtu}".format(
+                                **set["metric"]
+                            )
                         )
                     elif set["metric"]["deviation"] == "minus":
-                        cmd += " -{eigrp_delay} {metric_reliability} {metric_bandwidth} {mtu}".format(
-                            **set["metric"]
+                        cmd += (
+                            " -{eigrp_delay} {metric_reliability} {metric_bandwidth} {mtu}".format(
+                                **set["metric"]
+                            )
                         )
             if set["metric"].get("deviation") and not set["metric"].get(
-                "eigrp_delay"
+                "eigrp_delay",
             ):
                 if set["metric"]["deviation"] == "plus":
                     cmd = "set metric +{metric_value}".format(**set["metric"])
@@ -547,7 +538,7 @@ def _tmplt_route_map_set_ip(config_data):
         cmd = "set ip"
         if set_ip.get("address"):
             command.append(
-                "{0} address prefix-list {address}".format(cmd, **set_ip)
+                "{0} address prefix-list {address}".format(cmd, **set_ip),
             )
         if set_ip.get("df"):
             command.append("{0} df {df}".format(cmd, **set_ip))
@@ -564,15 +555,13 @@ def _tmplt_route_map_set_ip(config_data):
             cmd += " next-hop"
             if set_ip["next_hop"].get("address"):
                 command.append(
-                    "{0} {address}".format(cmd, **set_ip["next_hop"])
+                    "{0} {address}".format(cmd, **set_ip["next_hop"]),
                 )
             if set_ip["next_hop"].get("dynamic"):
                 command.append("{0} dynamic dhcp".format(cmd))
             if set_ip["next_hop"].get("encapsulate"):
                 command.append(
-                    "{0} encapsulate l3vpn {encapsulate}".format(
-                        cmd, **set_ip["next_hop"]
-                    )
+                    "{0} encapsulate l3vpn {encapsulate}".format(cmd, **set_ip["next_hop"]),
                 )
             if set_ip["next_hop"].get("peer_address"):
                 command.append("{0} peer-address".format(cmd))
@@ -581,13 +570,9 @@ def _tmplt_route_map_set_ip(config_data):
                 if set_ip["next_hop"]["recursive"].get("global_route"):
                     child_cmd += " global"
                 elif set_ip["next_hop"]["recursive"].get("vrf"):
-                    child_cmd += " vrf {vrf}".format(
-                        **set_ip["next_hop"]["recursive"]
-                    )
+                    child_cmd += " vrf {vrf}".format(**set_ip["next_hop"]["recursive"])
                 if set_ip["next_hop"]["recursive"].get("address"):
-                    child_cmd += " {address}".format(
-                        **set_ip["next_hop"]["recursive"]
-                    )
+                    child_cmd += " {address}".format(**set_ip["next_hop"]["recursive"])
                 command.append(child_cmd)
             if set_ip["next_hop"].get("self"):
                 command.append("{0} self".format(cmd))
@@ -595,7 +580,7 @@ def _tmplt_route_map_set_ip(config_data):
                 command.append(
                     "{0} verify-availability {address} {sequence} track {track}".format(
                         cmd, **set_ip["next_hop"]["verify_availability"]
-                    )
+                    ),
                 )
         if set_ip.get("precedence"):
             cmd += " precedence"
@@ -664,16 +649,16 @@ def _tmplt_route_map_set_ipv6(config_data):
             if set_ipv6["next_hop"].get("address"):
                 cmd += " {address}".format(**set_ipv6["next_hop"])
             if set_ipv6["next_hop"].get("encapsulate"):
-                cmd += " encapsulate l3vpn {encapsulate}".format(
-                    **set_ipv6["next_hop"]
-                )
+                cmd += " encapsulate l3vpn {encapsulate}".format(**set_ipv6["next_hop"])
             if set_ipv6["next_hop"].get("peer_address"):
                 cmd += " peer-address"
         if set_ipv6.get("precedence"):
             cmd += " precedence {precedence}".format(**set_ipv6)
         if set_ipv6.get("vrf"):
-            cmd += " vrf {vrf} next-hop verify-availability {address} {sequence} track {track}".format(
-                **set_ipv6["vrf"]["verify_availability"]
+            cmd += (
+                " vrf {vrf} next-hop verify-availability {address} {sequence} track {track}".format(
+                    **set_ipv6["vrf"]["verify_availability"]
+                )
             )
         return cmd
 
@@ -691,7 +676,7 @@ class Route_mapsTemplate(NetworkTemplate):
                 \s*(?P<route_map>\S+)*
                 \s*(?P<action>deny|permit)*
                 \s*(?P<sequence>\d+)*
-                $""",
+                (\s|$)""",
                 re.VERBOSE,
             ),
             "setval": "",
@@ -702,9 +687,9 @@ class Route_mapsTemplate(NetworkTemplate):
                         "entries": {
                             "action": "{{ action }}",
                             "sequence": "{{ sequence }}",
-                        }
+                        },
                     },
-                }
+                },
             },
             "shared": True,
         },
@@ -725,10 +710,10 @@ class Route_mapsTemplate(NetworkTemplate):
                             "continue_entry": {
                                 "set": "{{ True if entry_sequence is not defined }}",
                                 "entry_sequence": "{{ entry_sequence }}",
-                            }
-                        }
-                    }
-                }
+                            },
+                        },
+                    },
+                },
             },
         },
         {
@@ -744,9 +729,9 @@ class Route_mapsTemplate(NetworkTemplate):
             "result": {
                 "{{ route_map }}": {
                     "{{ action|d() + '_' + sequence|d() }}": {
-                        "entries": {"description": "{{ description }}"}
-                    }
-                }
+                        "entries": {"description": "{{ description }}"},
+                    },
+                },
             },
         },
         {
@@ -878,10 +863,10 @@ class Route_mapsTemplate(NetworkTemplate):
                                     "tag_list": "{{ tag.split('tag list ')[1].split(' ') if tag is defined and 'list' in tag }}",
                                 },
                                 "track": "{{ track.split('track ')[1] if track is defined }}",
-                            }
-                        }
-                    }
-                }
+                            },
+                        },
+                    },
+                },
             },
         },
         {
@@ -942,11 +927,11 @@ class Route_mapsTemplate(NetworkTemplate):
                                         "prefix_lists": "{{ route_source.split('route-source prefix-list ')[1].split(' ') if route_source is defined and\
                                                 'prefix-list' in route_source else '' }}",
                                     },
-                                }
-                            }
-                        }
-                    }
-                }
+                                },
+                            },
+                        },
+                    },
+                },
             },
         },
         {
@@ -989,11 +974,11 @@ class Route_mapsTemplate(NetworkTemplate):
                                         "prefix_list": "{{ route_source.split('route-source prefix-list ')[1] if route_source is defined and\
                                                 'prefix-list' in route_source }}",
                                     },
-                                }
-                            }
-                        }
-                    }
-                }
+                                },
+                            },
+                        },
+                    },
+                },
             },
         },
         {
@@ -1160,10 +1145,10 @@ class Route_mapsTemplate(NetworkTemplate):
                                 "traffic_index": "{{ traffic_index.split('traffic-index ')[1] if traffic_index is defined }}",
                                 "vrf": "{{ vrf.split('vrf ')[1] if vrf is defined }}",
                                 "weight": "{{ weight.split('weight ')[1] if weight is defined }}",
-                            }
-                        }
-                    }
-                }
+                            },
+                        },
+                    },
+                },
             },
         },
         {
@@ -1261,11 +1246,11 @@ class Route_mapsTemplate(NetworkTemplate):
                                             "track": "{{ vrf.split('track ')[1] if vrf is defined and 'track' in vrf }}",
                                         },
                                     },
-                                }
-                            }
-                        }
-                    }
-                }
+                                },
+                            },
+                        },
+                    },
+                },
             },
         },
         {
@@ -1318,11 +1303,11 @@ class Route_mapsTemplate(NetworkTemplate):
                                             "track": "{{ vrf.split('track ')[1] if vrf is defined and 'verify-availability' in vrf }}",
                                         },
                                     },
-                                }
-                            }
-                        }
-                    }
-                }
+                                },
+                            },
+                        },
+                    },
+                },
             },
         },
     ]
