@@ -10,6 +10,7 @@ The module file for ios_acls
 
 from __future__ import absolute_import, division, print_function
 
+
 __metaclass__ = type
 
 DOCUMENTATION = """
@@ -614,7 +615,7 @@ options:
     default: merged
     description:
       - The state the configuration should be left in
-      - The states I(merged) is the default state which merges the want and
+      - The state I(merged) is the default state which merges the want and
         have config, but for ACL module as the IOS platform doesn't allow
         update of ACE over an pre-existing ACE sequence in ACL, same way ACLs
         resource module will error out for respective scenario and only addition
@@ -637,8 +638,15 @@ options:
         device. Config data from both the commands should be kept together one after
         another for the parsers to pick the commands correctly.
         For state I(parsed) active connection to remote host is not required.
+      - The state I(overridden), modify/add the ACLs defined, deleted all other ACLs.
+      - The state I(replaced), modify/add only the ACEs of the ACLs defined only.
+        It does not perform any other change on the device.
+      - The state I(deleted), deletes only the specified ACLs, or all if not specified.
+
+
+
     type: str
-short_description: ACLs resource module
+short_description: Resource module to configure ACLs.
 version_added: 1.0.0
 """
 
@@ -1470,12 +1478,11 @@ parsed:
 """
 
 from ansible.module_utils.basic import AnsibleModule
+
 from ansible_collections.cisco.ios.plugins.module_utils.network.ios.argspec.acls.acls import (
     AclsArgs,
 )
-from ansible_collections.cisco.ios.plugins.module_utils.network.ios.config.acls.acls import (
-    Acls,
-)
+from ansible_collections.cisco.ios.plugins.module_utils.network.ios.config.acls.acls import Acls
 
 
 def main():
