@@ -17,11 +17,12 @@
 #
 from __future__ import absolute_import, division, print_function
 
+
 __metaclass__ = type
 DOCUMENTATION = """
 module: ios_config
 author: Peter Sprygada (@privateip)
-short_description: Manage Cisco IOS configuration sections
+short_description: Module to manage configuration sections.
 description:
 - Cisco IOS configurations use a simple block indent file syntax for segmenting configuration
   into sections.  This module provides an implementation for working with IOS configuration
@@ -358,31 +359,29 @@ time:
   sample: "22:28:34"
 """
 import json
+
 from ansible.module_utils._text import to_text
-from ansible.module_utils.connection import ConnectionError
-from ansible_collections.cisco.ios.plugins.module_utils.network.ios.ios import (
-    run_commands,
-    get_config,
-)
-from ansible_collections.cisco.ios.plugins.module_utils.network.ios.ios import (
-    get_defaults_flag,
-    get_connection,
-)
-from ansible_collections.cisco.ios.plugins.module_utils.network.ios.ios import (
-    ios_argument_spec,
-)
 from ansible.module_utils.basic import AnsibleModule
+from ansible.module_utils.connection import ConnectionError
 from ansible_collections.ansible.netcommon.plugins.module_utils.network.common.config import (
     NetworkConfig,
     dumps,
 )
 
+from ansible_collections.cisco.ios.plugins.module_utils.network.ios.ios import (
+    get_config,
+    get_connection,
+    get_defaults_flag,
+    ios_argument_spec,
+    run_commands,
+)
+
 
 def check_args(module, warnings):
     if module.params["multiline_delimiter"]:
         if len(module.params["multiline_delimiter"]) != 1:
             module.fail_json(
-                msg="multiline_delimiter value can only be a single character"
+                msg="multiline_delimiter value can only be a single character",
             )
 
 
@@ -423,13 +422,12 @@ def save_config(module, result):
         run_commands(module, "copy running-config startup-config\r")
     else:
         module.warn(
-            "Skipping command `copy running-config startup-config` due to check_mode.  Configuration not copied to non-volatile storage"
+            "Skipping command `copy running-config startup-config` due to check_mode.  Configuration not copied to non-volatile storage",
         )
 
 
 def main():
-    """ main entry point for module execution
-    """
+    """main entry point for module execution"""
     backup_spec = dict(filename=dict(), dir_path=dict(type="path"))
     argument_spec = dict(
         src=dict(type="str"),
@@ -438,7 +436,8 @@ def main():
         before=dict(type="list", elements="str"),
         after=dict(type="list", elements="str"),
         match=dict(
-            default="line", choices=["line", "strict", "exact", "none"]
+            default="line",
+            choices=["line", "strict", "exact", "none"],
         ),
         replace=dict(default="line", choices=["line", "block"]),
         multiline_delimiter=dict(default="@"),
@@ -448,7 +447,8 @@ def main():
         backup=dict(type="bool", default=False),
         backup_options=dict(type="dict", options=backup_spec),
         save_when=dict(
-            choices=["always", "never", "modified", "changed"], default="never"
+            choices=["always", "never", "modified", "changed"],
+            default="never",
         ),
         diff_against=dict(choices=["startup", "intended", "running"]),
         diff_ignore_lines=dict(type="list", elements="str"),
@@ -476,11 +476,7 @@ def main():
     contents = None
     flags = get_defaults_flag(module) if module.params["defaults"] else []
     connection = get_connection(module)
-    if (
-        module.params["backup"]
-        or module._diff
-        and module.params["diff_against"] == "running"
-    ):
+    if module.params["backup"] or module._diff and module.params["diff_against"] == "running":
         contents = get_config(module, flags=flags)
         config = NetworkConfig(indent=1, contents=contents)
         if module.params["backup"]:
@@ -522,9 +518,7 @@ def main():
                 if banner_diff:
                     connection.edit_banner(
                         candidate=json.dumps(banner_diff),
-                        multiline_delimiter=module.params[
-                            "multiline_delimiter"
-                        ],
+                        multiline_delimiter=module.params["multiline_delimiter"],
                     )
             result["changed"] = True
     running_config = module.params["running_config"]
@@ -533,13 +527,18 @@ def main():
         save_config(module, result)
     elif module.params["save_when"] == "modified":
         output = run_commands(
-            module, ["show running-config", "show startup-config"]
+            module,
+            ["show running-config", "show startup-config"],
         )
         running_config = NetworkConfig(
-            indent=1, contents=output[0], ignore_lines=diff_ignore_lines
+            indent=1,
+            contents=output[0],
+            ignore_lines=diff_ignore_lines,
         )
         startup_config = NetworkConfig(
-            indent=1, contents=output[1], ignore_lines=diff_ignore_lines
+            indent=1,
+            contents=output[1],
+            ignore_lines=diff_ignore_lines,
         )
         if running_config.sha1 != startup_config.sha1:
             save_config(module, result)
@@ -554,12 +553,14 @@ def main():
 
         # recreate the object in order to process diff_ignore_lines
         running_config = NetworkConfig(
-            indent=1, contents=contents, ignore_lines=diff_ignore_lines
+            indent=1,
+            contents=contents,
+            ignore_lines=diff_ignore_lines,
         )
         if module.params["diff_against"] == "running":
             if module.check_mode:
                 module.warn(
-                    "unable to perform diff against running-config due to check mode"
+                    "unable to perform diff against running-config due to check mode",
                 )
                 contents = None
             else:
@@ -574,7 +575,9 @@ def main():
             contents = module.params["intended_config"]
         if contents is not None:
             base_config = NetworkConfig(
-                indent=1, contents=contents, ignore_lines=diff_ignore_lines
+                indent=1,
+                contents=contents,
+                ignore_lines=diff_ignore_lines,
             )
             if running_config.sha1 != base_config.sha1:
                 if module.params["diff_against"] == "intended":
@@ -587,11 +590,11 @@ def main():
                     {
                         "changed": True,
                         "diff": {"before": str(before), "after": str(after)},
-                    }
+                    },
                 )
 
     if result.get("changed") and any(
-        (module.params["src"], module.params["lines"])
+        (module.params["src"], module.params["lines"]),
     ):
         msg = (
             "To ensure idempotency and correct diff the input configuration lines should be"
