@@ -17,13 +17,14 @@
 #
 from __future__ import absolute_import, division, print_function
 
+
 __metaclass__ = type
 DOCUMENTATION = """
 module: ios_facts
 author:
 - Peter Sprygada (@privateip)
 - Sumit Jaiswal (@justjais)
-short_description: Collect facts from remote devices running Cisco IOS
+short_description: Module to collect facts from remote devices.
 description:
 - Collects a base set of device facts from a remote device that is running IOS.  This
   module prepends all of the base network fact keys with C(ansible_net_<fact>).  The
@@ -47,7 +48,7 @@ options:
     - Specify a list of values to include a larger subset.
     - Use a value with an initial C(!) to collect all facts except that subset.
     required: false
-    default: '!config'
+    default: 'min'
     type: list
     elements: str
   gather_network_resources:
@@ -209,16 +210,15 @@ ansible_net_neighbors:
   type: dict
 """
 from ansible.module_utils.basic import AnsibleModule
+
 from ansible_collections.cisco.ios.plugins.module_utils.network.ios.argspec.facts.facts import (
     FactsArgs,
 )
 from ansible_collections.cisco.ios.plugins.module_utils.network.ios.facts.facts import (
-    Facts,
     FACT_RESOURCE_SUBSETS,
+    Facts,
 )
-from ansible_collections.cisco.ios.plugins.module_utils.network.ios.ios import (
-    ios_argument_spec,
-)
+from ansible_collections.cisco.ios.plugins.module_utils.network.ios.ios import ios_argument_spec
 
 
 def main():
@@ -230,18 +230,15 @@ def main():
     argument_spec = FactsArgs.argument_spec
     argument_spec.update(ios_argument_spec)
     module = AnsibleModule(
-        argument_spec=argument_spec, supports_check_mode=True
+        argument_spec=argument_spec,
+        supports_check_mode=True,
     )
     warnings = []
-    if module.params["gather_subset"] == "!config":
-        warnings.append(
-            "default value for `gather_subset` will be changed to `min` from `!config` v2.11 onwards"
-        )
 
     ansible_facts = {}
     if module.params.get("available_network_resources"):
         ansible_facts["available_network_resources"] = sorted(
-            FACT_RESOURCE_SUBSETS.keys()
+            FACT_RESOURCE_SUBSETS.keys(),
         )
     result = Facts(module).get_facts()
     additional_facts, additional_warnings = result
