@@ -17,12 +17,13 @@
 #
 from __future__ import absolute_import, division, print_function
 
+
 __metaclass__ = type
 DOCUMENTATION = """
 module: ios_ntp
 extends_documentation_fragment:
 - cisco.ios.ios
-short_description: Manages core NTP configuration.
+short_description: (deprecated, removed after 2024-01-01) Manages core NTP configuration.
 description:
 - Manages core NTP configuration.
 version_added: 1.0.0
@@ -115,34 +116,32 @@ commands:
     sample: ["no ntp server 10.0.255.10", "no ntp source Loopback0"]
 """
 import re
+
 from ansible.module_utils.basic import AnsibleModule
+
 from ansible_collections.cisco.ios.plugins.module_utils.network.ios.ios import (
     get_config,
-    load_config,
-)
-from ansible_collections.cisco.ios.plugins.module_utils.network.ios.ios import (
     ios_argument_spec,
+    load_config,
 )
 
 
 def parse_server(line, dest):
     if dest == "server":
+        vrf, server = None, None
         match = re.search(
             "(ntp\\sserver\\s)(vrf\\s\\w+\\s)?(\\d+\\.\\d+\\.\\d+\\.\\d+)",
             line,
             re.M,
         )
 
-        if match.group(2) and match.group(3):
+        if match and match.group(2) and match.group(3):
             vrf = match.group(2)
             server = match.group(3)
-
             return vrf, server
 
-        if match.group(3):
-            vrf = None
+        if match and match.group(3):
             server = match.group(3)
-
             return vrf, server
 
 
@@ -157,7 +156,9 @@ def parse_source_int(line, dest):
 def parse_acl(line, dest):
     if dest == "access-group":
         match = re.search(
-            "ntp\\saccess-group\\s(?:peer|serve)(?:\\s+)(\\S+)", line, re.M
+            "ntp\\saccess-group\\s(?:peer|serve)(?:\\s+)(\\S+)",
+            line,
+            re.M,
         )
         if match:
             acl = match.group(1)
@@ -173,7 +174,9 @@ def parse_logging(line, dest):
 def parse_auth_key(line, dest):
     if dest == "authentication-key":
         match = re.search(
-            "(ntp\\sauthentication-key\\s\\d+\\smd5\\s)(\\w+)", line, re.M
+            "(ntp\\sauthentication-key\\s\\d+\\smd5\\s)(\\w+)",
+            line,
+            re.M,
         )
         if match:
             auth_key = match.group(2)
@@ -259,7 +262,7 @@ def map_params_to_obj(module):
             "auth_key": module.params["auth_key"],
             "key_id": module.params["key_id"],
             "vrf": module.params["vrf"],
-        }
+        },
     )
 
     return obj
@@ -295,7 +298,7 @@ def map_obj_to_commands(want, have, module):
             if server_have and (vrf, server) in server_have:
                 if vrf is not None:
                     commands.append(
-                        "no ntp server vrf {0} {1}".format(vrf, server)
+                        "no ntp server vrf {0} {1}".format(vrf, server),
                     )
                 else:
                     commands.append("no ntp server {0}".format(server))
@@ -319,15 +322,16 @@ def map_obj_to_commands(want, have, module):
                 if key_id and key_id_have:
                     commands.append(
                         "no ntp authentication-key {0} md5 {1} 7".format(
-                            key_id, auth_key
-                        )
+                            key_id,
+                            auth_key,
+                        ),
                     )
         elif state == "present":
 
             if server is not None and (vrf, server) not in server_have:
                 if vrf is not None:
                     commands.append(
-                        "ntp server vrf {0} {1}".format(vrf, server)
+                        "ntp server vrf {0} {1}".format(vrf, server),
                     )
                 else:
                     commands.append("ntp server {0}".format(server))
@@ -338,11 +342,7 @@ def map_obj_to_commands(want, have, module):
             if acl is not None and acl != acl_have:
                 commands.append("ntp access-group peer {0}".format(acl))
 
-            if (
-                logging is not None
-                and logging != logging_have
-                and logging is not False
-            ):
+            if logging is not None and logging != logging_have and logging is not False:
                 commands.append("ntp logging")
 
             if auth is not None and auth != auth_have and auth is not False:
@@ -355,8 +355,9 @@ def map_obj_to_commands(want, have, module):
                 if key_id is not None:
                     commands.append(
                         "ntp authentication-key {0} md5 {1} 7".format(
-                            key_id, auth_key
-                        )
+                            key_id,
+                            auth_key,
+                        ),
                     )
     return commands
 
@@ -378,7 +379,8 @@ def main():
     argument_spec.update(ios_argument_spec)
 
     module = AnsibleModule(
-        argument_spec=argument_spec, supports_check_mode=True
+        argument_spec=argument_spec,
+        supports_check_mode=True,
     )
 
     result = {"changed": False}
