@@ -10,6 +10,7 @@ The module file for ios_snmp_server
 
 from __future__ import absolute_import, division, print_function
 
+
 __metaclass__ = type
 
 DOCUMENTATION = """
@@ -412,6 +413,41 @@ options:
           energywise:
             description: Enable SNMP energywise traps
             type: bool
+          envmon:
+            description: Allow envmon related traps
+            suboptions:
+              fan:
+                description: Enable SNMP envmon fan traps
+                suboptions:
+                  shutdown:
+                    description: Enable SNMP environmental monitor shutdown traps
+                    type: bool
+                  enable:
+                    description: Enable/disable fan traps
+                    type: bool
+                  status:
+                    description: Enable SNMP environmental status change traps
+                    type: bool
+                  supply:
+                    description: Enable SNMP environmental monitor supply traps
+                    type: bool
+                  temperature:
+                    description: Enable SNMP environmental monitor temperature traps
+                    type: bool
+                type: dict
+              shutdown:
+                description: Enable SNMP environmental monitor shutdown traps
+                type: bool
+              status:
+                description: Enable SNMP environmental status change traps
+                type: bool
+              supply:
+                description: Enable SNMP environmental monitor supply traps
+                type: bool
+              temperature:
+                description: Enable SNMP environmental monitor temperature traps
+                type: bool
+            type: dict
           ethernet:
             description: Allow ethernet traps
             suboptions:
@@ -828,7 +864,7 @@ options:
       - The states I(replaced) and I(overridden) have identical
         behaviour for this module.
     type: str
-short_description: snmp_server resource module
+short_description: Resource module to configure snmp server.
 version_added: 2.6.0
 """
 
@@ -1956,6 +1992,7 @@ parsed:
 """
 
 from ansible.module_utils.basic import AnsibleModule
+
 from ansible_collections.cisco.ios.plugins.module_utils.network.ios.argspec.snmp_server.snmp_server import (
     Snmp_serverArgs,
 )
