@@ -17,11 +17,12 @@
 #
 from __future__ import absolute_import, division, print_function
 
+
 __metaclass__ = type
 DOCUMENTATION = """
 module: ios_user
 author: Trishna Guha (@trishnaguha)
-short_description: Manage the aggregate of local users on Cisco IOS device
+short_description: Module to manage the aggregates of local users.
 description:
 - This module provides declarative management of the local usernames configured on
   network devices. It allows playbooks to manage either individual usernames or the
@@ -305,26 +306,27 @@ commands:
 import base64
 import hashlib
 import re
+
 from copy import deepcopy
 from functools import partial
+
 from ansible.module_utils.basic import AnsibleModule
+from ansible.module_utils.six import iteritems
 from ansible_collections.ansible.netcommon.plugins.module_utils.network.common.utils import (
     remove_default_spec,
 )
+
 from ansible_collections.cisco.ios.plugins.module_utils.network.ios.ios import (
     get_config,
+    ios_argument_spec,
     load_config,
 )
-from ansible_collections.cisco.ios.plugins.module_utils.network.ios.ios import (
-    ios_argument_spec,
-)
-from ansible.module_utils.six import iteritems
 
 
 def validate_privilege(value, module):
     if value and not 1 <= value <= 15:
         module.fail_json(
-            msg="privilege must be between 1 and 15, got %s" % value
+            msg="privilege must be between 1 and 15, got %s" % value,
         )
 
 
@@ -346,16 +348,11 @@ def sshkey_fingerprint(sshkey):
     if " " in sshkey:
         # ssh-rsa AAA...== comment
         keyparts = sshkey.split(" ")
-        keyparts[1] = (
-            hashlib.md5(base64.b64decode(keyparts[1])).hexdigest().upper()
-        )
+        keyparts[1] = hashlib.md5(base64.b64decode(keyparts[1])).hexdigest().upper()
         return " ".join(keyparts)
     else:
         # just the key, assume rsa type
-        return (
-            "ssh-rsa %s"
-            % hashlib.md5(base64.b64decode(sshkey)).hexdigest().upper()
-        )
+        return "ssh-rsa %s" % hashlib.md5(base64.b64decode(sshkey)).hexdigest().upper()
 
 
 def map_obj_to_commands(updates, module):
@@ -371,8 +368,7 @@ def map_obj_to_commands(updates, module):
 
     def add_hashed_password(command, want, x):
         command.append(
-            "username %s secret %s %s"
-            % (want["name"], x.get("type"), x.get("value"))
+            "username %s secret %s %s" % (want["name"], x.get("type"), x.get("value")),
         )
 
     def add_ssh(command, want, x=None):
@@ -401,14 +397,10 @@ def map_obj_to_commands(updates, module):
             add_ssh(commands, want, want["sshkey"])
         if needs_update(want, have, "configured_password"):
             if update_password == "always" or not have:
-                if (
-                    have
-                    and have["password_type"]
-                    and password_type != have["password_type"]
-                ):
+                if have and have["password_type"] and password_type != have["password_type"]:
                     module.fail_json(
                         msg="Can not have both a user password and a user secret."
-                        + " Please choose one or the other."
+                        + " Please choose one or the other.",
                     )
                 add(
                     commands,
@@ -437,7 +429,9 @@ def parse_sshkey(data, user):
     key_list = []
     if sshcfg:
         match = re.findall(
-            "key-hash (\\S+ \\S+(?: .+)?)$", sshcfg.group(), re.M
+            "key-hash (\\S+ \\S+(?: .+)?)$",
+            sshcfg.group(),
+            re.M,
         )
         if match:
             key_list = match
@@ -553,8 +547,7 @@ def update_objects(want, have):
 
 
 def main():
-    """ main entry point for module execution
-    """
+    """main entry point for module execution"""
     hashed_password_spec = dict(
         type=dict(type="int", required=True),
         value=dict(no_log=True, required=True),
@@ -563,11 +556,14 @@ def main():
         name=dict(),
         configured_password=dict(no_log=True),
         hashed_password=dict(
-            no_log=True, type="dict", options=hashed_password_spec
+            no_log=True,
+            type="dict",
+            options=hashed_password_spec,
         ),
         nopassword=dict(type="bool"),
         update_password=dict(
-            default="always", choices=["on_create", "always"]
+            default="always",
+            choices=["on_create", "always"],
         ),
         password_type=dict(default="secret", choices=["secret", "password"]),
         privilege=dict(type="int"),
