@@ -5,13 +5,14 @@
 
 from __future__ import absolute_import, division, print_function
 
+
 __metaclass__ = type
 
 
 DOCUMENTATION = """
 module: iosxr_config
 author: Ricardo Carrillo Cruz (@rcarrillocruz)
-short_description: Manage Cisco IOS XR configuration sections
+short_description: Module to manage configuration sections.
 description:
 - Cisco IOS XR configurations use a simple block indent file syntax for segmenting
   configuration into sections.  This module provides an implementation for working
@@ -253,29 +254,29 @@ time:
   sample: "22:28:34"
 """
 import re
-from ansible.module_utils._text import to_text, to_bytes
+
+from ansible.module_utils._text import to_bytes, to_text
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import ConnectionError
-from ansible_collections.cisco.iosxr.plugins.module_utils.network.iosxr.iosxr import (
-    load_config,
-    get_config,
-    get_connection,
-)
-from ansible_collections.cisco.iosxr.plugins.module_utils.network.iosxr.iosxr import (
-    iosxr_argument_spec,
-    copy_file,
-)
 from ansible_collections.ansible.netcommon.plugins.module_utils.network.common.config import (
     NetworkConfig,
     dumps,
 )
 
+from ansible_collections.cisco.iosxr.plugins.module_utils.network.iosxr.iosxr import (
+    copy_file,
+    get_config,
+    get_connection,
+    iosxr_argument_spec,
+    load_config,
+)
+
+
 DEFAULT_COMMIT_COMMENT = "configured by iosxr_config"
 
 
 def copy_file_to_node(module):
-    """ Copy config file to IOS-XR node. We use SFTP because older IOS-XR versions don't handle SCP very well.
-    """
+    """Copy config file to IOS-XR node. We use SFTP because older IOS-XR versions don't handle SCP very well."""
     src = "/tmp/ansible_config.txt"
     file = open(src, "wb")
     file.write(to_bytes(module.params["src"], errors="surrogate_or_strict"))
@@ -291,13 +292,13 @@ def check_args(module, warnings):
     if module.params["comment"]:
         if len(module.params["comment"]) > 60:
             module.fail_json(
-                msg="comment argument cannot be more than 60 characters"
+                msg="comment argument cannot be more than 60 characters",
             )
     if module.params["label"]:
         label = module.params["label"]
         if len(label) > 30:
             module.fail_json(
-                msg="label argument cannot be more than 30 characters"
+                msg="label argument cannot be more than 30 characters",
             )
         if not label[0].isalpha():
             module.fail_json(msg="label argument must begin with an alphabet")
@@ -305,13 +306,13 @@ def check_args(module, warnings):
         if not valid_chars:
             module.fail_json(
                 msg="label argument must only contain alphabets,"
-                + "digits, underscores or hyphens"
+                + "digits, underscores or hyphens",
             )
     if module.params["force"]:
         warnings.append(
             "The force argument is deprecated, please use "
             "match=none instead.  This argument will be "
-            "removed in the future"
+            "removed in the future",
         )
 
 
@@ -411,8 +412,7 @@ def run(module, result):
 
 
 def main():
-    """main entry point for module execution
-    """
+    """main entry point for module execution"""
     backup_spec = dict(filename=dict(), dir_path=dict(type="path"))
     argument_spec = dict(
         src=dict(type="path"),
@@ -421,7 +421,8 @@ def main():
         before=dict(type="list", elements="str"),
         after=dict(type="list", elements="str"),
         match=dict(
-            default="line", choices=["line", "strict", "exact", "none"]
+            default="line",
+            choices=["line", "strict", "exact", "none"],
         ),
         replace=dict(default="line", choices=["line", "block", "config"]),
         # this argument is deprecated in favor of setting match: none
@@ -475,7 +476,7 @@ def main():
         run(module, result)
 
     if result.get("changed") and any(
-        (module.params["src"], module.params["lines"])
+        (module.params["src"], module.params["lines"]),
     ):
         msg = (
             "To ensure idempotency and correct diff the input configuration lines should be"
