@@ -10,6 +10,7 @@ module: active_directory_trusted_domains_info
 short_description: Information module for Active Directory Trusted Domains
 description:
 - Get all Active Directory Trusted Domains.
+- This API gets the list of domains that are accessible through the given join.
 version_added: '1.0.0'
 extends_documentation_fragment:
   - cisco.ise.module_info
@@ -20,13 +21,15 @@ options:
     - Id path parameter.
     type: str
 requirements:
-- ciscoisesdk >= 1.1.0
+- ciscoisesdk >= 2.0.3
 - python >= 3.5
-seealso:
-# Reference by Internet resource
-- name: Active Directory Trusted Domains reference
-  description: Complete reference of the Active Directory Trusted Domains object model.
-  link: https://ciscoisesdk.readthedocs.io/en/latest/api/api.html#v3-0-0-summary
+notes:
+  - SDK Method used are
+    active_directory.ActiveDirectory.get_trusted_domains,
+
+  - Paths used are
+    put /ers/config/activedirectory/{id}/getTrustedDomains,
+
 """
 
 EXAMPLES = r"""
