@@ -10,6 +10,9 @@ module: allowed_protocols
 short_description: Resource module for Allowed Protocols
 description:
 - Manage operations create, update and delete of the resource Allowed Protocols.
+- This API creates an allowed protocol.
+- This API deletes an allowed protocol.
+- This API allows the client to update an allowed protocol.
 version_added: '1.0.0'
 extends_documentation_fragment:
   - cisco.ise.module
@@ -307,13 +310,19 @@ options:
         type: bool
     type: dict
 requirements:
-- ciscoisesdk >= 1.1.0
+- ciscoisesdk >= 2.0.3
 - python >= 3.5
-seealso:
-# Reference by Internet resource
-- name: Allowed Protocols reference
-  description: Complete reference of the Allowed Protocols object model.
-  link: https://ciscoisesdk.readthedocs.io/en/latest/api/api.html#v3-0-0-summary
+notes:
+  - SDK Method used are
+    allowed_protocols.AllowedProtocols.create_allowed_protocol,
+    allowed_protocols.AllowedProtocols.delete_allowed_protocol_by_id,
+    allowed_protocols.AllowedProtocols.update_allowed_protocol_by_id,
+
+  - Paths used are
+    post /ers/config/allowedprotocols,
+    delete /ers/config/allowedprotocols/{id},
+    put /ers/config/allowedprotocols/{id},
+
 """
 
 EXAMPLES = r"""
@@ -608,16 +617,18 @@ ise_response:
 ise_update_response:
   description: A dictionary or list with the response returned by the Cisco ISE Python SDK
   returned: always
-  version_added: "1.1.0"
+  version_added: '1.1.0'
   type: dict
   sample: >
     {
       "UpdatedFieldsList": {
-        "updatedField": {
-          "field": "string",
-          "oldValue": "string",
-          "newValue": "string"
-        },
+        "updatedField": [
+          {
+            "field": "string",
+            "oldValue": "string",
+            "newValue": "string"
+          }
+        ],
         "field": "string",
         "oldValue": "string",
         "newValue": "string"
