@@ -7,28 +7,31 @@
 DOCUMENTATION = r"""
 ---
 module: anc_endpoint_bulk_request
-short_description: Resource module for Anc Endpoint Bulk Request
+short_description: Resource module for ANC Endpoint Bulk Request
 description:
-- Manage operation update of the resource Anc Endpoint Bulk Request.
+- Manage operation update of the resource ANC Endpoint Bulk Request.
+- This API allows the client to submit the bulk request.
 version_added: '1.0.0'
 extends_documentation_fragment:
   - cisco.ise.module
 author: Rafael Campos (@racampos)
 options:
   operationType:
-    description: Anc Endpoint Bulk Request's operationType.
+    description: ANC Endpoint Bulk Request's operationType.
     type: str
   resourceMediaType:
-    description: Anc Endpoint Bulk Request's resourceMediaType.
+    description: ANC Endpoint Bulk Request's resourceMediaType.
     type: str
 requirements:
-- ciscoisesdk >= 1.1.0
+- ciscoisesdk >= 2.0.3
 - python >= 3.5
-seealso:
-# Reference by Internet resource
-- name: Anc Endpoint Bulk Request reference
-  description: Complete reference of the Anc Endpoint Bulk Request object model.
-  link: https://ciscoisesdk.readthedocs.io/en/latest/api/api.html#v3-0-0-summary
+notes:
+  - SDK Method used are
+    anc_endpoint.AncEndpoint.bulk_request_for_anc_endpoint,
+
+  - Paths used are
+    put /ers/config/ancendpoint/bulk/submit,
+
 """
 
 EXAMPLES = r"""
