@@ -10,6 +10,8 @@ module: certificate_profile
 short_description: Resource module for Certificate Profile
 description:
 - Manage operations create and update of the resource Certificate Profile.
+- This API allows the client to create a certificate profile.
+- This API allows the client to update a certificate profile.
 version_added: '1.0.0'
 extends_documentation_fragment:
   - cisco.ise.module
@@ -49,13 +51,17 @@ options:
       - an option only in AD).
     type: str
 requirements:
-- ciscoisesdk >= 1.1.0
+- ciscoisesdk >= 2.0.3
 - python >= 3.5
-seealso:
-# Reference by Internet resource
-- name: Certificate Profile reference
-  description: Complete reference of the Certificate Profile object model.
-  link: https://ciscoisesdk.readthedocs.io/en/latest/api/api.html#v3-0-0-summary
+notes:
+  - SDK Method used are
+    certificate_profile.CertificateProfile.create_certificate_profile,
+    certificate_profile.CertificateProfile.update_certificate_profile_by_id,
+
+  - Paths used are
+    post /ers/config/certificateprofile,
+    put /ers/config/certificateprofile/{id},
+
 """
 
 EXAMPLES = r"""
@@ -118,7 +124,7 @@ ise_response:
 ise_update_response:
   description: A dictionary or list with the response returned by the Cisco ISE Python SDK
   returned: always
-  version_added: "1.1.0"
+  version_added: '1.1.0'
   type: dict
   sample: >
     {
