@@ -7,22 +7,29 @@
 DOCUMENTATION = r"""
 ---
 module: csr_generate_intermediate_ca
-short_description: Resource module for Csr Generate Intermediate Ca
+short_description: Resource module for CSR Generate Intermediate CA
 description:
-- Manage operation create of the resource Csr Generate Intermediate Ca.
+- Manage operation create of the resource CSR Generate Intermediate CA.
+- CSR Generation for Intermediate Certificates.
 version_added: '1.0.0'
 extends_documentation_fragment:
   - cisco.ise.module
 author: Rafael Campos (@racampos)
 options: {}
 requirements:
-- ciscoisesdk >= 1.1.0
+- ciscoisesdk >= 2.0.3
 - python >= 3.5
 seealso:
-# Reference by Internet resource
-- name: Csr Generate Intermediate Ca reference
-  description: Complete reference of the Csr Generate Intermediate Ca object model.
-  link: https://ciscoisesdk.readthedocs.io/en/latest/api/api.html#v3-0-0-summary
+- name: Cisco ISE documentation for Certificates
+  description: Complete reference of the Certificates API.
+  link: https://developer.cisco.com/docs/identity-services-engine/v1/#!certificate-openapi
+notes:
+  - SDK Method used are
+    certificates.Certificates.generate_intermediate_ca_csr,
+
+  - Paths used are
+    post /api/v1/certs/certificate-signing-request/intermediate-ca,
+
 """
 
 EXAMPLES = r"""
