@@ -10,6 +10,9 @@ module: device_administration_global_exception_rules
 short_description: Resource module for Device Administration Global Exception Rules
 description:
 - Manage operations create, update and delete of the resource Device Administration Global Exception Rules.
+- Device Admin - Create global exception authorization rule.
+- Device Admin - Delete global exception authorization rule.
+- Device Admin - Update global exception authorization rule.
 version_added: '1.0.0'
 extends_documentation_fragment:
   - cisco.ise.module
@@ -46,9 +49,6 @@ options:
       condition:
         description: Device Administration Global Exception Rules's condition.
         suboptions:
-          attributeId:
-            description: Dictionary attribute id (Optional), used for additional verification.
-            type: str
           attributeName:
             description: Dictionary attribute name.
             type: str
@@ -60,6 +60,7 @@ options:
           children:
             description: In case type is andBlock or orBlock addtional conditions will
               be aggregated under this logical (OR/AND) condition.
+            elements: dict
             suboptions:
               conditionType:
                 description: <ul><li>Inidicates whether the record is the condition
@@ -94,12 +95,11 @@ options:
               that additional conditions are present under the children field</li></ul>.
             type: str
           datesRange:
-            description: <p>Defines for which date/s TimeAndDate condition will be matched
-              or NOT matched if used in exceptionDates prooperty<br> Options are - Date
-              range, for specific date, the same date should be used for start/end date
-              <br> Default - no specific dates<br> In order to reset the dates to have
-              no specific dates Date format - yyyy-mm-dd (MM = month, dd = day, yyyy
-              = year)</p>.
+            description: <p>Defines for which date/s TimeAndDate condition will be matched<br>
+              Options are - Date range, for specific date, the same date should be used
+              for start/end date <br> Default - no specific dates<br> In order to reset
+              the dates to have no specific dates Date format - yyyy-mm-dd (MM = month,
+              dd = day, yyyy = year)</p>.
             suboptions:
               endDate:
                 description: Device Administration Global Exception Rules's endDate.
@@ -109,12 +109,11 @@ options:
                 type: str
             type: dict
           datesRangeException:
-            description: <p>Defines for which date/s TimeAndDate condition will be matched
-              or NOT matched if used in exceptionDates prooperty<br> Options are - Date
-              range, for specific date, the same date should be used for start/end date
-              <br> Default - no specific dates<br> In order to reset the dates to have
-              no specific dates Date format - yyyy-mm-dd (MM = month, dd = day, yyyy
-              = year)</p>.
+            description: <p>Defines for which date/s TimeAndDate condition will be matched<br>
+              Options are - Date range, for specific date, the same date should be used
+              for start/end date <br> Default - no specific dates<br> In order to reset
+              the dates to have no specific dates Date format - yyyy-mm-dd (MM = month,
+              dd = day, yyyy = year)</p>.
             suboptions:
               endDate:
                 description: Device Administration Global Exception Rules's endDate.
@@ -134,8 +133,8 @@ options:
             type: str
           hoursRange:
             description: <p>Defines for which hours a TimeAndDate condition will be
-              matched or not matched if used in exceptionHours property<br> Time foramt
-              - hh mm ( h = hour , mm = minutes ) <br> Default - All Day </p>.
+              matched<br> Time format - hh mm ( h = hour , mm = minutes ) <br> Default
+              - All Day </p>.
             suboptions:
               endTime:
                 description: Device Administration Global Exception Rules's endTime.
@@ -146,8 +145,8 @@ options:
             type: dict
           hoursRangeException:
             description: <p>Defines for which hours a TimeAndDate condition will be
-              matched or not matched if used in exceptionHours property<br> Time foramt
-              - hh mm ( h = hour , mm = minutes ) <br> Default - All Day </p>.
+              matched<br> Time format - hh mm ( h = hour , mm = minutes ) <br> Default
+              - All Day </p>.
             suboptions:
               endTime:
                 description: Device Administration Global Exception Rules's endTime.
@@ -215,13 +214,23 @@ options:
         type: str
     type: dict
 requirements:
-- ciscoisesdk >= 1.1.0
+- ciscoisesdk >= 2.0.3
 - python >= 3.5
 seealso:
-# Reference by Internet resource
-- name: Device Administration Global Exception Rules reference
-  description: Complete reference of the Device Administration Global Exception Rules object model.
-  link: https://ciscoisesdk.readthedocs.io/en/latest/api/api.html#v3-0-0-summary
+- name: Cisco ISE documentation for Device Administration - Authorization Global Exception Rules
+  description: Complete reference of the Device Administration - Authorization Global Exception Rules API.
+  link: https://developer.cisco.com/docs/identity-services-engine/v1/#!policy-openapi
+notes:
+  - SDK Method used are
+    device_administration_authorization_global_exception_rules.DeviceAdministrationAuthorizationGlobalExceptionRules.create_device_admin_policy_set_global_exception,
+    device_administration_authorization_global_exception_rules.DeviceAdministrationAuthorizationGlobalExceptionRules.delete_device_admin_policy_set_global_exception_by_rule_id,
+    device_administration_authorization_global_exception_rules.DeviceAdministrationAuthorizationGlobalExceptionRules.update_device_admin_policy_set_global_exception_by_rule_id,
+
+  - Paths used are
+    post /device-admin/policy-set/global-exception,
+    delete /device-admin/policy-set/global-exception/{id},
+    put /device-admin/policy-set/global-exception/{id},
+
 """
 
 EXAMPLES = r"""
@@ -241,7 +250,6 @@ EXAMPLES = r"""
     profile: string
     rule:
       condition:
-        attributeId: string
         attributeName: string
         attributeValue: string
         children:
@@ -303,7 +311,6 @@ EXAMPLES = r"""
     profile: string
     rule:
       condition:
-        attributeId: string
         attributeName: string
         attributeValue: string
         children:
@@ -388,7 +395,6 @@ ise_response:
           "id": "string",
           "name": "string",
           "attributeName": "string",
-          "attributeId": "string",
           "attributeValue": "string",
           "dictionaryName": "string",
           "dictionaryValue": "string",
@@ -439,7 +445,7 @@ ise_response:
 ise_update_response:
   description: A dictionary or list with the response returned by the Cisco ISE Python SDK
   returned: always
-  version_added: "1.1.0"
+  version_added: '1.1.0'
   type: dict
   sample: >
     {
@@ -466,7 +472,6 @@ ise_update_response:
             "id": "string",
             "name": "string",
             "attributeName": "string",
-            "attributeId": "string",
             "attributeValue": "string",
             "dictionaryName": "string",
             "dictionaryValue": "string",
