@@ -10,19 +10,26 @@ module: device_administration_identity_stores_info
 short_description: Information module for Device Administration Identity Stores
 description:
 - Get all Device Administration Identity Stores.
+- Device Admin - Return list of identity stores for authentication.
 version_added: '1.0.0'
 extends_documentation_fragment:
   - cisco.ise.module_info
 author: Rafael Campos (@racampos)
 options: {}
 requirements:
-- ciscoisesdk >= 1.1.0
+- ciscoisesdk >= 2.0.3
 - python >= 3.5
 seealso:
-# Reference by Internet resource
-- name: Device Administration Identity Stores reference
-  description: Complete reference of the Device Administration Identity Stores object model.
-  link: https://ciscoisesdk.readthedocs.io/en/latest/api/api.html#v3-0-0-summary
+- name: Cisco ISE documentation for Device Administration - Identity Stores
+  description: Complete reference of the Device Administration - Identity Stores API.
+  link: https://developer.cisco.com/docs/identity-services-engine/v1/#!policy-openapi
+notes:
+  - SDK Method used are
+    device_administration_identity_stores.DeviceAdministrationIdentityStores.get_device_admin_identity_stores,
+
+  - Paths used are
+    get /device-admin/identity-stores,
+
 """
 
 EXAMPLES = r"""
