@@ -10,19 +10,26 @@ module: device_administration_profiles_info
 short_description: Information module for Device Administration Profiles
 description:
 - Get all Device Administration Profiles.
+- Device Admin - Returns list of shell profiles.
 version_added: '1.0.0'
 extends_documentation_fragment:
   - cisco.ise.module_info
 author: Rafael Campos (@racampos)
 options: {}
 requirements:
-- ciscoisesdk >= 1.1.0
+- ciscoisesdk >= 2.0.3
 - python >= 3.5
 seealso:
-# Reference by Internet resource
-- name: Device Administration Profiles reference
-  description: Complete reference of the Device Administration Profiles object model.
-  link: https://ciscoisesdk.readthedocs.io/en/latest/api/api.html#v3-0-0-summary
+- name: Cisco ISE documentation for Device Administration - Profiles
+  description: Complete reference of the Device Administration - Profiles API.
+  link: https://developer.cisco.com/docs/identity-services-engine/v1/#!policy-openapi
+notes:
+  - SDK Method used are
+    device_administration_profiles.DeviceAdministrationProfiles.get_device_admin_profiles,
+
+  - Paths used are
+    get /device-admin/shell-profiles,
+
 """
 
 EXAMPLES = r"""
