@@ -10,19 +10,26 @@ module: device_administration_service_names_info
 short_description: Information module for Device Administration Service Names
 description:
 - Get all Device Administration Service Names.
+- Returns list of Allowed Protocols and Server Sequences for Device Admin Policy.
 version_added: '1.0.0'
 extends_documentation_fragment:
   - cisco.ise.module_info
 author: Rafael Campos (@racampos)
 options: {}
 requirements:
-- ciscoisesdk >= 1.1.0
+- ciscoisesdk >= 2.0.3
 - python >= 3.5
 seealso:
-# Reference by Internet resource
-- name: Device Administration Service Names reference
-  description: Complete reference of the Device Administration Service Names object model.
-  link: https://ciscoisesdk.readthedocs.io/en/latest/api/api.html#v3-0-0-summary
+- name: Cisco ISE documentation for Device Administration - Service Names
+  description: Complete reference of the Device Administration - Service Names API.
+  link: https://developer.cisco.com/docs/identity-services-engine/v1/#!policy-openapi
+notes:
+  - SDK Method used are
+    device_administration_service_names.DeviceAdministrationServiceNames.get_device_admin_service_names,
+
+  - Paths used are
+    get /device-admin/service-names,
+
 """
 
 EXAMPLES = r"""
