@@ -10,6 +10,7 @@ module: egress_matrix_cell_bulk_request
 short_description: Resource module for Egress Matrix Cell Bulk Request
 description:
 - Manage operation update of the resource Egress Matrix Cell Bulk Request.
+- This API allows the client to submit the bulk request.
 version_added: '1.0.0'
 extends_documentation_fragment:
   - cisco.ise.module
@@ -22,13 +23,15 @@ options:
     description: Egress Matrix Cell Bulk Request's resourceMediaType.
     type: str
 requirements:
-- ciscoisesdk >= 1.1.0
+- ciscoisesdk >= 2.0.3
 - python >= 3.5
-seealso:
-# Reference by Internet resource
-- name: Egress Matrix Cell Bulk Request reference
-  description: Complete reference of the Egress Matrix Cell Bulk Request object model.
-  link: https://ciscoisesdk.readthedocs.io/en/latest/api/api.html#v3-0-0-summary
+notes:
+  - SDK Method used are
+    egress_matrix_cell.EgressMatrixCell.bulk_request_for_egress_matrix_cell,
+
+  - Paths used are
+    put /ers/config/egressmatrixcell/bulk/submit,
+
 """
 
 EXAMPLES = r"""
