@@ -10,19 +10,31 @@ module: egress_matrix_cell_clone
 short_description: Resource module for Egress Matrix Cell Clone
 description:
 - Manage operation update of the resource Egress Matrix Cell Clone.
+- This API allows the client to clone an egress matrix cell.
 version_added: '1.0.0'
 extends_documentation_fragment:
   - cisco.ise.module
 author: Rafael Campos (@racampos)
-options: {}
+options:
+  dstSGtId:
+    description: DstSGtId path parameter.
+    type: str
+  id:
+    description: Id path parameter.
+    type: str
+  srcSGtId:
+    description: SrcSGtId path parameter.
+    type: str
 requirements:
-- ciscoisesdk >= 1.1.0
+- ciscoisesdk >= 2.0.3
 - python >= 3.5
-seealso:
-# Reference by Internet resource
-- name: Egress Matrix Cell Clone reference
-  description: Complete reference of the Egress Matrix Cell Clone object model.
-  link: https://ciscoisesdk.readthedocs.io/en/latest/api/api.html#v3-0-0-summary
+notes:
+  - SDK Method used are
+    egress_matrix_cell.EgressMatrixCell.clone_matrix_cell,
+
+  - Paths used are
+    put /ers/config/egressmatrixcell/clonecell/{id}/srcSgt/{srcSgtId}/dstSgt/{dstSgtId},
+
 """
 
 EXAMPLES = r"""
