@@ -10,19 +10,25 @@ module: egress_matrix_cell_set_all_status
 short_description: Resource module for Egress Matrix Cell Set All Status
 description:
 - Manage operation update of the resource Egress Matrix Cell Set All Status.
+- This API allows the client to set status of all the egress matrix cells.
 version_added: '1.0.0'
 extends_documentation_fragment:
   - cisco.ise.module
 author: Rafael Campos (@racampos)
-options: {}
+options:
+  status:
+    description: Status path parameter.
+    type: str
 requirements:
-- ciscoisesdk >= 1.1.0
+- ciscoisesdk >= 2.0.3
 - python >= 3.5
-seealso:
-# Reference by Internet resource
-- name: Egress Matrix Cell Set All Status reference
-  description: Complete reference of the Egress Matrix Cell Set All Status object model.
-  link: https://ciscoisesdk.readthedocs.io/en/latest/api/api.html#v3-0-0-summary
+notes:
+  - SDK Method used are
+    egress_matrix_cell.EgressMatrixCell.set_all_cells_status,
+
+  - Paths used are
+    put /ers/config/egressmatrixcell/status/{status},
+
 """
 
 EXAMPLES = r"""
