@@ -10,19 +10,25 @@ module: endpoint_release_rejected_endpoint
 short_description: Resource module for Endpoint Release Rejected Endpoint
 description:
 - Manage operation update of the resource Endpoint Release Rejected Endpoint.
+- This API allows the client to release a rejected endpoint.
 version_added: '1.0.0'
 extends_documentation_fragment:
   - cisco.ise.module
 author: Rafael Campos (@racampos)
-options: {}
+options:
+  id:
+    description: Id path parameter.
+    type: str
 requirements:
-- ciscoisesdk >= 1.1.0
+- ciscoisesdk >= 2.0.3
 - python >= 3.5
-seealso:
-# Reference by Internet resource
-- name: Endpoint Release Rejected Endpoint reference
-  description: Complete reference of the Endpoint Release Rejected Endpoint object model.
-  link: https://ciscoisesdk.readthedocs.io/en/latest/api/api.html#v3-0-0-summary
+notes:
+  - SDK Method used are
+    endpoint.Endpoint.release_rejected_endpoint,
+
+  - Paths used are
+    put /ers/config/endpoint/{id}/releaserejectedendpoint,
+
 """
 
 EXAMPLES = r"""
