@@ -7,9 +7,9 @@
 DOCUMENTATION = r"""
 ---
 module: mnt_session_by_username_info
-short_description: Information module for Mnt Session By Username
+short_description: Information module for MNT Session By Username
 description:
-- Get Mnt Session By Username by name.
+- Get MNT Session By Username by name.
 version_added: '1.0.0'
 extends_documentation_fragment:
   - cisco.ise.module_info
@@ -20,17 +20,19 @@ options:
     - Username path parameter.
     type: str
 requirements:
-- ciscoisesdk >= 1.1.0
+- ciscoisesdk >= 2.0.3
 - python >= 3.5
-seealso:
-# Reference by Internet resource
-- name: Mnt Session By Username reference
-  description: Complete reference of the Mnt Session By Username object model.
-  link: https://ciscoisesdk.readthedocs.io/en/latest/api/api.html#v3-0-0-summary
+notes:
+  - SDK Method used are
+    misc.Misc.get_sessions_by_username,
+
+  - Paths used are
+    get /Session/UserName/{username},
+
 """
 
 EXAMPLES = r"""
-- name: Get Mnt Session By Username by name
+- name: Get MNT Session By Username by name
   cisco.ise.mnt_session_by_username_info:
     ise_hostname: "{{ise_hostname}}"
     ise_username: "{{ise_username}}"
@@ -46,6 +48,6 @@ ise_response:
   description: A dictionary or list with the response returned by the Cisco ISE Python SDK
   returned: always
   type: dict
-  sample:
-  - {}
+  sample: >
+    {}
 """
