@@ -7,26 +7,28 @@
 DOCUMENTATION = r"""
 ---
 module: mnt_session_posture_count_info
-short_description: Information module for Mnt Session Posture Count
+short_description: Information module for MNT Session Posture Count
 description:
-- Get all Mnt Session Posture Count.
+- Get all MNT Session Posture Count.
 version_added: '1.0.0'
 extends_documentation_fragment:
   - cisco.ise.module_info
 author: Rafael Campos (@racampos)
 options: {}
 requirements:
-- ciscoisesdk >= 1.1.0
+- ciscoisesdk >= 2.0.3
 - python >= 3.5
-seealso:
-# Reference by Internet resource
-- name: Mnt Session Posture Count reference
-  description: Complete reference of the Mnt Session Posture Count object model.
-  link: https://ciscoisesdk.readthedocs.io/en/latest/api/api.html#v3-0-0-summary
+notes:
+  - SDK Method used are
+    misc.Misc.get_posture_count,
+
+  - Paths used are
+    get /Session/PostureCount,
+
 """
 
 EXAMPLES = r"""
-- name: Get all Mnt Session Posture Count
+- name: Get all MNT Session Posture Count
   cisco.ise.mnt_session_posture_count_info:
     ise_hostname: "{{ise_hostname}}"
     ise_username: "{{ise_username}}"
