@@ -10,19 +10,26 @@ module: network_access_global_exception_rules_reset_hitcount
 short_description: Resource module for Network Access Global Exception Rules Reset Hitcount
 description:
 - Manage operation create of the resource Network Access Global Exception Rules Reset Hitcount.
+- Network Access - Reset HitCount for Global Exceptions.
 version_added: '1.0.0'
 extends_documentation_fragment:
   - cisco.ise.module
 author: Rafael Campos (@racampos)
 options: {}
 requirements:
-- ciscoisesdk >= 1.1.0
+- ciscoisesdk >= 2.0.3
 - python >= 3.5
 seealso:
-# Reference by Internet resource
-- name: Network Access Global Exception Rules Reset Hitcount reference
-  description: Complete reference of the Network Access Global Exception Rules Reset Hitcount object model.
-  link: https://ciscoisesdk.readthedocs.io/en/latest/api/api.html#v3-0-0-summary
+- name: Cisco ISE documentation for Network Access - Authorization Global Exception Rules
+  description: Complete reference of the Network Access - Authorization Global Exception Rules API.
+  link: https://developer.cisco.com/docs/identity-services-engine/v1/#!policy-openapi
+notes:
+  - SDK Method used are
+    network_access_authorization_global_exception_rules.NetworkAccessAuthorizationGlobalExceptionRules.reset_hit_counts_network_access_global_exceptions,
+
+  - Paths used are
+    post /network-access/policy-set/global-exception/reset-hitcount,
+
 """
 
 EXAMPLES = r"""
