@@ -10,19 +10,26 @@ module: network_access_identity_stores_info
 short_description: Information module for Network Access Identity Stores
 description:
 - Get all Network Access Identity Stores.
+- Network Access - Return list of identity stores for authentication policy.
 version_added: '1.0.0'
 extends_documentation_fragment:
   - cisco.ise.module_info
 author: Rafael Campos (@racampos)
 options: {}
 requirements:
-- ciscoisesdk >= 1.1.0
+- ciscoisesdk >= 2.0.3
 - python >= 3.5
 seealso:
-# Reference by Internet resource
-- name: Network Access Identity Stores reference
-  description: Complete reference of the Network Access Identity Stores object model.
-  link: https://ciscoisesdk.readthedocs.io/en/latest/api/api.html#v3-0-0-summary
+- name: Cisco ISE documentation for Network Access - Identity Stores
+  description: Complete reference of the Network Access - Identity Stores API.
+  link: https://developer.cisco.com/docs/identity-services-engine/v1/#!policy-openapi
+notes:
+  - SDK Method used are
+    network_access_identity_stores.NetworkAccessIdentityStores.get_network_access_identity_stores,
+
+  - Paths used are
+    get /network-access/identity-stores,
+
 """
 
 EXAMPLES = r"""
