@@ -10,19 +10,26 @@ module: network_access_profiles_info
 short_description: Information module for Network Access Profiles
 description:
 - Get all Network Access Profiles.
+- Network Access - Returns list of authorization profiles.
 version_added: '1.0.0'
 extends_documentation_fragment:
   - cisco.ise.module_info
 author: Rafael Campos (@racampos)
 options: {}
 requirements:
-- ciscoisesdk >= 1.1.0
+- ciscoisesdk >= 2.0.3
 - python >= 3.5
 seealso:
-# Reference by Internet resource
-- name: Network Access Profiles reference
-  description: Complete reference of the Network Access Profiles object model.
-  link: https://ciscoisesdk.readthedocs.io/en/latest/api/api.html#v3-0-0-summary
+- name: Cisco ISE documentation for Network Access - Profiles
+  description: Complete reference of the Network Access - Profiles API.
+  link: https://developer.cisco.com/docs/identity-services-engine/v1/#!policy-openapi
+notes:
+  - SDK Method used are
+    network_access_profiles.NetworkAccessProfiles.get_network_access_profiles,
+
+  - Paths used are
+    get /network-access/authorization-profiles,
+
 """
 
 EXAMPLES = r"""
