@@ -10,19 +10,26 @@ module: network_access_security_groups_info
 short_description: Information module for Network Access Security Groups
 description:
 - Get all Network Access Security Groups.
+- Network Access - Return list of available security groups for authorization.
 version_added: '1.0.0'
 extends_documentation_fragment:
   - cisco.ise.module_info
 author: Rafael Campos (@racampos)
 options: {}
 requirements:
-- ciscoisesdk >= 1.1.0
+- ciscoisesdk >= 2.0.3
 - python >= 3.5
 seealso:
-# Reference by Internet resource
-- name: Network Access Security Groups reference
-  description: Complete reference of the Network Access Security Groups object model.
-  link: https://ciscoisesdk.readthedocs.io/en/latest/api/api.html#v3-0-0-summary
+- name: Cisco ISE documentation for Network Access - Security Groups
+  description: Complete reference of the Network Access - Security Groups API.
+  link: https://developer.cisco.com/docs/identity-services-engine/v1/#!policy-openapi
+notes:
+  - SDK Method used are
+    network_access_security_groups.NetworkAccessSecurityGroups.get_network_access_security_groups,
+
+  - Paths used are
+    get /network-access/security-groups,
+
 """
 
 EXAMPLES = r"""
