@@ -10,19 +10,26 @@ module: network_access_service_name_info
 short_description: Information module for Network Access Service Name
 description:
 - Get all Network Access Service Name.
+- Returns list of Allowed Protocols and Server Sequences for Network Access.
 version_added: '1.0.0'
 extends_documentation_fragment:
   - cisco.ise.module_info
 author: Rafael Campos (@racampos)
 options: {}
 requirements:
-- ciscoisesdk >= 1.1.0
+- ciscoisesdk >= 2.0.3
 - python >= 3.5
 seealso:
-# Reference by Internet resource
-- name: Network Access Service Name reference
-  description: Complete reference of the Network Access Service Name object model.
-  link: https://ciscoisesdk.readthedocs.io/en/latest/api/api.html#v3-0-0-summary
+- name: Cisco ISE documentation for Network Access - Service Names
+  description: Complete reference of the Network Access - Service Names API.
+  link: https://developer.cisco.com/docs/identity-services-engine/v1/#!policy-openapi
+notes:
+  - SDK Method used are
+    network_access_service_names.NetworkAccessServiceNames.get_network_access_service_names,
+
+  - Paths used are
+    get /network-access/service-names,
+
 """
 
 EXAMPLES = r"""
