@@ -11,6 +11,8 @@ short_description: Information module for Portal Global Setting
 description:
 - Get all Portal Global Setting.
 - Get Portal Global Setting by id.
+- This API allows the client to get all the portal global settings.
+- This API allows the client to get the portal global settings by id.
 version_added: '1.0.0'
 extends_documentation_fragment:
   - cisco.ise.module_info
@@ -39,14 +41,22 @@ options:
   filter:
     description:
     - >
-      Filter query parameter. <br/> **Simple filtering** should be available through the filter query string
-      parameter. The structure of a filter is a triplet of field operator and value separated with dots. More than
-      one filter can be sent. The logical operator common to ALL filter criteria will be by default AND, and can
-      be changed by using the "filterType=or" query string parameter. Each resource Data model description should
-      specify if an attribute is a filtered field. <br/> Operator | Description <br/>
-      ------------|----------------- <br/> EQ | Equals <br/> NEQ | Not Equals <br/> GT | Greater Than <br/> LT |
-      Less Then <br/> STARTSW | Starts With <br/> NSTARTSW | Not Starts With <br/> ENDSW | Ends With <br/> NENDSW
-      | Not Ends With <br/> CONTAINS | Contains <br/> NCONTAINS | Not Contains <br/>.
+      Filter query parameter. **Simple filtering** should be available through the filter query string parameter.
+      The structure of a filter is a triplet of field operator and value separated with dots. More than one filter
+      can be sent. The logical operator common to ALL filter criteria will be by default AND, and can be changed
+      by using the "filterType=or" query string parameter.
+    - Each resource Data model description should specify if an attribute is a filtered field.
+    - The 'EQ' operator describes 'Equals'.
+    - The 'NEQ' operator describes 'Not Equals'.
+    - The 'GT' operator describes 'Greater Than'.
+    - The 'LT' operator describes 'Less Than'.
+    - The 'STARTSW' operator describes 'Starts With'.
+    - The 'NSTARTSW' operator describes 'Not Starts With'.
+    - The 'ENDSW' operator describes 'Ends With'.
+    - The 'NENDSW' operator describes 'Not Ends With'.
+    - The 'CONTAINS' operator describes 'Contains'.
+    - The 'NCONTAINS' operator describes 'Not Contains'.
+    elements: str
     type: list
   filterType:
     description:
@@ -55,13 +65,17 @@ options:
       can be changed by using the parameter.
     type: str
 requirements:
-- ciscoisesdk >= 1.1.0
+- ciscoisesdk >= 2.0.3
 - python >= 3.5
-seealso:
-# Reference by Internet resource
-- name: Portal Global Setting reference
-  description: Complete reference of the Portal Global Setting object model.
-  link: https://ciscoisesdk.readthedocs.io/en/latest/api/api.html#v3-0-0-summary
+notes:
+  - SDK Method used are
+    portal_global_setting.PortalGlobalSetting.get_portal_global_setting_by_id,
+    portal_global_setting.PortalGlobalSetting.get_portal_global_settings_generator,
+
+  - Paths used are
+    get /ers/config/portalglobalsetting,
+    get /ers/config/portalglobalsetting/{id},
+
 """
 
 EXAMPLES = r"""
@@ -105,16 +119,18 @@ ise_response:
         "type": "string"
       }
     }
+
 ise_responses:
   description: A dictionary or list with the response returned by the Cisco ISE Python SDK
   returned: always
-  version_added: "1.1.0"
+  version_added: '1.1.0'
   type: list
   elements: dict
   sample: >
     [
       {
         "id": "string",
+        "customization": "string",
         "link": {
           "rel": "string",
           "href": "string",
