@@ -7,25 +7,27 @@
 DOCUMENTATION = r"""
 ---
 module: pxgrid_account_activate
-short_description: Resource module for Pxgrid Account Activate
+short_description: Resource module for pxGrid Account Activate
 description:
-- Manage operation create of the resource Pxgrid Account Activate.
+- Manage operation create of the resource pxGrid Account Activate.
 version_added: '1.0.0'
 extends_documentation_fragment:
   - cisco.ise.module
 author: Rafael Campos (@racampos)
 options:
   description:
-    description: Pxgrid Account Activate's description.
+    description: pxGrid Account Activate's description.
     type: str
 requirements:
-- ciscoisesdk >= 1.1.0
+- ciscoisesdk >= 2.0.3
 - python >= 3.5
-seealso:
-# Reference by Internet resource
-- name: Pxgrid Account Activate reference
-  description: Complete reference of the Pxgrid Account Activate object model.
-  link: https://ciscoisesdk.readthedocs.io/en/latest/api/api.html#v3-0-0-summary
+notes:
+  - SDK Method used are
+    consumer.Consumer.activate_account,
+
+  - Paths used are
+    post /control/AccountActivate,
+
 """
 
 EXAMPLES = r"""
