@@ -7,22 +7,24 @@
 DOCUMENTATION = r"""
 ---
 module: pxgrid_authorization
-short_description: Resource module for Pxgrid Authorization
+short_description: Resource module for pxGrid Authorization
 description:
-- Manage operation create of the resource Pxgrid Authorization.
+- Manage operation create of the resource pxGrid Authorization.
 version_added: '1.0.0'
 extends_documentation_fragment:
   - cisco.ise.module
 author: Rafael Campos (@racampos)
 options: {}
 requirements:
-- ciscoisesdk >= 1.1.0
+- ciscoisesdk >= 2.0.3
 - python >= 3.5
-seealso:
-# Reference by Internet resource
-- name: Pxgrid Authorization reference
-  description: Complete reference of the Pxgrid Authorization object model.
-  link: https://ciscoisesdk.readthedocs.io/en/latest/api/api.html#v3-0-0-summary
+notes:
+  - SDK Method used are
+    provider.Provider.authorization,
+
+  - Paths used are
+    post /control/Authorization,
+
 """
 
 EXAMPLES = r"""
