@@ -7,26 +7,28 @@
 DOCUMENTATION = r"""
 ---
 module: pxgrid_bindings_info
-short_description: Information module for Pxgrid Bindings Info
+short_description: Information module for pxGrid Bindings Info
 description:
-- Get Pxgrid Bindings Info.
+- Get pxGrid Bindings Info.
 version_added: '1.0.0'
 extends_documentation_fragment:
   - cisco.ise.module_info
 author: Rafael Campos (@racampos)
 options: {}
 requirements:
-- ciscoisesdk >= 1.1.0
+- ciscoisesdk >= 2.0.3
 - python >= 3.5
-seealso:
-# Reference by Internet resource
-- name: Pxgrid Bindings Info reference
-  description: Complete reference of the Pxgrid Bindings Info object model.
-  link: https://ciscoisesdk.readthedocs.io/en/latest/api/api.html#v3-0-0-summary
+notes:
+  - SDK Method used are
+    trust_sec_sxp.TrustSecSxp.get_bindings,
+
+  - Paths used are
+    post /ise/sxp/getBindings,
+
 """
 
 EXAMPLES = r"""
-- name: Get all Pxgrid Bindings Info
+- name: Get all pxGrid Bindings Info
   cisco.ise.pxgrid_bindings_info:
     ise_hostname: "{{ise_hostname}}"
     ise_username: "{{ise_username}}"
@@ -41,6 +43,6 @@ ise_response:
   description: A dictionary or list with the response returned by the Cisco ISE Python SDK
   returned: always
   type: dict
-  sample:
-  - {}
+  sample: >
+    {}
 """
