@@ -7,26 +7,28 @@
 DOCUMENTATION = r"""
 ---
 module: pxgrid_endpoints_by_type_info
-short_description: Information module for Pxgrid Endpoints By Type Info
+short_description: Information module for pxGrid Endpoints By Type Info
 description:
-- Get Pxgrid Endpoints By Type Info.
+- Get pxGrid Endpoints By Type Info.
 version_added: '1.0.0'
 extends_documentation_fragment:
   - cisco.ise.module_info
 author: Rafael Campos (@racampos)
 options: {}
 requirements:
-- ciscoisesdk >= 1.1.0
+- ciscoisesdk >= 2.0.3
 - python >= 3.5
-seealso:
-# Reference by Internet resource
-- name: Pxgrid Endpoints By Type Info reference
-  description: Complete reference of the Pxgrid Endpoints By Type Info object model.
-  link: https://ciscoisesdk.readthedocs.io/en/latest/api/api.html#v3-0-0-summary
+notes:
+  - SDK Method used are
+    mdm.Mdm.get_endpoints_by_type,
+
+  - Paths used are
+    post /ise/mdm/getEndpointsByType,
+
 """
 
 EXAMPLES = r"""
-- name: Get all Pxgrid Endpoints By Type Info
+- name: Get all pxGrid Endpoints By Type Info
   cisco.ise.pxgrid_endpoints_by_type_info:
     ise_hostname: "{{ise_hostname}}"
     ise_username: "{{ise_username}}"
@@ -41,6 +43,6 @@ ise_response:
   description: A dictionary or list with the response returned by the Cisco ISE Python SDK
   returned: always
   type: dict
-  sample:
-  - {}
+  sample: >
+    {}
 """
