@@ -7,26 +7,28 @@
 DOCUMENTATION = r"""
 ---
 module: pxgrid_failures_info
-short_description: Information module for Pxgrid Failures
+short_description: Information module for pxGrid Failures
 description:
-- Get all Pxgrid Failures.
+- Get all pxGrid Failures.
 version_added: '1.0.0'
 extends_documentation_fragment:
   - cisco.ise.module_info
 author: Rafael Campos (@racampos)
 options: {}
 requirements:
-- ciscoisesdk >= 1.1.0
+- ciscoisesdk >= 2.0.3
 - python >= 3.5
-seealso:
-# Reference by Internet resource
-- name: Pxgrid Failures reference
-  description: Complete reference of the Pxgrid Failures object model.
-  link: https://ciscoisesdk.readthedocs.io/en/latest/api/api.html#v3-0-0-summary
+notes:
+  - SDK Method used are
+    radius_failure.RadiusFailure.get_failures,
+
+  - Paths used are
+    get /getFailures,
+
 """
 
 EXAMPLES = r"""
-- name: Get all Pxgrid Failures
+- name: Get all pxGrid Failures
   cisco.ise.pxgrid_failures_info:
     ise_hostname: "{{ise_hostname}}"
     ise_username: "{{ise_username}}"
@@ -41,6 +43,6 @@ ise_response:
   description: A dictionary or list with the response returned by the Cisco ISE Python SDK
   returned: always
   type: dict
-  sample:
-  - {}
+  sample: >
+    {}
 """
