@@ -7,26 +7,28 @@
 DOCUMENTATION = r"""
 ---
 module: pxgrid_security_groups_info
-short_description: Information module for Pxgrid Security Groups Info
+short_description: Information module for pxGrid Security Groups Info
 description:
-- Get Pxgrid Security Groups Info.
+- Get pxGrid Security Groups Info.
 version_added: '1.0.0'
 extends_documentation_fragment:
   - cisco.ise.module_info
 author: Rafael Campos (@racampos)
 options: {}
 requirements:
-- ciscoisesdk >= 1.1.0
+- ciscoisesdk >= 2.0.3
 - python >= 3.5
-seealso:
-# Reference by Internet resource
-- name: Pxgrid Security Groups Info reference
-  description: Complete reference of the Pxgrid Security Groups Info object model.
-  link: https://ciscoisesdk.readthedocs.io/en/latest/api/api.html#v3-0-0-summary
+notes:
+  - SDK Method used are
+    trust_sec_configuration.TrustSecConfiguration.get_security_groups,
+
+  - Paths used are
+    post /ise/config/trustsec/getSecurityGroups,
+
 """
 
 EXAMPLES = r"""
-- name: Get all Pxgrid Security Groups Info
+- name: Get all pxGrid Security Groups Info
   cisco.ise.pxgrid_security_groups_info:
     ise_hostname: "{{ise_hostname}}"
     ise_username: "{{ise_username}}"
@@ -41,6 +43,6 @@ ise_response:
   description: A dictionary or list with the response returned by the Cisco ISE Python SDK
   returned: always
   type: dict
-  sample:
-  - {}
+  sample: >
+    {}
 """
