@@ -7,25 +7,27 @@
 DOCUMENTATION = r"""
 ---
 module: pxgrid_service_register
-short_description: Resource module for Pxgrid Service Register
+short_description: Resource module for pxGrid Service Register
 description:
-- Manage operation create of the resource Pxgrid Service Register.
+- Manage operation create of the resource pxGrid Service Register.
 version_added: '1.0.0'
 extends_documentation_fragment:
   - cisco.ise.module
 author: Rafael Campos (@racampos)
 options:
   name:
-    description: Pxgrid Service Register's name.
+    description: pxGrid Service Register's name.
     type: str
 requirements:
-- ciscoisesdk >= 1.1.0
+- ciscoisesdk >= 2.0.3
 - python >= 3.5
-seealso:
-# Reference by Internet resource
-- name: Pxgrid Service Register reference
-  description: Complete reference of the Pxgrid Service Register object model.
-  link: https://ciscoisesdk.readthedocs.io/en/latest/api/api.html#v3-0-0-summary
+notes:
+  - SDK Method used are
+    provider.Provider.register_service,
+
+  - Paths used are
+    post /control/ServiceRegister,
+
 """
 
 EXAMPLES = r"""
