@@ -7,22 +7,24 @@
 DOCUMENTATION = r"""
 ---
 module: pxgrid_service_unregister
-short_description: Resource module for Pxgrid Service Unregister
+short_description: Resource module for pxGrid Service Unregister
 description:
-- Manage operation create of the resource Pxgrid Service Unregister.
+- Manage operation create of the resource pxGrid Service Unregister.
 version_added: '1.0.0'
 extends_documentation_fragment:
   - cisco.ise.module
 author: Rafael Campos (@racampos)
 options: {}
 requirements:
-- ciscoisesdk >= 1.1.0
+- ciscoisesdk >= 2.0.3
 - python >= 3.5
-seealso:
-# Reference by Internet resource
-- name: Pxgrid Service Unregister reference
-  description: Complete reference of the Pxgrid Service Unregister object model.
-  link: https://ciscoisesdk.readthedocs.io/en/latest/api/api.html#v3-0-0-summary
+notes:
+  - SDK Method used are
+    provider.Provider.unregister_service,
+
+  - Paths used are
+    post /control/ServiceUnregister,
+
 """
 
 EXAMPLES = r"""
