@@ -7,26 +7,28 @@
 DOCUMENTATION = r"""
 ---
 module: pxgrid_session_by_ip_info
-short_description: Information module for Pxgrid Session By Ip Info
+short_description: Information module for pxGrid Session By Ip Info
 description:
-- Get Pxgrid Session By Ip Info.
+- Get pxGrid Session By Ip Info.
 version_added: '1.0.0'
 extends_documentation_fragment:
   - cisco.ise.module_info
 author: Rafael Campos (@racampos)
 options: {}
 requirements:
-- ciscoisesdk >= 1.1.0
+- ciscoisesdk >= 2.0.3
 - python >= 3.5
-seealso:
-# Reference by Internet resource
-- name: Pxgrid Session By Ip Info reference
-  description: Complete reference of the Pxgrid Session By Ip Info object model.
-  link: https://ciscoisesdk.readthedocs.io/en/latest/api/api.html#v3-0-0-summary
+notes:
+  - SDK Method used are
+    session_directory.SessionDirectory.get_session_by_ip_address,
+
+  - Paths used are
+    post /ise/session/getSessionByIpAddress,
+
 """
 
 EXAMPLES = r"""
-- name: Get all Pxgrid Session By Ip Info
+- name: Get all pxGrid Session By Ip Info
   cisco.ise.pxgrid_session_by_ip_info:
     ise_hostname: "{{ise_hostname}}"
     ise_username: "{{ise_username}}"
@@ -41,6 +43,6 @@ ise_response:
   description: A dictionary or list with the response returned by the Cisco ISE Python SDK
   returned: always
   type: dict
-  sample:
-  - {}
+  sample: >
+    {}
 """
