@@ -7,22 +7,29 @@
 DOCUMENTATION = r"""
 ---
 module: sg_mapping_deploy_all
-short_description: Resource module for Sg Mapping Deploy All
+short_description: Resource module for SG Mapping Deploy All
 description:
-- Manage operation update of the resource Sg Mapping Deploy All.
+- Manage operation update of the resource SG Mapping Deploy All.
+- This API allows the client to deploy all the IP to SGT mappings.
 version_added: '1.0.0'
 extends_documentation_fragment:
   - cisco.ise.module
 author: Rafael Campos (@racampos)
 options: {}
 requirements:
-- ciscoisesdk >= 1.1.0
+- ciscoisesdk >= 2.0.3
 - python >= 3.5
 seealso:
-# Reference by Internet resource
-- name: Sg Mapping Deploy All reference
-  description: Complete reference of the Sg Mapping Deploy All object model.
-  link: https://ciscoisesdk.readthedocs.io/en/latest/api/api.html#v3-0-0-summary
+- name: Cisco ISE documentation for IPToSGTMapping
+  description: Complete reference of the IPToSGTMapping API.
+  link: https://developer.cisco.com/docs/identity-services-engine/v1/#!sgmapping
+notes:
+  - SDK Method used are
+    ip_to_sgt_mapping.IpToSgtMapping.deploy_all_ip_to_sgt_mapping,
+
+  - Paths used are
+    put /ers/config/sgmapping/deployall,
+
 """
 
 EXAMPLES = r"""
