@@ -10,6 +10,9 @@ module: sponsored_guest_portal
 short_description: Resource module for Sponsored Guest Portal
 description:
 - Manage operations create, update and delete of the resource Sponsored Guest Portal.
+- This API creates a sponsored guest portal.
+- This API deletes a sponsored guest portal by ID.
+- This API allows the client to update a sponsored guest portal by ID.
 version_added: '1.0.0'
 extends_documentation_fragment:
   - cisco.ise.module
@@ -76,6 +79,7 @@ options:
         suboptions:
           data:
             description: The Dictionary will be exposed here as key value pair.
+            elements: dict
             suboptions:
               key:
                 description: Sponsored Guest Portal's key.
@@ -288,6 +292,7 @@ options:
             type: bool
           socialConfigs:
             description: Sponsored Guest Portal's socialConfigs.
+            elements: dict
             suboptions:
               socialMediaType:
                 description: Sponsored Guest Portal's socialMediaType.
@@ -307,7 +312,8 @@ options:
           allowedInterfaces:
             description: Interfaces that the portal will be reachable on. Allowed values
               - eth0, - eth1, - eth2, - eth3, - eth4, - eth5, - bond0, - bond1, - bond2.
-            type: str
+            elements: str
+            type: list
           alwaysUsedLanguage:
             description: Sponsored Guest Portal's alwaysUsedLanguage.
             type: str
@@ -379,13 +385,19 @@ options:
         type: dict
     type: dict
 requirements:
-- ciscoisesdk >= 1.1.0
+- ciscoisesdk >= 2.0.3
 - python >= 3.5
-seealso:
-# Reference by Internet resource
-- name: Sponsored Guest Portal reference
-  description: Complete reference of the Sponsored Guest Portal object model.
-  link: https://ciscoisesdk.readthedocs.io/en/latest/api/api.html#v3-0-0-summary
+notes:
+  - SDK Method used are
+    sponsored_guest_portal.SponsoredGuestPortal.create_sponsored_guest_portal,
+    sponsored_guest_portal.SponsoredGuestPortal.delete_sponsored_guest_portal_by_id,
+    sponsored_guest_portal.SponsoredGuestPortal.update_sponsored_guest_portal_by_id,
+
+  - Paths used are
+    post /ers/config/sponsoredguestportal,
+    delete /ers/config/sponsoredguestportal/{id},
+    put /ers/config/sponsoredguestportal/{id},
+
 """
 
 EXAMPLES = r"""
@@ -477,7 +489,8 @@ EXAMPLES = r"""
           socialMediaValue: string
         timeBetweenLoginsDuringRateLimit: 0
       portalSettings:
-        allowedInterfaces: string
+        allowedInterfaces:
+        - string
         alwaysUsedLanguage: string
         assignedGuestTypeForEmployee: string
         authenticationMethod: string
@@ -595,7 +608,8 @@ EXAMPLES = r"""
           socialMediaValue: string
         timeBetweenLoginsDuringRateLimit: 0
       portalSettings:
-        allowedInterfaces: string
+        allowedInterfaces:
+        - string
         alwaysUsedLanguage: string
         assignedGuestTypeForEmployee: string
         authenticationMethod: string
@@ -770,16 +784,18 @@ ise_response:
 ise_update_response:
   description: A dictionary or list with the response returned by the Cisco ISE Python SDK
   returned: always
-  version_added: "1.1.0"
+  version_added: '1.1.0'
   type: dict
   sample: >
     {
       "UpdatedFieldsList": {
-        "updatedField": {
-          "field": "string",
-          "oldValue": "string",
-          "newValue": "string"
-        },
+        "updatedField": [
+          {
+            "field": "string",
+            "oldValue": "string",
+            "newValue": "string"
+          }
+        ],
         "field": "string",
         "oldValue": "string",
         "newValue": "string"
