@@ -7,28 +7,31 @@
 DOCUMENTATION = r"""
 ---
 module: sxp_connections_bulk_request
-short_description: Resource module for Sxp Connections Bulk Request
+short_description: Resource module for SXP Connections Bulk Request
 description:
-- Manage operation update of the resource Sxp Connections Bulk Request.
+- Manage operation update of the resource SXP Connections Bulk Request.
+- This API allows the client to submit the bulk request.
 version_added: '1.0.0'
 extends_documentation_fragment:
   - cisco.ise.module
 author: Rafael Campos (@racampos)
 options:
   operationType:
-    description: Sxp Connections Bulk Request's operationType.
+    description: SXP Connections Bulk Request's operationType.
     type: str
   resourceMediaType:
-    description: Sxp Connections Bulk Request's resourceMediaType.
+    description: SXP Connections Bulk Request's resourceMediaType.
     type: str
 requirements:
-- ciscoisesdk >= 1.1.0
+- ciscoisesdk >= 2.0.3
 - python >= 3.5
-seealso:
-# Reference by Internet resource
-- name: Sxp Connections Bulk Request reference
-  description: Complete reference of the Sxp Connections Bulk Request object model.
-  link: https://ciscoisesdk.readthedocs.io/en/latest/api/api.html#v3-0-0-summary
+notes:
+  - SDK Method used are
+    sxp_connections.SxpConnections.bulk_request_for_sxp_connections,
+
+  - Paths used are
+    put /ers/config/sxpconnections/bulk/submit,
+
 """
 
 EXAMPLES = r"""
