@@ -5,6 +5,7 @@
 # (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
 from __future__ import absolute_import, division, print_function
 
+
 __metaclass__ = type
 """
 The facts class for nxos
@@ -14,17 +15,28 @@ calls the appropriate facts gathering function
 from ansible_collections.ansible.netcommon.plugins.module_utils.network.common.facts.facts import (
     FactsBase,
 )
-from ansible_collections.cisco.nxos.plugins.module_utils.network.nxos.facts.legacy.base import (
-    Default,
-    Legacy,
-    Hardware,
-    Config,
-    Interfaces,
-    Features,
+
+from ansible_collections.cisco.nxos.plugins.module_utils.network.nxos.facts.acl_interfaces.acl_interfaces import (
+    Acl_interfacesFacts,
+)
+from ansible_collections.cisco.nxos.plugins.module_utils.network.nxos.facts.acls.acls import (
+    AclsFacts,
 )
 from ansible_collections.cisco.nxos.plugins.module_utils.network.nxos.facts.bfd_interfaces.bfd_interfaces import (
     Bfd_interfacesFacts,
 )
+from ansible_collections.cisco.nxos.plugins.module_utils.network.nxos.facts.bgp_address_family.bgp_address_family import (
+    Bgp_address_familyFacts,
+)
+from ansible_collections.cisco.nxos.plugins.module_utils.network.nxos.facts.bgp_global.bgp_global import (
+    Bgp_globalFacts,
+)
+from ansible_collections.cisco.nxos.plugins.module_utils.network.nxos.facts.bgp_neighbor_address_family.bgp_neighbor_address_family import (
+    Bgp_neighbor_address_familyFacts,
+)
+from ansible_collections.cisco.nxos.plugins.module_utils.network.nxos.facts.hostname.hostname import (
+    HostnameFacts,
+)
 from ansible_collections.cisco.nxos.plugins.module_utils.network.nxos.facts.hsrp_interfaces.hsrp_interfaces import (
     Hsrp_interfacesFacts,
 )
@@ -34,23 +46,25 @@ from ansible_collections.cisco.nxos.plugins.module_utils.network.nxos.facts.inte
 from ansible_collections.cisco.nxos.plugins.module_utils.network.nxos.facts.l2_interfaces.l2_interfaces import (
     L2_interfacesFacts,
 )
+from ansible_collections.cisco.nxos.plugins.module_utils.network.nxos.facts.l3_interfaces.l3_interfaces import (
+    L3_interfacesFacts,
+)
 from ansible_collections.cisco.nxos.plugins.module_utils.network.nxos.facts.lacp.lacp import (
     LacpFacts,
 )
-from ansible_collections.cisco.nxos.plugins.module_utils.network.nxos.facts.l3_interfaces.l3_interfaces import (
-    L3_interfacesFacts,
+from ansible_collections.cisco.nxos.plugins.module_utils.network.nxos.facts.lacp_interfaces.lacp_interfaces import (
+    Lacp_interfacesFacts,
 )
 from ansible_collections.cisco.nxos.plugins.module_utils.network.nxos.facts.lag_interfaces.lag_interfaces import (
     Lag_interfacesFacts,
 )
-from ansible_collections.cisco.nxos.plugins.module_utils.network.nxos.facts.telemetry.telemetry import (
-    TelemetryFacts,
-)
-from ansible_collections.cisco.nxos.plugins.module_utils.network.nxos.facts.vlans.vlans import (
-    VlansFacts,
-)
-from ansible_collections.cisco.nxos.plugins.module_utils.network.nxos.facts.lacp_interfaces.lacp_interfaces import (
-    Lacp_interfacesFacts,
+from ansible_collections.cisco.nxos.plugins.module_utils.network.nxos.facts.legacy.base import (
+    Config,
+    Default,
+    Features,
+    Hardware,
+    Interfaces,
+    Legacy,
 )
 from ansible_collections.cisco.nxos.plugins.module_utils.network.nxos.facts.lldp_global.lldp_global import (
     Lldp_globalFacts,
@@ -58,14 +72,14 @@ from ansible_collections.cisco.nxos.plugins.module_utils.network.nxos.facts.lldp
 from ansible_collections.cisco.nxos.plugins.module_utils.network.nxos.facts.lldp_interfaces.lldp_interfaces import (
     Lldp_interfacesFacts,
 )
-from ansible_collections.cisco.nxos.plugins.module_utils.network.nxos.facts.acl_interfaces.acl_interfaces import (
-    Acl_interfacesFacts,
+from ansible_collections.cisco.nxos.plugins.module_utils.network.nxos.facts.logging_global.logging_global import (
+    Logging_globalFacts,
 )
-from ansible_collections.cisco.nxos.plugins.module_utils.network.nxos.facts.acls.acls import (
-    AclsFacts,
+from ansible_collections.cisco.nxos.plugins.module_utils.network.nxos.facts.ntp_global.ntp_global import (
+    Ntp_globalFacts,
 )
-from ansible_collections.cisco.nxos.plugins.module_utils.network.nxos.facts.static_routes.static_routes import (
-    Static_routesFacts,
+from ansible_collections.cisco.nxos.plugins.module_utils.network.nxos.facts.ospf_interfaces.ospf_interfaces import (
+    Ospf_interfacesFacts,
 )
 from ansible_collections.cisco.nxos.plugins.module_utils.network.nxos.facts.ospfv2.ospfv2 import (
     Ospfv2Facts,
@@ -73,35 +87,23 @@ from ansible_collections.cisco.nxos.plugins.module_utils.network.nxos.facts.ospf
 from ansible_collections.cisco.nxos.plugins.module_utils.network.nxos.facts.ospfv3.ospfv3 import (
     Ospfv3Facts,
 )
-from ansible_collections.cisco.nxos.plugins.module_utils.network.nxos.facts.ospf_interfaces.ospf_interfaces import (
-    Ospf_interfacesFacts,
-)
-from ansible_collections.cisco.nxos.plugins.module_utils.network.nxos.facts.bgp_global.bgp_global import (
-    Bgp_globalFacts,
-)
-from ansible_collections.cisco.nxos.plugins.module_utils.network.nxos.facts.bgp_address_family.bgp_address_family import (
-    Bgp_address_familyFacts,
-)
-from ansible_collections.cisco.nxos.plugins.module_utils.network.nxos.facts.bgp_neighbor_address_family.bgp_neighbor_address_family import (
-    Bgp_neighbor_address_familyFacts,
+from ansible_collections.cisco.nxos.plugins.module_utils.network.nxos.facts.prefix_lists.prefix_lists import (
+    Prefix_listsFacts,
 )
 from ansible_collections.cisco.nxos.plugins.module_utils.network.nxos.facts.route_maps.route_maps import (
     Route_mapsFacts,
 )
-from ansible_collections.cisco.nxos.plugins.module_utils.network.nxos.facts.prefix_lists.prefix_lists import (
-    Prefix_listsFacts,
-)
-from ansible_collections.cisco.nxos.plugins.module_utils.network.nxos.facts.logging_global.logging_global import (
-    Logging_globalFacts,
-)
-from ansible_collections.cisco.nxos.plugins.module_utils.network.nxos.facts.ntp_global.ntp_global import (
-    Ntp_globalFacts,
-)
 from ansible_collections.cisco.nxos.plugins.module_utils.network.nxos.facts.snmp_server.snmp_server import (
     Snmp_serverFacts,
 )
-from ansible_collections.cisco.nxos.plugins.module_utils.network.nxos.facts.hostname.hostname import (
-    HostnameFacts,
+from ansible_collections.cisco.nxos.plugins.module_utils.network.nxos.facts.static_routes.static_routes import (
+    Static_routesFacts,
+)
+from ansible_collections.cisco.nxos.plugins.module_utils.network.nxos.facts.telemetry.telemetry import (
+    TelemetryFacts,
+)
+from ansible_collections.cisco.nxos.plugins.module_utils.network.nxos.facts.vlans.vlans import (
+    VlansFacts,
 )
 
 
@@ -145,8 +147,7 @@ FACT_RESOURCE_SUBSETS = dict(
 
 
 class Facts(FactsBase):
-    """ The fact class for nxos
-    """
+    """The fact class for nxos"""
 
     VALID_LEGACY_GATHER_SUBSETS = frozenset(FACT_LEGACY_SUBSETS.keys())
     VALID_RESOURCE_SUBSETS = frozenset(FACT_RESOURCE_SUBSETS.keys())
@@ -154,10 +155,8 @@ class Facts(FactsBase):
     def __init__(self, module):
         super(Facts, self).__init__(module)
 
-    def get_facts(
-        self, legacy_facts_type=None, resource_facts_type=None, data=None
-    ):
-        """ Collect the facts for nxos
+    def get_facts(self, legacy_facts_type=None, resource_facts_type=None, data=None):
+        """Collect the facts for nxos
         :param legacy_facts_type: List of legacy facts types
         :param resource_facts_type: List of resource fact types
         :param data: previously collected conf
@@ -165,13 +164,9 @@ class Facts(FactsBase):
         :return: the facts gathered
         """
         if self.VALID_RESOURCE_SUBSETS:
-            self.get_network_resources_facts(
-                FACT_RESOURCE_SUBSETS, resource_facts_type, data
-            )
+            self.get_network_resources_facts(FACT_RESOURCE_SUBSETS, resource_facts_type, data)
 
         if self.VALID_LEGACY_GATHER_SUBSETS:
-            self.get_network_legacy_facts(
-                FACT_LEGACY_SUBSETS, legacy_facts_type
-            )
+            self.get_network_legacy_facts(FACT_LEGACY_SUBSETS, legacy_facts_type)
 
         return self.ansible_facts, self._warnings
