@@ -6,6 +6,7 @@
 
 from __future__ import absolute_import, division, print_function
 
+
 __metaclass__ = type
 
 
@@ -180,19 +181,18 @@ commands:
 
 from copy import deepcopy
 
-from ansible_collections.cisco.nxos.plugins.module_utils.network.nxos.nxos import (
-    load_config,
-    run_commands,
-)
-from ansible_collections.cisco.nxos.plugins.module_utils.network.nxos.nxos import (
-    nxos_argument_spec,
-    get_interface_type,
-)
 from ansible.module_utils.basic import AnsibleModule
 from ansible_collections.ansible.netcommon.plugins.module_utils.network.common.utils import (
     remove_default_spec,
 )
 
+from ansible_collections.cisco.nxos.plugins.module_utils.network.nxos.nxos import (
+    get_interface_type,
+    load_config,
+    nxos_argument_spec,
+    run_commands,
+)
+
 
 def get_interface_mode(name, module):
     """Gets current mode of interface: layer2 or layer3
@@ -299,9 +299,7 @@ def remove_switchport_config_commands(name, existing, proposed, module):
     if mode == "access":
         av_check = existing.get("access_vlan") == proposed.get("access_vlan")
         if av_check:
-            command = "no switchport access vlan {0}".format(
-                existing.get("access_vlan")
-            )
+            command = "no switchport access vlan {0}".format(existing.get("access_vlan"))
             commands.append(command)
 
     elif mode == "trunk":
@@ -311,21 +309,13 @@ def remove_switchport_config_commands(name, existing, proposed, module):
 
         if vlans_to_remove:
             proposed_allowed_vlans = proposed.get("trunk_allowed_vlans")
-            remove_trunk_allowed_vlans = proposed.get(
-                "trunk_vlans", proposed_allowed_vlans
-            )
-            command = "switchport trunk allowed vlan remove {0}".format(
-                remove_trunk_allowed_vlans
-            )
+            remove_trunk_allowed_vlans = proposed.get("trunk_vlans", proposed_allowed_vlans)
+            command = "switchport trunk allowed vlan remove {0}".format(remove_trunk_allowed_vlans)
             commands.append(command)
 
-        native_check = existing.get("native_vlan") == proposed.get(
-            "native_vlan"
-        )
+        native_check = existing.get("native_vlan") == proposed.get("native_vlan")
         if native_check and proposed.get("native_vlan"):
-            command = "no switchport trunk native vlan {0}".format(
-                existing.get("native_vlan")
-            )
+            command = "no switchport trunk native vlan {0}".format(existing.get("native_vlan"))
             commands.append(command)
 
     if commands:
@@ -334,8 +324,7 @@ def remove_switchport_config_commands(name, existing, proposed, module):
 
 
 def get_switchport_config_commands(name, existing, proposed, module):
-    """Gets commands required to config a given switchport interface
-    """
+    """Gets commands required to config a given switchport interface"""
 
     proposed_mode = proposed.get("mode")
     existing_mode = existing.get("mode")
@@ -352,24 +341,18 @@ def get_switchport_config_commands(name, existing, proposed, module):
         commands.append(command)
 
     if proposed_mode == "access":
-        av_check = str(existing.get("access_vlan")) == str(
-            proposed.get("access_vlan")
-        )
+        av_check = str(existing.get("access_vlan")) == str(proposed.get("access_vlan"))
         if not av_check:
-            command = "switchport access vlan {0}".format(
-                proposed.get("access_vlan")
-            )
+            command = "switchport access vlan {0}".format(proposed.get("access_vlan"))
             commands.append(command)
 
     elif proposed_mode == "trunk":
-        tv_check = existing.get("trunk_vlans_list") == proposed.get(
-            "trunk_vlans_list"
-        )
+        tv_check = existing.get("trunk_vlans_list") == proposed.get("trunk_vlans_list")
 
         if not tv_check:
             if proposed.get("allowed"):
                 command = "switchport trunk allowed vlan {0}".format(
-                    proposed.get("trunk_allowed_vlans")
+                    proposed.get("trunk_allowed_vlans"),
                 )
                 commands.append(command)
 
@@ -379,17 +362,13 @@ def get_switchport_config_commands(name, existing, proposed, module):
                 vlans_to_add = set(proposed_vlans).difference(existing_vlans)
                 if vlans_to_add:
                     command = "switchport trunk allowed vlan add {0}".format(
-                        proposed.get("trunk_vlans")
+                        proposed.get("trunk_vlans"),
                     )
                     commands.append(command)
 
-        native_check = str(existing.get("native_vlan")) == str(
-            proposed.get("native_vlan")
-        )
+        native_check = str(existing.get("native_vlan")) == str(proposed.get("native_vlan"))
         if not native_check and proposed.get("native_vlan"):
-            command = "switchport trunk native vlan {0}".format(
-                proposed.get("native_vlan")
-            )
+            command = "switchport trunk native vlan {0}".format(proposed.get("native_vlan"))
             commands.append(command)
 
     if commands:
@@ -464,8 +443,7 @@ def get_list_of_vlans(module):
 
 
 def numerical_sort(string_int_list):
-    """Sorts list of strings/integers that are digits in numerical order.
-    """
+    """Sorts list of strings/integers that are digits in numerical order."""
 
     as_int_list = []
     as_str_list = []
@@ -523,15 +501,14 @@ def map_params_to_obj(module):
                 "trunk_vlans": module.params["trunk_vlans"],
                 "trunk_allowed_vlans": module.params["trunk_allowed_vlans"],
                 "state": module.params["state"],
-            }
+            },
         )
 
     return obj
 
 
 def main():
-    """ main entry point for module execution
-    """
+    """main entry point for module execution"""
     element_spec = dict(
         name=dict(type="str", aliases=["interface"]),
         mode=dict(choices=["access", "trunk"]),
@@ -539,9 +516,7 @@ def main():
         native_vlan=dict(type="str"),
         trunk_vlans=dict(type="str", aliases=["trunk_add_vlans"]),
         trunk_allowed_vlans=dict(type="str"),
-        state=dict(
-            choices=["absent", "present", "unconfigured"], default="present"
-        ),
+        state=dict(choices=["absent", "present", "unconfigured"], default="present"),
     )
 
     aggregate_spec = deepcopy(element_spec)
@@ -549,9 +524,7 @@ def main():
     # remove default in aggregate spec, to handle common arguments
     remove_default_spec(aggregate_spec)
 
-    argument_spec = dict(
-        aggregate=dict(type="list", elements="dict", options=aggregate_spec)
-    )
+    argument_spec = dict(aggregate=dict(type="list", elements="dict", options=aggregate_spec))
 
     argument_spec.update(element_spec)
     argument_spec.update(nxos_argument_spec)
@@ -596,14 +569,10 @@ def main():
         name = name.lower()
 
         if mode == "access" and state == "present" and not access_vlan:
-            module.fail_json(
-                msg="access_vlan param is required when mode=access && state=present"
-            )
+            module.fail_json(msg="access_vlan param is required when mode=access && state=present")
 
         if mode == "trunk" and access_vlan:
-            module.fail_json(
-                msg="access_vlan param not supported when using mode=trunk"
-            )
+            module.fail_json(msg="access_vlan param not supported when using mode=trunk")
 
         current_mode = get_interface_mode(name, module)
 
@@ -612,14 +581,14 @@ def main():
             module.fail_json(
                 msg="Ensure interface is configured to be a L2"
                 "\nport first before using this module. You can use"
-                "\nthe nxos_interface module for this."
+                "\nthe nxos_interface module for this.",
             )
 
         if interface_is_portchannel(name, module):
             module.fail_json(
                 msg="Cannot change L2 config on physical "
                 "\nport because it is in a portchannel. "
-                "\nYou should update the portchannel config."
+                "\nYou should update the portchannel config.",
             )
 
         # existing will never be null for Eth intfs as there is always a default
@@ -628,9 +597,7 @@ def main():
         # Safeguard check
         # If there isn't an existing, something is wrong per previous comment
         if not existing:
-            module.fail_json(
-                msg="Make sure you are using the FULL interface name"
-            )
+            module.fail_json(msg="Make sure you are using the FULL interface name")
 
         if trunk_vlans or trunk_allowed_vlans:
             if trunk_vlans:
@@ -639,9 +606,7 @@ def main():
                 trunk_vlans_list = vlan_range_to_list(trunk_allowed_vlans)
                 proposed["allowed"] = True
 
-            existing_trunks_list = vlan_range_to_list(
-                (existing["trunk_vlans"])
-            )
+            existing_trunks_list = vlan_range_to_list((existing["trunk_vlans"]))
 
             existing["trunk_vlans_list"] = existing_trunks_list
             proposed["trunk_vlans_list"] = trunk_vlans_list
@@ -664,9 +629,7 @@ def main():
                     vlan=native_vlan,
                 )
             else:
-                command = get_switchport_config_commands(
-                    name, existing, proposed, module
-                )
+                command = get_switchport_config_commands(name, existing, proposed, module)
                 commands.append(command)
         elif state == "unconfigured":
             is_default = is_switchport_default(existing)
@@ -674,9 +637,7 @@ def main():
                 command = default_switchport_config(name)
                 commands.append(command)
         elif state == "absent":
-            command = remove_switchport_config_commands(
-                name, existing, proposed, module
-            )
+            command = remove_switchport_config_commands(name, existing, proposed, module)
             commands.append(command)
 
         if trunk_vlans or trunk_allowed_vlans:
