@@ -2,6 +2,7 @@
 # -*- coding: utf-8 -*-
 from __future__ import absolute_import, division, print_function
 
+
 __metaclass__ = type
 
 # GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
@@ -166,17 +167,15 @@ commands:
 """
 
 import re
+
 from ansible.module_utils.basic import AnsibleModule
+
 from ansible_collections.cisco.nxos.plugins.module_utils.network.nxos.nxos import (
     get_config,
-    load_config,
-    run_commands,
-)
-from ansible_collections.cisco.nxos.plugins.module_utils.network.nxos.nxos import (
-    nxos_argument_spec,
-)
-from ansible_collections.cisco.nxos.plugins.module_utils.network.nxos.nxos import (
     get_interface_type,
+    load_config,
+    nxos_argument_spec,
+    run_commands,
 )
 
 
@@ -286,7 +285,8 @@ def get_pim_interface(module, interface):
         for each in all_lines:
             if "jp-policy" in each:
                 policy_name = re.search(
-                    r"ip pim jp-policy(?: prefix-list)? (\S+)(?: \S+)?", each
+                    r"ip pim jp-policy(?: prefix-list)? (\S+)(?: \S+)?",
+                    each,
                 ).group(1)
                 if "prefix-list" in each:
                     ptype = "prefix"
@@ -304,7 +304,8 @@ def get_pim_interface(module, interface):
                     pim_interface["jp_bidir"] = True
             elif "neighbor-policy" in each:
                 pim_interface["neighbor_policy"] = re.search(
-                    r"ip pim neighbor-policy(?: prefix-list)? (\S+)", each
+                    r"ip pim neighbor-policy(?: prefix-list)? (\S+)",
+                    each,
                 ).group(1)
                 if "prefix-list" in each:
                     pim_interface["neighbor_type"] = "prefix"
@@ -315,23 +316,18 @@ def get_pim_interface(module, interface):
             elif "sparse-mode" in each:
                 pim_interface["sparse"] = True
             elif "bfd-instance" in each:
-                m = re.search(
-                    r"ip pim bfd-instance(?P<disable> disable)?", each
-                )
+                m = re.search(r"ip pim bfd-instance(?P<disable> disable)?", each)
                 if m:
-                    pim_interface["bfd"] = (
-                        "disable" if m.group("disable") else "enable"
-                    )
+                    pim_interface["bfd"] = "disable" if m.group("disable") else "enable"
             elif "border" in each:
                 pim_interface["border"] = True
             elif "hello-interval" in each:
                 pim_interface["hello_interval"] = re.search(
-                    r"ip pim hello-interval (\d+)", body
+                    r"ip pim hello-interval (\d+)",
+                    body,
                 ).group(1)
             elif "dr-priority" in each:
-                pim_interface["dr_prio"] = re.search(
-                    r"ip pim dr-priority (\d+)", body
-                ).group(1)
+                pim_interface["dr_prio"] = re.search(r"ip pim dr-priority (\d+)", body).group(1)
 
     return pim_interface
 
@@ -339,10 +335,7 @@ def get_pim_interface(module, interface):
 def fix_delta(delta, existing):
     for key in list(delta):
         if key in ["dr_prio", "hello_interval", "sparse", "border"]:
-            if (
-                delta.get(key) == PARAM_TO_DEFAULT_KEYMAP.get(key)
-                and existing.get(key) is None
-            ):
+            if delta.get(key) == PARAM_TO_DEFAULT_KEYMAP.get(key) and existing.get(key) is None:
                 delta.pop(key)
     return delta
 
@@ -356,13 +349,9 @@ def config_pim_interface(delta, existing, jp_bidir, isauth):
     if jp_bidir:
         if delta.get("jp_policy_in") or delta.get("jp_policy_out"):
             if existing.get("jp_type_in") == "prefix":
-                command = "no ip pim jp-policy prefix-list {0}".format(
-                    existing.get("jp_policy_in")
-                )
+                command = "no ip pim jp-policy prefix-list {0}".format(existing.get("jp_policy_in"))
             else:
-                command = "no ip pim jp-policy {0}".format(
-                    existing.get("jp_policy_in")
-                )
+                command = "no ip pim jp-policy {0}".format(existing.get("jp_policy_in"))
             if command:
                 commands.append(command)
 
@@ -394,9 +383,7 @@ def config_pim_interface(delta, existing, jp_bidir, isauth):
             "neighbor_type",
         ]:
             if k in ["neighbor_policy", "neighbor_type"]:
-                temp = delta.get("neighbor_policy") or existing.get(
-                    "neighbor_policy"
-                )
+                temp = delta.get("neighbor_policy") or existing.get("neighbor_policy")
                 if delta.get("neighbor_type") == "prefix":
                     command = PARAM_TO_COMMAND_KEYMAP.get(k).format(temp)
                 elif delta.get("neighbor_type") == "routemap":
@@ -406,9 +393,7 @@ def config_pim_interface(delta, existing, jp_bidir, isauth):
                 elif existing.get("neighbor_type") == "routemap":
                     command = "ip pim neighbor-policy {0}".format(temp)
             elif k in ["jp_policy_in", "jp_type_in"]:
-                temp = delta.get("jp_policy_in") or existing.get(
-                    "jp_policy_in"
-                )
+                temp = delta.get("jp_policy_in") or existing.get("jp_policy_in")
                 if delta.get("jp_type_in") == "prefix":
                     command = PARAM_TO_COMMAND_KEYMAP.get(k).format(temp)
                 elif delta.get("jp_type_in") == "routemap":
@@ -418,9 +403,7 @@ def config_pim_interface(delta, existing, jp_bidir, isauth):
                 elif existing.get("jp_type_in") == "routemap":
                     command = "ip pim jp-policy {0} in".format(temp)
             elif k in ["jp_policy_out", "jp_type_out"]:
-                temp = delta.get("jp_policy_out") or existing.get(
-                    "jp_policy_out"
-                )
+                temp = delta.get("jp_policy_out") or existing.get("jp_policy_out")
                 if delta.get("jp_type_out") == "prefix":
                     command = PARAM_TO_COMMAND_KEYMAP.get(k).format(temp)
                 elif delta.get("jp_type_out") == "routemap":
@@ -451,9 +434,7 @@ def get_pim_interface_defaults():
         hello_auth_key=PARAM_TO_DEFAULT_KEYMAP.get("hello_auth_key"),
     )
 
-    default = dict(
-        (param, value) for (param, value) in args.items() if value is not None
-    )
+    default = dict((param, value) for (param, value) in args.items() if value is not None)
 
     return default
 
@@ -464,9 +445,7 @@ def default_pim_interface_policies(existing, jp_bidir):
     if jp_bidir:
         if existing.get("jp_policy_in") or existing.get("jp_policy_out"):
             if existing.get("jp_type_in") == "prefix":
-                command = "no ip pim jp-policy prefix-list {0}".format(
-                    existing.get("jp_policy_in")
-                )
+                command = "no ip pim jp-policy prefix-list {0}".format(existing.get("jp_policy_in"))
         if command:
             commands.append(command)
 
@@ -477,21 +456,19 @@ def default_pim_interface_policies(existing, jp_bidir):
                 if existing.get("jp_policy_in"):
                     if existing.get("jp_type_in") == "prefix":
                         command = "no ip pim jp-policy prefix-list {0} in".format(
-                            existing.get("jp_policy_in")
+                            existing.get("jp_policy_in"),
                         )
                     else:
-                        command = "no ip pim jp-policy {0} in".format(
-                            existing.get("jp_policy_in")
-                        )
+                        command = "no ip pim jp-policy {0} in".format(existing.get("jp_policy_in"))
             elif k == "jp_policy_out":
                 if existing.get("jp_policy_out"):
                     if existing.get("jp_type_out") == "prefix":
                         command = "no ip pim jp-policy prefix-list {0} out".format(
-                            existing.get("jp_policy_out")
+                            existing.get("jp_policy_out"),
                         )
                     else:
                         command = "no ip pim jp-policy {0} out".format(
-                            existing.get("jp_policy_out")
+                            existing.get("jp_policy_out"),
                         )
             if command:
                 commands.append(command)
@@ -582,27 +559,19 @@ def main():
 
     if jp_policy_in:
         if not jp_type_in:
-            module.fail_json(
-                msg="jp_type_in required when using jp_policy_in."
-            )
+            module.fail_json(msg="jp_type_in required when using jp_policy_in.")
     if jp_policy_out:
         if not jp_type_out:
-            module.fail_json(
-                msg="jp_type_out required when using jp_policy_out."
-            )
+            module.fail_json(msg="jp_type_out required when using jp_policy_out.")
     if neighbor_policy:
         if not neighbor_type:
-            module.fail_json(
-                msg="neighbor_type required when using neighbor_policy."
-            )
+            module.fail_json(msg="neighbor_type required when using neighbor_policy.")
 
     get_existing = get_pim_interface(module, interface)
     existing, jp_bidir, isauth = local_existing(get_existing)
 
     args = PARAM_TO_COMMAND_KEYMAP.keys()
-    proposed = dict(
-        (k, v) for k, v in module.params.items() if v is not None and k in args
-    )
+    proposed = dict((k, v) for k, v in module.params.items() if v is not None and k in args)
     normalize_proposed_values(proposed, module)
 
     delta = dict(set(proposed.items()).difference(existing.items()))
