@@ -13,7 +13,6 @@ version_added: 1.0.0
 short_description: Gather information about AWS KMS keys
 description:
     - Gather information about AWS KMS keys including tags and grants
-    - This module was called C(aws_kms_facts) before Ansible 2.9. The usage did not change.
 author: "Will Thames (@willthames)"
 options:
   alias:
@@ -48,14 +47,11 @@ options:
     type: bool
   keys_attr:
     description:
-      - Whether to return the results in the C(keys) attribute as well as the
-        C(kms_keys) attribute.
-      - Returning the C(keys) attribute conflicts with the builtin keys()
-        method on dictionaries and as such has been deprecated.
-      - After version C(3.0.0) this parameter will do nothing, and after
-        version C(4.0.0) this parameter will be removed.
+      - Returning the C(keys) attribute conflicted with the builtin keys()
+        method on dictionaries and as such was deprecated.
+      - This parameter now does nothing, and after version C(4.0.0) this
+        parameter will be removed.
     type: bool
-    default: True
     version_added: 2.0.0
 extends_documentation_fragment:
 - amazon.aws.aws
@@ -154,9 +150,10 @@ kms_keys:
         Name: myKey
         Purpose: protecting_stuff
     policies:
-      description: list of policy documents for the keys. Empty when access is denied even if there are policies.
+      description: list of policy documents for the key. Empty when access is denied even if there are policies.
       type: list
       returned: always
+      elements: str
       sample:
         Version: "2012-10-17"
         Id: "auto-ebs-2"
@@ -187,6 +184,42 @@ kms_keys:
           - "kms:List*"
           - "kms:RevokeGrant"
           Resource: "*"
+    key_policies:
+      description: list of policy documents for the key. Empty when access is denied even if there are policies.
+      type: list
+      returned: always
+      elements: dict
+      sample:
+        Version: "2012-10-17"
+        Id: "auto-ebs-2"
+        Statement:
+        - Sid: "Allow access through EBS for all principals in the account that are authorized to use EBS"
+          Effect: "Allow"
+          Principal:
+            AWS: "*"
+          Action:
+          - "kms:Encrypt"
+          - "kms:Decrypt"
+          - "kms:ReEncrypt*"
+          - "kms:GenerateDataKey*"
+          - "kms:CreateGrant"
+          - "kms:DescribeKey"
+          Resource: "*"
+          Condition:
+            StringEquals:
+              kms:CallerAccount: "111111111111"
+              kms:ViaService: "ec2.ap-southeast-2.amazonaws.com"
+        - Sid: "Allow direct access to key metadata to the account"
+          Effect: "Allow"
+          Principal:
+            AWS: "arn:aws:iam::111111111111:root"
+          Action:
+          - "kms:Describe*"
+          - "kms:Get*"
+          - "kms:List*"
+          - "kms:RevokeGrant"
+          Resource: "*"
+      version_added: 3.3.0
     grants:
       description: list of grants associated with a key
       type: complex
@@ -244,6 +277,7 @@ kms_keys:
           sample: arn:aws:sts::0123456789012:assumed-role/lambda_xyz/xyz
 '''
 
+import json
 
 try:
     import botocore
@@ -398,13 +432,19 @@ def get_key_details(connection, module, key_id, tokens=None):
         key_id = result['Arn']
     except is_boto3_error_code('NotFoundException'):
         return None
+    except is_boto3_error_code('AccessDeniedException'):  # pylint: disable=duplicate-except
+        module.warn('Permission denied fetching key metadata ({0})'.format(key_id))
+        return None
     except (botocore.exceptions.ClientError, botocore.exceptions.BotoCoreError) as e:  # pylint: disable=duplicate-except
         module.fail_json_aws(e, msg="Failed to obtain key metadata")
     result['KeyArn'] = result.pop('Arn')
 
     try:
         aliases = get_kms_aliases_lookup(connection)
-    except (botocore.exceptions.ClientError, botocore.exceptions.BotoCoreError) as e:
+    except is_boto3_error_code('AccessDeniedException'):
+        module.warn('Permission denied fetching key aliases')
+        aliases = {}
+    except (botocore.exceptions.ClientError, botocore.exceptions.BotoCoreError) as e:  # pylint: disable=duplicate-except
         module.fail_json_aws(e, msg="Failed to obtain aliases")
     # We can only get aliases for our own account, so we don't need the full ARN
     result['aliases'] = aliases.get(result['KeyId'], [])
@@ -415,13 +455,18 @@ def get_key_details(connection, module, key_id, tokens=None):
 
     try:
         result['grants'] = get_kms_grants_with_backoff(connection, key_id, tokens=tokens)['Grants']
-    except (botocore.exceptions.ClientError, botocore.exceptions.BotoCoreError) as e:
+    except is_boto3_error_code('AccessDeniedException'):
+        module.warn('Permission denied fetching key grants ({0})'.format(key_id))
+        result['grants'] = []
+    except (botocore.exceptions.ClientError, botocore.exceptions.BotoCoreError) as e:  # pylint: disable=duplicate-except
         module.fail_json_aws(e, msg="Failed to obtain key grants")
+
     tags = get_kms_tags(connection, module, key_id)
 
     result = camel_dict_to_snake_dict(result)
     result['tags'] = boto3_tag_list_to_ansible_dict(tags, 'TagKey', 'TagValue')
     result['policies'] = get_kms_policies(connection, module, key_id)
+    result['key_policies'] = [json.loads(policy) for policy in result['policies']]
     return result
 
 
@@ -452,31 +497,31 @@ def main():
         key_id=dict(aliases=['key_arn']),
         filters=dict(type='dict'),
         pending_deletion=dict(type='bool', default=False),
-        keys_attr=dict(type='bool', default=True),
+        keys_attr=dict(type='bool'),
     )
 
     module = AnsibleAWSModule(argument_spec=argument_spec,
                               mutually_exclusive=[['alias', 'filters', 'key_id']],
                               supports_check_mode=True)
-    if module._name == 'aws_kms_facts':
-        module.deprecate("The 'aws_kms_facts' module has been renamed to 'aws_kms_info'", date='2021-12-01', collection_name='community.aws')
 
     try:
         connection = module.client('kms')
     except (botocore.exceptions.ClientError, botocore.exceptions.BotoCoreError) as e:
         module.fail_json_aws(e, msg='Failed to connect to AWS')
 
+    module.deprecate("The 'policies' return key is deprecated and will be replaced by 'key_policies'. Both values are returned for now.",
+                     date='2024-05-01', collection_name='community.aws')
+
     all_keys = get_kms_info(connection, module)
     filtered_keys = [key for key in all_keys if key_matches_filters(key, module.params['filters'])]
     ret_params = dict(kms_keys=filtered_keys)
 
     # We originally returned "keys"
-    if module.params['keys_attr']:
+    if module.params.get('keys_attr') is not None:
         module.deprecate("Returning results in the 'keys' attribute conflicts with the builtin keys() method on "
-                         "dicts and as such is deprecated.  Please use the kms_keys attribute.  This warning can be "
-                         "silenced by setting keys_attr to False.",
-                         version='3.0.0', collection_name='community.aws')
-        ret_params.update(dict(keys=filtered_keys))
+                         "dicts and as such was removed in version 3.0.0.  Please use the kms_keys attribute. "
+                         "This parameter is now ignored and will be removed in version 4.0.0.",
+                         version='4.0.0', collection_name='community.aws')
     module.exit_json(**ret_params)
 
 
