@@ -172,8 +172,6 @@ author: "Ryan Scott Brown (@ryansb)"
 extends_documentation_fragment:
 - amazon.aws.aws
 - amazon.aws.ec2
-
-requirements: [ boto3>=1.6, botocore>=1.10.26 ]
 '''
 
 EXAMPLES = r'''
@@ -363,7 +361,7 @@ def compare_stack_instances(cfn, stack_set_name, accounts, regions):
     return (desired_stack_instances - existing_stack_instances), existing_stack_instances, (existing_stack_instances - desired_stack_instances)
 
 
-@AWSRetry.backoff(tries=3, delay=4)
+@AWSRetry.jittered_backoff(retries=3, delay=4)
 def stack_set_facts(cfn, stack_set_name):
     try:
         ss = cfn.describe_stack_set(StackSetName=stack_set_name)['StackSet']
@@ -531,8 +529,6 @@ def main():
         mutually_exclusive=[['template_url', 'template', 'template_body']],
         supports_check_mode=True
     )
-    if not (module.boto3_at_least('1.6.0') and module.botocore_at_least('1.10.26')):
-        module.fail_json(msg="Boto3 or botocore version is too low. This module requires at least boto3 1.6 and botocore 1.10.26")
 
     # Wrap the cloudformation client methods that this module uses with
     # automatic backoff / retry for throttling error codes
