@@ -15,7 +15,6 @@ short_description: Manage a Network Load Balancer
 description:
     - Manage an AWS Network Elastic Load Balancer. See
       U(https://aws.amazon.com/blogs/aws/new-network-load-balancer-effortless-scaling-to-millions-of-requests-per-second/) for details.
-requirements: [ boto3 ]
 author: "Rob White (@wimnat)"
 options:
   cross_zone_load_balancing:
@@ -64,8 +63,14 @@ options:
                     description: The type of action.
                     type: str
                 TargetGroupArn:
-                    description: The Amazon Resource Name (ARN) of the target group.
+                    description:
+                      - The Amazon Resource Name (ARN) of the target group.
+                      - Mutually exclusive with I(TargetGroupName).
                     type: str
+                TargetGroupName:
+                    description:
+                      - The name of the target group.
+                      - Mutually exclusive with I(TargetGroupArn).
   name:
     description:
       - The name of the load balancer. This name must be unique within your AWS account, can have a maximum of 32 characters, must contain only alphanumeric
@@ -87,7 +92,8 @@ options:
   subnet_mappings:
     description:
       - A list of dicts containing the IDs of the subnets to attach to the load balancer. You can also specify the allocation ID of an Elastic IP
-        to attach to the load balancer. You can specify one Elastic IP address per subnet.
+        to attach to the load balancer or the internal IP address for an internal load balancer. You can specify one Elastic IP address or internal
+        address per subnet.
       - This parameter is mutually exclusive with I(subnets).
     type: list
     elements: dict
@@ -109,7 +115,7 @@ options:
     description:
       - Create or destroy the load balancer.
       - The current default is C(absent).  However, this behavior is inconsistent with other modules
-        and as such the default will change to C(present) in 2.14.
+        and as such the default will change to C(present) in a release after 2022-06-01.
         To maintain the existing behavior explicitly set I(state=absent).
     choices: [ 'present', 'absent' ]
     type: str
@@ -170,6 +176,21 @@ EXAMPLES = r'''
             TargetGroupName: mytargetgroup # Required. The name of the target group
     state: present
 
+- name: Create an internal ELB with a specified IP address
+  community.aws.elb_network_lb:
+    name: myelb
+    scheme: internal
+    subnet_mappings:
+      - SubnetId: subnet-012345678
+        PrivateIPv4Address: 192.168.0.1 # Must be an address from within the CIDR of the subnet.
+    listeners:
+      - Protocol: TCP # Required. The protocol for connections from clients to the load balancer (TCP, TLS, UDP or TCP_UDP) (case-sensitive).
+        Port: 80 # Required. The port on which the load balancer is listening.
+        DefaultActions:
+          - Type: forward # Required. Only 'forward' is accepted at this time
+            TargetGroupName: mytargetgroup # Required. The name of the target group
+    state: present
+
 - name: Remove an ELB
   community.aws.elb_network_lb:
     name: myelb
@@ -453,7 +474,7 @@ def main():
     if state is None:
         # See below, unless state==present we delete.  Ouch.
         module.deprecate('State currently defaults to absent.  This is inconsistent with other modules'
-                         ' and the default will be changed to `present` in Ansible 2.14',
+                         ' and the default will be changed to `present` in a release after 2022-06-01',
                          date='2022-06-01', collection_name='community.aws')
 
     # Quick check of listeners parameters
