@@ -1,19 +1,8 @@
 # -*- coding: utf-8 -*-
 #
-# (c) 2016, Yanis Guenane <yanis+ansible@guenane.org>
-#
-# Ansible is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# Ansible is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with Ansible.  If not, see <http://www.gnu.org/licenses/>.
+# Copyright (c) 2016, Yanis Guenane <yanis+ansible@guenane.org>
+# GNU General Public License v3.0+ (see LICENSES/GPL-3.0-or-later.txt or https://www.gnu.org/licenses/gpl-3.0.txt)
+# SPDX-License-Identifier: GPL-3.0-or-later
 
 from __future__ import absolute_import, division, print_function
 __metaclass__ = type
@@ -32,7 +21,7 @@ from ansible.module_utils.common.text.converters import to_native, to_bytes
 try:
     from OpenSSL import crypto
     HAS_PYOPENSSL = True
-except ImportError:
+except (ImportError, AttributeError):
     # Error handled in the calling module.
     HAS_PYOPENSSL = False
 
@@ -162,13 +151,13 @@ def load_privatekey(path, passphrase=None, check_passphrase=True, content=None,
                                        to_bytes('y' if passphrase == 'x' else 'x'))
                 if passphrase is not None:
                     # Since we can load the key without an exception, the
-                    # key isn't password-protected
+                    # key is not password-protected
                     raise OpenSSLBadPassphraseError('Passphrase provided, but private key is not password-protected!')
             except crypto.Error as e:
                 if passphrase is None and len(e.args) > 0 and len(e.args[0]) > 0:
                     if e.args[0][0][2] in ('bad decrypt', 'bad password read'):
                         # The key is obviously protected by the empty string.
-                        # Don't do this at home (if it's possible at all)...
+                        # Do not do this at home (if it's possible at all)...
                         raise OpenSSLBadPassphraseError('No passphrase provided, but private key is password-protected!')
     elif backend == 'cryptography':
         try:
