@@ -1,8 +1,9 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
 
-# Copyright: (c) 2017, Thom Wiggers  <ansible@thomwiggers.nl>
-# GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
+# Copyright (c) 2017, Thom Wiggers  <ansible@thomwiggers.nl>
+# GNU General Public License v3.0+ (see LICENSES/GPL-3.0-or-later.txt or https://www.gnu.org/licenses/gpl-3.0.txt)
+# SPDX-License-Identifier: GPL-3.0-or-later
 
 from __future__ import absolute_import, division, print_function
 __metaclass__ = type
@@ -67,7 +68,7 @@ options:
         version_added: "1.0.0"
     return_content:
         description:
-            - If set to C(yes), will return the (current or generated) DH params' content as I(dhparams).
+            - If set to C(yes), will return the (current or generated) DH parameter's content as I(dhparams).
         type: bool
         default: no
         version_added: "1.0.0"
@@ -128,11 +129,11 @@ import re
 import tempfile
 import traceback
 
-from distutils.version import LooseVersion
-
 from ansible.module_utils.basic import AnsibleModule, missing_required_lib
 from ansible.module_utils.common.text.converters import to_native
 
+from ansible_collections.community.crypto.plugins.module_utils.version import LooseVersion
+
 from ansible_collections.community.crypto.plugins.module_utils.io import (
     load_file_if_exists,
     write_file,
@@ -286,7 +287,7 @@ class DHParameterOpenSSL(DHParameterBase):
         rc, out, err = module.run_command(command, check_rc=False)
         result = to_native(out)
         if rc != 0:
-            # If the call failed the file probably doesn't exist or is
+            # If the call failed the file probably does not exist or is
             # unreadable
             return False
         # output contains "(xxxx bit)"
@@ -380,7 +381,7 @@ def main():
 
             # Success?
             if backend == 'auto':
-                module.fail_json(msg=("Can't detect either the required Python library cryptography (>= {0}) "
+                module.fail_json(msg=("Cannot detect either the required Python library cryptography (>= {0}) "
                                       "or the OpenSSL binary openssl").format(MINIMAL_CRYPTOGRAPHY_VERSION))
 
         if backend == 'openssl':
