@@ -88,6 +88,7 @@ options:
         description: The number of Droplet instances in the node pool.
       tags:
         type: list
+        elements: str
         description:
           - An array containing the tags applied to the node pool.
           - All node pools are automatically tagged C("k8s"), C("k8s-worker"), and C("k8s:$K8S_CLUSTER_ID").
@@ -96,6 +97,7 @@ options:
         description: An object containing a set of Kubernetes labels. The keys are user-defined.
       taints:
         type: list
+        elements: dict
         description:
           - An array of taints to apply to all nodes in a pool.
           - Taints will automatically be applied to all existing nodes and any subsequent nodes added to the pool.
@@ -337,12 +339,12 @@ class DOKubernetes(object):
 
     def ensure_running(self):
         """Waits for the newly created DigitalOcean Kubernetes cluster to be running"""
-        end_time = time.time() + self.wait_timeout
-        while time.time() < end_time:
+        end_time = time.monotonic() + self.wait_timeout
+        while time.monotonic() < end_time:
             cluster = self.get_by_id()
             if cluster["kubernetes_cluster"]["status"]["state"] == "running":
                 return cluster
-            time.sleep(min(2, end_time - time.time()))
+            time.sleep(10)
         self.module.fail_json(msg="Wait for Kubernetes cluster to be running")
 
     def create(self):
