@@ -28,7 +28,7 @@ options:
          be specified when this value is used."
       - "Use C(pull) to pull the image from a registry."
       - "Use C(local) to make sure that the image is already available on the local
-         docker daemon, i.e. do not try to build, pull or load the image."
+         docker daemon. This means that the module does not try to build, pull or load the image."
     type: str
     choices:
     - build
@@ -60,17 +60,17 @@ options:
           - Use with state 'present' to build an image. Will be the path to a directory containing the context and
             Dockerfile for building an image.
         type: path
-        required: yes
+        required: true
       pull:
         description:
           - When building an image downloads any updates to the FROM image in Dockerfile.
         type: bool
-        default: no
+        default: false
       rm:
         description:
           - Remove intermediate containers after build.
         type: bool
-        default: yes
+        default: true
       network:
         description:
           - The network to use for C(RUN) build instructions.
@@ -79,7 +79,7 @@ options:
         description:
           - Do not use cache when building an image.
         type: bool
-        default: no
+        default: false
       etc_hosts:
         description:
           - Extra hosts to add to C(/etc/hosts) in building containers, as a mapping of hostname to IP address.
@@ -101,7 +101,8 @@ options:
             type: int
           memswap:
             description:
-              - Total memory (memory + swap), -1 to disable swap.
+              - Total memory (memory + swap).
+              - Use C(-1) to disable swap.
             type: int
           cpushares:
             description:
@@ -109,11 +110,12 @@ options:
             type: int
           cpusetcpus:
             description:
-              - CPUs in which to allow execution, e.g., "0-3", "0,1".
+              - CPUs in which to allow execution.
+              - For example, C(0-3) or C(0,1).
             type: str
       use_config_proxy:
         description:
-          - If set to C(yes) and a proxy configuration is specified in the docker client configuration
+          - If set to C(true) and a proxy configuration is specified in the docker client configuration
             (by default C($HOME/.docker/config.json)), the corresponding environment variables will
             be set in the container being built.
           - Needs Docker SDK for Python >= 3.7.0.
@@ -160,7 +162,7 @@ options:
       - Note that image IDs (hashes) are only supported for I(state=absent), for I(state=present) with I(source=load),
         and for I(state=present) with I(source=local).
     type: str
-    required: yes
+    required: true
   pull:
     description:
       - "Specifies options used for pulling images."
@@ -177,7 +179,7 @@ options:
     description:
       - Push the image to the registry. Specify the registry as part of the I(name) or I(repository) parameter.
     type: bool
-    default: no
+    default: false
   repository:
     description:
       - Use with state C(present) to tag the image.
@@ -235,7 +237,7 @@ EXAMPLES = '''
   community.docker.docker_image:
     name: pacur/centos-7:56
     repository: dcoppenhagan/myimage:7.56
-    push: yes
+    push: true
     source: local
 
 - name: Tag and push to local registry
@@ -245,7 +247,7 @@ EXAMPLES = '''
     # Will be pushed to localhost:5000/centos:7
     repository: localhost:5000/centos
     tag: 7
-    push: yes
+    push: true
     source: local
 
 - name: Add tag latest to image
@@ -253,7 +255,7 @@ EXAMPLES = '''
     name: myimage:7.1.2
     repository: myimage:latest
     # As 'latest' usually already is present, we need to enable overwriting of existing tags:
-    force_tag: yes
+    force_tag: true
     source: local
 
 - name: Remove image
@@ -268,7 +270,7 @@ EXAMPLES = '''
       path: ./sinatra
     name: registry.ansible.com/chouseknecht/sinatra
     tag: v1
-    push: yes
+    push: true
     source: build
 
 - name: Archive image
@@ -282,7 +284,7 @@ EXAMPLES = '''
   community.docker.docker_image:
     name: localhost:5000/myimages/sinatra
     tag: v1
-    push: yes
+    push: true
     load_path: my_sinatra.tar
     source: load
 
@@ -326,19 +328,21 @@ import errno
 import os
 import traceback
 
-from distutils.version import LooseVersion
-
 from ansible_collections.community.docker.plugins.module_utils.common import (
-    clean_dict_booleans_for_docker_api,
-    docker_version,
     AnsibleDockerClient,
+    RequestException,
+    docker_version,
+)
+from ansible_collections.community.docker.plugins.module_utils.util import (
+    clean_dict_booleans_for_docker_api,
     DockerBaseClass,
     is_image_name_id,
     is_valid_tag,
-    RequestException,
 )
 from ansible.module_utils.common.text.converters import to_native
 
+from ansible_collections.community.docker.plugins.module_utils.version import LooseVersion
+
 if docker_version is not None:
     try:
         if LooseVersion(docker_version) >= LooseVersion('2.0.0'):
