@@ -21,7 +21,7 @@ options:
     description:
       - Stack name
     type: str
-    required: yes
+    required: true
   state:
     description:
       - Service state.
@@ -44,13 +44,13 @@ options:
         This will have docker remove the services not present in the
         current stack definition.
     type: bool
-    default: no
+    default: false
   with_registry_auth:
     description:
       - If true will add the C(--with-registry-auth) option to the C(docker stack deploy) command.
         This will have docker send registry authentication details to Swarm agents.
     type: bool
-    default: no
+    default: false
   resolve_image:
     description:
       - If set will add the C(--resolve-image) option to the C(docker stack deploy) command.
@@ -78,7 +78,7 @@ requirements:
   - pyyaml
 
 notes:
-  - Return values I(out) and I(err) have been deprecated and will be removed in community.docker 2.0.0. Use I(stdout) and I(stderr) instead.
+  - Return values I(out) and I(err) have been deprecated and will be removed in community.docker 3.0.0. Use I(stdout) and I(stderr) instead.
 '''
 
 RETURN = '''
@@ -248,8 +248,7 @@ def main():
             elif isinstance(compose_def, string_types):
                 compose_files.append(compose_def)
             else:
-                module.fail_json(msg="compose element '%s' must be a " +
-                                 "string or a dictionary" % compose_def)
+                module.fail_json(msg="compose element '%s' must be a string or a dictionary" % compose_def)
 
         before_stack_services = docker_stack_inspect(module, name)
 
