@@ -19,7 +19,7 @@ options:
     description:
       - Name of the volume to operate on.
     type: str
-    required: yes
+    required: true
     aliases:
       - name
 
@@ -118,11 +118,13 @@ except ImportError:
     pass
 
 from ansible_collections.community.docker.plugins.module_utils.common import (
-    DockerBaseClass,
     AnsibleDockerClient,
-    DifferenceTracker,
     RequestException,
 )
+from ansible_collections.community.docker.plugins.module_utils.util import (
+    DockerBaseClass,
+    DifferenceTracker,
+)
 from ansible.module_utils.six import iteritems, text_type
 
 
