@@ -1,9 +1,10 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
 
-# Copyright: (c) 2016, Adfinis SyGroup AG
+# Copyright (c) 2016, Adfinis SyGroup AG
 # Tobias Rueetschi <tobias.ruetschi@adfinis-sygroup.ch>
-# GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
+# GNU General Public License v3.0+ (see LICENSES/GPL-3.0-or-later.txt or https://www.gnu.org/licenses/gpl-3.0.txt)
+# SPDX-License-Identifier: GPL-3.0-or-later
 
 from __future__ import absolute_import, division, print_function
 __metaclass__ = type
@@ -36,15 +37,15 @@ options:
         type: str
     firstname:
         description:
-            - First name. Required if C(state=present).
+            - First name. Required if I(state=present).
         type: str
     lastname:
         description:
-            - Last name. Required if C(state=present).
+            - Last name. Required if I(state=present).
         type: str
     password:
         description:
-            - Password. Required if C(state=present).
+            - Password. Required if I(state=present).
         type: str
     birthday:
         description:
@@ -148,13 +149,13 @@ options:
         type: str
     overridePWHistory:
         type: bool
-        default: 'no'
+        default: false
         description:
             - Override password history
         aliases: [ override_pw_history ]
     overridePWLength:
         type: bool
-        default: 'no'
+        default: false
         description:
             - Override password check
         aliases: [ override_pw_length ]
