@@ -1,14 +1,15 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
 
-# (c) 2020, Lee Goolsbee <lgoolsbee@atlassian.com>
-# (c) 2020, Michal Middleton <mm.404@icloud.com>
-# (c) 2017, Steve Pletcher <steve@steve-pletcher.com>
-# (c) 2016, René Moser <mail@renemoser.net>
-# (c) 2015, Stefan Berggren <nsg@nsg.cc>
-# (c) 2014, Ramon de la Fuente <ramon@delafuente.nl>
+# Copyright (c) 2020, Lee Goolsbee <lgoolsbee@atlassian.com>
+# Copyright (c) 2020, Michal Middleton <mm.404@icloud.com>
+# Copyright (c) 2017, Steve Pletcher <steve@steve-pletcher.com>
+# Copyright (c) 2016, René Moser <mail@renemoser.net>
+# Copyright (c) 2015, Stefan Berggren <nsg@nsg.cc>
+# Copyright (c) 2014, Ramon de la Fuente <ramon@delafuente.nl>
 #
-# GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
+# GNU General Public License v3.0+ (see LICENSES/GPL-3.0-or-later.txt or https://www.gnu.org/licenses/gpl-3.0.txt)
+# SPDX-License-Identifier: GPL-3.0-or-later
 
 from __future__ import absolute_import, division, print_function
 __metaclass__ = type
@@ -68,7 +69,8 @@ options:
   message_id:
     description:
       - Optional. Message ID to edit, instead of posting a new message.
-        Corresponds to C(ts) in the Slack API (U(https://api.slack.com/messaging/modifying)).
+      - If supplied I(channel_id) must be in form of C(C0xxxxxxx). use C({{ slack_response.channel_id }}) to get I(channel_id) from previous task run.
+      - Corresponds to C(ts) in the Slack API (U(https://api.slack.com/messaging/modifying)).
     type: str
     version_added: 1.2.0
   username:
@@ -103,10 +105,10 @@ options:
       - 'none'
   validate_certs:
     description:
-      - If C(no), SSL certificates will not be validated. This should only be used
+      - If C(false), SSL certificates will not be validated. This should only be used
         on personally controlled sites using self-signed certificates.
     type: bool
-    default: 'yes'
+    default: true
   color:
     type: str
     description:
@@ -174,10 +176,10 @@ EXAMPLES = """
         fields:
           - title: System A
             value: "load average: 0,74, 0,66, 0,63"
-            short: True
+            short: true
           - title: System B
             value: 'load average: 5,16, 4,64, 2,43'
-            short: True
+            short: true
 
 - name: Use the blocks API
   community.general.slack:
@@ -233,6 +235,8 @@ EXAMPLES = """
 - name: Edit message
   community.general.slack:
     token: thetoken/generatedby/slack
+    # The 'channel' option does not accept the channel name. It must use the 'channel_id',
+    # which can be retrieved for example from 'slack_response' from the previous task.
     channel: "{{ slack_response.channel }}"
     msg: Deployment complete!
     message_id: "{{ slack_response.ts }}"
@@ -293,7 +297,7 @@ def build_payload_for_slack(text, channel, thread_id, username, icon_url, icon_e
         # With a custom color we have to set the message as attachment, and explicitly turn markdown parsing on for it.
         payload = dict(attachments=[dict(text=escape_quotes(text), color=color, mrkdwn_in=["text"])])
     if channel is not None:
-        if channel.startswith(('#', '@', 'C0')):
+        if channel.startswith(('#', '@', 'C0', 'GF', 'G0', 'CP')):
             payload['channel'] = channel
         else:
             payload['channel'] = '#' + channel
@@ -346,7 +350,7 @@ def build_payload_for_slack(text, channel, thread_id, username, icon_url, icon_e
 
 def get_slack_message(module, token, channel, ts):
     headers = {
-        'Content-Type': 'application/json',
+        'Content-Type': 'application/json; charset=UTF-8',
         'Accept': 'application/json',
         'Authorization': 'Bearer ' + token
     }
@@ -383,7 +387,7 @@ def do_notify_slack(module, domain, token, payload):
         slack_uri = OLD_SLACK_INCOMING_WEBHOOK % (domain, token)
 
     headers = {
-        'Content-Type': 'application/json',
+        'Content-Type': 'application/json; charset=UTF-8',
         'Accept': 'application/json',
     }
     if use_webapi:
