@@ -25,7 +25,7 @@ options:
   ds_type:
     description:
     - The type of the datasource.
-    required: true
+    - Required when C(state=present).
     choices:
     - graphite
     - prometheus
@@ -36,6 +36,7 @@ options:
     - postgres
     - cloudwatch
     - alexanderzobnin-zabbix-datasource
+    - grafana-azure-monitor-datasource
     - sni-thruk-datasource
     - camptocamp-prometheus-alertmanager-datasource
     - loki
@@ -44,7 +45,7 @@ options:
   ds_url:
     description:
     - The URL of the datasource.
-    required: true
+    - Required when C(state=present).
     type: str
   access:
     description:
@@ -274,6 +275,32 @@ options:
     default: ''
     required: false
     type: str
+  azure_cloud:
+    description:
+    - The national cloud for your Azure account
+    default: 'azuremonitor'
+    required: false
+    type: str
+    choices:
+    - azuremonitor
+    - chinaazuremonitor
+    - govazuremonitor
+    - germanyazuremonitor
+  azure_tenant:
+    description:
+    - The directory/tenant ID for the Azure AD app registration to use for authentication
+    required: false
+    type: str
+  azure_client:
+    description:
+    - The application/client ID for the Azure AD app registration to use for authentication.
+    required: false
+    type: str
+  azure_secret:
+    description:
+    - The application client secret for the Azure AD app registration to use for auth
+    required: false
+    type: str
   zabbix_user:
     description:
     - User for Zabbix API
@@ -474,8 +501,10 @@ def compare_datasources(new, current, compareSecureData=True):
         del current['readOnly']
     if current['basicAuth'] is False:
         del current['basicAuthUser']
-    del current['password']
-    del current['basicAuthPassword']
+    if 'password' in current:
+        del current['password']
+    if 'basicAuthPassword' in current:
+        del current['basicAuthPassword']
 
     # check if secureJsonData should be compared
     if not compareSecureData:
@@ -579,6 +608,14 @@ def get_datasource_payload(data):
         json_data['username'] = data['zabbix_user']
         json_data['password'] = data['zabbix_password']
 
+    if data['ds_type'] == 'grafana-azure-monitor-datasource':
+        json_data['tenantId'] = data['azure_tenant']
+        json_data['clientId'] = data['azure_client']
+        json_data['cloudName'] = data['azure_cloud']
+        json_data['clientsecret'] = 'clientsecret'
+        if data.get('azure_secret'):
+            secure_json_data['clientSecret'] = data['azure_secret']
+
     if data['ds_type'] == 'cloudwatch':
         if data.get('aws_credentials_profile'):
             payload['database'] = data.get('aws_credentials_profile')
@@ -670,11 +707,12 @@ def main():
                               'postgres',
                               'cloudwatch',
                               'alexanderzobnin-zabbix-datasource',
+                              'grafana-azure-monitor-datasource',
                               'camptocamp-prometheus-alertmanager-datasource',
                               'sni-thruk-datasource',
                               'redis-datasource',
-                              'loki'], required=True),
-        ds_url=dict(required=True, type='str'),
+                              'loki']),
+        ds_url=dict(type='str'),
         access=dict(default='proxy', choices=['proxy', 'direct']),
         database=dict(type='str', default=""),
         user=dict(default='', type='str'),
@@ -709,6 +747,10 @@ def main():
         aws_credentials_profile=dict(default='', type='str'),
         aws_assume_role_arn=dict(default='', type='str'),
         aws_custom_metrics_namespaces=dict(type='str'),
+        azure_cloud=dict(type='str', default='azuremonitor', choices=['azuremonitor', 'chinaazuremonitor', 'govazuremonitor', 'germanyazuremonitor']),
+        azure_tenant=dict(type='str'),
+        azure_client=dict(type='str'),
+        azure_secret=dict(type='str', no_log=True),
         zabbix_user=dict(type='str'),
         zabbix_password=dict(type='str', no_log=True),
         additional_json_data=dict(type='dict', default={}, required=False),
@@ -722,6 +764,7 @@ def main():
         required_together=[['url_username', 'url_password', 'org_id'], ['tls_client_cert', 'tls_client_key']],
         mutually_exclusive=[['url_username', 'grafana_api_key'], ['tls_ca_cert', 'tls_skip_verify']],
         required_if=[
+            ['state', 'present', ['ds_type', 'ds_url']],
             ['ds_type', 'opentsdb', ['tsdb_version', 'tsdb_resolution']],
             ['ds_type', 'influxdb', ['database']],
             ['ds_type', 'elasticsearch', ['database', 'es_version', 'time_field', 'interval']],
