@@ -100,6 +100,14 @@ options:
       - Add additonal info for debug.
     type: bool
     default: false
+  cluster_cmd:
+    description:
+      - Command the module should use to obtain information about the MongoDB node we are connecting to.
+    type: str
+    choices:
+      - isMaster
+      - hello
+    default: hello
 notes:
 - Requires the pymongo Python package on the remote host, version 2.4.2+. This
   can be installed using pip or the OS package manager. @see U(http://api.mongodb.org/python/current/installation.html)
@@ -283,12 +291,13 @@ from ansible.module_utils._text import to_native
 from ansible_collections.community.mongodb.plugins.module_utils.mongodb_common import (
     missing_required_lib,
     mongodb_common_argument_spec,
-    ssl_connection_options,
     mongo_auth,
     member_dicts_different,
-    lists_are_different
+    lists_are_different,
+    PYMONGO_IMP_ERR,
+    pymongo_found,
+    get_mongodb_client,
 )
-from ansible_collections.community.mongodb.plugins.module_utils.mongodb_common import PYMONGO_IMP_ERR, pymongo_found, MongoClient
 
 
 def get_replicaset_config(client):
@@ -391,17 +400,18 @@ def replicaset_reconfigure(module, client, config, force, max_time_ms):
     # return result
 
 
-def replicaset_find(client):
+def replicaset_find(client, cluster_cmd):
     """Check if a replicaset exists.
 
     Args:
         client (cursor): Mongodb cursor on admin database.
+        cluster_cmd (str): Either isMaster or hello
 
     Returns:
-        dict: when user exists, False otherwise.
+        str: when the node is a member of a replicaset , False otherwise.
     """
-    doc = client['admin'].command('isMaster')
-    if 'setName' in doc.keys():
+    doc = client['admin'].command(cluster_cmd)
+    if 'setName' in doc:
         return str(doc['setName'])
     return False
 
@@ -518,6 +528,7 @@ def main():
         force=dict(type='bool', default=False),
         max_time_ms=dict(type='int', default=None),
         debug=dict(type='bool', default=False),
+        cluster_cmd=dict(type='str', choices=['isMaster', 'hello'], default='hello')
     )
     module = AnsibleModule(
         argument_spec=argument_spec,
@@ -529,21 +540,19 @@ def main():
         module.fail_json(msg=missing_required_lib('pymongo'),
                          exception=PYMONGO_IMP_ERR)
 
-    login_host = module.params['login_host']
-    login_port = module.params['login_port']
     replica_set = module.params['replica_set']
     members = module.params['members']
     arbiter_at_index = module.params['arbiter_at_index']
     validate = module.params['validate']
-    ssl = module.params['ssl']
     protocol_version = module.params['protocol_version']
     chaining_allowed = module.params['chaining_allowed']
     heartbeat_timeout_secs = module.params['heartbeat_timeout_secs']
     election_timeout_millis = module.params['election_timeout_millis']
     reconfigure = module.params['reconfigure']
-    force = module.params['force']
+    force = module.params['force']  # TODO tidy this stuff up
     max_time_ms = module.params['max_time_ms']
     debug = module.params['debug']
+    cluster_cmd = module.params['cluster_cmd']
 
     if validate and reconfigure is False:
         if len(members) <= 2 or len(members) % 2 == 0:
@@ -556,31 +565,20 @@ def main():
         replica_set=replica_set,
     )
 
-    connection_params = dict(
-        host=login_host,
-        port=int(login_port),
-    )
-
-    if reconfigure and replica_set:
-        connection_params["replicaset"] = replica_set
-
-    if ssl:
-        connection_params = ssl_connection_options(connection_params, module)
-
     try:
-        client = MongoClient(**connection_params)
+        client = get_mongodb_client(module, directConnection=True)
     except Exception as e:
         module.fail_json(msg='Unable to connect to database: %s' % to_native(e))
 
     try:
-        rs = replicaset_find(client)  # does not require auth
+        rs = replicaset_find(client, cluster_cmd)  # does not require auth
     except Exception as e:
         module.fail_json(msg='Unable to connect to query replicaset: %s' % to_native(e))
 
     if isinstance(rs, str):
         if replica_set == rs:
             if reconfigure:
-                mongo_auth(module, client)
+                client = mongo_auth(module, client)
                 result = modify_members_flow(module, client, members, result)
             else:
                 result['changed'] = False
