@@ -76,9 +76,12 @@ EXAMPLES = r'''
 # Display all info from databases group except settings:
 # ansible databases -m mysql_info -a 'filter=!settings'
 
+# If you encounter the "Please explicitly state intended protocol" error,
+# use the login_unix_socket argument
 - name: Collect all possible information using passwordless root access
   community.mysql.mysql_info:
     login_user: root
+    login_unix_socket: /run/mysqld/mysqld.sock
 
 - name: Get MySQL version with non-default credentials
   community.mysql.mysql_info:
@@ -474,6 +477,9 @@ class MySQL_Info(object):
                 self.info['databases'][db['name']] = {}
 
                 if not exclude_fields or 'db_size' not in exclude_fields:
+                    if db['size'] is None:
+                        db['size'] = 0
+
                     self.info['databases'][db['name']]['size'] = int(db['size'])
 
         # If empty dbs are not needed in the returned dict, exit from the method
