@@ -213,6 +213,7 @@ from ansible_collections.community.postgresql.plugins.module_utils.database impo
 from ansible_collections.community.postgresql.plugins.module_utils.postgres import (
     connect_to_db,
     exec_sql,
+    ensure_required_libs,
     get_conn_params,
     postgres_common_argument_spec,
 )
@@ -264,6 +265,21 @@ def convert_subscr_params(params_dict):
     return ', '.join(params_list)
 
 
+def cast_connparams(connparams_dict):
+    """Cast the passed connparams_dict dictionary
+
+    Returns:
+        Dictionary
+    """
+    for (param, val) in iteritems(connparams_dict):
+        try:
+            connparams_dict[param] = int(val)
+        except ValueError:
+            connparams_dict[param] = val
+
+    return connparams_dict
+
+
 class PgSubscription():
     """Class to work with PostgreSQL subscription.
 
@@ -367,7 +383,7 @@ class PgSubscription():
         """Update the subscription.
 
         Args:
-            connparams (str): Connection string in libpq style.
+            connparams (dict): Connection dict in libpq style.
             publications (list): Publications on the primary to use.
             subsparams (dict): Dictionary of optional parameters.
 
@@ -643,6 +659,8 @@ def main():
         if subsparams:
             module.warn("parameter 'subsparams' is ignored when state is not 'present'")
 
+    # Ensure psycopg2 libraries are available before connecting to DB:
+    ensure_required_libs(module)
     # Connect to DB and make cursor object:
     pg_conn_params = get_conn_params(module, module.params)
     # We check subscription state without DML queries execution, so set autocommit:
@@ -680,6 +698,9 @@ def main():
                                           check_mode=module.check_mode)
 
         else:
+            if connparams:
+                connparams = cast_connparams(connparams)
+
             changed = subscription.update(connparams,
                                           publications,
                                           subsparams,
