@@ -8,7 +8,7 @@ from __future__ import absolute_import, division, print_function
 __metaclass__ = type
 
 
-DOCUMENTATION = '''
+DOCUMENTATION = r'''
 ---
 module: rabbitmq_user
 short_description: Manage RabbitMQ users
@@ -77,6 +77,17 @@ options:
       - This option will be ignored when permissions option is used.
     type: str
     default: '^$'
+  topic_permissions:
+    description:
+      - A list of dicts, each dict contains vhost, exchange, read_priv and write_priv,
+        and represents a topic permission rule for that vhost.
+      - By default vhost is C(/) and exchange is C(amq.topic).
+      - Supported since RabbitMQ 3.7.0. If RabbitMQ is older and topic_permissions are
+        set, the module will fail.
+    type: list
+    elements: dict
+    default: []
+    version_added: '1.2.0'
   force:
     description:
       - Deletes and recreates the user.
@@ -97,10 +108,11 @@ options:
     choices: ['on_create', 'always']
 '''
 
-EXAMPLES = '''
-# Add user to server and assign full access control on / vhost.
-# The user might have permission rules for other vhost but you don't care.
-- community.rabbitmq.rabbitmq_user:
+EXAMPLES = r'''
+- name: |-
+    Add user to server and assign full access control on / vhost.
+    The user might have permission rules for other vhost but you don't care.
+  community.rabbitmq.rabbitmq_user:
     user: joe
     password: changeme
     vhost: /
@@ -109,9 +121,10 @@ EXAMPLES = '''
     write_priv: .*
     state: present
 
-# Add user to server and assign full access control on / vhost.
-# The user doesn't have permission rules for other vhosts
-- community.rabbitmq.rabbitmq_user:
+- name: |-
+    Add user to server and assign full access control on / vhost.
+    The user doesn't have permission rules for other vhosts
+  community.rabbitmq.rabbitmq_user:
     user: joe
     password: changeme
     permissions:
@@ -120,9 +133,22 @@ EXAMPLES = '''
         read_priv: .*
         write_priv: .*
     state: present
+
+- name: |-
+    Add user to server and assign some topic permissions on / vhost.
+    The user doesn't have topic permission rules for other vhosts
+  community.rabbitmq.rabbitmq_user:
+    user: joe
+    password: changeme
+    topic_permissions:
+      - vhost: /
+        exchange: amq.topic
+        read_priv: .*
+        write_priv: 'prod\\.logging\\..*'
+    state: present
 '''
 
-import distutils.version
+import ansible_collections.community.rabbitmq.plugins.module_utils.version as Version
 import json
 import re
 
@@ -154,6 +180,11 @@ def as_permission_dict(vhost_permission_list):
                  in normalized_permissions(vhost_permission_list)])
 
 
+def as_topic_permission_dict(topic_permission_list):
+    return dict([((perm['vhost'], perm['exchange']), perm) for perm
+                 in topic_permission_list])
+
+
 def only(vhost, vhost_permissions):
     return {vhost: vhost_permissions.get(vhost, {})}
 
@@ -164,17 +195,19 @@ def first(iterable):
 
 class RabbitMqUser(object):
     def __init__(self, module, username, password, tags, permissions,
-                 node, bulk_permissions=False):
+                 topic_permissions, node, bulk_permissions=False):
         self.module = module
         self.username = username
         self.password = password or ''
         self.node = node
         self.tags = list() if not tags else tags.replace(' ', '').split(',')
         self.permissions = as_permission_dict(permissions)
+        self.topic_permissions = as_topic_permission_dict(topic_permissions)
         self.bulk_permissions = bulk_permissions
 
         self.existing_tags = None
         self.existing_permissions = dict()
+        self.existing_topic_permissions = dict()
         self._rabbitmqctl = module.get_bin_path('rabbitmqctl', True)
         self._version = self._check_version()
 
@@ -211,13 +244,13 @@ class RabbitMqUser(object):
         try:
             status_json = json.loads(output)
             if 'rabbitmq_version' in status_json:
-                return distutils.version.StrictVersion(status_json['rabbitmq_version'])
+                return Version.StrictVersion(status_json['rabbitmq_version'])
             for application in status_json.get('running_applications', list()):
                 if application[0] == 'rabbit':
                     if isinstance(application[1][0], int):
-                        return distutils.version.StrictVersion(int_list_to_str(application[2]))
+                        return Version.StrictVersion(int_list_to_str(application[2]))
                     else:
-                        return distutils.version.StrictVersion(application[1])
+                        return Version.StrictVersion(application[1])
             return self._fail(msg="Could not find RabbitMQ version of `rabbitmqctl status` command.",
                               stop_execution=fail_on_error)
         except ValueError as e:
@@ -244,7 +277,7 @@ class RabbitMqUser(object):
                                   "`rabbitmqctl status` command: {output}.".format(output=output),
                               stop_execution=fail_on_error)
         try:
-            return distutils.version.StrictVersion(reg_ex_res.group(1))
+            return Version.StrictVersion(reg_ex_res.group(1))
         except ValueError as e:
             return self._fail(msg="Could not parse the version of the RabbitMQ server: {exc}.".format(exc=repr(e)),
                               stop_execution=fail_on_error)
@@ -280,11 +313,12 @@ class RabbitMqUser(object):
     def get(self):
         """Retrieves the list of registered users from the node.
 
-        If the user is already present, the node will also be queried for the user's permissions.
+        If the user is already present, the node will also be queried for the user's permissions and topic
+        permissions.
         If the version of the node is >= 3.7.6 the JSON formatter will be used, otherwise the plaintext will be
         parsed.
         """
-        if self._version >= distutils.version.StrictVersion('3.7.6'):
+        if self._version >= Version.StrictVersion('3.7.6'):
             users = dict([(user_entry['user'], user_entry['tags'])
                           for user_entry in json.loads(self._exec(['list_users', '--formatter', 'json']))])
         else:
@@ -303,11 +337,12 @@ class RabbitMqUser(object):
 
         self.existing_tags = users.get(self.username, list())
         self.existing_permissions = self._get_permissions() if self.username in users else dict()
+        self.existing_topic_permissions = self._get_topic_permissions() if self.username in users else dict()
         return self.username in users
 
     def _get_permissions(self):
         """Get permissions of the user from RabbitMQ."""
-        if self._version >= distutils.version.StrictVersion('3.7.6'):
+        if self._version >= Version.StrictVersion('3.7.6'):
             permissions = json.loads(self._exec(['list_user_permissions', self.username, '--formatter', 'json']))
         else:
             output = self._exec(['list_user_permissions', self.username]).strip().split('\n')
@@ -324,6 +359,20 @@ class RabbitMqUser(object):
         else:
             return only(first(self.permissions.keys()), as_permission_dict(permissions))
 
+    def _get_topic_permissions(self):
+        """Get topic permissions of the user from RabbitMQ."""
+        if self._version < Version.StrictVersion('3.7.0'):
+            return dict()
+        if self._version >= Version.StrictVersion('3.7.6'):
+            permissions = json.loads(self._exec(['list_user_topic_permissions', self.username, '--formatter', 'json']))
+        else:
+            output = self._exec(['list_user_topic_permissions', self.username]).strip().split('\n')
+            perms_out = [perm.split('\t') for perm in output if perm.strip()]
+            permissions = list()
+            for vhost, exchange, write, read in perms_out:
+                permissions.append(dict(vhost=vhost, exchange=exchange, write=write, read=read))
+        return as_topic_permission_dict(permissions)
+
     def check_password(self):
         """Return `True` if the user can authenticate successfully."""
         rc, out, err = self._exec(['authenticate_user', self.username, self.password], check_rc=False)
@@ -366,12 +415,37 @@ class RabbitMqUser(object):
             self._exec(cmd.split(' '))
         self.existing_permissions = self._get_permissions()
 
+    def set_topic_permissions(self):
+        permissions_to_add = list()
+        for vhost_exchange, permission_dict in self.topic_permissions.items():
+            if permission_dict != self.existing_topic_permissions.get(vhost_exchange, {}):
+                permissions_to_add.append(permission_dict)
+
+        permissions_to_clear = list()
+        for vhost_exchange in self.existing_topic_permissions.keys():
+            if vhost_exchange not in self.topic_permissions:
+                permissions_to_clear.append(vhost_exchange)
+
+        for vhost_exchange in permissions_to_clear:
+            vhost, exchange = vhost_exchange
+            cmd = ('clear_topic_permissions -p {vhost} {username} {exchange}'
+                   .format(username=self.username, vhost=vhost, exchange=exchange))
+            self._exec(cmd.split(' '))
+        for permissions in permissions_to_add:
+            cmd = ('set_topic_permissions -p {vhost} {username} {exchange} {write} {read}'
+                   .format(username=self.username, **permissions))
+            self._exec(cmd.split(' '))
+        self.existing_topic_permissions = self._get_topic_permissions()
+
     def has_tags_modifications(self):
         return set(self.tags) != set(self.existing_tags)
 
     def has_permissions_modifications(self):
         return self.existing_permissions != self.permissions
 
+    def has_topic_permissions_modifications(self):
+        return self.existing_topic_permissions != self.topic_permissions
+
 
 def main():
     arg_spec = dict(
@@ -383,6 +457,7 @@ def main():
         configure_priv=dict(default='^$'),
         write_priv=dict(default='^$'),
         read_priv=dict(default='^$'),
+        topic_permissions=dict(default=list(), type='list', elements='dict'),
         force=dict(default='no', type='bool'),
         state=dict(default='present', choices=['present', 'absent']),
         node=dict(default='rabbit'),
@@ -390,7 +465,7 @@ def main():
     )
     module = AnsibleModule(
         argument_spec=arg_spec,
-        supports_check_mode=True
+        supports_check_mode=False
     )
 
     username = module.params['user']
@@ -401,6 +476,7 @@ def main():
     configure_priv = module.params['configure_priv']
     write_priv = module.params['write_priv']
     read_priv = module.params['read_priv']
+    topic_permissions = module.params['topic_permissions']
     force = module.params['force']
     state = module.params['state']
     node = module.params['node']
@@ -408,7 +484,7 @@ def main():
 
     if permissions:
         vhosts = [permission.get('vhost', '/') for permission in permissions]
-        if any([vhost_count > 1 for vhost_count in count(vhosts).values()]):
+        if any(vhost_count > 1 for vhost_count in count(vhosts).values()):
             module.fail_json(msg="Error parsing vhost permissions: You can't "
                                  "have two permission dicts for the same vhost")
         bulk_permissions = True
@@ -422,13 +498,33 @@ def main():
         permissions.append(perm)
         bulk_permissions = False
 
+    if topic_permissions:
+        vhost_exchanges = [
+            (permission.get('vhost', '/'), permission.get('exchange'))
+            for permission in topic_permissions
+        ]
+        if any(ve_count > 1 for ve_count in count(vhost_exchanges).values()):
+            module.fail_json(msg="Error parsing vhost topic_permissions: You can't "
+                                 "have two topic permission dicts for the same vhost "
+                                 "and the same exchange")
+
     for permission in permissions:
         if not permission['vhost']:
             module.fail_json(msg="Error parsing vhost permissions: You can't"
                                  "have an empty vhost when setting permissions")
 
+    for permission in topic_permissions:
+        permission.setdefault('vhost', '/')
+        permission.setdefault('exchange', 'amq.topic')
+        # Normalize the arguments
+        for perm_name in ("read", "write"):
+            suffixed_perm_name = "{perm_name}_priv".format(perm_name=perm_name)
+            if suffixed_perm_name in permission:
+                permission[perm_name] = permission.pop(suffixed_perm_name)
+
     rabbitmq_user = RabbitMqUser(module, username, password, tags, permissions,
-                                 node, bulk_permissions=bulk_permissions)
+                                 topic_permissions, node,
+                                 bulk_permissions=bulk_permissions)
 
     result = dict(changed=False, user=username, state=state)
     if rabbitmq_user.get():
@@ -453,10 +549,15 @@ def main():
             if rabbitmq_user.has_permissions_modifications():
                 rabbitmq_user.set_permissions()
                 result['changed'] = True
+
+            if rabbitmq_user.has_topic_permissions_modifications():
+                rabbitmq_user.set_topic_permissions()
+                result['changed'] = True
     elif state == 'present':
         rabbitmq_user.add()
         rabbitmq_user.set_tags()
         rabbitmq_user.set_permissions()
+        rabbitmq_user.set_topic_permissions()
         result['changed'] = True
 
     module.exit_json(**result)
