@@ -5,7 +5,8 @@
 # Copyright (c) 2019 Ansible Project
 # Copyright (c) 2020 Felix Fontein <felix@fontein.de>
 # Copyright (c) 2021 Ansible Project
-# GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
+# GNU General Public License v3.0+ (see LICENSES/GPL-3.0-or-later.txt or https://www.gnu.org/licenses/gpl-3.0.txt)
+# SPDX-License-Identifier: GPL-3.0-or-later
 
 # Parts taken from ansible.module_utils.basic and ansible.module_utils.common.warnings.
 
@@ -216,7 +217,7 @@ class AnsibleActionModule(object):
 
         # this uses exceptions as it happens before we can safely call fail_json
         alias_warnings = []
-        alias_results, self._legal_inputs = handle_aliases(spec, param, alias_warnings=alias_warnings)
+        alias_results, self._legal_inputs = handle_aliases(spec, param, alias_warnings=alias_warnings)  # pylint: disable=used-before-assignment
         for option, alias in alias_warnings:
             self.warn('Both option %s and its alias %s are set.' % (option_prefix + option, option_prefix + alias))
 
@@ -240,12 +241,12 @@ class AnsibleActionModule(object):
             param = self.params
 
         try:
-            self.no_log_values.update(list_no_log_values(spec, param))
+            self.no_log_values.update(list_no_log_values(spec, param))  # pylint: disable=used-before-assignment
         except TypeError as te:
             self.fail_json(msg="Failure when processing no_log parameters. Module invocation will be hidden. "
                                "%s" % to_native(te), invocation={'module_args': 'HIDDEN DUE TO FAILURE'})
 
-        for message in list_deprecations(spec, param):
+        for message in list_deprecations(spec, param):  # pylint: disable=used-before-assignment
             self.deprecate(message['msg'], version=message.get('version'), date=message.get('date'),
                            collection_name=message.get('collection_name'))
 
