@@ -1,8 +1,10 @@
 # -*- coding: utf-8 -*-
+
 # Copyright: (c) 2015, Joseph Callen <jcallen () csc.com>
 # Copyright: (c) 2018, Ansible Project
 # Copyright: (c) 2018, James E. King III (@jeking3) <jking@apache.org>
-# GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
+# GNU General Public License v3.0+ (see LICENSES/GPL-3.0-or-later.txt or https://www.gnu.org/licenses/gpl-3.0.txt)
+# SPDX-License-Identifier: GPL-3.0-or-later
 
 from __future__ import absolute_import, division, print_function
 __metaclass__ = type
@@ -17,7 +19,7 @@ import time
 import traceback
 import datetime
 from collections import OrderedDict
-from distutils.version import StrictVersion
+from ansible_collections.community.vmware.plugins.module_utils.version import StrictVersion
 from random import randint
 
 REQUESTS_IMP_ERR = None
@@ -216,7 +218,6 @@ def find_object_by_name(content, name, obj_type, folder=None, recurse=True):
 
 
 def find_cluster_by_name(content, cluster_name, datacenter=None):
-
     if datacenter and hasattr(datacenter, 'hostFolder'):
         folder = datacenter.hostFolder
     else:
@@ -303,8 +304,12 @@ def find_dvs_by_name(content, switch_name, folder=None):
     return find_object_by_name(content, switch_name, [vim.DistributedVirtualSwitch], folder=folder)
 
 
-def find_hostsystem_by_name(content, hostname):
-    return find_object_by_name(content, hostname, [vim.HostSystem])
+def find_hostsystem_by_name(content, hostname, datacenter=None):
+    if datacenter and hasattr(datacenter, 'hostFolder'):
+        folder = datacenter.hostFolder
+    else:
+        folder = content.rootFolder
+    return find_object_by_name(content, hostname, [vim.HostSystem], folder=folder)
 
 
 def find_resource_pool_by_name(content, resource_pool_name):
@@ -554,6 +559,12 @@ def gather_vm_facts(content, vm):
         facts['current_snapshot'] = snapshot_facts['current_snapshot']
 
     facts['vnc'] = get_vnc_extraconfig(vm)
+
+    # Gather vTPM information
+    facts['tpm_info'] = {
+        'tpm_present': vm.summary.config.tpmPresent if hasattr(vm.summary.config, 'tpmPresent') else None,
+        'provider_id': vm.config.keyId.providerId.id if vm.config.keyId else None
+    }
     return facts
 
 
@@ -918,6 +929,8 @@ def set_vm_power_state(content, vm, state, force, timeout=0, answers=None):
     requested states. force is forceful
     """
     facts = gather_vm_facts(content, vm)
+    if state == 'present':
+        state = 'poweredon'
     expected_state = state.replace('_', '').replace('-', '').lower()
     current_state = facts['hw_power_status'].lower()
     result = dict(
@@ -971,9 +984,11 @@ def set_vm_power_state(content, vm, state, force, timeout=0, answers=None):
                     else:
                         result['failed'] = True
                         result['msg'] = "VMware tools should be installed for guest shutdown/reboot"
+                elif current_state == 'poweredoff':
+                    result['changed'] = False
                 else:
                     result['failed'] = True
-                    result['msg'] = "Virtual machine %s must be in poweredon state for guest shutdown/reboot" % vm.name
+                    result['msg'] = "Virtual machine %s must be in poweredon state for guest reboot" % vm.name
 
             else:
                 result['failed'] = True
@@ -1129,6 +1144,18 @@ class PyVmomi(object):
         elif api_type == 'HostAgent':
             return False
 
+    def vcenter_version_at_least(self, version=None):
+        """
+        Check that the vCenter server is at least a specific version number
+        Args:
+            version (tuple): a version tuple, for example (6, 7, 0)
+        Returns: bool
+        """
+        if version:
+            vc_version = self.content.about.version
+            return StrictVersion(vc_version) >= StrictVersion('.'.join(map(str, version)))
+        self.module.fail_json(msg='The passed vCenter version: %s is None.' % version)
+
     def get_managed_objects_properties(self, vim_type, properties=None):
         """
         Look up a Managed Object Reference in vCenter / ESXi Environment
@@ -1384,16 +1411,17 @@ class PyVmomi(object):
             return []
 
     # Hosts related functions
-    def find_hostsystem_by_name(self, host_name):
+    def find_hostsystem_by_name(self, host_name, datacenter=None):
         """
         Find Host by name
         Args:
             host_name: Name of ESXi host
+            datacenter: (optional) Datacenter of ESXi resides
 
         Returns: True if found
 
         """
-        return find_hostsystem_by_name(self.content, hostname=host_name)
+        return find_hostsystem_by_name(self.content, hostname=host_name, datacenter=datacenter)
 
     def get_all_host_objs(self, cluster_name=None, esxi_host_name=None):
         """
