@@ -2,7 +2,8 @@
 # -*- coding: utf-8 -*-
 
 # Copyright: (c) 2018, Abhijeet Kasurde <akasurde@redhat.com>
-# GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
+# GNU General Public License v3.0+ (see LICENSES/GPL-3.0-or-later.txt or https://www.gnu.org/licenses/gpl-3.0.txt)
+# SPDX-License-Identifier: GPL-3.0-or-later
 
 from __future__ import absolute_import, division, print_function
 __metaclass__ = type
@@ -17,11 +18,6 @@ description:
 author:
 - Abhijeet Kasurde (@Akasurde)
 - Aaron Longchamps (@alongchamps)
-notes:
-- Tested on vSphere 6.0, vSphere 6.5
-requirements:
-- python >= 2.6
-- PyVmomi
 options:
   cluster_name:
     description:
@@ -405,7 +401,7 @@ def main():
             module.deprecate(
                 msg=('Please adjust your playbook to ensure the `allowed_hosts` '
                      'entries come with an `all_ip` key (boolean).'),
-                version='2.0.0',
+                version='3.0.0',
                 collection_name='community.vmware'
             )
 
