@@ -2,7 +2,8 @@
 # -*- coding: utf-8 -*-
 
 # Copyright: (c) 2018, Ansible Project
-# GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
+# GNU General Public License v3.0+ (see LICENSES/GPL-3.0-or-later.txt or https://www.gnu.org/licenses/gpl-3.0.txt)
+# SPDX-License-Identifier: GPL-3.0-or-later
 
 from __future__ import absolute_import, division, print_function
 
@@ -21,11 +22,6 @@ description:
 - You can supply an esxi_hostname or a cluster_name
 author:
 - Michael Eaton (@michaeldeaton)
-notes:
-- Tested on vSphere 6.0
-requirements:
-- python >= 2.6
-- PyVmomi
 options:
   esxi_hostname:
     description:
