@@ -2,7 +2,8 @@
 # -*- coding: utf-8 -*-
 
 # Copyright: (c) 2017, Davis Phillips davis.phillips@gmail.com
-# GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
+# GNU General Public License v3.0+ (see LICENSES/GPL-3.0-or-later.txt or https://www.gnu.org/licenses/gpl-3.0.txt)
+# SPDX-License-Identifier: GPL-3.0-or-later
 
 from __future__ import absolute_import, division, print_function
 __metaclass__ = type
@@ -16,11 +17,6 @@ description:
     - This module can be used to add/remove a resource pool to/from vCenter
 author:
 - Davis Phillips (@dav1x)
-notes:
-    - Tested on vSphere 6.5
-requirements:
-    - "python >= 2.6"
-    - PyVmomi
 options:
     datacenter:
         description:
@@ -31,18 +27,21 @@ options:
         description:
             - Name of the cluster to configure the resource pool.
             - This parameter is required if C(esxi_hostname) or C(parent_resource_pool) is not specified.
+            - The C(cluster), C(esxi_hostname) and C(parent_resource_pool) parameters are mutually exclusive.
         type: str
     esxi_hostname:
         description:
             - Name of the host to configure the resource pool.
             - The host must not be member of a cluster.
             - This parameter is required if C(cluster) or C(parent_resource_pool) is not specified.
+            - The C(cluster), C(esxi_hostname) and C(parent_resource_pool) parameters are mutually exclusive.
         type: str
         version_added: '1.5.0'
     parent_resource_pool:
         description:
             - Name of the parent resource pool.
             - This parameter is required if C(cluster) or C(esxi_hostname) is not specified.
+            - The C(cluster), C(esxi_hostname) and C(parent_resource_pool) parameters are mutually exclusive.
         type: str
         version_added: '1.9.0'
     resource_pool:
