@@ -1,9 +1,11 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
+
 # Copyright: (c) 2018, Ansible Project
 # Copyright: (c) 2018, CrySyS Lab <www.crysys.hu>
 # Copyright: (c) 2018, Peter Gyorgy <gyorgy.peter@edu.bme.hu>
-# GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
+# GNU General Public License v3.0+ (see LICENSES/GPL-3.0-or-later.txt or https://www.gnu.org/licenses/gpl-3.0.txt)
+# SPDX-License-Identifier: GPL-3.0-or-later
 
 from __future__ import absolute_import, division, print_function
 
@@ -18,11 +20,6 @@ description:
    - This module can be used to create, delete or edit different kind of port mirroring sessions.
 author:
 - Peter Gyorgy (@gyorgypeter)
-notes:
-    - Tested on vSphere 6.7
-requirements:
-    - "python > =  2.6"
-    - PyVmomi
 options:
     switch:
         description:
@@ -391,21 +388,21 @@ class VMwareVspanSession(PyVmomi):
                 for port in session_ports:
                     if vspan_session.name == self.name:
                         ports_of_selected_session.append(port)
-                    elif not(port in ports):
+                    elif not (port in ports):
                         ports.append(port)
             if vspan_session.sourcePortTransmitted is not None:
                 session_ports = vspan_session.sourcePortTransmitted.portKey
                 for port in session_ports:
                     if vspan_session.name == self.name:
                         ports_of_selected_session.append(port)
-                    elif not(port in ports):
+                    elif not (port in ports):
                         ports.append(port)
             if vspan_session.destinationPort is not None:
                 session_ports = vspan_session.destinationPort.portKey
                 for port in session_ports:
                     if vspan_session.name == self.name:
                         ports_of_selected_session.append(port)
-                    elif not(port in ports):
+                    elif not (port in ports):
                         ports.append(port)
         promiscuous_ports = []
         if ports:
