@@ -6,6 +6,7 @@
 
 from __future__ import absolute_import, division, print_function
 __metaclass__ = type
+
 from ansible.module_utils.basic import env_fallback
 
 
@@ -73,10 +74,11 @@ def helper_cleanup_data(obj):
         return obj
 
 
-def helper_to_numeric_value(strs, value):
+def helper_to_numeric_value(elements, value):
     """Converts string values to integers
 
     Parameters:
+        elements: list of elements to enumerate
         value: string value
 
     Returns:
@@ -84,10 +86,13 @@ def helper_to_numeric_value(strs, value):
     """
     if value is None:
         return None
-    strs = [s.lower() if isinstance(s, str) else s for s in strs]
-    value = value.lower()
-    tmp_dict = dict(zip(strs, list(range(len(strs)))))
-    return tmp_dict[value]
+    for index, element in enumerate(elements):
+        if isinstance(element, str) and element.lower() == value.lower():
+            return index
+        if isinstance(element, list):
+            for deep_element in element:
+                if isinstance(deep_element, str) and deep_element.lower() == value.lower():
+                    return index
 
 
 def helper_convert_unicode_to_str(data):
@@ -128,8 +133,13 @@ def helper_compare_lists(l1, l2, diff_dict):
         return diff_dict
     for i, item in enumerate(l1):
         if isinstance(item, dict):
-            diff_dict.insert(i, {})
-            diff_dict[i] = helper_compare_dictionaries(item, l2[i], diff_dict[i])
+            for item2 in l2:
+                diff_dict2 = {}
+                diff_dict2 = helper_compare_dictionaries(item, item2, diff_dict2)
+                if len(diff_dict2) == 0:
+                    break
+            if len(diff_dict2) != 0:
+                diff_dict.insert(i, item)
         else:
             if item != l2[i]:
                 diff_dict.append(item)
