@@ -72,6 +72,7 @@ options:
             type:
                 description:
                     - Type (label) of the condition.
+                    - C(application) is available only with <= Zabbix 5.2.
                     - 'Possible values when I(event_source=trigger):'
                     - ' - C(host_group)'
                     - ' - C(host)'
@@ -142,19 +143,20 @@ options:
                     - Condition operator.
                     - When I(type) is set to C(time_period), the choices are C(in), C(not in).
                     - C(matches), C(does not match), C(Yes) and C(No) condition operators work only with >= Zabbix 4.0
+                    - When I(type) is set to C(maintenance_status), the choices are C(Yes) and C(No) for Zabbix >= 6.0
                 choices:
-                    - '='
-                    - '<>'
-                    - 'like'
-                    - 'not like'
-                    - 'in'
-                    - '>='
-                    - '<='
-                    - 'not in'
-                    - 'matches'
-                    - 'does not match'
-                    - 'Yes'
-                    - 'No'
+                    - C(equals) or C(=)
+                    - C(does not equal) or C(<>)
+                    - C(contains) or C(like)
+                    - C(does not contain) or C(not like)
+                    - C(in)
+                    - C(is greater than or equals) or C(>=)
+                    - C(is less than or equals) or C(<=)
+                    - C(not in)
+                    - C(matches)
+                    - C(does not match)
+                    - C(Yes)
+                    - C(No)
             formulaid:
                 description:
                     - Arbitrary unique ID that is used to reference the condition from a custom expression.
@@ -492,11 +494,12 @@ msg:
 '''
 
 
-from distutils.version import LooseVersion
 from ansible.module_utils.basic import AnsibleModule
 
 from ansible_collections.community.zabbix.plugins.module_utils.base import ZabbixBase
 from ansible_collections.community.zabbix.plugins.module_utils.wrappers import ZapiWrapper
+from ansible_collections.community.zabbix.plugins.module_utils.version import LooseVersion
+
 import ansible_collections.community.zabbix.plugins.module_utils.helpers as zabbix_utils
 
 
@@ -516,14 +519,17 @@ class Zapi(ZapiWrapper):
 
         """
         try:
-            _action = self._zapi.action.get({
+            _params = {
                 "selectOperations": "extend",
                 "selectRecoveryOperations": "extend",
                 "selectAcknowledgeOperations": "extend",
                 "selectFilter": "extend",
                 'filter': {'name': [name]}
-            })
-            if len(_action) > 0:
+            }
+            if LooseVersion(self._zbx_api_version) >= LooseVersion('6.0'):
+                _params['selectUpdateOperations'] = _params.pop('selectAcknowledgeOperations', 'extend')
+            _action = self._zapi.action.get(_params)
+            if len(_action) > 0 and LooseVersion(self._zbx_api_version) < LooseVersion('6.0'):
                 _action[0]['recovery_operations'] = _action[0].pop('recoveryOperations', [])
                 _action[0]['acknowledge_operations'] = _action[0].pop('acknowledgeOperations', [])
             return _action
@@ -546,7 +552,7 @@ class Zapi(ZapiWrapper):
                 'filter': {'name': [name]}
             })
             if len(action_list) < 1:
-                self._module.fail_json(msg="Action not found: " % name)
+                self._module.fail_json(msg="Action not found: %s" % name)
             else:
                 return action_list[0]
         except Exception as e:
@@ -674,14 +680,40 @@ class Zapi(ZapiWrapper):
 
         """
         try:
-            discovery_check_list = self._zapi.dcheck.get({
-                'output': 'extend',
-                'filter': {'key_': [discovery_check_name]}
+            discovery_rule_name, dcheck_type = discovery_check_name.split(': ')
+            dcheck_type_to_number = {
+                'SSH': '0',
+                'LDAP': '1',
+                'SMTP': '2',
+                'FTP': '3',
+                'HTTP': '4',
+                'POP': '5',
+                'NNTP': '6',
+                'IMAP': '7',
+                'TCP': '8',
+                'Zabbix agent': '9',
+                'SNMPv1 agent': '10',
+                'SNMPv2 agent': '11',
+                'ICMP ping': '12',
+                'SNMPv3 agent': '13',
+                'HTTPS': '14',
+                'Telnet': '15'
+            }
+            if dcheck_type not in dcheck_type_to_number:
+                self._module.fail_json(msg="Discovery check type: %s does not exist" % dcheck_type)
+
+            discovery_rule_list = self._zapi.drule.get({
+                'output': ['dchecks'],
+                'filter': {'name': [discovery_rule_name]},
+                'selectDChecks': 'extend'
             })
-            if len(discovery_check_list) < 1:
+            if len(discovery_rule_list) < 1:
                 self._module.fail_json(msg="Discovery check not found: %s" % discovery_check_name)
-            else:
-                return discovery_check_list[0]
+
+            for dcheck in discovery_rule_list[0]['dchecks']:
+                if dcheck_type_to_number[dcheck_type] == dcheck['type']:
+                    return dcheck
+            self._module.fail_json(msg="Discovery check not found: %s" % discovery_check_name)
         except Exception as e:
             self._module.fail_json(msg="Failed to get discovery check '%s': %s" % (discovery_check_name, e))
 
@@ -827,7 +859,7 @@ class Action(ZabbixBase):
 
         _params = {
             'name': kwargs['name'],
-            'eventsource': to_numeric_value([
+            'eventsource': zabbix_utils.helper_to_numeric_value([
                 'trigger',
                 'discovery',
                 'auto_registration',
@@ -843,7 +875,7 @@ class Action(ZabbixBase):
             'operations': kwargs['operations'],
             'recovery_operations': kwargs.get('recovery_operations'),
             'acknowledge_operations': kwargs.get('acknowledge_operations'),
-            'status': to_numeric_value([
+            'status': zabbix_utils.helper_to_numeric_value([
                 'enabled',
                 'disabled'], kwargs['status'])
         }
@@ -867,6 +899,30 @@ class Action(ZabbixBase):
             _params.pop('ack_longdata', None)
             _params.pop('ack_shortdata', None)
 
+        if LooseVersion(self._zbx_api_version) >= LooseVersion('6.0'):
+            _params['update_operations'] = kwargs.get('update_operations')
+            if 'update_operations' in _params and not isinstance(_params.get('update_operations', None), type(None)):
+                _params.pop('acknowledge_operations', None)
+            elif isinstance(_params.get('acknowledge_operations', None), list):
+                _params['update_operations'] = _params.pop('acknowledge_operations', [])
+            else:
+                _params['update_operations'] = []
+                _params.pop('acknowledge_operations', None)
+
+            if 'esc_period' in _params and isinstance(_params.get('esc_period', None), type(None)):
+                _params.pop('esc_period')
+
+            if 'recovery_operations' in _params:
+                if isinstance(_params.get('recovery_operations', None), type(None)) or len(_params.get('recovery_operations', [])) == 0:
+                    _params.pop('recovery_operations')
+
+            if 'update_operations' in _params:
+                if isinstance(_params.get('update_operations', None), type(None)) or len(_params.get('update_operations', [])) == 0:
+                    _params.pop('update_operations')
+
+            if _params['eventsource'] not in [0, 3]:
+                _params.pop('esc_period')
+
         return _params
 
     def check_difference(self, **kwargs):
@@ -878,10 +934,10 @@ class Action(ZabbixBase):
         Returns:
             dict: dictionary of differences
         """
-        existing_action = convert_unicode_to_str(self._zapi_wrapper.check_if_action_exists(kwargs['name'])[0])
-        parameters = convert_unicode_to_str(self._construct_parameters(**kwargs))
+        existing_action = zabbix_utils.helper_convert_unicode_to_str(self._zapi_wrapper.check_if_action_exists(kwargs['name'])[0])
+        parameters = zabbix_utils.helper_convert_unicode_to_str(self._construct_parameters(**kwargs))
         change_parameters = {}
-        _diff = cleanup_data(compare_dictionaries(parameters, existing_action, change_parameters))
+        _diff = zabbix_utils.helper_cleanup_data(zabbix_utils.helper_compare_dictionaries(parameters, existing_action, change_parameters))
         return _diff
 
     def update_action(self, **kwargs):
@@ -947,7 +1003,7 @@ class Operations(Zapi):
             str: constructed operation
         """
         try:
-            return to_numeric_value([
+            return zabbix_utils.helper_to_numeric_value([
                 "send_message",
                 "remote_command",
                 "add_host",
@@ -1024,31 +1080,42 @@ class Operations(Zapi):
             list: constructed operation command
         """
         try:
-            return {
-                'type': to_numeric_value([
-                    'custom_script',
-                    'ipmi',
-                    'ssh',
-                    'telnet',
-                    'global_script'], operation.get('command_type', 'custom_script')),
-                'command': operation.get('command'),
-                'execute_on': to_numeric_value([
-                    'agent',
-                    'server',
-                    'proxy'], operation.get('execute_on', 'server')),
-                'scriptid': self._zapi_wrapper.get_script_by_script_name(
-                    operation.get('script_name')
-                ).get('scriptid'),
-                'authtype': to_numeric_value([
-                    'password',
-                    'public_key'
-                ], operation.get('ssh_auth_type')),
-                'privatekey': operation.get('ssh_privatekey_file'),
-                'publickey': operation.get('ssh_publickey_file'),
-                'username': operation.get('username'),
-                'password': operation.get('password'),
-                'port': operation.get('port')
-            }
+            if LooseVersion(self._zbx_api_version) < LooseVersion('6.0'):
+                opcommand = {
+                    'type': zabbix_utils.helper_to_numeric_value([
+                        'custom_script',
+                        'ipmi',
+                        'ssh',
+                        'telnet',
+                        'global_script'], operation.get('command_type', 'custom_script')),
+                    'command': operation.get('command'),
+                    'execute_on': zabbix_utils.helper_to_numeric_value([
+                        'agent',
+                        'server',
+                        'proxy'], operation.get('execute_on', 'server')),
+                    'scriptid': self._zapi_wrapper.get_script_by_script_name(
+                        operation.get('script_name')
+                    ).get('scriptid'),
+                    'authtype': zabbix_utils.helper_to_numeric_value([
+                        'password',
+                        'public_key'
+                    ], operation.get('ssh_auth_type')),
+                    'privatekey': operation.get('ssh_privatekey_file'),
+                    'publickey': operation.get('ssh_publickey_file'),
+                    'username': operation.get('username'),
+                    'password': operation.get('password'),
+                    'port': operation.get('port')
+                }
+            else:
+                # In 6.0 opcommand is an opbject with just one key 'scriptid'
+                opcommand = {
+                    'scriptid': self._zapi_wrapper.get_script_by_script_name(
+                        operation.get('script_name')
+                    ).get('scriptid')
+                }
+
+            return opcommand
+
         except Exception as e:
             self._module.fail_json(msg="Failed to construct operation command. The error was: %s" % e)
 
@@ -1079,7 +1146,7 @@ class Operations(Zapi):
         if operation.get('run_on_groups') is None:
             return None
         return [{
-            'groupid': self._zapi_wrapper.get_hostgroup_by_hostgroup_name(_group)['hostid']
+            'groupid': self._zapi_wrapper.get_hostgroup_by_hostgroup_name(_group)['groupid']
         } for _group in operation.get('run_on_groups')]
 
     def _construct_opgroup(self, operation):
@@ -1118,7 +1185,7 @@ class Operations(Zapi):
             dict: constructed operation inventory
         """
         return {
-            'inventory_mode': to_numeric_value([
+            'inventory_mode': zabbix_utils.helper_to_numeric_value([
                 'manual',
                 'automatic'
             ], operation.get('inventory'))
@@ -1146,7 +1213,7 @@ class Operations(Zapi):
             }]
         return []
 
-    def construct_the_data(self, operations):
+    def construct_the_data(self, operations, event_source):
         """Construct the operation data using helper methods.
 
         Args:
@@ -1165,34 +1232,47 @@ class Operations(Zapi):
                 'esc_step_to': op.get('esc_step_to')
             }
             # Send Message type
-            if constructed_operation['operationtype'] == '0':
+            if constructed_operation['operationtype'] == 0:
                 constructed_operation['opmessage'] = self._construct_opmessage(op)
                 constructed_operation['opmessage_usr'] = self._construct_opmessage_usr(op)
                 constructed_operation['opmessage_grp'] = self._construct_opmessage_grp(op)
-                constructed_operation['opconditions'] = self._construct_opconditions(op)
+                if event_source == 'trigger':
+                    # opconditions valid only for 'trigger' action
+                    constructed_operation['opconditions'] = self._construct_opconditions(op)
 
             # Send Command type
-            if constructed_operation['operationtype'] == '1':
+            if constructed_operation['operationtype'] == 1:
                 constructed_operation['opcommand'] = self._construct_opcommand(op)
                 constructed_operation['opcommand_hst'] = self._construct_opcommand_hst(op)
                 constructed_operation['opcommand_grp'] = self._construct_opcommand_grp(op)
-                constructed_operation['opconditions'] = self._construct_opconditions(op)
+                if event_source == 'trigger':
+                    # opconditions valid only for 'trigger' action
+                    constructed_operation['opconditions'] = self._construct_opconditions(op)
 
             # Add to/Remove from host group
-            if constructed_operation['operationtype'] in ('4', '5'):
+            if constructed_operation['operationtype'] in (4, 5):
                 constructed_operation['opgroup'] = self._construct_opgroup(op)
 
             # Link/Unlink template
-            if constructed_operation['operationtype'] in ('6', '7'):
+            if constructed_operation['operationtype'] in (6, 7):
                 constructed_operation['optemplate'] = self._construct_optemplate(op)
 
             # Set inventory mode
-            if constructed_operation['operationtype'] == '10':
+            if constructed_operation['operationtype'] == 10:
                 constructed_operation['opinventory'] = self._construct_opinventory(op)
 
+            # Remove escalation params when for event sources where they are not applicable
+            if event_source in ['trigger', 'internal']:
+                if isinstance(constructed_operation.get('esc_period'), type(None)):
+                    constructed_operation['esc_period'] = 0
+            else:
+                constructed_operation.pop('esc_period')
+                constructed_operation.pop('esc_step_from')
+                constructed_operation.pop('esc_step_to')
+
             constructed_data.append(constructed_operation)
 
-        return cleanup_data(constructed_data)
+        return zabbix_utils.helper_cleanup_data(constructed_data)
 
 
 class RecoveryOperations(Operations):
@@ -1209,7 +1289,7 @@ class RecoveryOperations(Operations):
             str: constructed operation type
         """
         try:
-            return to_numeric_value([
+            return zabbix_utils.helper_to_numeric_value([
                 "send_message",
                 "remote_command",
                 None,
@@ -1243,20 +1323,25 @@ class RecoveryOperations(Operations):
             }
 
             # Send Message type
-            if constructed_operation['operationtype'] in ('0', '11'):
+            if constructed_operation['operationtype'] == 0:
                 constructed_operation['opmessage'] = self._construct_opmessage(op)
                 constructed_operation['opmessage_usr'] = self._construct_opmessage_usr(op)
                 constructed_operation['opmessage_grp'] = self._construct_opmessage_grp(op)
 
+            if constructed_operation['operationtype'] == 11:
+                constructed_operation['opmessage'] = self._construct_opmessage(op)
+                if LooseVersion(self._zbx_api_version) >= LooseVersion('6.0'):
+                    constructed_operation['opmessage'].pop('mediatypeid')
+
             # Send Command type
-            if constructed_operation['operationtype'] == '1':
+            if constructed_operation['operationtype'] == 1:
                 constructed_operation['opcommand'] = self._construct_opcommand(op)
                 constructed_operation['opcommand_hst'] = self._construct_opcommand_hst(op)
                 constructed_operation['opcommand_grp'] = self._construct_opcommand_grp(op)
 
             constructed_data.append(constructed_operation)
 
-        return cleanup_data(constructed_data)
+        return zabbix_utils.helper_cleanup_data(constructed_data)
 
 
 class AcknowledgeOperations(Operations):
@@ -1273,7 +1358,7 @@ class AcknowledgeOperations(Operations):
             str: constructed operation type
         """
         try:
-            return to_numeric_value([
+            return zabbix_utils.helper_to_numeric_value([
                 "send_message",
                 "remote_command",
                 None,
@@ -1308,20 +1393,25 @@ class AcknowledgeOperations(Operations):
             }
 
             # Send Message type
-            if constructed_operation['operationtype'] in ('0', '11'):
+            if constructed_operation['operationtype'] == 0:
                 constructed_operation['opmessage'] = self._construct_opmessage(op)
                 constructed_operation['opmessage_usr'] = self._construct_opmessage_usr(op)
                 constructed_operation['opmessage_grp'] = self._construct_opmessage_grp(op)
 
+            if constructed_operation['operationtype'] == 12:
+                constructed_operation['opmessage'] = self._construct_opmessage(op)
+                if LooseVersion(self._zbx_api_version) >= LooseVersion('6.0'):
+                    constructed_operation['opmessage'].pop('mediatypeid')
+
             # Send Command type
-            if constructed_operation['operationtype'] == '1':
+            if constructed_operation['operationtype'] == 1:
                 constructed_operation['opcommand'] = self._construct_opcommand(op)
                 constructed_operation['opcommand_hst'] = self._construct_opcommand_hst(op)
                 constructed_operation['opcommand_grp'] = self._construct_opcommand_grp(op)
 
             constructed_data.append(constructed_operation)
 
-        return cleanup_data(constructed_data)
+        return zabbix_utils.helper_cleanup_data(constructed_data)
 
 
 class Filter(Zapi):
@@ -1382,8 +1472,13 @@ class Filter(Zapi):
         Returns:
             str: constructed condition type data
         """
+        # application is disabled is disabled for condition type since 5.4 version.
+        if (LooseVersion(self._zbx_api_version) >= LooseVersion('5.4')
+                and _condition['type'] == 'application'):
+            self._module.fail_json(msg="'%s' is disabled for condition type since 5.4 version." % _condition['type'])
+
         try:
-            return to_numeric_value([
+            return zabbix_utils.helper_to_numeric_value([
                 "host_group",
                 "host",
                 "trigger",
@@ -1425,14 +1520,14 @@ class Filter(Zapi):
             str: constructed operator
         """
         try:
-            return to_numeric_value([
-                "=",
-                "<>",
-                "like",
-                "not like",
+            return zabbix_utils.helper_to_numeric_value([
+                ["equals", "="],
+                ["does not equal", "<>"],
+                ["contains", "like"],
+                ["does not contain", "not like"],
                 "in",
-                ">=",
-                "<=",
+                ["is greater than or equals", ">="],
+                ["is less than or equals", "<="],
                 "not in",
                 "matches",
                 "does not match",
@@ -1454,18 +1549,18 @@ class Filter(Zapi):
         """
         try:
             # Host group
-            if conditiontype == '0':
+            if conditiontype == 0:
                 return self._zapi_wrapper.get_hostgroup_by_hostgroup_name(value)['groupid']
             # Host
-            if conditiontype == '1':
+            if conditiontype == 1:
                 return self._zapi_wrapper.get_host_by_host_name(value)['hostid']
             # Trigger
-            if conditiontype == '2':
+            if conditiontype == 2:
                 return self._zapi_wrapper.get_trigger_by_trigger_name(value)['triggerid']
             # Trigger name: return as is
             # Trigger severity
-            if conditiontype == '4':
-                return to_numeric_value([
+            if conditiontype == 4:
+                return zabbix_utils.helper_to_numeric_value([
                     "not classified",
                     "information",
                     "warning",
@@ -1475,16 +1570,16 @@ class Filter(Zapi):
                 )
 
             # Trigger value
-            if conditiontype == '5':
-                return to_numeric_value([
+            if conditiontype == 5:
+                return zabbix_utils.helper_to_numeric_value([
                     "ok",
                     "problem"], value or "ok"
                 )
             # Time period: return as is
             # Host IP: return as is
             # Discovered service type
-            if conditiontype == '8':
-                return to_numeric_value([
+            if conditiontype == 8:
+                return zabbix_utils.helper_to_numeric_value([
                     "SSH",
                     "LDAP",
                     "SMTP",
@@ -1504,29 +1599,36 @@ class Filter(Zapi):
                 )
             # Discovered service port: return as is
             # Discovery status
-            if conditiontype == '10':
-                return to_numeric_value([
+            if conditiontype == 10:
+                return zabbix_utils.helper_to_numeric_value([
                     "up",
                     "down",
                     "discovered",
                     "lost"], value
                 )
-            if conditiontype == '13':
+            if conditiontype == 13:
                 return self._zapi_wrapper.get_template_by_template_name(value)['templateid']
-            if conditiontype == '18':
+            if LooseVersion(self._zapi_wrapper._zbx_api_version) >= LooseVersion('6.0'):
+                # maintenance_status
+                if conditiontype == 16:
+                    return zabbix_utils.helper_to_numeric_value([
+                        "Yes",
+                        "No"], value
+                    )
+            if conditiontype == 18:
                 return self._zapi_wrapper.get_discovery_rule_by_discovery_rule_name(value)['druleid']
-            if conditiontype == '19':
+            if conditiontype == 19:
                 return self._zapi_wrapper.get_discovery_check_by_discovery_check_name(value)['dcheckid']
-            if conditiontype == '20':
+            if conditiontype == 20:
                 return self._zapi_wrapper.get_proxy_by_proxy_name(value)['proxyid']
-            if conditiontype == '21':
-                return to_numeric_value([
+            if conditiontype == 21:
+                return zabbix_utils.helper_to_numeric_value([
                     "pchldrfor0",
                     "host",
                     "service"], value
                 )
-            if conditiontype == '23':
-                return to_numeric_value([
+            if conditiontype == 23:
+                return zabbix_utils.helper_to_numeric_value([
                     "item in not supported state",
                     "item in normal state",
                     "LLD rule in not supported state",
@@ -1574,124 +1676,7 @@ class Filter(Zapi):
         )
         constructed_data['evaltype'] = _constructed_evaltype['evaltype']
         constructed_data['formula'] = _constructed_evaltype['formula']
-        return cleanup_data(constructed_data)
-
-
-def convert_unicode_to_str(data):
-    """Converts unicode objects to strings in dictionary
-    args:
-        data: unicode object
-
-    Returns:
-        dict: strings in dictionary
-    """
-    if isinstance(data, dict):
-        return dict(map(convert_unicode_to_str, data.items()))
-    elif isinstance(data, (list, tuple, set)):
-        return type(data)(map(convert_unicode_to_str, data))
-    elif data is None:
-        return data
-    else:
-        return str(data)
-
-
-def to_numeric_value(strs, value):
-    """Converts string values to integers
-    Args:
-        value: string value
-
-    Returns:
-        int: converted integer
-    """
-    if value is None:
-        return value
-
-    strs = [s.lower() if isinstance(s, str) else s for s in strs]
-    value = value.lower()
-    tmp_dict = dict(zip(strs, list(range(len(strs)))))
-    return str(tmp_dict[value])
-
-
-def compare_lists(l1, l2, diff_dict):
-    """
-    Compares l1 and l2 lists and adds the items that are different
-    to the diff_dict dictionary.
-    Used in recursion with compare_dictionaries() function.
-    Args:
-        l1: first list to compare
-        l2: second list to compare
-        diff_dict: dictionary to store the difference
-
-    Returns:
-        dict: items that are different
-    """
-    if len(l1) != len(l2):
-        diff_dict.append(l1)
-        return diff_dict
-    for i, item in enumerate(l1):
-        if isinstance(item, dict):
-            diff_dict.insert(i, {})
-            diff_dict[i] = compare_dictionaries(item, l2[i], diff_dict[i])
-        else:
-            if item != l2[i]:
-                diff_dict.append(item)
-    while {} in diff_dict:
-        diff_dict.remove({})
-    return diff_dict
-
-
-def compare_dictionaries(d1, d2, diff_dict):
-    """
-    Compares d1 and d2 dictionaries and adds the items that are different
-    to the diff_dict dictionary.
-    Used in recursion with compare_lists() function.
-    Args:
-        d1: first dictionary to compare
-        d2: second dictionary to compare
-        diff_dict: dictionary to store the difference
-
-    Returns:
-        dict: items that are different
-    """
-    for k, v in d1.items():
-        if k not in d2:
-            diff_dict[k] = v
-            continue
-        if isinstance(v, dict):
-            diff_dict[k] = {}
-            compare_dictionaries(v, d2[k], diff_dict[k])
-            if diff_dict[k] == {}:
-                del diff_dict[k]
-            else:
-                diff_dict[k] = v
-        elif isinstance(v, list):
-            diff_dict[k] = []
-            compare_lists(v, d2[k], diff_dict[k])
-            if diff_dict[k] == []:
-                del diff_dict[k]
-            else:
-                diff_dict[k] = v
-        else:
-            if v != d2[k]:
-                diff_dict[k] = v
-    return diff_dict
-
-
-def cleanup_data(obj):
-    """Removes the None values from the object and returns the object
-    Args:
-        obj: object to cleanup
-
-    Returns:
-       object: cleaned object
-    """
-    if isinstance(obj, (list, tuple, set)):
-        return type(obj)(cleanup_data(x) for x in obj if x is not None)
-    elif isinstance(obj, dict):
-        return type(obj)((cleanup_data(k), cleanup_data(v))
-                         for k, v in obj.items() if k is not None and v is not None)
-    else:
-        return obj
+        return zabbix_utils.helper_cleanup_data(constructed_data)
 
 
 def main():
@@ -1721,7 +1706,7 @@ def main():
                 formulaid=dict(type='str', required=False),
                 operator=dict(type='str', required=True),
                 type=dict(type='str', required=True),
-                value=dict(type='str', required=True),
+                value=dict(type='str', required=False),
                 value2=dict(type='str', required=False)
             ),
             required_if=[
@@ -1962,7 +1947,6 @@ def main():
         argument_spec=argument_spec,
         required_if=[
             ['state', 'present', [
-                'esc_period',
                 'event_source'
             ]]
         ],
@@ -2003,7 +1987,7 @@ def main():
             result = action.delete_action(action_id)
             module.exit_json(changed=True, msg="Action Deleted: %s, ID: %s" % (name, result))
         else:
-            difference = action.check_difference(
+            kwargs = dict(
                 action_id=action_id,
                 name=name,
                 event_source=event_source,
@@ -2016,12 +2000,18 @@ def main():
                 recovery_default_subject=recovery_default_subject,
                 acknowledge_default_message=acknowledge_default_message,
                 acknowledge_default_subject=acknowledge_default_subject,
-                operations=ops.construct_the_data(operations),
+                operations=ops.construct_the_data(operations, event_source),
                 recovery_operations=recovery_ops.construct_the_data(recovery_operations),
-                acknowledge_operations=acknowledge_ops.construct_the_data(acknowledge_operations),
                 conditions=fltr.construct_the_data(eval_type, formula, conditions)
             )
 
+            if LooseVersion(zapi_wrapper._zbx_api_version) >= LooseVersion('6.0'):
+                kwargs[argument_spec['acknowledge_operations']['aliases'][0]] = acknowledge_ops.construct_the_data(acknowledge_operations)
+            else:
+                kwargs['acknowledge_operations'] = acknowledge_ops.construct_the_data(acknowledge_operations)
+
+            difference = action.check_difference(**kwargs)
+
             if difference == {}:
                 module.exit_json(changed=False, msg="Action is up to date: %s" % (name))
             else:
@@ -2034,7 +2024,7 @@ def main():
         if state == "absent":
             module.exit_json(changed=False)
         else:
-            action_id = action.add_action(
+            kwargs = dict(
                 name=name,
                 event_source=event_source,
                 esc_period=esc_period,
@@ -2046,11 +2036,17 @@ def main():
                 recovery_default_subject=recovery_default_subject,
                 acknowledge_default_message=acknowledge_default_message,
                 acknowledge_default_subject=acknowledge_default_subject,
-                operations=ops.construct_the_data(operations),
+                operations=ops.construct_the_data(operations, event_source),
                 recovery_operations=recovery_ops.construct_the_data(recovery_operations),
-                acknowledge_operations=acknowledge_ops.construct_the_data(acknowledge_operations),
                 conditions=fltr.construct_the_data(eval_type, formula, conditions)
             )
+
+            if LooseVersion(zapi_wrapper._zbx_api_version) >= LooseVersion('6.0'):
+                kwargs[argument_spec['acknowledge_operations']['aliases'][0]] = acknowledge_ops.construct_the_data(acknowledge_operations)
+            else:
+                kwargs['acknowledge_operations'] = acknowledge_ops.construct_the_data(acknowledge_operations)
+
+            action_id = action.add_action(**kwargs)
             module.exit_json(changed=True, msg="Action created: %s, ID: %s" % (name, action_id))
 
 
