@@ -1,10 +1,12 @@
 from __future__ import (absolute_import, division, print_function)
 import json  # noqa: F402
 import shlex  # noqa: F402
-from distutils.version import LooseVersion  # noqa: F402
 
 from ansible.module_utils._text import to_bytes, to_native  # noqa: F402
+from ansible_collections.containers.podman.plugins.module_utils.podman.common import LooseVersion
 from ansible_collections.containers.podman.plugins.module_utils.podman.common import lower_keys
+from ansible_collections.containers.podman.plugins.module_utils.podman.common import generate_systemd
+from ansible_collections.containers.podman.plugins.module_utils.podman.common import normalize_signal
 
 __metaclass__ = type
 
@@ -54,6 +56,7 @@ ARGUMENTS_SPEC_CONTAINER = dict(
                 'exposed', 'exposed_ports']),
     force_restart=dict(type='bool', default=False,
                        aliases=['restart']),
+    generate_systemd=dict(type='dict', default={}),
     gidmap=dict(type='list', elements='str'),
     group_add=dict(type='list', elements='str', aliases=['groups']),
     healthcheck=dict(type='str'),
@@ -88,8 +91,9 @@ ARGUMENTS_SPEC_CONTAINER = dict(
     memory_reservation=dict(type='str'),
     memory_swap=dict(type='str'),
     memory_swappiness=dict(type='int'),
-    mount=dict(type='str'),
+    mount=dict(type='list', elements='str', aliases=['mounts']),
     network=dict(type='list', elements='str', aliases=['net', 'network_mode']),
+    network_aliases=dict(type='list', elements='str'),
     no_hosts=dict(type='bool'),
     oom_kill_disable=dict(type='bool'),
     oom_score_adj=dict(type='int'),
@@ -103,6 +107,7 @@ ARGUMENTS_SPEC_CONTAINER = dict(
     read_only=dict(type='bool'),
     read_only_tmpfs=dict(type='bool'),
     recreate=dict(type='bool', default=False),
+    requires=dict(type='list', elements='str'),
     restart_policy=dict(type='str'),
     rm=dict(type='bool', aliases=['remove', 'auto_remove']),
     rootfs=dict(type='bool'),
@@ -468,11 +473,19 @@ class PodmanModuleParams:
         return c + ['--memory-swappiness', self.params['memory_swappiness']]
 
     def addparam_mount(self, c):
-        return c + ['--mount', self.params['mount']]
+        for mnt in self.params['mount']:
+            if mnt:
+                c += ['--mount', mnt]
+        return c
 
     def addparam_network(self, c):
         return c + ['--network', ",".join(self.params['network'])]
 
+    def addparam_network_aliases(self, c):
+        for alias in self.params['network_aliases']:
+            c += ['--network-alias', alias]
+        return c
+
     def addparam_no_hosts(self, c):
         return c + ['--no-hosts=%s' % self.params['no_hosts']]
 
@@ -508,6 +521,9 @@ class PodmanModuleParams:
     def addparam_read_only_tmpfs(self, c):
         return c + ['--read-only-tmpfs=%s' % self.params['read_only_tmpfs']]
 
+    def addparam_requires(self, c):
+        return c + ['--requires', ",".join(self.params['requires'])]
+
     def addparam_restart_policy(self, c):
         return c + ['--restart=%s' % self.params['restart_policy']]
 
@@ -629,7 +645,6 @@ class PodmanDefaults:
             "group_add": [],
             "ipc": "",
             "kernelmemory": "0",
-            "log_driver": "k8s-file",
             "log_level": "error",
             "memory": "0",
             "memory_swap": "0",
@@ -640,6 +655,7 @@ class PodmanDefaults:
             "oom_score_adj": 0,
             "pid": "",
             "privileged": False,
+            "read_only": False,
             "rm": False,
             "security_opt": [],
             "stop_signal": self.image_info['config'].get('stopsignal', "15"),
@@ -662,6 +678,8 @@ class PodmanDefaults:
             self.defaults['pid'] = "private"
         if (LooseVersion(self.version) >= LooseVersion('3.0.0')):
             self.defaults['log_level'] = "warning"
+        if (LooseVersion(self.version) >= LooseVersion('4.1.0')):
+            self.defaults['ipc'] = "shareable"
         return self.defaults
 
 
@@ -944,17 +962,11 @@ class PodmanContainerDiff:
 
     def diffparam_log_driver(self):
         before = self.info['hostconfig']['logconfig']['type']
-        after = self.params['log_driver']
-        return self._diff_update_and_compare('log_driver', before, after)
-
-    def diffparam_log_level(self):
-        excom = self.info['exitcommand']
-        if '--log-level' in excom:
-            before = excom[excom.index('--log-level') + 1].lower()
+        if self.module_params['log_driver'] is not None:
+            after = self.params['log_driver']
         else:
-            before = self.params['log_level']
-        after = self.params['log_level']
-        return self._diff_update_and_compare('log_level', before, after)
+            after = before
+        return self._diff_update_and_compare('log_driver', before, after)
 
     # Parameter has limited idempotency, unable to guess the default log_path
     def diffparam_log_opt(self):
@@ -1020,32 +1032,22 @@ class PodmanContainerDiff:
 
     def diffparam_mac_address(self):
         before = str(self.info['networksettings']['macaddress'])
+        if not before and self.info['networksettings'].get('networks'):
+            nets = self.info['networksettings']['networks']
+            macs = [
+                nets[i]["macaddress"] for i in nets if nets[i]["macaddress"]]
+            if macs:
+                before = macs[0]
+        if not before and 'createcommand' in self.info['config']:
+            cr_com = self.info['config']['createcommand']
+            if '--mac-address' in cr_com:
+                before = cr_com[cr_com.index('--mac-address') + 1].lower()
         if self.module_params['mac_address'] is not None:
             after = self.params['mac_address']
         else:
             after = before
         return self._diff_update_and_compare('mac_address', before, after)
 
-    def diffparam_memory(self):
-        before = str(self.info['hostconfig']['memory'])
-        after = self.params['memory']
-        return self._diff_update_and_compare('memory', before, after)
-
-    def diffparam_memory_swap(self):
-        # By default it's twice memory parameter
-        before = str(self.info['hostconfig']['memoryswap'])
-        after = self.params['memory_swap']
-        if (self.module_params['memory_swap'] is None
-                and self.params['memory'] != 0
-                and self.params['memory'].isdigit()):
-            after = str(int(self.params['memory']) * 2)
-        return self._diff_update_and_compare('memory_swap', before, after)
-
-    def diffparam_memory_reservation(self):
-        before = str(self.info['hostconfig']['memoryreservation'])
-        after = self.params['memory_reservation']
-        return self._diff_update_and_compare('memory_reservation', before, after)
-
     def diffparam_network(self):
         net_mode_before = self.info['hostconfig']['networkmode']
         net_mode_after = ''
@@ -1076,6 +1078,11 @@ class PodmanContainerDiff:
             net_mode_before = net_mode_before.replace('bridge', 'default')
             net_mode_before = net_mode_before.replace('slirp4netns', 'default')
             return self._diff_update_and_compare('network', net_mode_before, net_mode_after)
+        # If container is attached to network of a different container
+        if "container" in net_mode_before:
+            for netw in after:
+                if "container" in netw:
+                    before = after = netw
         before, after = sorted(list(set(before))), sorted(list(set(after)))
         return self._diff_update_and_compare('network', before, after)
 
@@ -1107,8 +1114,9 @@ class PodmanContainerDiff:
         ports = self.info['hostconfig']['portbindings']
         before = []
         for port, hosts in ports.items():
-            for h in hosts:
-                before.append(compose(port, h))
+            if hosts:
+                for h in hosts:
+                    before.append(compose(port, h))
         after = self.params['publish'] or []
         if self.params['publish_all']:
             image_ports = self.image_info['config'].get('exposedports', {})
@@ -1124,6 +1132,11 @@ class PodmanContainerDiff:
         before, after = sorted(list(set(before))), sorted(list(set(after)))
         return self._diff_update_and_compare('publish', before, after)
 
+    def diffparam_read_only(self):
+        before = self.info['hostconfig']['readonlyrootfs']
+        after = self.params['read_only']
+        return self._diff_update_and_compare('read_only', before, after)
+
     def diffparam_rm(self):
         before = self.info['hostconfig']['autoremove']
         after = self.params['rm']
@@ -1138,47 +1151,8 @@ class PodmanContainerDiff:
         return self._diff_update_and_compare('security_opt', before, after)
 
     def diffparam_stop_signal(self):
-        signals = {
-            "sighup": "1",
-            "sigint": "2",
-            "sigquit": "3",
-            "sigill": "4",
-            "sigtrap": "5",
-            "sigabrt": "6",
-            "sigiot": "6",
-            "sigbus": "7",
-            "sigfpe": "8",
-            "sigkill": "9",
-            "sigusr1": "10",
-            "sigsegv": "11",
-            "sigusr2": "12",
-            "sigpipe": "13",
-            "sigalrm": "14",
-            "sigterm": "15",
-            "sigstkflt": "16",
-            "sigchld": "17",
-            "sigcont": "18",
-            "sigstop": "19",
-            "sigtstp": "20",
-            "sigttin": "21",
-            "sigttou": "22",
-            "sigurg": "23",
-            "sigxcpu": "24",
-            "sigxfsz": "25",
-            "sigvtalrm": "26",
-            "sigprof": "27",
-            "sigwinch": "28",
-            "sigio": "29",
-            "sigpwr": "30",
-            "sigsys": "31",
-            "sigrtmin+3": "37"
-        }
-        before = str(self.info['config']['stopsignal'])
-        if not before.isdigit():
-            before = signals[before.lower()]
-        after = str(self.params['stop_signal'])
-        if not after.isdigit():
-            after = signals[after.lower()]
+        before = normalize_signal(self.info['config']['stopsignal'])
+        after = normalize_signal(self.params['stop_signal'])
         return self._diff_update_and_compare('stop_signal', before, after)
 
     def diffparam_timezone(self):
@@ -1244,9 +1218,14 @@ class PodmanContainerDiff:
             local_vols = []
             for m in before:
                 if m['type'] != 'volume':
-                    volumes.append([m['source'], m['destination']])
+                    volumes.append(
+                        [
+                            clean_volume(m['source']),
+                            clean_volume(m['destination'])
+                        ])
                 elif m['type'] == 'volume':
-                    local_vols.append([m['name'], m['destination']])
+                    local_vols.append(
+                        [m['name'], clean_volume(m['destination'])])
             before = [":".join(v) for v in volumes]
             before_local_vols = [":".join(v) for v in local_vols]
         if self.params['volume'] is not None:
@@ -1521,6 +1500,8 @@ class PodmanManager:
             self.results.update({'diff': self.container.diff})
         if self.module.params['debug'] or self.module_params['debug']:
             self.results.update({'podman_version': self.container.version})
+        self.results.update(
+            {'podman_systemd': generate_systemd(self.module, self.module_params, self.name)})
 
     def make_started(self):
         """Run actions if desired state is 'started'."""
