@@ -608,7 +608,7 @@ options:
   pod:
     description:
       - Run container in an existing pod.
-        If you want podman to make the pod for you, preference the pod name
+        If you want podman to make the pod for you, prefix the pod name
         with "new:"
     type: str
   privileged:
@@ -648,6 +648,13 @@ options:
         existing container.
     type: bool
     default: False
+  requires:
+    description:
+      - Specify one or more requirements. A requirement is a dependency
+        container that will be started before this container.
+        Containers can be specified by name or ID.
+    type: list
+    elements: str
   restart_policy:
     description:
       - Restart policy to follow when containers exit.
