@@ -3,8 +3,8 @@
 
 #
 # Dell EMC OpenManage Ansible Modules
-# Version 4.0.0
-# Copyright (C) 2018-2021 Dell Inc. or its subsidiaries. All Rights Reserved.
+# Version 5.1.0
+# Copyright (C) 2018-2022 Dell Inc. or its subsidiaries. All Rights Reserved.
 
 # GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
 #
@@ -74,8 +74,8 @@ options:
         default: False
 
 requirements:
-    - "omsdk"
-    - "python >= 2.7.5"
+    - "omsdk >= 1.2.488"
+    - "python >= 3.8.6"
 author:
     - "Rajeev Arakkal (@rajeevarakkal)"
     - "Felix Stephen (@felixs88)"
@@ -95,6 +95,7 @@ EXAMPLES = """
        idrac_ip: "192.168.0.1"
        idrac_user: "user_name"
        idrac_password: "user_password"
+       ca_path: "/path/to/ca_cert.pem"
        share_name: "192.168.0.0:/share"
        reboot: True
        job_wait: True
@@ -106,6 +107,7 @@ EXAMPLES = """
        idrac_ip: "192.168.0.1"
        idrac_user: "user_name"
        idrac_password: "user_password"
+       ca_path: "/path/to/ca_cert.pem"
        share_name: "full_cifs_path"
        share_user: "share_user"
        share_password: "share_password"
@@ -119,6 +121,7 @@ EXAMPLES = """
        idrac_ip: "192.168.0.1"
        idrac_user: "user_name"
        idrac_password: "user_password"
+       ca_path: "/path/to/ca_cert.pem"
        share_name: "http://downloads.dell.com"
        reboot: True
        job_wait: True
@@ -129,6 +132,7 @@ EXAMPLES = """
        idrac_ip: "192.168.0.1"
        idrac_user: "user_name"
        idrac_password: "user_password"
+       ca_path: "/path/to/ca_cert.pem"
        share_name: "https://downloads.dell.com"
        reboot: True
        job_wait: True
@@ -139,6 +143,7 @@ EXAMPLES = """
        idrac_ip: "192.168.0.1"
        idrac_user: "user_name"
        idrac_password: "user_password"
+       ca_path: "/path/to/ca_cert.pem"
        share_name: "ftp://ftp.dell.com"
        reboot: True
        job_wait: True
@@ -169,12 +174,11 @@ update_status:
 
 
 import os
-import re
 import json
 import time
 from ssl import SSLError
 from xml.etree import ElementTree as ET
-from ansible_collections.dellemc.openmanage.plugins.module_utils.dellemc_idrac import iDRACConnection
+from ansible_collections.dellemc.openmanage.plugins.module_utils.dellemc_idrac import iDRACConnection, idrac_auth_params
 from ansible_collections.dellemc.openmanage.plugins.module_utils.idrac_redfish import iDRACRedfishAPI
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.six.moves.urllib.parse import urlparse
@@ -191,7 +195,7 @@ except ImportError:
 SHARE_TYPE = {'nfs': 'NFS', 'cifs': 'CIFS', 'ftp': 'FTP',
               'http': 'HTTP', 'https': 'HTTPS', 'tftp': 'TFTP'}
 CERT_WARN = {True: 'On', False: 'Off'}
-IDRAC_PATH = "/redfish/v1/Managers/iDRAC.Embedded.1"
+IDRAC_PATH = "/redfish/v1/Dell/Systems/System.Embedded.1/DellSoftwareInstallationService"
 PATH = "/redfish/v1/Dell/Systems/System.Embedded.1/DellSoftwareInstallationService/Actions/" \
        "DellSoftwareInstallationService.InstallFromRepository"
 GET_REPO_BASED_UPDATE_LIST_PATH = "/redfish/v1/Dell/Systems/System.Embedded.1/DellSoftwareInstallationService/" \
@@ -219,7 +223,7 @@ def wait_for_job_completion(module, job_uri, job_wait=False, reboot=False, apply
                 response = redfish.invoke_request(job_uri, "GET")
             track_counter += 5
             msg = None
-        except (SSLError, URLError, ConnectionError, HTTPError) as error_message:
+        except Exception as error_message:
             msg = str(error_message)
             track_counter += 1
             time.sleep(10)
@@ -233,8 +237,9 @@ def wait_for_job_completion(module, job_uri, job_wait=False, reboot=False, apply
                 response = redfish.invoke_request(job_uri, "GET")
                 job_state = response.json_data.get("JobState")
             msg = None
-        except (SSLError, URLError, ConnectionError, HTTPError) as error_message:
-            track_counter += 1
+        except Exception as error_message:
+            msg = str(error_message)
+            track_counter += 2
             time.sleep(INTERVAL)
         else:
             if response.json_data.get("PercentComplete") == 100 and job_state == "Completed":  # apply now
@@ -277,7 +282,6 @@ def get_job_status(module, each_comp, idrac):
                 resp = idrac.job_mgr.job_wait(each_comp.get("JobID"))
                 if resp.get("JobStatus") is not None and (not resp.get('JobStatus') == "Scheduled"):
                     break
-            # module.warn("omsdk job wait 315: "+json.dumps(resp))
             each_comp['Message'] = resp.get('Message')
             each_comp['JobStatus'] = "OK"
             fail_words_lower = ['fail', 'invalid', 'unable', 'not', 'cancel']
@@ -341,8 +345,7 @@ def handle_HTTP_error(module, httperr):
         module.fail_json(msg=err_message)
 
 
-def update_firmware_url_redfish(module, idrac, share_name, catalog_file_name, apply_update, reboot,
-                                ignore_cert_warning, job_wait, payload):
+def update_firmware_url_redfish(module, idrac, share_name, apply_update, reboot, job_wait, payload, repo_urls):
     """Update firmware through HTTP/HTTPS/FTP and return the job details."""
     repo_url = urlparse(share_name)
     job_details, status = {}, {}
@@ -353,7 +356,14 @@ def update_firmware_url_redfish(module, idrac, share_name, catalog_file_name, ap
     if repo_url.path:
         payload['ShareName'] = sharename
     payload['ShareType'] = SHARE_TYPE[share_type]
-    resp = idrac.invoke_request(PATH, method="POST", data=payload)
+    install_url = PATH
+    get_repo_url = GET_REPO_BASED_UPDATE_LIST_PATH
+    actions = repo_urls.get('Actions')
+    if actions:
+        install_url = actions.get("#DellSoftwareInstallationService.InstallFromRepository", {}).get("target", PATH)
+        get_repo_url = actions.get("#DellSoftwareInstallationService.GetRepoBasedUpdateList", {}).\
+            get("target", GET_REPO_BASED_UPDATE_LIST_PATH)
+    resp = idrac.invoke_request(install_url, method="POST", data=payload)
     job_id = get_jobid(module, resp)
     resp, msg = wait_for_job_completion(module, JOB_URI.format(job_id=job_id), job_wait, reboot, apply_update)
     if not msg:
@@ -361,7 +371,7 @@ def update_firmware_url_redfish(module, idrac, share_name, catalog_file_name, ap
     else:
         status['update_msg'] = msg
     try:
-        resp_repo_based_update_list = idrac.invoke_request(GET_REPO_BASED_UPDATE_LIST_PATH, method="POST", data="{}",
+        resp_repo_based_update_list = idrac.invoke_request(get_repo_url, method="POST", data="{}",
                                                            dump=False)
         job_details = resp_repo_based_update_list.json_data
     except HTTPError as err:
@@ -383,7 +393,6 @@ def update_firmware_url_omsdk(module, idrac, share_name, catalog_file_name, appl
                                                             share_name=sharename, catalog_file=catalog_file_name,
                                                             apply_update=apply_update, reboot_needed=reboot,
                                                             ignore_cert_warning=ignore_cert_warning, job_wait=job_wait)
-        # module.warn(json.dumps(status))
         get_check_mode_status(status, module)
     else:
         status = idrac.update_mgr.update_from_repo_url(ipaddress=ipaddr, share_type=share_type,
@@ -481,7 +490,7 @@ def update_firmware_omsdk(idrac, module):
     return msg
 
 
-def update_firmware_redfish(idrac, module):
+def update_firmware_redfish(idrac, module, repo_urls):
     """Update firmware from a network share and return the job details."""
     msg = {}
     msg['changed'], msg['failed'] = False, False
@@ -503,9 +512,8 @@ def update_firmware_redfish(idrac, module):
             payload['Password'] = share_pwd
 
         if share_name.lower().startswith(('http://', 'https://', 'ftp://')):
-            msg['update_status'], job_details = update_firmware_url_redfish(module, idrac, share_name, catalog_file_name,
-                                                                            apply_update, reboot, ignore_cert_warning,
-                                                                            job_wait, payload)
+            msg['update_status'], job_details = update_firmware_url_redfish(
+                module, idrac, share_name, apply_update, reboot, job_wait, payload, repo_urls)
             if job_details:
                 msg['update_status']['job_details'] = job_details
         else:
@@ -586,39 +594,31 @@ def update_firmware_redfish(idrac, module):
 
 
 def main():
+    specs = {
+        "share_name": {"required": True, "type": 'str'},
+        "share_user": {"required": False, "type": 'str'},
+        "share_password": {"required": False, "type": 'str', "aliases": ['share_pwd'], "no_log": True},
+        "share_mnt": {"required": False, "type": 'str'},
+
+        "catalog_file_name": {"required": False, "type": 'str', "default": "Catalog.xml"},
+        "reboot": {"required": False, "type": 'bool', "default": False},
+        "job_wait": {"required": False, "type": 'bool', "default": True},
+        "ignore_cert_warning": {"required": False, "type": 'bool', "default": True},
+        "apply_update": {"required": False, "type": 'bool', "default": True},
+    }
+    specs.update(idrac_auth_params)
     module = AnsibleModule(
-        argument_spec={
-            "idrac_ip": {"required": True, "type": 'str'},
-            "idrac_user": {"required": True, "type": 'str'},
-            "idrac_password": {"required": True, "type": 'str', "aliases": ['idrac_pwd'], "no_log": True},
-            "idrac_port": {"required": False, "default": 443, "type": 'int'},
-
-            "share_name": {"required": True, "type": 'str'},
-            "share_user": {"required": False, "type": 'str'},
-            "share_password": {"required": False, "type": 'str', "aliases": ['share_pwd'], "no_log": True},
-            "share_mnt": {"required": False, "type": 'str'},
-
-            "catalog_file_name": {"required": False, "type": 'str', "default": "Catalog.xml"},
-            "reboot": {"required": False, "type": 'bool', "default": False},
-            "job_wait": {"required": False, "type": 'bool', "default": True},
-            "ignore_cert_warning": {"required": False, "type": 'bool', "default": True},
-            "apply_update": {"required": False, "type": 'bool', "default": True},
-        },
-
+        argument_spec=specs,
         supports_check_mode=True)
 
     redfish_check = False
     try:
         with iDRACRedfishAPI(module.params) as obj:
             resp = obj.invoke_request(IDRAC_PATH, method="GET")
-            idrac_data = resp.json_data
-            if idrac_data:
-                firm_id = idrac_data.get("FirmwareVersion")
-                firmware_version = re.match(r"^\d.\d{2}", firm_id).group()
-                if float(firmware_version) >= float(REDFISH_VERSION):
-                    redfish_check = True
-    except (HTTPError, RuntimeError, URLError, SSLValidationError, ConnectionError, KeyError, ImportError, ValueError,
-            TypeError, SSLError) as e:
+            software_service_data = resp.json_data
+            redfish_check = True
+    except Exception:
+        software_service_data = {}
         redfish_check = False
 
     try:
@@ -631,15 +631,17 @@ def main():
         # Connect to iDRAC and update firmware
         if redfish_check:
             with iDRACRedfishAPI(module.params) as redfish_obj:
-                status = update_firmware_redfish(redfish_obj, module)
+                status = update_firmware_redfish(redfish_obj, module, software_service_data)
         else:
             with iDRACConnection(module.params) as idrac:
                 status = update_firmware_omsdk(idrac, module)
     except HTTPError as err:
         module.fail_json(msg=str(err), update_status=json.load(err))
     except (RuntimeError, URLError, SSLValidationError, ConnectionError, KeyError,
-            ImportError, ValueError, TypeError) as e:
+            ImportError, ValueError, TypeError, SSLError) as e:
         module.fail_json(msg=str(e))
+    except Exception as exc:
+        module.fail_json(msg="Unhandled Exception {0}".format(exc))
 
     module.exit_json(msg=status['update_msg'], update_status=status['update_status'],
                      changed=status['changed'], failed=status['failed'])
