@@ -3,8 +3,8 @@
 
 #
 # Dell EMC OpenManage Ansible Modules
-# Version 3.5.0
-# Copyright (C) 2018-2021 Dell Inc. or its subsidiaries. All Rights Reserved.
+# Version 5.0.1
+# Copyright (C) 2018-2022 Dell Inc. or its subsidiaries. All Rights Reserved.
 
 # GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
 #
@@ -108,8 +108,8 @@ options:
         type: str
         description: Enter the static IP subnet mask to iDRAC.
 requirements:
-    - "omsdk"
-    - "python >= 2.7.5"
+    - "omsdk >= 1.2.488"
+    - "python >= 3.8.6"
 author:
     - "Felix Stephen (@felixs88)"
     - "Anooja Vardhineni (@anooja-vardhineni)"
@@ -126,6 +126,7 @@ EXAMPLES = """
        idrac_ip:   "192.168.0.1"
        idrac_user: "user_name"
        idrac_password:  "user_password"
+       ca_path: "/path/to/ca_cert.pem"
        share_name: "192.168.0.1:/share"
        share_password:  "share_pwd"
        share_user: "share_user"
@@ -212,7 +213,7 @@ error_info:
 import json
 from ansible.module_utils.six.moves.urllib.error import URLError, HTTPError
 from ansible.module_utils.urls import ConnectionError, SSLValidationError
-from ansible_collections.dellemc.openmanage.plugins.module_utils.dellemc_idrac import iDRACConnection
+from ansible_collections.dellemc.openmanage.plugins.module_utils.dellemc_idrac import iDRACConnection, idrac_auth_params
 from ansible.module_utils.basic import AnsibleModule
 try:
     from omdrivers.enums.iDRAC.iDRAC import (DNSRegister_NICTypes, DNSDomainFromDHCP_NICStaticTypes,
@@ -346,55 +347,50 @@ def run_idrac_network_config(idrac, module):
 
 # Main
 def main():
+    specs = {
+        # Export Destination
+        "share_name": {"required": True, "type": 'str'},
+        "share_password": {"required": False, "type": 'str', "aliases": ['share_pwd'], "no_log": True},
+        "share_user": {"required": False, "type": 'str'},
+        "share_mnt": {"required": False, "type": 'str'},
+
+        # setup DNS
+        "register_idrac_on_dns": {"required": False, "choices": ['Enabled', 'Disabled'], "default": None},
+        "dns_idrac_name": {"required": False, "default": None, "type": 'str'},
+        "auto_config": {"required": False, "choices": ['Enabled', 'Disabled'], "default": None, 'type': 'str'},
+        "static_dns": {"required": False, "default": None, "type": "str"},
+
+        # set up idrac vlan
+        "setup_idrac_nic_vlan": {"required": False, "choices": ['Enabled', 'Disabled']},
+        "vlan_id": {"required": False, "type": 'int'},
+        "vlan_priority": {"required": False, "type": 'int'},
+
+        # set up NIC
+        "enable_nic": {"required": False, "choices": ['Enabled', 'Disabled'], "default": None},
+        "nic_selection": {"required": False, "choices": ['Dedicated', 'LOM1', 'LOM2', 'LOM3', 'LOM4'], "default": None},
+        "failover_network": {"required": False, "choices": ['ALL', 'LOM1', 'LOM2', 'LOM3', 'LOM4', 'T_None'],
+                             "default": None},
+        "auto_detect": {"required": False, "choices": ['Enabled', 'Disabled'], "default": None},
+        "auto_negotiation": {"required": False, "choices": ['Enabled', 'Disabled'], "default": None},
+        "network_speed": {"required": False, "choices": ['T_10', 'T_100', 'T_1000'], "default": None},
+        "duplex_mode": {"required": False, "choices": ['Full', 'Half'], "default": None},
+        "nic_mtu": {"required": False, 'type': 'int'},
+
+        # setup iDRAC IPV4
+        "ip_address": {"required": False, "default": None, "type": "str"},
+        "enable_dhcp": {"required": False, "choices": ["Enabled", "Disabled"], "default": None},
+        "enable_ipv4": {"required": False, "choices": ["Enabled", "Disabled"], "default": None},
+
+        # setup iDRAC Static IPv4
+        "dns_from_dhcp": {"required": False, "choices": ["Enabled", "Disabled"], "default": None},
+        "static_dns_1": {"required": False, "default": None, "type": "str"},
+        "static_dns_2": {"required": False, "default": None, "type": "str"},
+        "static_gateway": {"required": False, "type": "str"},
+        "static_net_mask": {"required": False, "type": "str"},
+    }
+    specs.update(idrac_auth_params)
     module = AnsibleModule(
-        argument_spec={
-
-            # iDRAC credentials
-            "idrac_ip": {"required": True, "type": 'str'},
-            "idrac_user": {"required": True, "type": 'str'},
-            "idrac_password": {"required": True, "type": 'str', "aliases": ['idrac_pwd'], "no_log": True},
-            "idrac_port": {"required": False, "default": 443, "type": 'int'},
-
-            # Export Destination
-            "share_name": {"required": True, "type": 'str'},
-            "share_password": {"required": False, "type": 'str', "aliases": ['share_pwd'], "no_log": True},
-            "share_user": {"required": False, "type": 'str'},
-            "share_mnt": {"required": False, "type": 'str'},
-
-            # setup DNS
-            "register_idrac_on_dns": {"required": False, "choices": ['Enabled', 'Disabled'], "default": None},
-            "dns_idrac_name": {"required": False, "default": None, "type": 'str'},
-            "auto_config": {"required": False, "choices": ['Enabled', 'Disabled'], "default": None, 'type': 'str'},
-            "static_dns": {"required": False, "default": None, "type": "str"},
-
-            # set up idrac vlan
-            "setup_idrac_nic_vlan": {"required": False, "choices": ['Enabled', 'Disabled']},
-            "vlan_id": {"required": False, "type": 'int'},
-            "vlan_priority": {"required": False, "type": 'int'},
-
-            # set up NIC
-            "enable_nic": {"required": False, "choices": ['Enabled', 'Disabled'], "default": None},
-            "nic_selection": {"required": False, "choices": ['Dedicated', 'LOM1', 'LOM2', 'LOM3', 'LOM4'], "default": None},
-            "failover_network": {"required": False, "choices": ['ALL', 'LOM1', 'LOM2', 'LOM3', 'LOM4', 'T_None'],
-                                 "default": None},
-            "auto_detect": {"required": False, "choices": ['Enabled', 'Disabled'], "default": None},
-            "auto_negotiation": {"required": False, "choices": ['Enabled', 'Disabled'], "default": None},
-            "network_speed": {"required": False, "choices": ['T_10', 'T_100', 'T_1000'], "default": None},
-            "duplex_mode": {"required": False, "choices": ['Full', 'Half'], "default": None},
-            "nic_mtu": {"required": False, 'type': 'int'},
-
-            # setup iDRAC IPV4
-            "ip_address": {"required": False, "default": None, "type": "str"},
-            "enable_dhcp": {"required": False, "choices": ["Enabled", "Disabled"], "default": None},
-            "enable_ipv4": {"required": False, "choices": ["Enabled", "Disabled"], "default": None},
-
-            # setup iDRAC Static IPv4
-            "dns_from_dhcp": {"required": False, "choices": ["Enabled", "Disabled"], "default": None},
-            "static_dns_1": {"required": False, "default": None, "type": "str"},
-            "static_dns_2": {"required": False, "default": None, "type": "str"},
-            "static_gateway": {"required": False, "type": "str"},
-            "static_net_mask": {"required": False, "type": "str"},
-        },
+        argument_spec=specs,
         supports_check_mode=True)
 
     try:
