@@ -235,6 +235,7 @@ base:
   type: str
   sample: base
 '''
+
 from datetime import datetime
 
 from ansible.module_utils.basic import (
@@ -295,6 +296,7 @@ class Parameters(AnsibleF5Parameters):
         'chase_referrals',
         'manual_resume',
         'target_username',
+        'target_password',
         'filter',
         'base',
     ]
@@ -344,26 +346,23 @@ class Parameters(AnsibleF5Parameters):
     def manual_resume(self):
         return flatten_boolean(self._values['manual_resume'])
 
-    @property
-    def security(self):
-        if self._values['security'] in ['none', None]:
-            return ''
-        return self._values['security']
-
 
 class ApiParameters(Parameters):
     @property
     def ip(self):
-        ip, port = self._values['destination'].split(':')
+        des = self._values['destination']
+        ip, d, port = des.rpartition('.')
+        if not is_valid_ip(ip) and ip != '*':
+            ip, d, port = des.rpartition(':')
         return ip
 
     @property
     def port(self):
-        ip, port = self._values['destination'].split(':')
-        try:
-            return int(port)
-        except ValueError:
-            return port
+        des = self._values['destination']
+        ip, d, port = des.rpartition('.')
+        if not is_valid_ip(ip) and ip != '*':
+            ip, d, port = des.rpartition(':')
+        return int(port) if port.isnumeric() else port
 
     @property
     def description(self):
@@ -371,6 +370,12 @@ class ApiParameters(Parameters):
             return None
         return self._values['description']
 
+    @property
+    def security(self):
+        if self._values['security'] in ['none', None]:
+            return ''
+        return self._values['security']
+
 
 class ModuleParameters(Parameters):
     @property
@@ -436,6 +441,12 @@ class ModuleParameters(Parameters):
             return ''
         return self._values['description']
 
+    @property
+    def security(self):
+        if self._values['security'] in ['none', None]:
+            return ''
+        return self._values['security']
+
 
 class Changes(Parameters):
     def to_return(self):
@@ -466,15 +477,19 @@ class ReportableChanges(Changes):
 
     @property
     def ip(self):
-        ip, port = self._values['destination'].split(':')
+        des = self._values['destination']
+        ip, d, port = des.rpartition('.')
+        if not is_valid_ip(ip) and ip != '*':
+            ip, d, port = des.rpartition(':')
         return ip
 
     @property
     def port(self):
-        ip, port = self._values['destination'].split(':')
-        if port == '*':
-            return port
-        return int(port)
+        des = self._values['destination']
+        ip, d, port = des.rpartition('.')
+        if not is_valid_ip(ip) and ip != '*':
+            ip, d, port = des.rpartition(':')
+        return int(port) if port.isnumeric() else port
 
 
 class Difference(object):
@@ -777,7 +792,8 @@ class ArgumentSpec(object):
             chase_referrals=dict(type='bool'),
             update_password=dict(
                 default='always',
-                choices=['always', 'on_create']
+                choices=['always', 'on_create'],
+                no_log=False
             ),
             state=dict(
                 default='present',
