@@ -30,7 +30,17 @@ options:
     description:
       - Specifies the list of ciphers the system supports. When creating a new
         profile, the default cipher list is provided by the parent profile.
+      - When the C(cipher_group) parameter is in use, the C(ciphers) parameter needs to be set to either C(none) or C('').
     type: str
+  cipher_group:
+    description:
+      - Specifies the cipher group to assign to this profile.
+      - When the C(ciphers) parameter is in use, the C(cipher_group) must be set to either C(none) or C('').
+      - When creating a new profile with C(cipher_group), if the parent profile has C(ciphers) set by default,
+        the C(cipher) parameter must be set to C(none) or C('') during creation.
+      - The parameter only works on TMOS version 13.x and later.
+    type: str
+    version_added: "1.12.0"
   renegotiation:
     description:
       - Enables or disables SSL renegotiation.
@@ -40,7 +50,7 @@ options:
     description:
       - Specifies the method of secure renegotiations for SSL connections. When
         creating a new profile, the setting is provided by the parent profile.
-      - When C(request) is set, the system requests secure renegotation of SSL
+      - When C(request) is set, the system requests secure renegotiation of SSL
         connections.
       - C(require) is a default setting and when set, the system permits initial SSL
         handshakes from clients but terminates renegotiations from unpatched clients.
@@ -100,8 +110,8 @@ options:
     type: str
   update_password:
     description:
-      - C(always) will allow users to update passwords if they choose to do so.
-        C(on_create) will only set the password for newly created profiles.
+      - C(always) allows users to update passwords if they choose to do so.
+        C(on_create) only sets the password for newly created profiles.
     type: str
     choices:
       - always
@@ -109,7 +119,7 @@ options:
     default: always
   ocsp_profile:
     description:
-      - Specifies the name of the OCSP profile for purpose of validating status
+      - Specifies the name of the OCSP profile for purpose of validating the status
         of server certificate.
     type: str
   partition:
@@ -140,6 +150,18 @@ EXAMPLES = r'''
       server: lb.mydomain.com
       user: admin
   delegate_to: localhost
+
+- name: Create server SSL profile with specific cipher group
+  bigip_profile_server_ssl:
+    state: present
+    name: foo_group
+    ciphers: "none"
+    cipher_group: "/Common/f5-secure"
+    provider:
+      server: lb.mydomain.com
+      user: admin
+      password: secret
+  delegate_to: localhost
 '''
 
 RETURN = r'''
@@ -148,6 +170,11 @@ ciphers:
   returned: changed
   type: str
   sample: "!SSLv3:!SSLv2:ECDHE+AES-GCM+SHA256:ECDHE-RSA-AES128-CBC-SHA"
+cipher_group:
+  description: The cipher group applied to the profile.
+  returned: changed
+  type: str
+  sample: "/Common/f5-secure"
 secure_renegotiation:
   description: The method of secure SSL renegotiation.
   returned: changed
@@ -176,6 +203,7 @@ from ..module_utils.teem import send_teem
 class Parameters(AnsibleF5Parameters):
     api_map = {
         'cert': 'certificate',
+        'cipherGroup': 'cipher_group',
         'ocsp': 'ocsp_profile',
         'defaultsFrom': 'parent',
         'secureRenegotiation': 'secure_renegotiation',
@@ -189,6 +217,7 @@ class Parameters(AnsibleF5Parameters):
         'cert',
         'chain',
         'ciphers',
+        'cipherGroup',
         'defaultsFrom',
         'key',
         'ocsp',
@@ -204,6 +233,7 @@ class Parameters(AnsibleF5Parameters):
         'certificate',
         'chain',
         'ciphers',
+        'cipher_group',
         'key',
         'ocsp_profile',
         'secure_renegotiation',
@@ -219,6 +249,7 @@ class Parameters(AnsibleF5Parameters):
         'certificate',
         'chain',
         'ciphers',
+        'cipher_group',
         'key',
         'ocsp_profile',
         'secure_renegotiation',
@@ -322,6 +353,27 @@ class ModuleParameters(Parameters):
                     "Cannot set 'sni_require' to {0} if 'sni_default' is set as {1}".format(require, default))
         return require
 
+    @property
+    def ciphers(self):
+        if self._values['ciphers'] is None:
+            return None
+        if self._values['ciphers'] in ['', 'none']:
+            return 'none'
+        if self.cipher_group and self.cipher_group != 'none':
+            raise F5ModuleError("The cipher parameter must be set to 'none' if cipher_group is defined.")
+        return self._values['ciphers']
+
+    @property
+    def cipher_group(self):
+        if self._values['cipher_group'] is None:
+            return None
+        if self._values['cipher_group'] in ['', 'none']:
+            return 'none'
+        if self.ciphers and self.ciphers != 'none':
+            raise F5ModuleError("The cipher_group parameter must be set to 'none' if cipher is defined.")
+        result = fq_name(self.partition, self._values['cipher_group'])
+        return result
+
 
 class Changes(Parameters):
     def to_return(self):
@@ -379,6 +431,15 @@ class Difference(object):
         except AttributeError:
             return self.__default(param)
 
+    def __default(self, param):
+        attr1 = getattr(self.want, param)
+        try:
+            attr2 = getattr(self.have, param)
+            if attr1 != attr2:
+                return attr1
+        except AttributeError:
+            return attr1
+
     @property
     def sni_require(self):
         if self.want.sni_require is None:
@@ -402,14 +463,14 @@ class Difference(object):
         if self.want.server_name != self.have.server_name:
             return self.want.server_name
 
-    def __default(self, param):
-        attr1 = getattr(self.want, param)
-        try:
-            attr2 = getattr(self.have, param)
-            if attr1 != attr2:
-                return attr1
-        except AttributeError:
-            return attr1
+    @property
+    def cipher_group(self):
+        if self.want.cipher_group is None:
+            return None
+        if self.want.cipher_group == 'none' and self.have.cipher_group == 'none':
+            return None
+        if self.want.cipher_group != self.have.cipher_group:
+            return self.want.cipher_group
 
 
 class ModuleManager(object):
@@ -629,6 +690,7 @@ class ArgumentSpec(object):
             passphrase=dict(no_log=True),
             parent=dict(default='/Common/serverssl'),
             ciphers=dict(),
+            cipher_group=dict(),
             secure_renegotiation=dict(
                 choices=['require', 'require-strict', 'request']
             ),
@@ -641,7 +703,8 @@ class ArgumentSpec(object):
             ),
             update_password=dict(
                 default='always',
-                choices=['always', 'on_create']
+                choices=['always', 'on_create'],
+                no_log=False
             ),
             sni_default=dict(type='bool'),
             sni_require=dict(type='bool'),
