@@ -232,7 +232,7 @@ options:
 '''
 
 EXAMPLES = '''
- - hosts: fortimanager-inventory
+ - hosts: fortimanager00
    collections:
      - fortinet.fortimanager
    connection: httpapi
@@ -243,55 +243,37 @@ EXAMPLES = '''
    tasks:
     - name: Application list entries.
       fmgr_application_list_entries:
-         bypass_validation: False
-         workspace_locking_adom: <value in [global, custom adom including root]>
-         workspace_locking_timeout: 300
-         rc_succeeded: [0, -2, -3, ...]
-         rc_failed: [-2, -3, ...]
-         adom: <your own value>
-         list: <your own value>
-         state: <value in [present, absent]>
+         adom: ansible
+         list: 'ansible-test' # name
+         state: present
          application_list_entries:
-            action: <value in [pass, block, reset]>
-            application: <value of integer>
-            behavior: <value of string>
-            category: <value of string>
-            id: <value of integer>
-            log: <value in [disable, enable]>
-            log-packet: <value in [disable, enable]>
-            parameters:
-              -
-                  id: <value of integer>
-                  value: <value of string>
-                  members:
-                    -
-                        id: <value of integer>
-                        name: <value of string>
-                        value: <value of string>
-            per-ip-shaper: <value of string>
-            popularity:
-              - 1
-              - 2
-              - 3
-              - 4
-              - 5
-            protocols: <value of string>
-            quarantine: <value in [none, attacker]>
-            quarantine-expiry: <value of string>
-            quarantine-log: <value in [disable, enable]>
-            rate-count: <value of integer>
-            rate-duration: <value of integer>
-            rate-mode: <value in [periodical, continuous]>
-            rate-track: <value in [none, src-ip, dest-ip, ...]>
-            risk: <value of integer>
-            session-ttl: <value of integer>
-            shaper: <value of string>
-            shaper-reverse: <value of string>
-            sub-category: <value of integer>
-            technology: <value of string>
-            vendor: <value of string>
-            exclusion: <value of integer>
+            action: pass
+            behavior: 'all'
+            category: '2'
+            id: 1
+            log: enable
+            log-packet: enable
+            protocols: 'all'
 
+ - name: gathering fortimanager facts
+   hosts: fortimanager00
+   gather_facts: no
+   connection: httpapi
+   collections:
+     - fortinet.fortimanager
+   vars:
+     ansible_httpapi_use_ssl: True
+     ansible_httpapi_validate_certs: False
+     ansible_httpapi_port: 443
+   tasks:
+    - name: retrieve all the entries in application list
+      fmgr_fact:
+        facts:
+            selector: 'application_list_entries'
+            params:
+                adom: 'ansible'
+                list: 'ansible-test' # name
+                entries: ''
 '''
 
 RETURN = '''
@@ -338,6 +320,11 @@ def main():
             'required': False,
             'default': False
         },
+        'forticloud_access_token': {
+            'type': 'str',
+            'required': False,
+            'no_log': True
+        },
         'proposed_method': {
             'type': 'str',
             'required': False,
@@ -882,6 +869,8 @@ def main():
     if module._socket_path:
         connection = Connection(module._socket_path)
         connection.set_option('enable_log', module.params['enable_log'] if 'enable_log' in module.params else False)
+        connection.set_option('forticloud_access_token',
+                              module.params['forticloud_access_token'] if 'forticloud_access_token' in module.params else None)
         fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
         fmgr.validate_parameters(params_validation_blob)
         fmgr.process_curd(argument_specs=module_arg_spec)
