@@ -236,7 +236,7 @@ options:
 '''
 
 EXAMPLES = '''
- - hosts: fortimanager-inventory
+ - hosts: fortimanager00
    collections:
      - fortinet.fortimanager
    connection: httpapi
@@ -248,16 +248,12 @@ EXAMPLES = '''
     - name: SNMP user configuration.
       fmgr_devprof_system_snmp_user:
          bypass_validation: False
-         workspace_locking_adom: <value in [global, custom adom including root]>
-         workspace_locking_timeout: 300
-         rc_succeeded: [0, -2, -3, ...]
-         rc_failed: [-2, -3, ...]
-         adom: <your own value>
-         devprof: <your own value>
-         state: <value in [present, absent]>
+         adom: ansible
+         devprof: 'ansible-test' # system template name, could find it in FortiManager UI: Device Manager --> Provisioning Templates --> System Templates
+         state: present
          devprof_system_snmp_user:
-            auth-proto: <value in [md5, sha, sha224, ...]>
-            auth-pwd: <value of string>
+            auth-proto: md5
+            auth-pwd: 'fortinet'
             events:
               - cpu-high
               - mem-low
@@ -303,28 +299,28 @@ EXAMPLES = '''
               - per-cpu-high
               - power-blade-down
               - confsync_failure
-              - dhcp
-              - pool-usage
-              - power-redundancy-degrade
-              - power-redundancy-failure
-              - ospf-nbr-state-change
-              - ospf-virtnbr-state-change
-            ha-direct: <value in [disable, enable]>
-            name: <value of string>
-            notify-hosts: <value of string>
-            notify-hosts6: <value of string>
-            priv-proto: <value in [aes, des, aes256, ...]>
-            priv-pwd: <value of string>
-            queries: <value in [disable, enable]>
-            query-port: <value of integer>
-            security-level: <value in [no-auth-no-priv, auth-no-priv, auth-priv]>
-            source-ip: <value of string>
-            source-ipv6: <value of string>
-            status: <value in [disable, enable]>
-            trap-lport: <value of integer>
-            trap-rport: <value of integer>
-            trap-status: <value in [disable, enable]>
+            ha-direct: disable
+            name: 'ansible-test'
 
+ - name: gathering fortimanager facts
+   hosts: fortimanager00
+   gather_facts: no
+   connection: httpapi
+   collections:
+     - fortinet.fortimanager
+   vars:
+     ansible_httpapi_use_ssl: True
+     ansible_httpapi_validate_certs: False
+     ansible_httpapi_port: 443
+   tasks:
+    - name: retrieve all the scripts
+      fmgr_fact:
+        facts:
+            selector: 'devprof_system_snmp_user'
+            params:
+                adom: 'ansible'
+                devprof: 'ansible-test' # system template name, could find it in FortiManager UI: Device Manager --> Provisioning Templates --> System Templates
+                user: ''
 '''
 
 RETURN = '''
@@ -369,6 +365,11 @@ def main():
             'required': False,
             'default': False
         },
+        'forticloud_access_token': {
+            'type': 'str',
+            'required': False,
+            'no_log': True
+        },
         'proposed_method': {
             'type': 'str',
             'required': False,
@@ -782,6 +783,8 @@ def main():
     if module._socket_path:
         connection = Connection(module._socket_path)
         connection.set_option('enable_log', module.params['enable_log'] if 'enable_log' in module.params else False)
+        connection.set_option('forticloud_access_token',
+                              module.params['forticloud_access_token'] if 'forticloud_access_token' in module.params else None)
         fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
         fmgr.validate_parameters(params_validation_blob)
         fmgr.process_curd(argument_specs=module_arg_spec)
