@@ -154,6 +154,8 @@ options:
                             - '4.0'
                             - '5.0'
                             - '6.0'
+                            - '7.0'
+                            - '8.0'
                     patch:
                         type: int
                         description: '<i>add model device only</i>.'
@@ -185,6 +187,32 @@ options:
 '''
 
 EXAMPLES = '''
+ - hosts: fortimanager00
+   collections:
+     - fortinet.fortimanager
+   connection: httpapi
+   vars:
+      ansible_httpapi_use_ssl: True
+      ansible_httpapi_validate_certs: False
+      ansible_httpapi_port: 443
+   tasks:
+    - name: Add a device to the Device Manager database.
+      fmgr_dvm_cmd_add_device:
+         bypass_validation: False
+         dvm_cmd_add_device:
+            adom: ansible
+            device:
+               adm_pass: fortinet # device password
+               adm_usr: admin # device user name
+               ip: 0.0.0.0 # device ip
+               mgmt_mode: fmg #<value in [unreg, fmg, faz, ...]>
+               name: FGT_AWS 
+            flags:
+              - none
+              - create_task
+              - nonblocking
+              - log_dev
+
  - name: Add a FOS device to FMG
    hosts: fortimanager01
    gather_facts: no
@@ -237,32 +265,6 @@ EXAMPLES = '''
        delay: 5
        failed_when: taskinfo.meta.response_data.state == 'error' and 'devsnexist' not in taskinfo.meta.response_data.line[0].detail
 
- - hosts: fortimanager00
-   collections:
-     - fortinet.fortimanager
-   connection: httpapi
-   vars:
-      ansible_httpapi_use_ssl: True
-      ansible_httpapi_validate_certs: False
-      ansible_httpapi_port: 443
-   tasks:
-    - name: Add a device to the Device Manager database.
-      fmgr_dvm_cmd_add_device:
-         bypass_validation: False
-         dvm_cmd_add_device:
-            adom: ansible
-            device:
-               adm_pass: fortinet # device password
-               adm_usr: admin # device user name
-               ip: 0.0.0.0 # device ip
-               mgmt_mode: fmg #<value in [unreg, fmg, faz, ...]>
-               name: FGT_AWS 
-            flags:
-              - none
-              - create_task
-              - nonblocking
-              - log_dev
-
 '''
 
 RETURN = '''
@@ -543,7 +545,9 @@ def main():
                                 '3.0',
                                 '4.0',
                                 '5.0',
-                                '6.0'
+                                '6.0',
+                                '7.0',
+                                '8.0'
                             ],
                             'type': 'str'
                         },
