@@ -94,7 +94,7 @@ options:
 '''
 
 EXAMPLES = '''
- - hosts: fortimanager-inventory
+ - hosts: fortimanager00
    collections:
      - fortinet.fortimanager
    connection: httpapi
@@ -106,18 +106,58 @@ EXAMPLES = '''
     - name: Delete a device.
       fmgr_dvm_cmd_del_device:
          bypass_validation: False
-         workspace_locking_adom: <value in [global, custom adom including root]>
-         workspace_locking_timeout: 300
-         rc_succeeded: [0, -2, -3, ...]
-         rc_failed: [-2, -3, ...]
          dvm_cmd_del_device:
-            adom: <value of string>
-            device: <value of string>
-            flags:
-              - none
-              - create_task
-              - nonblocking
-              - log_dev
+            adom: ansible
+            device: ansible-test # device name 
+
+ - name: Delete first FOS devices from FMG In a specific adom
+   hosts: fortimanager00
+   gather_facts: no
+   connection: httpapi
+   collections:
+     - fortinet.fortimanager
+   vars:
+     ansible_httpapi_use_ssl: True
+     ansible_httpapi_validate_certs: False
+     ansible_httpapi_port: 443
+     device_adom: 'root'
+   tasks:
+     - name: fetch all devices
+       fmgr_fact:
+         facts:
+             selector: 'dvmdb_device'
+             params:
+                 adom: '{{ device_adom }}'
+                 device: ''
+       register: alldevices
+     - when: alldevices.meta.response_data != []
+       debug:
+         msg:
+          - 'We are going to delete device: {{ alldevices.meta.response_data[0].name }}'
+          - 'IP of the device is: {{ alldevices.meta.response_data[0].ip }}'
+     - when: alldevices.meta.response_data != [] and False
+       name: Create The Task To Delete The Device
+       fmgr_dvm_cmd_del_device:
+         dvm_cmd_del_device:
+             device: '{{ alldevices.meta.response_data[0].name }}'
+             adom: '{{ device_adom }}'
+             flags:
+              - 'create_task'
+              - 'nonblocking'
+       register: uninstalling_task
+     - when: alldevices.meta.response_data != [] and False
+       name: poll the task
+       fmgr_fact:
+         facts:
+             selector: 'task_task'
+             params:
+                 task: '{{uninstalling_task.meta.response_data.taskid}}'
+       register: taskinfo
+       until: taskinfo.meta.response_data.percent == 100
+       retries: 30
+       delay: 5
+       failed_when: taskinfo.meta.response_data.state == 'error'
+ 
 
 '''
 
@@ -162,6 +202,11 @@ def main():
             'required': False,
             'default': False
         },
+        'forticloud_access_token': {
+            'type': 'str',
+            'required': False,
+            'no_log': True
+        },
         'bypass_validation': {
             'type': 'bool',
             'required': False,
@@ -260,6 +305,8 @@ def main():
     if module._socket_path:
         connection = Connection(module._socket_path)
         connection.set_option('enable_log', module.params['enable_log'] if 'enable_log' in module.params else False)
+        connection.set_option('forticloud_access_token',
+                              module.params['forticloud_access_token'] if 'forticloud_access_token' in module.params else None)
         fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, None, url_params, module, connection, top_level_schema_name='data')
         fmgr.validate_parameters(params_validation_blob)
         fmgr.process_exec(argument_specs=module_arg_spec)
