@@ -97,17 +97,17 @@ options:
         suboptions:
             desc:
                 type: str
-                description: no description
+                description: 'Desc.'
             meta fields:
                 description: no description
                 type: dict
             name:
                 type: str
-                description: no description
+                description: 'Name.'
             os_type:
                 type: str
                 default: 'unknown'
-                description: no description
+                description: 'Os_Type.'
                 choices:
                     - 'unknown'
                     - 'fos'
@@ -134,7 +134,7 @@ options:
             type:
                 type: str
                 default: 'normal'
-                description: no description
+                description: 'Type.'
                 choices:
                     - 'normal'
                     - 'default'
@@ -143,7 +143,25 @@ options:
 '''
 
 EXAMPLES = '''
- - hosts: fortimanager-inventory
+ - name: gathering fortimanager facts
+   hosts: fortimanager00
+   gather_facts: no
+   connection: httpapi
+   collections:
+     - fortinet.fortimanager
+   vars:
+     ansible_httpapi_use_ssl: True
+     ansible_httpapi_validate_certs: False
+     ansible_httpapi_port: 443
+   tasks:
+    - name: retrieve all the groups in the device
+      fmgr_fact:
+        facts:
+            selector: 'dvmdb_group'
+            params:
+                adom: 'ansible'
+                group: ''
+ - hosts: fortimanager00
    collections:
      - fortinet.fortimanager
    connection: httpapi
@@ -155,19 +173,13 @@ EXAMPLES = '''
     - name: Device group table.
       fmgr_dvmdb_group:
          bypass_validation: False
-         workspace_locking_adom: <value in [global, custom adom including root]>
-         workspace_locking_timeout: 300
-         rc_succeeded: [0, -2, -3, ...]
-         rc_failed: [-2, -3, ...]
-         adom: <your own value>
-         state: <value in [present, absent]>
+         adom: ansible
+         state: present
          dvmdb_group:
-            desc: <value of string>
-            meta fields: <value of dict>
-            name: <value of string>
-            os_type: <value in [unknown, fos, fsw, ...]>
-            type: <value in [normal, default, auto]>
-
+            desc: 'ansible-test'
+            name: 'ansible-test'
+            os_type: fos
+            type: normal
 '''
 
 RETURN = '''
@@ -214,6 +226,11 @@ def main():
             'required': False,
             'default': False
         },
+        'forticloud_access_token': {
+            'type': 'str',
+            'required': False,
+            'no_log': True
+        },
         'proposed_method': {
             'type': 'str',
             'required': False,
@@ -384,6 +401,8 @@ def main():
     if module._socket_path:
         connection = Connection(module._socket_path)
         connection.set_option('enable_log', module.params['enable_log'] if 'enable_log' in module.params else False)
+        connection.set_option('forticloud_access_token',
+                              module.params['forticloud_access_token'] if 'forticloud_access_token' in module.params else None)
         fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
         fmgr.validate_parameters(params_validation_blob)
         fmgr.process_curd(argument_specs=module_arg_spec)
