@@ -97,27 +97,27 @@ options:
         suboptions:
             description:
                 type: str
-                description: no description
+                description: 'Description.'
             dynamic_mapping:
-                description: no description
+                description: 'Dynamic_Mapping.'
                 type: list
                 suboptions:
                     _scope:
-                        description: no description
+                        description: '_Scope.'
                         type: list
                         suboptions:
                             name:
                                 type: str
-                                description: no description
+                                description: 'Name.'
                             vdom:
                                 type: str
-                                description: no description
+                                description: 'Vdom.'
                     local-cert:
                         type: str
-                        description: no description
+                        description: 'Local-Cert.'
             name:
                 type: str
-                description: no description
+                description: 'Name.'
 
 '''
 
@@ -197,6 +197,11 @@ def main():
             'required': False,
             'default': False
         },
+        'forticloud_access_token': {
+            'type': 'str',
+            'required': False,
+            'no_log': True
+        },
         'proposed_method': {
             'type': 'str',
             'required': False,
@@ -370,6 +375,8 @@ def main():
     if module._socket_path:
         connection = Connection(module._socket_path)
         connection.set_option('enable_log', module.params['enable_log'] if 'enable_log' in module.params else False)
+        connection.set_option('forticloud_access_token',
+                              module.params['forticloud_access_token'] if 'forticloud_access_token' in module.params else None)
         fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
         fmgr.validate_parameters(params_validation_blob)
         fmgr.process_curd(argument_specs=module_arg_spec)
