@@ -102,7 +102,7 @@ options:
                 type: str
                 description: 'IPv6 address template name.'
             subnet-segment:
-                description: no description
+                description: 'Subnet-Segment.'
                 type: list
                 suboptions:
                     bits:
@@ -121,7 +121,7 @@ options:
                         type: str
                         description: 'Subnet segment name.'
                     values:
-                        description: no description
+                        description: 'Values.'
                         type: list
                         suboptions:
                             name:
@@ -135,7 +135,7 @@ options:
                 description: 'Number of IPv6 subnet segments.'
             _image-base64:
                 type: str
-                description: no description
+                description: '_Image-Base64.'
             fabric-object:
                 type: str
                 description: 'Security Fabric global object setting.'
@@ -146,7 +146,7 @@ options:
 '''
 
 EXAMPLES = '''
- - hosts: fortimanager-inventory
+ - hosts: fortimanager00
    collections:
      - fortinet.fortimanager
    connection: httpapi
@@ -158,29 +158,40 @@ EXAMPLES = '''
     - name: Configure IPv6 address templates.
       fmgr_firewall_address6template:
          bypass_validation: False
-         workspace_locking_adom: <value in [global, custom adom including root]>
-         workspace_locking_timeout: 300
-         rc_succeeded: [0, -2, -3, ...]
-         rc_failed: [-2, -3, ...]
-         adom: <your own value>
-         state: <value in [present, absent]>
+         adom: ansible
+         state: present
          firewall_address6template:
-            ip6: <value of string>
-            name: <value of string>
+            ip6: '::33/128'
+            name: 'ansible-name'
             subnet-segment:
               -
-                  bits: <value of integer>
-                  exclusive: <value in [disable, enable]>
-                  id: <value of integer>
-                  name: <value of string>
+                  bits: 1
+                  exclusive: enable
+                  id: 1
+                  name: 'ansible-name-sub'
                   values:
                     -
-                        name: <value of string>
-                        value: <value of string>
-            subnet-segment-count: <value of integer>
-            _image-base64: <value of string>
-            fabric-object: <value in [disable, enable]>
-
+                        name: 'ansible-name-val'
+                        value: 'ansible'
+            subnet-segment-count: 2
+ - name: gathering fortimanager facts
+   hosts: fortimanager00
+   gather_facts: no
+   connection: httpapi
+   collections:
+     - fortinet.fortimanager
+   vars:
+     ansible_httpapi_use_ssl: True
+     ansible_httpapi_validate_certs: False
+     ansible_httpapi_port: 443
+   tasks:
+    - name: retrieve all the IPv6 address templates
+      fmgr_fact:
+        facts:
+            selector: 'firewall_address6template'
+            params:
+                adom: 'ansible'
+                address6-template: ''
 '''
 
 RETURN = '''
@@ -227,6 +238,11 @@ def main():
             'required': False,
             'default': False
         },
+        'forticloud_access_token': {
+            'type': 'str',
+            'required': False,
+            'no_log': True
+        },
         'proposed_method': {
             'type': 'str',
             'required': False,
@@ -483,6 +499,8 @@ def main():
     if module._socket_path:
         connection = Connection(module._socket_path)
         connection.set_option('enable_log', module.params['enable_log'] if 'enable_log' in module.params else False)
+        connection.set_option('forticloud_access_token',
+                              module.params['forticloud_access_token'] if 'forticloud_access_token' in module.params else None)
         fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
         fmgr.validate_parameters(params_validation_blob)
         fmgr.process_curd(argument_specs=module_arg_spec)
