@@ -99,11 +99,11 @@ options:
                 type: str
                 description: 'Optional comments.'
             entries:
-                description: no description
+                description: 'Entries.'
                 type: list
                 suboptions:
                     action:
-                        description: no description
+                        description: 'Action to take on this end point'
                         type: list
                         choices:
                          - block
@@ -113,7 +113,7 @@ options:
                         type: str
                         description: 'End point to act on.'
                     log-action:
-                        description: no description
+                        description: 'Action to take on this end point'
                         type: list
                         choices:
                          - archive
@@ -141,7 +141,7 @@ options:
 '''
 
 EXAMPLES = '''
- - hosts: fortimanager-inventory
+ - hosts: fortimanager00
    collections:
      - fortinet.fortimanager
    connection: httpapi
@@ -153,29 +153,30 @@ EXAMPLES = '''
     - name: Carrier end point black/white list tables.
       fmgr_firewall_carrierendpointbwl:
          bypass_validation: False
-         workspace_locking_adom: <value in [global, custom adom including root]>
-         workspace_locking_timeout: 300
-         rc_succeeded: [0, -2, -3, ...]
-         rc_failed: [-2, -3, ...]
-         adom: <your own value>
-         state: <value in [present, absent]>
+         adom: FortiCarrier # This is FOC-only object, need a FortiCarrier adom
+         state: present
          firewall_carrierendpointbwl:
-            comment: <value of string>
-            entries:
-              -
-                  action:
-                    - block
-                    - exempt
-                    - exempt-mass-mms
-                  carrier-endpoint: <value of string>
-                  log-action:
-                    - archive
-                    - intercept
-                  pattern-type: <value in [wildcard, regexp, simple]>
-                  status: <value in [disable, enable]>
-            id: <value of integer>
-            name: <value of string>
-
+            comment: 'ansible-test'
+            id: 1
+            name: 'ansible-test'
+ - name: gathering fortimanager facts
+   hosts: fortimanager00
+   gather_facts: no
+   connection: httpapi
+   collections:
+     - fortinet.fortimanager
+   vars:
+     ansible_httpapi_use_ssl: True
+     ansible_httpapi_validate_certs: False
+     ansible_httpapi_port: 443
+   tasks:
+    - name: retrieve all the carrier endpoint black/white list tables
+      fmgr_fact:
+        facts:
+            selector: 'firewall_carrierendpointbwl'
+            params:
+                adom: 'FortiCarrier' # This is FOC-only object, need a FortiCarrier adom
+                carrier-endpoint-bwl: ''
 '''
 
 RETURN = '''
@@ -222,6 +223,11 @@ def main():
             'required': False,
             'default': False
         },
+        'forticloud_access_token': {
+            'type': 'str',
+            'required': False,
+            'no_log': True
+        },
         'proposed_method': {
             'type': 'str',
             'required': False,
@@ -435,6 +441,8 @@ def main():
     if module._socket_path:
         connection = Connection(module._socket_path)
         connection.set_option('enable_log', module.params['enable_log'] if 'enable_log' in module.params else False)
+        connection.set_option('forticloud_access_token',
+                              module.params['forticloud_access_token'] if 'forticloud_access_token' in module.params else None)
         fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
         fmgr.validate_parameters(params_validation_blob)
         fmgr.process_curd(argument_specs=module_arg_spec)
