@@ -139,7 +139,25 @@ options:
 '''
 
 EXAMPLES = '''
- - hosts: fortimanager-inventory
+ - name: gathering fortimanager facts
+   hosts: fortimanager00
+   gather_facts: no
+   connection: httpapi
+   collections:
+     - fortinet.fortimanager
+   vars:
+     ansible_httpapi_use_ssl: True
+     ansible_httpapi_validate_certs: False
+     ansible_httpapi_port: 443
+   tasks:
+    - name: retrieve all the per-IP traffic shapers
+      fmgr_fact:
+        facts:
+            selector: 'firewall_shaper_peripshaper'
+            params:
+                adom: 'ansible'
+                per-ip-shaper: ''
+ - hosts: fortimanager00
    collections:
      - fortinet.fortimanager
    connection: httpapi
@@ -151,24 +169,13 @@ EXAMPLES = '''
     - name: Configure per-IP traffic shaper.
       fmgr_firewall_shaper_peripshaper:
          bypass_validation: False
-         workspace_locking_adom: <value in [global, custom adom including root]>
-         workspace_locking_timeout: 300
-         rc_succeeded: [0, -2, -3, ...]
-         rc_failed: [-2, -3, ...]
-         adom: <your own value>
-         state: <value in [present, absent]>
+         adom: ansible
+         state: present
          firewall_shaper_peripshaper:
-            bandwidth-unit: <value in [kbps, mbps, gbps]>
-            diffserv-forward: <value in [disable, enable]>
-            diffserv-reverse: <value in [disable, enable]>
-            diffservcode-forward: <value of string>
-            diffservcode-rev: <value of string>
-            max-bandwidth: <value of integer>
-            max-concurrent-session: <value of integer>
-            name: <value of string>
-            max-concurrent-tcp-session: <value of integer>
-            max-concurrent-udp-session: <value of integer>
-
+            bandwidth-unit: mbps #<value in [kbps, mbps, gbps]>
+            diffserv-forward: enable
+            diffserv-reverse: disable
+            name: 'ansible-test'
 '''
 
 RETURN = '''
@@ -215,6 +222,11 @@ def main():
             'required': False,
             'default': False
         },
+        'forticloud_access_token': {
+            'type': 'str',
+            'required': False,
+            'no_log': True
+        },
         'proposed_method': {
             'type': 'str',
             'required': False,
@@ -425,6 +437,8 @@ def main():
     if module._socket_path:
         connection = Connection(module._socket_path)
         connection.set_option('enable_log', module.params['enable_log'] if 'enable_log' in module.params else False)
+        connection.set_option('forticloud_access_token',
+                              module.params['forticloud_access_token'] if 'forticloud_access_token' in module.params else None)
         fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
         fmgr.validate_parameters(params_validation_blob)
         fmgr.process_curd(argument_specs=module_arg_spec)
