@@ -158,7 +158,7 @@ options:
 '''
 
 EXAMPLES = '''
- - hosts: fortimanager-inventory
+ - hosts: fortimanager00
    collections:
      - fortinet.fortimanager
    connection: httpapi
@@ -170,28 +170,32 @@ EXAMPLES = '''
     - name: Configure shared traffic shaper.
       fmgr_firewall_shaper_trafficshaper:
          bypass_validation: False
-         workspace_locking_adom: <value in [global, custom adom including root]>
-         workspace_locking_timeout: 300
-         rc_succeeded: [0, -2, -3, ...]
-         rc_failed: [-2, -3, ...]
-         adom: <your own value>
-         state: <value in [present, absent]>
+         adom: ansible
+         state: present
          firewall_shaper_trafficshaper:
-            bandwidth-unit: <value in [kbps, mbps, gbps]>
-            diffserv: <value in [disable, enable]>
-            diffservcode: <value of string>
-            guaranteed-bandwidth: <value of integer>
-            maximum-bandwidth: <value of integer>
-            name: <value of string>
-            per-policy: <value in [disable, enable]>
-            priority: <value in [high, medium, low]>
-            dscp-marking-method: <value in [multi-stage, static]>
-            exceed-bandwidth: <value of integer>
-            exceed-class-id: <value of integer>
-            exceed-dscp: <value of string>
-            maximum-dscp: <value of string>
-            overhead: <value of integer>
-
+            bandwidth-unit: mbps #<value in [kbps, mbps, gbps]>
+            diffserv: disable
+            name: 'ansible'
+            per-policy: disable
+            priority: medium #<value in [high, medium, low]>
+ - name: gathering fortimanager facts
+   hosts: fortimanager00
+   gather_facts: no
+   connection: httpapi
+   collections:
+     - fortinet.fortimanager
+   vars:
+     ansible_httpapi_use_ssl: True
+     ansible_httpapi_validate_certs: False
+     ansible_httpapi_port: 443
+   tasks:
+    - name: retrieve all the shared traffic shapers
+      fmgr_fact:
+        facts:
+            selector: 'firewall_shaper_trafficshaper'
+            params:
+                adom: 'ansible'
+                traffic-shaper: ''
 '''
 
 RETURN = '''
@@ -238,6 +242,11 @@ def main():
             'required': False,
             'default': False
         },
+        'forticloud_access_token': {
+            'type': 'str',
+            'required': False,
+            'no_log': True
+        },
         'proposed_method': {
             'type': 'str',
             'required': False,
@@ -521,6 +530,8 @@ def main():
     if module._socket_path:
         connection = Connection(module._socket_path)
         connection.set_option('enable_log', module.params['enable_log'] if 'enable_log' in module.params else False)
+        connection.set_option('forticloud_access_token',
+                              module.params['forticloud_access_token'] if 'forticloud_access_token' in module.params else None)
         fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
         fmgr.validate_parameters(params_validation_blob)
         fmgr.process_curd(argument_specs=module_arg_spec)
