@@ -105,79 +105,79 @@ options:
                 suboptions:
                     name:
                         type: str
-                        description: no description
+                        description: 'Name.'
                     vdom:
                         type: str
-                        description: no description
+                        description: 'Vdom.'
             arp-reply:
                 type: str
-                description: no description
+                description: 'Enable to respond to ARP requests for this virtual IP address. Enabled by default.'
                 choices:
                     - 'disable'
                     - 'enable'
             color:
                 type: int
-                description: no description
+                description: 'Color of icon on the GUI.'
             comment:
                 type: str
-                description: no description
+                description: 'Comment.'
             extip:
                 type: str
-                description: no description
+                description: 'IP address or address range on the external interface that you want to map to an address or address range on the destination n...'
             extport:
                 type: str
-                description: no description
+                description: 'Incoming port number range that you want to map to a port number range on the destination network.'
             http-cookie-age:
                 type: int
-                description: no description
+                description: 'Time in minutes that client web browsers should keep a cookie. Default is 60 seconds. 0 = no time limit.'
             http-cookie-domain:
                 type: str
-                description: no description
+                description: 'Domain that HTTP cookie persistence should apply to.'
             http-cookie-domain-from-host:
                 type: str
-                description: no description
+                description: 'Enable/disable use of HTTP cookie domain from host field in HTTP.'
                 choices:
                     - 'disable'
                     - 'enable'
             http-cookie-generation:
                 type: int
-                description: no description
+                description: 'Generation of HTTP cookie to be accepted. Changing invalidates all existing cookies.'
             http-cookie-path:
                 type: str
-                description: no description
+                description: 'Limit HTTP cookie persistence to the specified path.'
             http-cookie-share:
                 type: str
-                description: no description
+                description: 'Control sharing of cookies across virtual servers. same-ip means a cookie from one virtual server can be used by another. Disa...'
                 choices:
                     - 'disable'
                     - 'same-ip'
             http-ip-header:
                 type: str
-                description: no description
+                description: 'For HTTP multiplexing, enable to add the original client IP address in the XForwarded-For HTTP header.'
                 choices:
                     - 'disable'
                     - 'enable'
             http-ip-header-name:
                 type: str
-                description: no description
+                description: 'For HTTP multiplexing, enter a custom HTTPS header name. The original client IP address is added to this header. If empty, X-F...'
             http-multiplex:
                 type: str
-                description: no description
+                description: 'Enable/disable HTTP multiplexing.'
                 choices:
                     - 'disable'
                     - 'enable'
             https-cookie-secure:
                 type: str
-                description: no description
+                description: 'Enable/disable verification that inserted HTTPS cookies are secure.'
                 choices:
                     - 'disable'
                     - 'enable'
             id:
                 type: int
-                description: no description
+                description: 'Custom defined ID.'
             ldb-method:
                 type: str
-                description: no description
+                description: 'Method used to distribute sessions to real servers.'
                 choices:
                     - 'static'
                     - 'round-robin'
@@ -188,45 +188,45 @@ options:
                     - 'http-host'
             mappedip:
                 type: str
-                description: no description
+                description: 'Mapped IP address range in the format startIP-endIP.'
             mappedport:
                 type: str
-                description: no description
+                description: 'Port number range on the destination network to which the external port number range is mapped.'
             max-embryonic-connections:
                 type: int
-                description: no description
+                description: 'Maximum number of incomplete connections.'
             monitor:
                 type: str
-                description: no description
+                description: 'Name of the health check monitor to use when polling to determine a virtual servers connectivity status.'
             outlook-web-access:
                 type: str
-                description: no description
+                description: 'Enable to add the Front-End-Https header for Microsoft Outlook Web Access.'
                 choices:
                     - 'disable'
                     - 'enable'
             persistence:
                 type: str
-                description: no description
+                description: 'Configure how to make sure that clients connect to the same server every time they make a request that is part of the same ses...'
                 choices:
                     - 'none'
                     - 'http-cookie'
                     - 'ssl-session-id'
             portforward:
                 type: str
-                description: no description
+                description: 'Enable port forwarding.'
                 choices:
                     - 'disable'
                     - 'enable'
             protocol:
                 type: str
-                description: no description
+                description: 'Protocol to use when forwarding packets.'
                 choices:
                     - 'tcp'
                     - 'udp'
                     - 'sctp'
             server-type:
                 type: str
-                description: no description
+                description: 'Protocol to be load balanced by the virtual server (also called the server load balance virtual IP).'
                 choices:
                     - 'http'
                     - 'https'
@@ -242,7 +242,7 @@ options:
                 type: str
             ssl-algorithm:
                 type: str
-                description: no description
+                description: 'Permitted encryption algorithms for SSL sessions according to encryption strength.'
                 choices:
                     - 'high'
                     - 'low'
@@ -250,29 +250,29 @@ options:
                     - 'custom'
             ssl-certificate:
                 type: str
-                description: no description
+                description: 'The name of the SSL certificate to use for SSL acceleration.'
             ssl-client-fallback:
                 type: str
-                description: no description
+                description: 'Enable/disable support for preventing Downgrade Attacks on client connections (RFC 7507).'
                 choices:
                     - 'disable'
                     - 'enable'
             ssl-client-renegotiation:
                 type: str
-                description: no description
+                description: 'Allow, deny, or require secure renegotiation of client sessions to comply with RFC 5746.'
                 choices:
                     - 'deny'
                     - 'allow'
                     - 'secure'
             ssl-client-session-state-max:
                 type: int
-                description: no description
+                description: 'Maximum number of client to FortiGate SSL session states to keep.'
             ssl-client-session-state-timeout:
                 type: int
-                description: no description
+                description: 'Number of minutes to keep client to FortiGate SSL session state.'
             ssl-client-session-state-type:
                 type: str
-                description: no description
+                description: 'How to expire SSL sessions for the segment of the SSL connection between the client and the FortiGate.'
                 choices:
                     - 'disable'
                     - 'time'
@@ -280,7 +280,7 @@ options:
                     - 'both'
             ssl-dh-bits:
                 type: str
-                description: no description
+                description: 'Number of bits to use in the Diffie-Hellman exchange for RSA encryption of SSL sessions.'
                 choices:
                     - '768'
                     - '1024'
@@ -290,59 +290,59 @@ options:
                     - '4096'
             ssl-hpkp:
                 type: str
-                description: no description
+                description: 'Enable/disable including HPKP header in response.'
                 choices:
                     - 'disable'
                     - 'enable'
                     - 'report-only'
             ssl-hpkp-age:
                 type: int
-                description: no description
+                description: 'Number of minutes the web browser should keep HPKP.'
             ssl-hpkp-backup:
                 type: str
-                description: no description
+                description: 'Certificate to generate backup HPKP pin from.'
             ssl-hpkp-include-subdomains:
                 type: str
-                description: no description
+                description: 'Indicate that HPKP header applies to all subdomains.'
                 choices:
                     - 'disable'
                     - 'enable'
             ssl-hpkp-primary:
                 type: str
-                description: no description
+                description: 'Certificate to generate primary HPKP pin from.'
             ssl-hpkp-report-uri:
                 type: str
-                description: no description
+                description: 'URL to report HPKP violations to.'
             ssl-hsts:
                 type: str
-                description: no description
+                description: 'Enable/disable including HSTS header in response.'
                 choices:
                     - 'disable'
                     - 'enable'
             ssl-hsts-age:
                 type: int
-                description: no description
+                description: 'Number of seconds the client should honour the HSTS setting.'
             ssl-hsts-include-subdomains:
                 type: str
-                description: no description
+                description: 'Indicate that HSTS header applies to all subdomains.'
                 choices:
                     - 'disable'
                     - 'enable'
             ssl-http-location-conversion:
                 type: str
-                description: no description
+                description: 'Enable to replace HTTP with HTTPS in the replys Location HTTP header field.'
                 choices:
                     - 'disable'
                     - 'enable'
             ssl-http-match-host:
                 type: str
-                description: no description
+                description: 'Enable/disable HTTP host matching for location conversion.'
                 choices:
                     - 'disable'
                     - 'enable'
             ssl-max-version:
                 type: str
-                description: no description
+                description: 'Highest SSL/TLS version acceptable from a client.'
                 choices:
                     - 'ssl-3.0'
                     - 'tls-1.0'
@@ -351,7 +351,7 @@ options:
                     - 'tls-1.3'
             ssl-min-version:
                 type: str
-                description: no description
+                description: 'Lowest SSL/TLS version acceptable from a client.'
                 choices:
                     - 'ssl-3.0'
                     - 'tls-1.0'
@@ -360,26 +360,26 @@ options:
                     - 'tls-1.3'
             ssl-mode:
                 type: str
-                description: no description
+                description: 'Apply SSL offloading between the client and the FortiGate (half) or from the client to the FortiGate and from the FortiGate to...'
                 choices:
                     - 'half'
                     - 'full'
             ssl-pfs:
                 type: str
-                description: no description
+                description: 'Select the cipher suites that can be used for SSL perfect forward secrecy (PFS). Applies to both client and server sessions.'
                 choices:
                     - 'require'
                     - 'deny'
                     - 'allow'
             ssl-send-empty-frags:
                 type: str
-                description: no description
+                description: 'Enable/disable sending empty fragments to avoid CBC IV attacks (SSL 3.0 & TLS 1.0 only). May need to be disabled for compatibi...'
                 choices:
                     - 'disable'
                     - 'enable'
             ssl-server-algorithm:
                 type: str
-                description: no description
+                description: 'Permitted encryption algorithms for the server side of SSL full mode sessions according to encryption strength.'
                 choices:
                     - 'high'
                     - 'low'
@@ -388,7 +388,7 @@ options:
                     - 'client'
             ssl-server-max-version:
                 type: str
-                description: no description
+                description: 'Highest SSL/TLS version acceptable from a server. Use the client setting by default.'
                 choices:
                     - 'ssl-3.0'
                     - 'tls-1.0'
@@ -398,7 +398,7 @@ options:
                     - 'tls-1.3'
             ssl-server-min-version:
                 type: str
-                description: no description
+                description: 'Lowest SSL/TLS version acceptable from a server. Use the client setting by default.'
                 choices:
                     - 'ssl-3.0'
                     - 'tls-1.0'
@@ -408,13 +408,13 @@ options:
                     - 'tls-1.3'
             ssl-server-session-state-max:
                 type: int
-                description: no description
+                description: 'Maximum number of FortiGate to Server SSL session states to keep.'
             ssl-server-session-state-timeout:
                 type: int
-                description: no description
+                description: 'Number of minutes to keep FortiGate to Server SSL session state.'
             ssl-server-session-state-type:
                 type: str
-                description: no description
+                description: 'How to expire SSL sessions for the segment of the SSL connection between the server and the FortiGate.'
                 choices:
                     - 'disable'
                     - 'time'
@@ -422,37 +422,37 @@ options:
                     - 'both'
             type:
                 type: str
-                description: no description
+                description: 'Configure a static NAT or server load balance VIP.'
                 choices:
                     - 'static-nat'
                     - 'server-load-balance'
             uuid:
                 type: str
-                description: no description
+                description: 'Universally Unique Identifier (UUID; automatically assigned but can be manually reset).'
             weblogic-server:
                 type: str
-                description: no description
+                description: 'Enable to add an HTTP header to indicate SSL offloading for a WebLogic server.'
                 choices:
                     - 'disable'
                     - 'enable'
             websphere-server:
                 type: str
-                description: no description
+                description: 'Enable to add an HTTP header to indicate SSL offloading for a WebSphere server.'
                 choices:
                     - 'disable'
                     - 'enable'
             http-redirect:
                 type: str
-                description: no description
+                description: 'Enable/disable redirection of HTTP to HTTPS'
                 choices:
                     - 'disable'
                     - 'enable'
             ssl-client-rekey-count:
                 type: int
-                description: no description
+                description: 'Maximum length of data in MB before triggering a client rekey (0 = disable).'
             nat-source-vip:
                 type: str
-                description: no description
+                description: 'Nat-Source-Vip.'
                 choices:
                     - 'disable'
                     - 'enable'
@@ -460,7 +460,7 @@ options:
 '''
 
 EXAMPLES = '''
- - hosts: fortimanager-inventory
+ - hosts: fortimanager00
    collections:
      - fortinet.fortimanager
    connection: httpapi
@@ -469,86 +469,41 @@ EXAMPLES = '''
       ansible_httpapi_validate_certs: False
       ansible_httpapi_port: 443
    tasks:
-    - name: Configure virtual IP for IPv6.
+    - name: Configure dynamic mappings of virtual IP for IPv6
       fmgr_firewall_vip6_dynamicmapping:
          bypass_validation: False
-         workspace_locking_adom: <value in [global, custom adom including root]>
-         workspace_locking_timeout: 300
-         rc_succeeded: [0, -2, -3, ...]
-         rc_failed: [-2, -3, ...]
-         adom: <your own value>
-         vip6: <your own value>
-         state: <value in [present, absent]>
+         adom: ansible
+         vip6: 'ansible-test-vip6' # name
+         state: present
          firewall_vip6_dynamicmapping:
             _scope:
               -
-                  name: <value of string>
-                  vdom: <value of string>
-            arp-reply: <value in [disable, enable]>
-            color: <value of integer>
-            comment: <value of string>
-            extip: <value of string>
-            extport: <value of string>
-            http-cookie-age: <value of integer>
-            http-cookie-domain: <value of string>
-            http-cookie-domain-from-host: <value in [disable, enable]>
-            http-cookie-generation: <value of integer>
-            http-cookie-path: <value of string>
-            http-cookie-share: <value in [disable, same-ip]>
-            http-ip-header: <value in [disable, enable]>
-            http-ip-header-name: <value of string>
-            http-multiplex: <value in [disable, enable]>
-            https-cookie-secure: <value in [disable, enable]>
-            id: <value of integer>
-            ldb-method: <value in [static, round-robin, weighted, ...]>
-            mappedip: <value of string>
-            mappedport: <value of string>
-            max-embryonic-connections: <value of integer>
-            monitor: <value of string>
-            outlook-web-access: <value in [disable, enable]>
-            persistence: <value in [none, http-cookie, ssl-session-id]>
-            portforward: <value in [disable, enable]>
-            protocol: <value in [tcp, udp, sctp]>
-            server-type: <value in [http, https, ssl, ...]>
-            src-filter: <value of string>
-            ssl-algorithm: <value in [high, low, medium, ...]>
-            ssl-certificate: <value of string>
-            ssl-client-fallback: <value in [disable, enable]>
-            ssl-client-renegotiation: <value in [deny, allow, secure]>
-            ssl-client-session-state-max: <value of integer>
-            ssl-client-session-state-timeout: <value of integer>
-            ssl-client-session-state-type: <value in [disable, time, count, ...]>
-            ssl-dh-bits: <value in [768, 1024, 1536, ...]>
-            ssl-hpkp: <value in [disable, enable, report-only]>
-            ssl-hpkp-age: <value of integer>
-            ssl-hpkp-backup: <value of string>
-            ssl-hpkp-include-subdomains: <value in [disable, enable]>
-            ssl-hpkp-primary: <value of string>
-            ssl-hpkp-report-uri: <value of string>
-            ssl-hsts: <value in [disable, enable]>
-            ssl-hsts-age: <value of integer>
-            ssl-hsts-include-subdomains: <value in [disable, enable]>
-            ssl-http-location-conversion: <value in [disable, enable]>
-            ssl-http-match-host: <value in [disable, enable]>
-            ssl-max-version: <value in [ssl-3.0, tls-1.0, tls-1.1, ...]>
-            ssl-min-version: <value in [ssl-3.0, tls-1.0, tls-1.1, ...]>
-            ssl-mode: <value in [half, full]>
-            ssl-pfs: <value in [require, deny, allow]>
-            ssl-send-empty-frags: <value in [disable, enable]>
-            ssl-server-algorithm: <value in [high, low, medium, ...]>
-            ssl-server-max-version: <value in [ssl-3.0, tls-1.0, tls-1.1, ...]>
-            ssl-server-min-version: <value in [ssl-3.0, tls-1.0, tls-1.1, ...]>
-            ssl-server-session-state-max: <value of integer>
-            ssl-server-session-state-timeout: <value of integer>
-            ssl-server-session-state-type: <value in [disable, time, count, ...]>
-            type: <value in [static-nat, server-load-balance]>
-            uuid: <value of string>
-            weblogic-server: <value in [disable, enable]>
-            websphere-server: <value in [disable, enable]>
-            http-redirect: <value in [disable, enable]>
-            ssl-client-rekey-count: <value of integer>
-            nat-source-vip: <value in [disable, enable]>
+                  name: FGT_AWS # need a valid device name
+                  vdom: root # need a valid vdom name under the device
+            arp-reply: disable
+            color: 1
+            comment: 'ansible-comment'
+            id: 1
 
+ - name: gathering fortimanager facts
+   hosts: fortimanager00
+   gather_facts: no
+   connection: httpapi
+   collections:
+     - fortinet.fortimanager
+   vars:
+     ansible_httpapi_use_ssl: True
+     ansible_httpapi_validate_certs: False
+     ansible_httpapi_port: 443
+   tasks:
+    - name: retrieve all the dynamic mappings of virtual IP for IPv6
+      fmgr_fact:
+        facts:
+            selector: 'firewall_vip6_dynamicmapping'
+            params:
+                adom: 'ansible'
+                vip6: 'ansible-test-vip6' # name
+                dynamic_mapping: ''
 '''
 
 RETURN = '''
@@ -595,6 +550,11 @@ def main():
             'required': False,
             'default': False
         },
+        'forticloud_access_token': {
+            'type': 'str',
+            'required': False,
+            'no_log': True
+        },
         'proposed_method': {
             'type': 'str',
             'required': False,
@@ -1796,6 +1756,8 @@ def main():
     if module._socket_path:
         connection = Connection(module._socket_path)
         connection.set_option('enable_log', module.params['enable_log'] if 'enable_log' in module.params else False)
+        connection.set_option('forticloud_access_token',
+                              module.params['forticloud_access_token'] if 'forticloud_access_token' in module.params else None)
         fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
         fmgr.validate_parameters(params_validation_blob)
         fmgr.process_curd(argument_specs=module_arg_spec)
