@@ -189,7 +189,26 @@ options:
 '''
 
 EXAMPLES = '''
- - hosts: fortimanager-inventory
+ - name: gathering fortimanager facts
+   hosts: fortimanager00
+   gather_facts: no
+   connection: httpapi
+   collections:
+     - fortinet.fortimanager
+   vars:
+     ansible_httpapi_use_ssl: True
+     ansible_httpapi_validate_certs: False
+     ansible_httpapi_port: 443
+   tasks:
+    - name: retrieve all the SSL/TLS cipher suites
+      fmgr_fact:
+        facts:
+            selector: 'firewall_vip6_sslciphersuites'
+            params:
+                adom: 'ansible'
+                vip6: 'ansible-test-vip6' # name
+                ssl-cipher-suites: ''
+ - hosts: fortimanager00
    collections:
      - fortinet.fortimanager
    connection: httpapi
@@ -200,24 +219,18 @@ EXAMPLES = '''
    tasks:
     - name: SSL/TLS cipher suites acceptable from a client, ordered by priority.
       fmgr_firewall_vip6_sslciphersuites:
-         bypass_validation: False
-         workspace_locking_adom: <value in [global, custom adom including root]>
-         workspace_locking_timeout: 300
-         rc_succeeded: [0, -2, -3, ...]
-         rc_failed: [-2, -3, ...]
-         adom: <your own value>
-         vip6: <your own value>
-         state: <value in [present, absent]>
+         bypass_validation: True
+         adom: ansible
+         vip6: 'ansible-test-vip6' # name
+         state: present
          firewall_vip6_sslciphersuites:
-            cipher: <value in [TLS-RSA-WITH-RC4-128-MD5, TLS-RSA-WITH-RC4-128-SHA, TLS-RSA-WITH-DES-CBC-SHA, ...]>
-            priority: <value of integer>
+            cipher: 'TLS-RSA-WITH-RC4-128-MD5' #<value in [TLS-RSA-WITH-RC4-128-MD5, TLS-RSA-WITH-RC4-128-SHA, TLS-RSA-WITH-DES-CBC-SHA, ...]>
+            priority: 5
             versions:
               - ssl-3.0
               - tls-1.0
               - tls-1.1
               - tls-1.2
-              - tls-1.3
-
 '''
 
 RETURN = '''
@@ -264,6 +277,11 @@ def main():
             'required': False,
             'default': False
         },
+        'forticloud_access_token': {
+            'type': 'str',
+            'required': False,
+            'no_log': True
+        },
         'proposed_method': {
             'type': 'str',
             'required': False,
@@ -460,6 +478,8 @@ def main():
     if module._socket_path:
         connection = Connection(module._socket_path)
         connection.set_option('enable_log', module.params['enable_log'] if 'enable_log' in module.params else False)
+        connection.set_option('forticloud_access_token',
+                              module.params['forticloud_access_token'] if 'forticloud_access_token' in module.params else None)
         fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
         fmgr.validate_parameters(params_validation_blob)
         fmgr.process_curd(argument_specs=module_arg_spec)
