@@ -272,7 +272,7 @@ options:
                 required: false
                 suboptions:
                     servlist:
-                        description: no description
+                        description: 'Servlist.'
                         type: list
                         suboptions:
                             id:
@@ -292,7 +292,7 @@ options:
                                 default: 443
                                 description: 'Port number to use when contacting FortiGuard (1 - 65535, default = 443).'
                             service-type:
-                                description: no description
+                                description: 'Override service type.'
                                 type: list
                                 choices:
                                  - fgd
@@ -476,6 +476,11 @@ def main():
             'required': False,
             'default': False
         },
+        'forticloud_access_token': {
+            'type': 'str',
+            'required': False,
+            'no_log': True
+        },
         'proposed_method': {
             'type': 'str',
             'required': False,
@@ -1190,6 +1195,8 @@ def main():
     if module._socket_path:
         connection = Connection(module._socket_path)
         connection.set_option('enable_log', module.params['enable_log'] if 'enable_log' in module.params else False)
+        connection.set_option('forticloud_access_token',
+                              module.params['forticloud_access_token'] if 'forticloud_access_token' in module.params else None)
         fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
         fmgr.validate_parameters(params_validation_blob)
         fmgr.process_partial_curd(argument_specs=module_arg_spec)
