@@ -96,7 +96,7 @@ options:
         type: dict
         suboptions:
             friendly-name:
-                description: no description
+                description: 'Friendly-Name.'
                 type: list
                 suboptions:
                     friendly-name:
@@ -115,7 +115,7 @@ options:
                 type: str
                 description: 'OSU provider ID.'
             osu-method:
-                description: no description
+                description: 'OSU method list.'
                 type: list
                 choices:
                  - oma-dm
@@ -128,7 +128,7 @@ options:
                 type: str
                 description: 'Server URI.'
             service-description:
-                description: no description
+                description: 'Service-Description.'
                 type: list
                 suboptions:
                     lang:
@@ -228,6 +228,11 @@ def main():
             'required': False,
             'default': False
         },
+        'forticloud_access_token': {
+            'type': 'str',
+            'required': False,
+            'no_log': True
+        },
         'proposed_method': {
             'type': 'str',
             'required': False,
@@ -490,6 +495,8 @@ def main():
     if module._socket_path:
         connection = Connection(module._socket_path)
         connection.set_option('enable_log', module.params['enable_log'] if 'enable_log' in module.params else False)
+        connection.set_option('forticloud_access_token',
+                              module.params['forticloud_access_token'] if 'forticloud_access_token' in module.params else None)
         fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
         fmgr.validate_parameters(params_validation_blob)
         fmgr.process_curd(argument_specs=module_arg_spec)
