@@ -102,13 +102,13 @@ options:
                     - 'block'
                     - 'pass'
             application:
-                description: no description
+                description: 'Applications to be protected. Blank for all applications.'
                 type: str
             comment:
                 type: str
                 description: 'Comment.'
             location:
-                description: no description
+                description: 'Protect client or server traffic.'
                 type: str
             log:
                 type: str
@@ -123,20 +123,20 @@ options:
                     - 'disable'
                     - 'enable'
             os:
-                description: no description
+                description: 'Operating system(s) that the signature protects. Blank for all operating systems.'
                 type: str
             protocol:
                 type: str
                 description: 'Protocol(s) that the signature scans. Blank for all protocols.'
             rule-id:
                 type: int
-                description: no description
+                description: 'Rule-Id.'
             severity:
                 type: str
                 description: 'Relative severity of the signature, from info to critical. Log messages generated by the signature include the severity.'
             sig-name:
                 type: str
-                description: no description
+                description: 'Sig-Name.'
             signature:
                 type: str
                 description: 'Custom signature enclosed in single quotes.'
@@ -153,7 +153,25 @@ options:
 '''
 
 EXAMPLES = '''
- - hosts: fortimanager-inventory
+ - name: gathering fortimanager facts
+   hosts: fortimanager00
+   gather_facts: no
+   connection: httpapi
+   collections:
+     - fortinet.fortimanager
+   vars:
+     ansible_httpapi_use_ssl: True
+     ansible_httpapi_validate_certs: False
+     ansible_httpapi_port: 443
+   tasks:
+    - name: retrieve all the IPS custom signatures
+      fmgr_fact:
+        facts:
+            selector: 'ips_custom'
+            params:
+                adom: 'ansible'
+                custom: ''
+ - hosts: fortimanager00
    collections:
      - fortinet.fortimanager
    connection: httpapi
@@ -164,29 +182,13 @@ EXAMPLES = '''
    tasks:
     - name: Configure IPS custom signature.
       fmgr_ips_custom:
-         bypass_validation: False
-         workspace_locking_adom: <value in [global, custom adom including root]>
-         workspace_locking_timeout: 300
-         rc_succeeded: [0, -2, -3, ...]
-         rc_failed: [-2, -3, ...]
-         adom: <your own value>
-         state: <value in [present, absent]>
+         bypass_validation: True
+         adom: ansible
+         state: present
          ips_custom:
-            action: <value in [block, pass]>
-            application: <value of string>
-            comment: <value of string>
-            location: <value of string>
-            log: <value in [disable, enable]>
-            log-packet: <value in [disable, enable]>
-            os: <value of string>
-            protocol: <value of string>
-            rule-id: <value of integer>
-            severity: <value of string>
-            sig-name: <value of string>
-            signature: <value of string>
-            status: <value in [disable, enable]>
-            tag: <value of string>
-
+            rule-id: 1 # Required, no less than 1000;
+            signature: 'F-SBID(--name: [string]; --service: [string]; --flow: [string])' # Required; Need follow signature syntax, check 'https://docs.fortinet.com/document/ipsengine/3.6.0/custom-ips-and-application-control-signature-syntax-guide/274110/creating-ips-and-application-control-signatures' for more information;
+            tag: ansible-ipscustom #  Required
 '''
 
 RETURN = '''
@@ -233,6 +235,11 @@ def main():
             'required': False,
             'default': False
         },
+        'forticloud_access_token': {
+            'type': 'str',
+            'required': False,
+            'no_log': True
+        },
         'proposed_method': {
             'type': 'str',
             'required': False,
@@ -516,6 +523,8 @@ def main():
     if module._socket_path:
         connection = Connection(module._socket_path)
         connection.set_option('enable_log', module.params['enable_log'] if 'enable_log' in module.params else False)
+        connection.set_option('forticloud_access_token',
+                              module.params['forticloud_access_token'] if 'forticloud_access_token' in module.params else None)
         fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
         fmgr.validate_parameters(params_validation_blob)
         fmgr.process_curd(argument_specs=module_arg_spec)
