@@ -160,7 +160,7 @@ options:
 '''
 
 EXAMPLES = '''
- - hosts: fortimanager-inventory
+ - hosts: fortimanager00
    collections:
      - fortinet.fortimanager
    connection: httpapi
@@ -172,30 +172,38 @@ EXAMPLES = '''
     - name: Configure IPv6 multicast NAT policies.
       fmgr_pkg_firewall_multicastpolicy6:
          bypass_validation: False
-         workspace_locking_adom: <value in [global, custom adom including root]>
-         workspace_locking_timeout: 300
-         rc_succeeded: [0, -2, -3, ...]
-         rc_failed: [-2, -3, ...]
-         adom: <your own value>
-         pkg: <your own value>
-         state: <value in [present, absent]>
+         adom: ansible
+         pkg: ansible # package name
+         state: present
          pkg_firewall_multicastpolicy6:
-            action: <value in [deny, accept]>
-            auto-asic-offload: <value in [disable, enable]>
-            dstaddr: <value of string>
-            dstintf: <value of string>
-            end-port: <value of integer>
-            id: <value of integer>
-            logtraffic: <value in [disable, enable]>
-            protocol: <value of integer>
-            srcaddr: <value of string>
-            srcintf: <value of string>
-            start-port: <value of integer>
-            status: <value in [disable, enable]>
-            name: <value of string>
-            comments: <value of string>
-            uuid: <value of string>
-
+            action: accept #<value in [deny, accept]>
+            auto-asic-offload: enable
+            dstaddr: all
+            dstintf: any
+            id: 1
+            logtraffic: enable
+            srcaddr: all
+            srcintf: any
+            status: disable
+ - name: gathering fortimanager facts
+   hosts: fortimanager00
+   gather_facts: no
+   connection: httpapi
+   collections:
+     - fortinet.fortimanager
+   vars:
+     ansible_httpapi_use_ssl: True
+     ansible_httpapi_validate_certs: False
+     ansible_httpapi_port: 443
+   tasks:
+    - name: retrieve all the IPv6 multicast NAT policies
+      fmgr_fact:
+        facts:
+            selector: 'pkg_firewall_multicastpolicy6'
+            params:
+                adom: 'ansible'
+                pkg: 'ansible' # package name
+                multicast-policy6: ''
 '''
 
 RETURN = '''
@@ -240,6 +248,11 @@ def main():
             'required': False,
             'default': False
         },
+        'forticloud_access_token': {
+            'type': 'str',
+            'required': False,
+            'no_log': True
+        },
         'proposed_method': {
             'type': 'str',
             'required': False,
@@ -522,6 +535,8 @@ def main():
     if module._socket_path:
         connection = Connection(module._socket_path)
         connection.set_option('enable_log', module.params['enable_log'] if 'enable_log' in module.params else False)
+        connection.set_option('forticloud_access_token',
+                              module.params['forticloud_access_token'] if 'forticloud_access_token' in module.params else None)
         fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
         fmgr.validate_parameters(params_validation_blob)
         fmgr.process_curd(argument_specs=module_arg_spec)
