@@ -196,7 +196,26 @@ options:
 '''
 
 EXAMPLES = '''
- - hosts: fortimanager-inventory
+ - name: gathering fortimanager facts
+   hosts: fortimanager00
+   gather_facts: no
+   connection: httpapi
+   collections:
+     - fortinet.fortimanager
+   vars:
+     ansible_httpapi_use_ssl: True
+     ansible_httpapi_validate_certs: False
+     ansible_httpapi_port: 443
+   tasks:
+    - name: retrieve all the IPv6 to IPv4 policies
+      fmgr_fact:
+        facts:
+            selector: 'pkg_firewall_policy64'
+            params:
+                adom: 'ansible'
+                pkg: 'ansible' # package name
+                policy64: ''
+ - hosts: fortimanager00
    collections:
      - fortinet.fortimanager
    connection: httpapi
@@ -208,38 +227,20 @@ EXAMPLES = '''
     - name: Configure IPv6 to IPv4 policies.
       fmgr_pkg_firewall_policy64:
          bypass_validation: False
-         workspace_locking_adom: <value in [global, custom adom including root]>
-         workspace_locking_timeout: 300
-         rc_succeeded: [0, -2, -3, ...]
-         rc_failed: [-2, -3, ...]
-         adom: <your own value>
-         pkg: <your own value>
-         state: <value in [present, absent]>
+         adom: ansible
+         pkg: ansible # package name
+         state: present
          pkg_firewall_policy64:
-            action: <value in [deny, accept]>
-            comments: <value of string>
-            dstaddr: <value of string>
-            dstintf: <value of string>
-            fixedport: <value in [disable, enable]>
-            ippool: <value in [disable, enable]>
-            logtraffic: <value in [disable, enable]>
-            per-ip-shaper: <value of string>
-            permit-any-host: <value in [disable, enable]>
-            policyid: <value of integer>
-            poolname: <value of string>
-            schedule: <value of string>
-            service: <value of string>
-            srcaddr: <value of string>
-            srcintf: <value of string>
-            status: <value in [disable, enable]>
-            tags: <value of string>
-            tcp-mss-receiver: <value of integer>
-            tcp-mss-sender: <value of integer>
-            traffic-shaper: <value of string>
-            traffic-shaper-reverse: <value of string>
-            uuid: <value of string>
-            logtraffic-start: <value in [disable, enable]>
-            name: <value of string>
+            action: accept #<value in [deny, accept]>
+            comments: ansible-comment
+            dstaddr: all
+            dstintf: any
+            policyid: 1
+            schedule: always
+            service: ALL
+            srcaddr: all
+            srcintf: any
+            status: disable
 
 '''
 
@@ -285,6 +286,11 @@ def main():
             'required': False,
             'default': False
         },
+        'forticloud_access_token': {
+            'type': 'str',
+            'required': False,
+            'no_log': True
+        },
         'proposed_method': {
             'type': 'str',
             'required': False,
@@ -718,6 +724,8 @@ def main():
     if module._socket_path:
         connection = Connection(module._socket_path)
         connection.set_option('enable_log', module.params['enable_log'] if 'enable_log' in module.params else False)
+        connection.set_option('forticloud_access_token',
+                              module.params['forticloud_access_token'] if 'forticloud_access_token' in module.params else None)
         fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
         fmgr.validate_parameters(params_validation_blob)
         fmgr.process_curd(argument_specs=module_arg_spec)
