@@ -96,12 +96,12 @@ options:
         type: dict
         suboptions:
             802.1-tlvs:
-                description: no description
+                description: 'Transmitted IEEE 802.1 TLVs.'
                 type: list
                 choices:
                  - port-vlan-id
             802.3-tlvs:
-                description: no description
+                description: 'Transmitted IEEE 802.3 TLVs.'
                 type: list
                 choices:
                  - max-frame-size
@@ -122,7 +122,7 @@ options:
                 type: int
                 description: 'Auto inter-switch LAG timeout if no response is received (3 - 90 sec, default = 9).'
             custom-tlvs:
-                description: no description
+                description: 'Custom-Tlvs.'
                 type: list
                 suboptions:
                     information-string:
@@ -138,7 +138,7 @@ options:
                         type: int
                         description: 'Organizationally defined subtype (0 - 255).'
             med-network-policy:
-                description: no description
+                description: 'Med-Network-Policy.'
                 type: list
                 suboptions:
                     dscp:
@@ -169,7 +169,7 @@ options:
                             - 'disable'
                             - 'enable'
             med-tlvs:
-                description: no description
+                description: 'Transmitted LLDP-MED TLVs (type-length-value descriptions).'
                 type: list
                 choices:
                  - inventory-management
@@ -180,7 +180,7 @@ options:
                 type: str
                 description: 'Profile name.'
             med-location-service:
-                description: no description
+                description: 'Med-Location-Service.'
                 type: list
                 suboptions:
                     name:
@@ -307,6 +307,11 @@ def main():
             'required': False,
             'default': False
         },
+        'forticloud_access_token': {
+            'type': 'str',
+            'required': False,
+            'no_log': True
+        },
         'proposed_method': {
             'type': 'str',
             'required': False,
@@ -770,6 +775,8 @@ def main():
     if module._socket_path:
         connection = Connection(module._socket_path)
         connection.set_option('enable_log', module.params['enable_log'] if 'enable_log' in module.params else False)
+        connection.set_option('forticloud_access_token',
+                              module.params['forticloud_access_token'] if 'forticloud_access_token' in module.params else None)
         fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
         fmgr.validate_parameters(params_validation_blob)
         fmgr.process_curd(argument_specs=module_arg_spec)
