@@ -349,10 +349,10 @@ options:
                     - 'enable'
             mclag-icl-port:
                 type: int
-                description: no description
+                description: 'Mclag-Icl-Port.'
             p2p-port:
                 type: int
-                description: no description
+                description: 'P2P-Port.'
             aggregator-mode:
                 type: str
                 description: 'LACP member select mode.'
@@ -375,7 +375,7 @@ options:
                     - 'both'
             media-type:
                 type: str
-                description: no description
+                description: 'Media-Type.'
             pause-meter:
                 type: int
                 description: 'Configure ingress pause metering rate, in kbps (default = 0, disabled).'
@@ -550,6 +550,11 @@ def main():
             'required': False,
             'default': False
         },
+        'forticloud_access_token': {
+            'type': 'str',
+            'required': False,
+            'no_log': True
+        },
         'proposed_method': {
             'type': 'str',
             'required': False,
@@ -1586,6 +1591,8 @@ def main():
     if module._socket_path:
         connection = Connection(module._socket_path)
         connection.set_option('enable_log', module.params['enable_log'] if 'enable_log' in module.params else False)
+        connection.set_option('forticloud_access_token',
+                              module.params['forticloud_access_token'] if 'forticloud_access_token' in module.params else None)
         fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
         fmgr.validate_parameters(params_validation_blob)
         fmgr.process_curd(argument_specs=module_arg_spec)
