@@ -92,7 +92,7 @@ options:
         type: dict
         suboptions:
             alert-destination:
-                description: no description
+                description: 'Alert-Destination.'
                 type: list
                 suboptions:
                     from:
@@ -123,13 +123,13 @@ options:
                             - 'snmp'
                             - 'syslog'
             enable-generic-text:
-                description: no description
+                description: 'Enable/disable generic text match.'
                 type: list
                 choices:
                  - enable
                  - disable
             enable-severity-filter:
-                description: no description
+                description: 'Enable/disable alert severity filter.'
                 type: list
                 choices:
                  - enable
@@ -195,14 +195,14 @@ options:
                     - 'medium-low'
                     - 'low'
             severity-level-comp:
-                description: no description
+                description: 'Log severity threshold comparison criterion.'
                 type: list
                 choices:
                  - '>='
                  - '='
                  - '<='
             severity-level-logs:
-                description: no description
+                description: 'Log severity threshold level.'
                 type: list
                 choices:
                  - no-check
@@ -217,7 +217,7 @@ options:
 '''
 
 EXAMPLES = '''
- - hosts: fortimanager-inventory
+ - hosts: fortimanager00
    collections:
      - fortinet.fortimanager
    connection: httpapi
@@ -229,35 +229,20 @@ EXAMPLES = '''
     - name: Alert events.
       fmgr_system_alertevent:
          bypass_validation: False
-         workspace_locking_adom: <value in [global, custom adom including root]>
-         workspace_locking_timeout: 300
-         rc_succeeded: [0, -2, -3, ...]
-         rc_failed: [-2, -3, ...]
-         state: <value in [present, absent]>
+         state: present
          system_alertevent:
-            alert-destination:
-              -
-                  from: <value of string>
-                  smtp-name: <value of string>
-                  snmp-name: <value of string>
-                  syslog-name: <value of string>
-                  to: <value of string>
-                  type: <value in [mail, snmp, syslog]>
             enable-generic-text:
               - enable
               - disable
             enable-severity-filter:
               - enable
               - disable
-            event-time-period: <value in [0.5, 1, 3, ...]>
-            generic-text: <value of string>
-            name: <value of string>
-            num-events: <value in [1, 5, 10, ...]>
-            severity-filter: <value in [high, medium-high, medium, ...]>
-            severity-level-comp:
-              - '>='
-              - '='
-              - '<='
+            event-time-period: 1 #<value in [0.5, 1, 3, ...]>
+            name: ansible-test-sysalert
+            num-events: 1 #<value in [1, 5, 10, ...]>
+            severity-filter: high #<value in [high, medium-high, medium, ...]>
+            #severity-level-comp:
+            #  - <=
             severity-level-logs:
               - no-check
               - information
@@ -268,6 +253,23 @@ EXAMPLES = '''
               - alert
               - emergency
 
+ - name: gathering fortimanager facts
+   hosts: fortimanager00
+   gather_facts: no
+   connection: httpapi
+   collections:
+     - fortinet.fortimanager
+   vars:
+     ansible_httpapi_use_ssl: True
+     ansible_httpapi_validate_certs: False
+     ansible_httpapi_port: 443
+   tasks:
+    - name: retrieve all the alert events
+      fmgr_fact:
+        facts:
+            selector: 'system_alertevent'
+            params:
+                alert-event: ''
 '''
 
 RETURN = '''
@@ -312,6 +314,11 @@ def main():
             'required': False,
             'default': False
         },
+        'forticloud_access_token': {
+            'type': 'str',
+            'required': False,
+            'no_log': True
+        },
         'proposed_method': {
             'type': 'str',
             'required': False,
@@ -647,6 +654,8 @@ def main():
     if module._socket_path:
         connection = Connection(module._socket_path)
         connection.set_option('enable_log', module.params['enable_log'] if 'enable_log' in module.params else False)
+        connection.set_option('forticloud_access_token',
+                              module.params['forticloud_access_token'] if 'forticloud_access_token' in module.params else None)
         fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
         fmgr.validate_parameters(params_validation_blob)
         fmgr.process_curd(argument_specs=module_arg_spec)
