@@ -250,7 +250,7 @@ options:
                     - '6144'
                     - '8192'
             disable-module:
-                description: no description
+                description: 'Disable module list.'
                 type: list
                 choices:
                  - fortiview-noc
@@ -510,7 +510,7 @@ options:
                     - 'disable'
                     - 'enable'
             ssl-protocol:
-                description: no description
+                description: 'SSL protocols.'
                 type: list
                 choices:
                  - tlsv1.2
@@ -755,7 +755,7 @@ options:
                     - 'disable'
                     - 'enable'
             webservice-proto:
-                description: no description
+                description: 'Web Service connection support SSL protocols.'
                 type: list
                 choices:
                  - tlsv1.2
@@ -795,7 +795,7 @@ options:
                 type: str
                 description: 'set the extra fgfm CA certificates.'
             mc-policy-disabled-adoms:
-                description: no description
+                description: 'Mc-Policy-Disabled-Adoms.'
                 type: list
                 suboptions:
                     adom-name:
@@ -873,7 +873,7 @@ options:
 '''
 
 EXAMPLES = '''
- - hosts: fortimanager-inventory
+ - hosts: fortimanager00
    collections:
      - fortinet.fortimanager
    connection: httpapi
@@ -882,105 +882,39 @@ EXAMPLES = '''
       ansible_httpapi_validate_certs: False
       ansible_httpapi_port: 443
    tasks:
-    - name: Global range attributes.
+    - name: enable workspace mode
       fmgr_system_global:
-         bypass_validation: False
-         workspace_locking_adom: <value in [global, custom adom including root]>
-         workspace_locking_timeout: 300
-         rc_succeeded: [0, -2, -3, ...]
-         rc_failed: [-2, -3, ...]
          system_global:
-            admin-lockout-duration: <value of integer>
-            admin-lockout-threshold: <value of integer>
-            adom-mode: <value in [normal, advanced]>
-            adom-rev-auto-delete: <value in [disable, by-revisions, by-days]>
-            adom-rev-max-backup-revisions: <value of integer>
-            adom-rev-max-days: <value of integer>
-            adom-rev-max-revisions: <value of integer>
-            adom-select: <value in [disable, enable]>
-            adom-status: <value in [disable, enable]>
-            clt-cert-req: <value in [disable, enable, optional]>
-            console-output: <value in [standard, more]>
-            country-flag: <value in [disable, enable]>
-            create-revision: <value in [disable, enable]>
-            daylightsavetime: <value in [disable, enable]>
-            default-disk-quota: <value of integer>
-            detect-unregistered-log-device: <value in [disable, enable]>
-            device-view-mode: <value in [regular, tree]>
-            dh-params: <value in [1024, 1536, 2048, ...]>
-            disable-module:
-              - fortiview-noc
-              - none
-              - fortirecorder
-              - siem
-              - soc
-              - ai
-            enc-algorithm: <value in [low, medium, high]>
-            faz-status: <value in [disable, enable]>
-            fgfm-local-cert: <value of string>
-            fgfm-ssl-protocol: <value in [sslv3, tlsv1.0, tlsv1.1, ...]>
-            ha-member-auto-grouping: <value in [disable, enable]>
-            hitcount_concurrent: <value of integer>
-            hitcount_interval: <value of integer>
-            hostname: <value of string>
-            import-ignore-addr-cmt: <value in [disable, enable]>
-            language: <value in [english, simch, japanese, ...]>
-            latitude: <value of string>
-            ldap-cache-timeout: <value of integer>
-            ldapconntimeout: <value of integer>
-            lock-preempt: <value in [disable, enable]>
-            log-checksum: <value in [none, md5, md5-auth]>
-            log-forward-cache-size: <value of integer>
-            longitude: <value of string>
-            max-log-forward: <value of integer>
-            max-running-reports: <value of integer>
-            oftp-ssl-protocol: <value in [sslv3, tlsv1.0, tlsv1.1, ...]>
-            partial-install: <value in [disable, enable]>
-            partial-install-force: <value in [disable, enable]>
-            partial-install-rev: <value in [disable, enable]>
-            perform-improve-by-ha: <value in [disable, enable]>
-            policy-hit-count: <value in [disable, enable]>
-            policy-object-in-dual-pane: <value in [disable, enable]>
-            pre-login-banner: <value in [disable, enable]>
-            pre-login-banner-message: <value of string>
-            remoteauthtimeout: <value of integer>
-            search-all-adoms: <value in [disable, enable]>
-            ssl-low-encryption: <value in [disable, enable]>
-            ssl-protocol:
-              - tlsv1.2
-              - tlsv1.1
-              - tlsv1.0
-              - sslv3
-              - tlsv1.3
-            ssl-static-key-ciphers: <value in [disable, enable]>
-            task-list-size: <value of integer>
-            tftp: <value in [disable, enable]>
-            timezone: <value in [00, 01, 02, ...]>
-            tunnel-mtu: <value of integer>
-            usg: <value in [disable, enable]>
-            vdom-mirror: <value in [disable, enable]>
-            webservice-proto:
-              - tlsv1.2
-              - tlsv1.1
-              - tlsv1.0
-              - sslv3
-              - sslv2
-              - tlsv1.3
-            workflow-max-sessions: <value of integer>
-            workspace-mode: <value in [disabled, normal, workflow, ...]>
-            clone-name-option: <value in [default, keep]>
-            fgfm-ca-cert: <value of string>
-            mc-policy-disabled-adoms:
-              -
-                  adom-name: <value of string>
-            policy-object-icon: <value in [disable, enable]>
-            private-data-encryption: <value in [disable, enable]>
-            per-policy-lock: <value in [disable, enable]>
-            multiple-steps-upgrade-in-autolink: <value in [disable, enable]>
-            object-revision-db-max: <value of integer>
-            object-revision-mandatory-note: <value in [disable, enable]>
-            object-revision-object-max: <value of integer>
-            object-revision-status: <value in [disable, enable]>
+              adom-status: enable
+              workspace-mode: normal
+ 
+    - name: Script table.
+      fmgr_dvmdb_script:
+         bypass_validation: False
+         adom: root
+         state: present
+         workspace_locking_adom: 'root'
+         dvmdb_script:
+            content: 'ansiblt-test'
+            name: 'fooscript000'
+            target: device_database
+            type: cli
+ 
+    - name: verify script table
+      fmgr_fact:
+         facts:
+            selector: 'dvmdb_script'
+            params:
+                adom: 'root'
+                script: 'fooscript000'
+      register: info
+      failed_when: info.meta.response_code != 0
+ 
+    - name: restore workspace mode
+      fmgr_system_global:
+         system_global:
+             adom-status: enable
+             workspace-mode: disabled
 
 '''
 
@@ -1026,6 +960,11 @@ def main():
             'required': False,
             'default': False
         },
+        'forticloud_access_token': {
+            'type': 'str',
+            'required': False,
+            'no_log': True
+        },
         'proposed_method': {
             'type': 'str',
             'required': False,
@@ -2364,6 +2303,8 @@ def main():
     if module._socket_path:
         connection = Connection(module._socket_path)
         connection.set_option('enable_log', module.params['enable_log'] if 'enable_log' in module.params else False)
+        connection.set_option('forticloud_access_token',
+                              module.params['forticloud_access_token'] if 'forticloud_access_token' in module.params else None)
         fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
         fmgr.validate_parameters(params_validation_blob)
         fmgr.process_partial_curd(argument_specs=module_arg_spec)
