@@ -95,7 +95,7 @@ options:
                 type: str
                 description: 'Alias.'
             allowaccess:
-                description: no description
+                description: 'Allow management access to interface.'
                 type: list
                 choices:
                  - ping
@@ -123,7 +123,7 @@ options:
                         default: '::/0'
                         description: 'IPv6 address/prefix of interface.'
                     ip6-allowaccess:
-                        description: no description
+                        description: 'Allow management access to interface.'
                         type: list
                         choices:
                          - ping
@@ -151,7 +151,7 @@ options:
                 type: str
                 description: 'Interface name.'
             serviceaccess:
-                description: no description
+                description: 'Allow service access to interface.'
                 type: list
                 choices:
                  - fgtupdates
@@ -199,7 +199,7 @@ options:
 '''
 
 EXAMPLES = '''
- - hosts: fortimanager-inventory
+ - hosts: fortimanager00
    collections:
      - fortinet.fortimanager
    connection: httpapi
@@ -211,46 +211,34 @@ EXAMPLES = '''
     - name: Interface configuration.
       fmgr_system_interface:
          bypass_validation: False
-         workspace_locking_adom: <value in [global, custom adom including root]>
-         workspace_locking_timeout: 300
-         rc_succeeded: [0, -2, -3, ...]
-         rc_failed: [-2, -3, ...]
-         state: <value in [present, absent]>
+         state: present
          system_interface:
-            alias: <value of string>
             allowaccess:
               - ping
-              - https
-              - ssh
-              - snmp
-              - http
-              - webservice
-              - https-logging
-              - soc-fabric
-            description: <value of string>
-            ip: <value of string>
-            ipv6:
-               ip6-address: <value of string>
-               ip6-allowaccess:
-                 - ping
-                 - https
-                 - ssh
-                 - snmp
-                 - http
-                 - webservice
-                 - https-logging
-               ip6-autoconf: <value in [disable, enable]>
-            mtu: <value of integer>
-            name: <value of string>
+            ip: '222.222.22.2/24'
+            mtu: 1500
+            name: port4
             serviceaccess:
               - fgtupdates
-              - fclupdates
-              - webfilter-antispam
-            speed: <value in [auto, 10full, 10half, ...]>
-            status: <value in [down, up]>
-            rating-service-ip: <value of string>
-            update-service-ip: <value of string>
-
+            speed: auto #<value in [auto, 10full, 10half, ...]>
+            status: up
+ - name: gathering fortimanager facts
+   hosts: fortimanager00
+   gather_facts: no
+   connection: httpapi
+   collections:
+     - fortinet.fortimanager
+   vars:
+     ansible_httpapi_use_ssl: True
+     ansible_httpapi_validate_certs: False
+     ansible_httpapi_port: 443
+   tasks:
+    - name: retrieve all the interfaces
+      fmgr_fact:
+        facts:
+            selector: 'system_interface'
+            params:
+                interface: ''
 '''
 
 RETURN = '''
@@ -295,6 +283,11 @@ def main():
             'required': False,
             'default': False
         },
+        'forticloud_access_token': {
+            'type': 'str',
+            'required': False,
+            'no_log': True
+        },
         'proposed_method': {
             'type': 'str',
             'required': False,
@@ -601,6 +594,8 @@ def main():
     if module._socket_path:
         connection = Connection(module._socket_path)
         connection.set_option('enable_log', module.params['enable_log'] if 'enable_log' in module.params else False)
+        connection.set_option('forticloud_access_token',
+                              module.params['forticloud_access_token'] if 'forticloud_access_token' in module.params else None)
         fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
         fmgr.validate_parameters(params_validation_blob)
         fmgr.process_curd(argument_specs=module_arg_spec)
