@@ -124,7 +124,7 @@ options:
 '''
 
 EXAMPLES = '''
- - hosts: fortimanager-inventory
+ - hosts: fortimanager00
    collections:
      - fortinet.fortimanager
    connection: httpapi
@@ -136,19 +136,33 @@ EXAMPLES = '''
     - name: Replacement message table entries.
       fmgr_system_replacemsggroup_http:
          bypass_validation: False
-         workspace_locking_adom: <value in [global, custom adom including root]>
-         workspace_locking_timeout: 300
-         rc_succeeded: [0, -2, -3, ...]
-         rc_failed: [-2, -3, ...]
-         adom: <your own value>
-         replacemsg-group: <your own value>
-         state: <value in [present, absent]>
+         adom: ansible
+         replacemsg-group: ansible-test # name
+         state: present
          system_replacemsggroup_http:
-            buffer: <value of string>
-            format: <value in [none, text, html, ...]>
-            header: <value in [none, http, 8bit]>
-            msg-type: <value of string>
-
+            buffer: ansible-buffer
+            format: none #<value in [none, text, html, ...]>
+            header: http #<value in [none, http, 8bit]>
+            msg-type: ansible-msgtype # required
+ - name: gathering fortimanager facts
+   hosts: fortimanager00
+   gather_facts: no
+   connection: httpapi
+   collections:
+     - fortinet.fortimanager
+   vars:
+     ansible_httpapi_use_ssl: True
+     ansible_httpapi_validate_certs: False
+     ansible_httpapi_port: 443
+   tasks:
+    - name: retrieve all the HTTPs of replacement message group
+      fmgr_fact:
+        facts:
+            selector: 'system_replacemsggroup_http'
+            params:
+                adom: 'ansible'
+                replacemsg-group: 'ansible-test' # name
+                http: ''
 '''
 
 RETURN = '''
@@ -195,6 +209,11 @@ def main():
             'required': False,
             'default': False
         },
+        'forticloud_access_token': {
+            'type': 'str',
+            'required': False,
+            'no_log': True
+        },
         'proposed_method': {
             'type': 'str',
             'required': False,
@@ -337,6 +356,8 @@ def main():
     if module._socket_path:
         connection = Connection(module._socket_path)
         connection.set_option('enable_log', module.params['enable_log'] if 'enable_log' in module.params else False)
+        connection.set_option('forticloud_access_token',
+                              module.params['forticloud_access_token'] if 'forticloud_access_token' in module.params else None)
         fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
         fmgr.validate_parameters(params_validation_blob)
         fmgr.process_curd(argument_specs=module_arg_spec)
