@@ -102,10 +102,10 @@ options:
                     - 'md5'
                     - 'sha'
             auth-pwd:
-                description: no description
+                description: 'Password for authentication protocol.'
                 type: str
             events:
-                description: no description
+                description: 'SNMP notifications (traps) to send.'
                 type: list
                 choices:
                  - disk_low
@@ -140,7 +140,7 @@ options:
                     - 'aes'
                     - 'des'
             priv-pwd:
-                description: no description
+                description: 'Password for privacy (encryption) protocol.'
                 type: str
             queries:
                 type: str
@@ -172,7 +172,25 @@ options:
 '''
 
 EXAMPLES = '''
- - hosts: fortimanager-inventory
+ - name: gathering fortimanager facts
+   hosts: fortimanager00
+   gather_facts: no
+   connection: httpapi
+   collections:
+     - fortinet.fortimanager
+   vars:
+     ansible_httpapi_use_ssl: True
+     ansible_httpapi_validate_certs: False
+     ansible_httpapi_port: 443
+   tasks:
+    - name: retrieve all the SNMP users
+      fmgr_fact:
+        facts:
+            selector: 'system_snmp_user'
+            params:
+                user: ''
+
+ - hosts: fortimanager00
    collections:
      - fortinet.fortimanager
    connection: httpapi
@@ -184,14 +202,10 @@ EXAMPLES = '''
     - name: SNMP user configuration.
       fmgr_system_snmp_user:
          bypass_validation: False
-         workspace_locking_adom: <value in [global, custom adom including root]>
-         workspace_locking_timeout: 300
-         rc_succeeded: [0, -2, -3, ...]
-         rc_failed: [-2, -3, ...]
-         state: <value in [present, absent]>
+         state: present
          system_snmp_user:
-            auth-proto: <value in [md5, sha]>
-            auth-pwd: <value of string>
+            auth-proto: md5 #<value in [md5, sha]>
+            auth-pwd: fortinet
             events:
               - disk_low
               - ha_switch
@@ -205,15 +219,9 @@ EXAMPLES = '''
               - lic-gbday
               - lic-dev-quota
               - cpu-high-exclude-nice
-            name: <value of string>
-            notify-hosts: <value of string>
-            notify-hosts6: <value of string>
-            priv-proto: <value in [aes, des]>
-            priv-pwd: <value of string>
-            queries: <value in [disable, enable]>
-            query-port: <value of integer>
-            security-level: <value in [no-auth-no-priv, auth-no-priv, auth-priv]>
-
+            name: ansible-test-snmpuser
+            queries: disable
+            security-level: no-auth-no-priv #<value in [no-auth-no-priv, auth-no-priv, auth-priv]>
 '''
 
 RETURN = '''
@@ -258,6 +266,11 @@ def main():
             'required': False,
             'default': False
         },
+        'forticloud_access_token': {
+            'type': 'str',
+            'required': False,
+            'no_log': True
+        },
         'proposed_method': {
             'type': 'str',
             'required': False,
@@ -510,6 +523,8 @@ def main():
     if module._socket_path:
         connection = Connection(module._socket_path)
         connection.set_option('enable_log', module.params['enable_log'] if 'enable_log' in module.params else False)
+        connection.set_option('forticloud_access_token',
+                              module.params['forticloud_access_token'] if 'forticloud_access_token' in module.params else None)
         fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
         fmgr.validate_parameters(params_validation_blob)
         fmgr.process_curd(argument_specs=module_arg_spec)
