@@ -112,7 +112,27 @@ options:
 '''
 
 EXAMPLES = '''
- - hosts: fortimanager-inventory
+ - name: gathering fortimanager facts
+   hosts: fortimanager00
+   gather_facts: no
+   connection: httpapi
+   collections:
+     - fortinet.fortimanager
+   vars:
+     ansible_httpapi_use_ssl: True
+     ansible_httpapi_validate_certs: False
+     ansible_httpapi_port: 443
+   tasks:
+    - name: retrieve all the object taggings
+      fmgr_fact:
+        facts:
+            selector: 'user_device_tagging'
+            params:
+                adom: 'ansible'
+                device: 'ansible-test-device' # alias
+                tagging: '' 
+
+ - hosts: fortimanager00
    collections:
      - fortinet.fortimanager
    connection: httpapi
@@ -124,18 +144,13 @@ EXAMPLES = '''
     - name: Config object tagging.
       fmgr_user_device_tagging:
          bypass_validation: False
-         workspace_locking_adom: <value in [global, custom adom including root]>
-         workspace_locking_timeout: 300
-         rc_succeeded: [0, -2, -3, ...]
-         rc_failed: [-2, -3, ...]
-         adom: <your own value>
-         device: <your own value>
-         state: <value in [present, absent]>
+         adom: ansible
+         device: ansible-test-device # alias
+         state: present
          user_device_tagging:
-            category: <value of string>
-            name: <value of string>
-            tags: <value of string>
-
+            category: ansible-category # need a valid category
+            name: ansible-test-tagging
+            tags: ansible1
 '''
 
 RETURN = '''
@@ -182,6 +197,11 @@ def main():
             'required': False,
             'default': False
         },
+        'forticloud_access_token': {
+            'type': 'str',
+            'required': False,
+            'no_log': True
+        },
         'proposed_method': {
             'type': 'str',
             'required': False,
@@ -295,6 +315,8 @@ def main():
     if module._socket_path:
         connection = Connection(module._socket_path)
         connection.set_option('enable_log', module.params['enable_log'] if 'enable_log' in module.params else False)
+        connection.set_option('forticloud_access_token',
+                              module.params['forticloud_access_token'] if 'forticloud_access_token' in module.params else None)
         fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
         fmgr.validate_parameters(params_validation_blob)
         fmgr.process_curd(argument_specs=module_arg_spec)
