@@ -122,7 +122,7 @@ options:
 '''
 
 EXAMPLES = '''
- - hosts: fortimanager-inventory
+ - hosts: fortimanager00
    collections:
      - fortinet.fortimanager
    connection: httpapi
@@ -131,25 +131,47 @@ EXAMPLES = '''
       ansible_httpapi_validate_certs: False
       ansible_httpapi_port: 443
    tasks:
-    - name: no description
+    - name: Create User Device Group
+      fmgr_user_devicegroup:
+         adom: ansible
+         state: 'present'
+         user_devicegroup:
+             name: ansible-test
+ 
+    - name: Configure dynamic mappings of device group
       fmgr_user_devicegroup_dynamicmapping:
          bypass_validation: False
-         workspace_locking_adom: <value in [global, custom adom including root]>
-         workspace_locking_timeout: 300
-         rc_succeeded: [0, -2, -3, ...]
-         rc_failed: [-2, -3, ...]
-         adom: <your own value>
-         device-group: <your own value>
-         state: <value in [present, absent]>
+         adom: ansible
+         device-group: ansible-test # name
+         state: present
          user_devicegroup_dynamicmapping:
-            _if_unmanaged: <value of integer>
+            _if_unmanaged: 10
             _scope:
               -
-                  name: <value of string>
-                  vdom: <value of string>
-            comment: <value of string>
-            member: <value of string>
+                  name: FGT_AWS # need a valid device name
+                  vdom: root # need a valid vdom name under the device
+            comment: ansible-comment
+            member: ios-device
 
+ - name: gathering fortimanager facts
+   hosts: fortimanager00
+   gather_facts: no
+   connection: httpapi
+   collections:
+     - fortinet.fortimanager
+   vars:
+     ansible_httpapi_use_ssl: True
+     ansible_httpapi_validate_certs: False
+     ansible_httpapi_port: 443
+   tasks:
+    - name: retrieve all the dynamic mappings of device group
+      fmgr_fact:
+        facts:
+            selector: 'user_devicegroup_dynamicmapping'
+            params:
+                adom: 'ansible'
+                device-group: 'ansible-test'  # name
+                dynamic_mapping: ''
 '''
 
 RETURN = '''
@@ -196,6 +218,11 @@ def main():
             'required': False,
             'default': False
         },
+        'forticloud_access_token': {
+            'type': 'str',
+            'required': False,
+            'no_log': True
+        },
         'proposed_method': {
             'type': 'str',
             'required': False,
@@ -350,6 +377,8 @@ def main():
     if module._socket_path:
         connection = Connection(module._socket_path)
         connection.set_option('enable_log', module.params['enable_log'] if 'enable_log' in module.params else False)
+        connection.set_option('forticloud_access_token',
+                              module.params['forticloud_access_token'] if 'forticloud_access_token' in module.params else None)
         fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
         fmgr.validate_parameters(params_validation_blob)
         fmgr.process_curd(argument_specs=module_arg_spec)
