@@ -105,62 +105,62 @@ options:
                 suboptions:
                     name:
                         type: str
-                        description: no description
+                        description: 'Name.'
                     vdom:
                         type: str
-                        description: no description
+                        description: 'Vdom.'
             account-key-filter:
                 type: str
-                description: no description
+                description: 'Account key filter, using the UPN as the search filter.'
             account-key-name:
                 type: str
-                description: no description
+                description: 'Account-Key-Name.'
             account-key-processing:
                 type: str
-                description: no description
+                description: 'Account key processing operation, either keep or strip domain string of UPN in the token.'
                 choices:
                     - 'same'
                     - 'strip'
             ca-cert:
                 type: str
-                description: no description
+                description: 'CA certificate name.'
             cnid:
                 type: str
-                description: no description
+                description: 'Common name identifier for the LDAP server. The common name identifier for most LDAP servers is "cn".'
             dn:
                 type: str
-                description: no description
+                description: 'Distinguished name used to look up entries on the LDAP server.'
             filter:
                 type: str
-                description: no description
+                description: 'Filter.'
             group:
                 type: str
-                description: no description
+                description: 'Group.'
             group-filter:
                 type: str
-                description: no description
+                description: 'Filter used for group matching.'
             group-member-check:
                 type: str
-                description: no description
+                description: 'Group member checking methods.'
                 choices:
                     - 'user-attr'
                     - 'group-object'
                     - 'posix-group-object'
             group-object-filter:
                 type: str
-                description: no description
+                description: 'Filter used for group searching.'
             group-object-search-base:
                 type: str
-                description: no description
+                description: 'Group-Object-Search-Base.'
             group-search-base:
                 type: str
-                description: no description
+                description: 'Search base used for group searching.'
             member-attr:
                 type: str
-                description: no description
+                description: 'Name of attribute from which to get group membership.'
             obtain-user-info:
                 type: str
-                description: no description
+                description: 'Enable/disable obtaining of user information.'
                 choices:
                     - 'disable'
                     - 'enable'
@@ -169,22 +169,22 @@ options:
                 type: str
             password-expiry-warning:
                 type: str
-                description: no description
+                description: 'Enable/disable password expiry warnings.'
                 choices:
                     - 'disable'
                     - 'enable'
             password-renewal:
                 type: str
-                description: no description
+                description: 'Enable/disable online password renewal.'
                 choices:
                     - 'disable'
                     - 'enable'
             port:
                 type: int
-                description: no description
+                description: 'Port to be used for communication with the LDAP server (default = 389).'
             retrieve-protection-profile:
                 type: str
-                description: no description
+                description: 'Retrieve-Protection-Profile.'
             search-type:
                 description: no description
                 type: list
@@ -193,29 +193,29 @@ options:
                  - recursive
             secondary-server:
                 type: str
-                description: no description
+                description: 'Secondary LDAP server CN domain name or IP.'
             secure:
                 type: str
-                description: no description
+                description: 'Port to be used for authentication.'
                 choices:
                     - 'disable'
                     - 'starttls'
                     - 'ldaps'
             server:
                 type: str
-                description: no description
+                description: 'LDAP server CN domain name or IP.'
             server-identity-check:
                 type: str
-                description: no description
+                description: 'Enable/disable LDAP server identity check (verify server domain name/IP address against the server certificate).'
                 choices:
                     - 'disable'
                     - 'enable'
             source-ip:
                 type: str
-                description: no description
+                description: 'Source IP for communications to LDAP server.'
             ssl-min-proto-version:
                 type: str
-                description: no description
+                description: 'Minimum supported protocol version for SSL/TLS connections (default is to follow system global setting).'
                 choices:
                     - 'default'
                     - 'TLSv1'
@@ -224,46 +224,46 @@ options:
                     - 'SSLv3'
             tertiary-server:
                 type: str
-                description: no description
+                description: 'Tertiary LDAP server CN domain name or IP.'
             type:
                 type: str
-                description: no description
+                description: 'Authentication type for LDAP searches.'
                 choices:
                     - 'simple'
                     - 'anonymous'
                     - 'regular'
             user-info-exchange-server:
                 type: str
-                description: no description
+                description: 'MS Exchange server from which to fetch user information.'
             username:
                 type: str
-                description: no description
+                description: 'Username (full DN) for initial binding.'
             two-factor:
                 type: str
-                description: no description
+                description: 'Enable/disable two-factor authentication.'
                 choices:
                     - 'disable'
                     - 'fortitoken-cloud'
             interface:
                 type: str
-                description: no description
+                description: 'Specify outgoing interface to reach server.'
             interface-select-method:
                 type: str
-                description: no description
+                description: 'Specify how to select outgoing interface to reach server.'
                 choices:
                     - 'auto'
                     - 'sdwan'
                     - 'specify'
             two-factor-authentication:
                 type: str
-                description: no description
+                description: 'Authentication method by FortiToken Cloud.'
                 choices:
                     - 'fortitoken'
                     - 'email'
                     - 'sms'
             two-factor-notification:
                 type: str
-                description: no description
+                description: 'Notification method for user activation by FortiToken Cloud.'
                 choices:
                     - 'email'
                     - 'sms'
@@ -283,7 +283,27 @@ options:
 '''
 
 EXAMPLES = '''
- - hosts: fortimanager-inventory
+ - name: gathering fortimanager facts
+   hosts: fortimanager00
+   gather_facts: no
+   connection: httpapi
+   collections:
+     - fortinet.fortimanager
+   vars:
+     ansible_httpapi_use_ssl: True
+     ansible_httpapi_validate_certs: False
+     ansible_httpapi_port: 443
+   tasks:
+    - name: retrieve all the dynamic mappings of LDAP server
+      fmgr_fact:
+        facts:
+            selector: 'user_ldap_dynamicmapping'
+            params:
+                adom: 'ansible'
+                ldap: 'ansible-test-ldap' # name
+                dynamic_mapping: '' 
+
+ - hosts: fortimanager00
    collections:
      - fortinet.fortimanager
    connection: httpapi
@@ -292,63 +312,22 @@ EXAMPLES = '''
       ansible_httpapi_validate_certs: False
       ansible_httpapi_port: 443
    tasks:
-    - name: Configure LDAP server entries.
+    - name: Configure dynamic mappings of LDAP server
       fmgr_user_ldap_dynamicmapping:
          bypass_validation: False
-         workspace_locking_adom: <value in [global, custom adom including root]>
-         workspace_locking_timeout: 300
-         rc_succeeded: [0, -2, -3, ...]
-         rc_failed: [-2, -3, ...]
-         adom: <your own value>
-         ldap: <your own value>
-         state: <value in [present, absent]>
+         adom: ansible
+         ldap: ansible-test-ldap # name
+         state: present
          user_ldap_dynamicmapping:
             _scope:
               -
-                  name: <value of string>
-                  vdom: <value of string>
-            account-key-filter: <value of string>
-            account-key-name: <value of string>
-            account-key-processing: <value in [same, strip]>
-            ca-cert: <value of string>
-            cnid: <value of string>
-            dn: <value of string>
-            filter: <value of string>
-            group: <value of string>
-            group-filter: <value of string>
-            group-member-check: <value in [user-attr, group-object, posix-group-object]>
-            group-object-filter: <value of string>
-            group-object-search-base: <value of string>
-            group-search-base: <value of string>
-            member-attr: <value of string>
-            obtain-user-info: <value in [disable, enable]>
-            password: <value of string>
-            password-expiry-warning: <value in [disable, enable]>
-            password-renewal: <value in [disable, enable]>
-            port: <value of integer>
-            retrieve-protection-profile: <value of string>
-            search-type:
-              - nested
-              - recursive
-            secondary-server: <value of string>
-            secure: <value in [disable, starttls, ldaps]>
-            server: <value of string>
-            server-identity-check: <value in [disable, enable]>
-            source-ip: <value of string>
-            ssl-min-proto-version: <value in [default, TLSv1, TLSv1-1, ...]>
-            tertiary-server: <value of string>
-            type: <value in [simple, anonymous, regular]>
-            user-info-exchange-server: <value of string>
-            username: <value of string>
-            two-factor: <value in [disable, fortitoken-cloud]>
-            interface: <value of string>
-            interface-select-method: <value in [auto, sdwan, specify]>
-            two-factor-authentication: <value in [fortitoken, email, sms]>
-            two-factor-notification: <value in [email, sms]>
-            antiphish: <value in [disable, enable]>
-            password-attr: <value of string>
-            source-port: <value of integer>
-
+                  name: FGT_AWS # need a valid device name
+                  vdom: root # need a valid vdom name under the device
+            dn: ansible-test-dn
+            password: fortinet
+            port: 9000
+            server: ansible
+            username: ansible-test-dyn
 '''
 
 RETURN = '''
@@ -395,6 +374,11 @@ def main():
             'required': False,
             'default': False
         },
+        'forticloud_access_token': {
+            'type': 'str',
+            'required': False,
+            'no_log': True
+        },
         'proposed_method': {
             'type': 'str',
             'required': False,
@@ -1093,6 +1077,8 @@ def main():
     if module._socket_path:
         connection = Connection(module._socket_path)
         connection.set_option('enable_log', module.params['enable_log'] if 'enable_log' in module.params else False)
+        connection.set_option('forticloud_access_token',
+                              module.params['forticloud_access_token'] if 'forticloud_access_token' in module.params else None)
         fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
         fmgr.validate_parameters(params_validation_blob)
         fmgr.process_curd(argument_specs=module_arg_spec)
