@@ -1,35 +1,13 @@
-# This code is part of Ansible, but is an independent component.
-# This particular file snippet, and this file snippet only, is BSD licensed.
-# Modules you write using this snippet, which is embedded dynamically by Ansible
-# still belong to the author of the module, and may assign their own license
-# to the complete work.
-#
-# Miguel Angel Munoz <magonzalez@fortinet.com>, 2019
-# fortinet-ansible-dev <https://github.com/fortinet-ansible-dev>, 2020
-#
-# All rights reserved.
-#
-# Redistribution and use in source and binary forms, with or without modification,
-# are permitted provided that the following conditions are met:
-#
-#    * Redistributions of source code must retain the above copyright
-#      notice, this list of conditions and the following disclaimer.
-#    * Redistributions in binary form must reproduce the above copyright notice,
-#      this list of conditions and the following disclaimer in the documentation
-#      and/or other materials provided with the distribution.
-#
-# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
-# ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
-# WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
-# IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
-# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
-# PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
-# INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
-# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
-# USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE
-#
+# Copyright (c) 2022 Fortinet
+# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)
+
+# This program is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
 
 from __future__ import (absolute_import, division, print_function)
+
 __metaclass__ = type
 
 import os
@@ -37,10 +15,8 @@ import time
 import traceback
 
 from ansible.module_utils._text import to_text
-# from ansible.module_utils.basic import env_fallback
-from ansible.module_utils.basic import _load_params
-import sys
 import json
+from ansible_collections.fortinet.fortios.plugins.module_utils.fortios.secret_field import is_secret_field
 
 try:
     import urllib.parse as urlencoding
@@ -75,17 +51,15 @@ fortios_error_codes = {
 }
 
 
-def check_legacy_fortiosapi():
-    params = _load_params()
+def check_legacy_fortiosapi(module):
     legacy_schemas = ['host', 'username', 'password', 'ssl_verify', 'https']
     legacy_params = []
     for param in legacy_schemas:
-        if param in params:
+        if param in module.params:
             legacy_params.append(param)
     if len(legacy_params):
         error_message = 'Legacy fortiosapi parameters %s detected, please use HTTPAPI instead!' % (str(legacy_params))
-        sys.stderr.write(error_message)
-        sys.exit(1)
+        module.fail_json(msg=error_message)
 
 
 def schema_to_module_spec(schema):
@@ -96,11 +70,15 @@ def schema_to_module_spec(schema):
         if 'children' not in schema:
             raise AssertionError()
         rdata['type'] = schema['type']
+        if schema['type'] == 'list':
+            rdata['elements'] = schema.get('elements')
         rdata['required'] = False
         rdata['options'] = dict()
         for child in schema['children']:
             child_value = schema['children'][child]
             rdata['options'][child] = schema_to_module_spec(child_value)
+            if (child):
+                rdata['options'][child]['no_log'] = True
     elif schema['type'] in ['integer', 'string'] or (schema['type'] == 'list' and 'children' not in schema):
         if schema['type'] == 'integer':
             rdata['type'] = 'int'
@@ -108,24 +86,15 @@ def schema_to_module_spec(schema):
             rdata['type'] = 'str'
         elif schema['type'] == 'list':
             rdata['type'] = 'list'
+            rdata['elements'] = schema.get('elements')
         else:
             raise AssertionError()
         rdata['required'] = False
         if 'options' in schema:
             # see mantis #0690570, if the semantic meaning changes, remove choices as well
             # also see accept_auth_by_cert of module fortios_system_csf.
-            param_semantic_changed = False
-            for ver in schema['revisions']:
-                if not schema['revisions']:
-                    continue
-                for option in schema['options']:
-                    if ver not in option['revisions']:
-                        param_semantic_changed = True
-                        break
-                if param_semantic_changed:
-                    break
-            if not param_semantic_changed:
-                rdata['choices'] = [option['value'] for option in schema['options']]
+            # ansible-test now requires choices are present in spec
+            rdata['choices'] = [option['value'] for option in schema['options']]
     else:
         raise AssertionError()
     return rdata
@@ -200,7 +169,7 @@ def check_schema_versioning_internal(results, trace, schema, params, version):
             for list_item in params:
                 if type(list_item) is not dict:
                     # Parameter inconsistency here is not covered by Ansible, we gracefully throw a warning
-                    results['mismatches'].append('option [%s]\' playload is inconsitent with schmea.' % (__concat_attribute_sequence(trace)))
+                    results['mismatches'].append('option [%s]\' playload is inconsistent with schema.' % (__concat_attribute_sequence(trace)))
                     continue
                 for key in list_item:
                     value = list_item[key]
@@ -337,11 +306,7 @@ class FortiOSHandler(object):
             del trace_param[-1]
 
     def _process_sub_object(self, all_urls, toplevel_url_token, traced_url_tokens, path, name):
-        # toplevel_name_split = toplevel_name.split('_')
-        # if len(toplevel_name_split) != 2:
-            # raise AssertionError('Invalid top level parameter name:%s' % (toplevel_name))
         vdom = self._module.params['vdom'] if 'vdom' in self._module.params and self._module.params['vdom'] else None
-        #url_prefix = self.cmdb_url(toplevel_name_split[0], toplevel_name_split[1])
         url_prefix = self.cmdb_url(path, name)
         url_suffix = ''
         if vdom == 'global':
@@ -671,8 +636,8 @@ class FortiOSHandler(object):
             else:
                 url += "?"
             url += specific_params
-        status, result_data = self._conn.send_request(url=url, method=method, data=json.dumps(data), params=parameters)
-        return self.formatresponse(result_data, status=status, vdom=vdom)
+        http_status, result_data = self._conn.send_request(url=url, method=method, data=json.dumps(data), params=parameters)
+        return self.formatresponse(result_data, http_status, vdom=vdom)
 
 # BEGIN DEPRECATED
 
