@@ -89,6 +89,15 @@ from ansible_collections.junipernetworks.junos.plugins.module_utils.network.juno
 from ansible_collections.junipernetworks.junos.plugins.module_utils.network.junos.facts.ntp_global.ntp_global import (
     Ntp_globalFacts,
 )
+from ansible_collections.junipernetworks.junos.plugins.module_utils.network.junos.facts.security_policies.security_policies import (
+    Security_policiesFacts,
+)
+from ansible_collections.junipernetworks.junos.plugins.module_utils.network.junos.facts.security_policies_global.security_policies_global import (
+    Security_policies_globalFacts,
+)
+from ansible_collections.junipernetworks.junos.plugins.module_utils.network.junos.facts.security_zones.security_zones import (
+    Security_zonesFacts,
+)
 from ansible_collections.junipernetworks.junos.plugins.module_utils.network.junos.facts.snmp_server.snmp_server import (
     Snmp_serverFacts,
 )
@@ -124,6 +133,9 @@ FACT_RESOURCE_SUBSETS = dict(
     prefix_lists=Prefix_listsFacts,
     logging_global=Logging_globalFacts,
     ntp_global=Ntp_globalFacts,
+    security_policies=Security_policiesFacts,
+    security_policies_global=Security_policies_globalFacts,
+    security_zones=Security_zonesFacts,
     snmp_server=Snmp_serverFacts,
     routing_options=Routing_optionsFacts,
     hostname=HostnameFacts,
@@ -131,8 +143,7 @@ FACT_RESOURCE_SUBSETS = dict(
 
 
 class Facts(FactsBase):
-    """ The fact class for junos
-    """
+    """The fact class for junos"""
 
     VALID_LEGACY_GATHER_SUBSETS = frozenset(FACT_LEGACY_SUBSETS.keys())
     VALID_RESOURCE_SUBSETS = frozenset(FACT_RESOURCE_SUBSETS.keys())
@@ -143,7 +154,7 @@ class Facts(FactsBase):
     def get_facts(
         self, legacy_facts_type=None, resource_facts_type=None, data=None
     ):
-        """ Collect the facts for junos
+        """Collect the facts for junos
         :param legacy_facts_type: List of legacy facts types
         :param resource_facts_type: List of resource fact types
         :param data: previously collected conf
