@@ -1,7 +1,7 @@
 #!/usr/bin/python
-''' this is igroup module
+''' na_ontap_igroup
 
- (c) 2018-2019, NetApp, Inc
+ (c) 2018-2022, NetApp, Inc
  # GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
 '''
 
@@ -9,55 +9,49 @@ from __future__ import absolute_import, division, print_function
 
 __metaclass__ = type
 
-ANSIBLE_METADATA = {
-    'metadata_version': '1.1',
-    'status': ['preview'],
-    'supported_by': 'certified'
-}
-
 DOCUMENTATION = '''
 
 module: na_ontap_igroup
 short_description: NetApp ONTAP iSCSI or FC igroup configuration
 extends_documentation_fragment:
-    - netapp.ontap.netapp.na_ontap
+  - netapp.ontap.netapp.na_ontap
 version_added: 2.6.0
 author: NetApp Ansible Team (@carchi8py) <ng-ansibleteam@netapp.com>
 
 description:
-    - Create/Delete/Rename Igroups and Modify initiators belonging to an igroup
+  - Create/Delete/Rename Igroups and Modify initiators belonging to an igroup
 
 options:
   state:
     description:
-    - Whether the specified Igroup should exist or not.
+      - Whether the specified Igroup should exist or not.
     choices: ['present', 'absent']
     type: str
     default: present
 
   name:
     description:
-    - The name of the igroup to manage.
+      - The name of the igroup to manage.
     required: true
     type: str
 
   initiator_group_type:
     description:
-    - Type of the initiator group.
-    - Required when C(state=present).
+      - Type of the initiator group.
+      - Required when C(state=present).
     choices: ['fcp', 'iscsi', 'mixed']
     type: str
     aliases: ['protocol']
 
   from_name:
     description:
-    - Name of igroup to rename to name.
+      - Name of igroup to rename to name.
     version_added: 2.7.0
     type: str
 
   os_type:
     description:
-    - OS type of the initiators within the group.
+      - OS type of the initiators within the group.
     type: str
     aliases: ['ostype']
 
@@ -109,12 +103,13 @@ options:
 
   bind_portset:
     description:
-    - Name of a current portset to bind to the newly created igroup.
+      - Name of a current portset to bind to the newly created igroup.
     type: str
 
   force_remove_initiator:
     description:
-    -  Forcibly remove the initiator even if there are existing LUNs mapped to this initiator group.
+      - Forcibly remove the initiator even if there are existing LUNs mapped to this initiator group.
+      - This parameter should be used with caution.
     type: bool
     default: false
     aliases: ['allow_delete_while_mapped']
@@ -125,11 +120,14 @@ options:
     required: true
     type: str
 
+notes:
+  - supports check mode.
+  - supports ZAPI and REST.
 '''
 
 EXAMPLES = '''
     - name: Create iSCSI Igroup
-      na_ontap_igroup:
+      netapp.ontap.na_ontap_igroup:
         state: present
         name: ansibleIgroup3
         initiator_group_type: iscsi
@@ -141,7 +139,7 @@ EXAMPLES = '''
         password: "{{ netapp_password }}"
 
     - name: Create iSCSI Igroup - ONTAP 9.9
-      na_ontap_igroup:
+      netapp.ontap.na_ontap_igroup:
         state: present
         name: ansibleIgroup3
         initiator_group_type: iscsi
@@ -156,7 +154,7 @@ EXAMPLES = '''
         password: "{{ netapp_password }}"
 
     - name: Create FC Igroup
-      na_ontap_igroup:
+      netapp.ontap.na_ontap_igroup:
         state: present
         name: ansibleIgroup4
         initiator_group_type: fcp
@@ -168,7 +166,7 @@ EXAMPLES = '''
         password: "{{ netapp_password }}"
 
     - name: rename Igroup
-      na_ontap_igroup:
+      netapp.ontap.na_ontap_igroup:
         state: present
         from_name: ansibleIgroup3
         name: testexamplenewname
@@ -181,7 +179,7 @@ EXAMPLES = '''
         password: "{{ netapp_password }}"
 
     - name: Modify Igroup Initiators (replaces exisiting initiator_names)
-      na_ontap_igroup:
+      netapp.ontap.na_ontap_igroup:
         state: present
         name: ansibleIgroup3
         initiator_group_type: iscsi
@@ -193,7 +191,7 @@ EXAMPLES = '''
         password: "{{ netapp_password }}"
 
     - name: Delete Igroup
-      na_ontap_igroup:
+      netapp.ontap.na_ontap_igroup:
         state: absent
         name: ansibleIgroup3
         vserver: ansibleVServer
@@ -212,12 +210,10 @@ from ansible.module_utils._text import to_native
 import ansible_collections.netapp.ontap.plugins.module_utils.netapp as netapp_utils
 from ansible_collections.netapp.ontap.plugins.module_utils.netapp_module import NetAppModule
 from ansible_collections.netapp.ontap.plugins.module_utils.netapp import OntapRestAPI
-import ansible_collections.netapp.ontap.plugins.module_utils.rest_response_helpers as rrh
-
-HAS_NETAPP_LIB = netapp_utils.has_netapp_lib()
+from ansible_collections.netapp.ontap.plugins.module_utils import rest_generic
 
 
-class NetAppOntapIgroup(object):
+class NetAppOntapIgroup:
     """Create/Delete/Rename Igroups and Modify initiators list"""
     def __init__(self):
 
@@ -299,11 +295,9 @@ class NetAppOntapIgroup(object):
                 self.parameters['igroups'] = list()
 
         if not self.use_rest:
-            if HAS_NETAPP_LIB is False:
-                self.module.fail_json(
-                    msg="the python NetApp-Lib module is required")
-            else:
-                self.server = netapp_utils.setup_na_ontap_zapi(module=self.module, vserver=self.parameters['vserver'])
+            if not netapp_utils.has_netapp_lib():
+                self.module.fail_json(msg=netapp_utils.netapp_lib_is_required())
+            self.server = netapp_utils.setup_na_ontap_zapi(module=self.module, vserver=self.parameters['vserver'])
 
     def fail_on_error(self, error, stack=False):
         if error is None:
@@ -320,33 +314,32 @@ class NetAppOntapIgroup(object):
             fields += ',igroups'
         query = dict(name=name, fields=fields)
         query['svm.name'] = self.parameters['vserver']
-        response, error = self.rest_api.get(api, query)
-        igroup, error = rrh.check_for_0_or_1_records(api, response, error)
+        record, error = rest_generic.get_one_record(self.rest_api, api, query)
         self.fail_on_error(error)
-        if igroup:
+        if record:
             try:
                 igroup_details = dict(
-                    name=igroup['name'],
-                    uuid=igroup['uuid'],
-                    vserver=igroup['svm']['name'],
-                    os_type=igroup['os_type'],
-                    initiator_group_type=igroup['protocol'],
+                    name=record['name'],
+                    uuid=record['uuid'],
+                    vserver=record['svm']['name'],
+                    os_type=record['os_type'],
+                    initiator_group_type=record['protocol'],
                     name_to_uuid=dict()
                 )
             except KeyError as exc:
-                self.module.fail_json(msg='Error: unexpected igroup body: %s, KeyError on %s' % (str(igroup), str(exc)))
-            igroup_details['name_to_key'] = dict()
+                self.module.fail_json(msg='Error: unexpected igroup body: %s, KeyError on %s' % (str(record), str(exc)))
+            igroup_details['name_to_key'] = {}
             for attr in ('igroups', 'initiators'):
                 option = 'initiator_names' if attr == 'initiators' else attr
-                if attr in igroup:
-                    igroup_details[option] = [item['name'] for item in igroup[attr]]
+                if attr in record:
+                    igroup_details[option] = [item['name'] for item in record[attr]]
                     if attr == 'initiators':
-                        igroup_details['initiator_objects'] = [dict(name=item['name'], comment=item.get('comment')) for item in igroup[attr]]
+                        igroup_details['initiator_objects'] = [dict(name=item['name'], comment=item.get('comment')) for item in record[attr]]
                     # for initiators, there is no uuid, so we're using name as the key
-                    igroup_details['name_to_uuid'][option] = dict((item['name'], item.get('uuid', item['name'])) for item in igroup[attr])
+                    igroup_details['name_to_uuid'][option] = dict((item['name'], item.get('uuid', item['name'])) for item in record[attr])
                 else:
                     igroup_details[option] = []
-                    igroup_details['name_to_uuid'][option] = dict()
+                    igroup_details['name_to_uuid'][option] = {}
             return igroup_details
         return None
 
@@ -424,15 +417,15 @@ class NetAppOntapIgroup(object):
         else:
             records = [dict(name=name) for name in names]
         body = dict(records=records)
-        dummy, error = self.rest_api.post(api, body)
+        dummy, error = rest_generic.post_async(self.rest_api, api, body)
         self.fail_on_error(error)
 
     def modify_initiators_rest(self, uuid, initiator_objects):
         for initiator in initiator_objects:
             if 'comment' in initiator:
-                api = "protocols/san/igroups/%s/initiators/%s" % (uuid, initiator['name'])
+                api = "protocols/san/igroups/%s/initiators" % uuid
                 body = dict(comment=initiator['comment'])
-                dummy, error = self.rest_api.patch(api, body)
+                dummy, error = rest_generic.patch_async(self.rest_api, api, initiator['name'], body)
                 self.fail_on_error(error)
 
     def add_initiators_or_igroups(self, uuid, option, current_names):
@@ -453,8 +446,9 @@ class NetAppOntapIgroup(object):
 
     def delete_initiator_or_igroup_rest(self, uuid, option, name_or_uuid):
         self.check_option_is_valid(option)
-        api = "protocols/san/igroups/%s/%s/%s" % (uuid, self.get_rest_name_for_option(option), name_or_uuid)
-        dummy, error = self.rest_api.delete(api)
+        api = "protocols/san/igroups/%s/%s" % (uuid, self.get_rest_name_for_option(option))
+        query = {'allow_delete_while_mapped': True} if self.parameters['force_remove_initiator'] else None
+        dummy, error = rest_generic.delete_async(self.rest_api, api, name_or_uuid, query=query)
         self.fail_on_error(error)
 
     def remove_initiators_or_igroups(self, uuid, option, current_names, mapping):
@@ -476,6 +470,8 @@ class NetAppOntapIgroup(object):
         """
         options = {'initiator-group-name': self.parameters['name'],
                    'initiator': initiator}
+        if zapi == 'igroup-remove' and self.parameters.get('force_remove_initiator'):
+            options['force'] = 'true'
 
         igroup_modify = netapp_utils.zapi.NaElement.create_node_with_children(zapi, **options)
 
@@ -509,7 +505,7 @@ class NetAppOntapIgroup(object):
                         value = [dict(name=name) for name in value] if value else None
                 if value is not None:
                     body[mapping[option]] = value
-        dummy, error = self.rest_api.post(api, body)
+        dummy, error = rest_generic.post_async(self.rest_api, api, body)
         self.fail_on_error(error)
 
     def create_igroup(self):
@@ -517,8 +513,7 @@ class NetAppOntapIgroup(object):
         Create the igroup.
         """
         if self.use_rest:
-            self.create_igroup_rest()
-            return
+            return self.create_igroup_rest()
 
         options = {'initiator-group-name': self.parameters['name']}
         if self.parameters.get('os_type') is not None:
@@ -554,23 +549,20 @@ class NetAppOntapIgroup(object):
         return [item for item in modify['initiator_objects'] if has_changed_comment(item)]
 
     def modify_igroup_rest(self, uuid, modify):
-        api = "protocols/san/igroups/%s" % uuid
+        api = "protocols/san/igroups"
         body = dict()
         for option in modify:
             if option not in self.rest_modify_zapi_to_rest:
                 self.module.fail_json(msg='Error: modifying %s is not supported in REST' % option)
             body[self.rest_modify_zapi_to_rest[option]] = modify[option]
         if body:
-            dummy, error = self.rest_api.patch(api, body)
+            dummy, error = rest_generic.patch_async(self.rest_api, api, uuid, body)
             self.fail_on_error(error)
 
     def delete_igroup_rest(self, uuid):
-        api = "protocols/san/igroups/%s" % uuid
-        if self.parameters['force_remove_initiator']:
-            query = dict(allow_delete_while_mapped=True)
-        else:
-            query = None
-        dummy, error = self.rest_api.delete(api, params=query)
+        api = "protocols/san/igroups"
+        query = {'allow_delete_while_mapped': True} if self.parameters['force_remove_initiator'] else None
+        dummy, error = rest_generic.delete_async(self.rest_api, api, uuid, query=query)
         self.fail_on_error(error)
 
     def delete_igroup(self, uuid):
@@ -578,8 +570,7 @@ class NetAppOntapIgroup(object):
         Delete the igroup.
         """
         if self.use_rest:
-            self.delete_igroup_rest(uuid)
-            return
+            return self.delete_igroup_rest(uuid)
 
         igroup_delete = netapp_utils.zapi.NaElement.create_node_with_children(
             'igroup-destroy', **{'initiator-group-name': self.parameters['name'],
@@ -648,6 +639,25 @@ class NetAppOntapIgroup(object):
             cd_action = None
         return cd_action, rename, current
 
+    def modify_igroup(self, uuid, current, modify):
+        for attr in ('igroups', 'initiator_names'):
+            if attr in current:
+                # we need to remove everything first
+                self.remove_initiators_or_igroups(uuid, attr, current[attr], current['name_to_uuid'][attr])
+        for attr in ('igroups', 'initiator_names'):
+            if attr in current:
+                self.add_initiators_or_igroups(uuid, attr, current[attr])
+            modify.pop(attr, None)
+        if 'initiator_objects' in modify:
+            if self.use_rest:
+                # comments are not supported in ZAPI, we already checked for that in validate changes
+                changed_initiator_objects = self.change_in_initiator_comments(modify, current)
+                self.modify_initiators_rest(uuid, changed_initiator_objects)
+            modify.pop('initiator_objects',)
+        if modify:
+            # validate_modify ensured modify is empty with ZAPI
+            self.modify_igroup_rest(uuid, modify)
+
     def apply(self):
         self.autosupport_log()
         uuid = None
@@ -678,22 +688,7 @@ class NetAppOntapIgroup(object):
             elif cd_action == 'delete':
                 self.delete_igroup(uuid)
             if modify:
-                for attr in ('igroups', 'initiator_names'):
-                    if attr in current:
-                        # we need to remove everything first
-                        self.remove_initiators_or_igroups(uuid, attr, current[attr], current['name_to_uuid'][attr])
-                for attr in ('igroups', 'initiator_names'):
-                    if attr in current:
-                        self.add_initiators_or_igroups(uuid, attr, current[attr])
-                    modify.pop(attr, None)
-                if 'initiator_objects' in modify:
-                    if self.use_rest:
-                        # comments are not supported in ZAPI, we already checked for that in validate changes
-                        changed_initiator_objects = self.change_in_initiator_comments(modify, current)
-                        self.modify_initiators_rest(uuid, changed_initiator_objects)
-                    modify.pop('initiator_objects',)
-                if modify:
-                    self.modify_igroup_rest(uuid, modify)
+                self.modify_igroup(uuid, current, modify)
         self.module.exit_json(changed=self.na_helper.changed, current=current, modify=saved_modify)
 
 
