@@ -185,6 +185,7 @@ CONVERT_TO_ID = {
     "cluster_group": "cluster_groups",
     "cluster_groups": "cluster_groups",
     "cluster_type": "cluster_types",
+    "cluster_types": "cluster_types",
     "config_context": "config_contexts",
     "contact_groups": "contact_groups",
     "dcim.consoleport": "console_ports",
@@ -361,6 +362,7 @@ ALLOWED_QUERY_PARAMS = {
             "roles",
             "device_types",
             "platforms",
+            "cluster_types",
             "cluster_groups",
             "clusters",
             "tenant_groups",
@@ -429,7 +431,7 @@ ALLOWED_QUERY_PARAMS = {
     "primary_ip6": set(["address", "vrf"]),
     "provider": set(["slug"]),
     "provider_network": set(["name"]),
-    "rack": set(["name", "site"]),
+    "rack": set(["name", "site", "location"]),
     "rack_group": set(["slug"]),
     "rack_role": set(["slug"]),
     "region": set(["slug"]),
@@ -467,6 +469,7 @@ QUERY_PARAMS_IDS = set(
         "device",
         "group",
         "interface",
+        "location",
         "rir",
         "vrf",
         "site",
