@@ -72,6 +72,15 @@ options:
       type: bool
       default: false
       version_added: 1.2.0
+    follow:
+      description:
+        - List of linked entities, which should be fetched along with the main entity.
+        - This parameter replaces usage of C(fetch_nested) and C(nested_attributes).
+        - "All follow parameters can be found at following url: https://ovirt.github.io/ovirt-engine-api-model/master/#types/vm/links_summary"
+      type: list
+      version_added: 1.5.0
+      elements: str
+      aliases: ['follows']
 extends_documentation_fragment: ovirt.ovirt.ovirt_info
 '''
 
@@ -132,7 +141,10 @@ def main():
         case_sensitive=dict(default=True, type='bool'),
         max=dict(default=None, type='int'),
     )
-    module = AnsibleModule(argument_spec)
+    module = AnsibleModule(
+        argument_spec,
+        supports_check_mode=True,
+    )
     check_sdk(module)
     if module.params['fetch_nested'] or module.params['nested_attributes']:
         module.deprecate(
