@@ -187,13 +187,13 @@ options:
   filesystem:
     description:
     - List of filesystems to add to a policy on creation
-    - To amend policy members use the I(purefb_fs) module
+    - To amend policy members use the I(purestorage.flashblade.purefb_fs) module
     type: list
     elements: str
   replica_link:
     description:
     - List of filesystem replica links to add to a policy on creation
-    - To amend policy members use the I(purefb_fs_replica) module
+    - To amend policy members use the I(purestorage.flashblade.purefb_fs_replica) module
     type: list
     elements: str
   access:
@@ -276,19 +276,25 @@ options:
     - The index of the client rule to insert or move a client rule before.
     type: int
     version_added: "1.9.0"
+  rename:
+    description:
+    - New name for export policy
+    - Only applies to NFS export policies
+    type: str
+    version_added: "1.10.0"
 extends_documentation_fragment:
 - purestorage.flashblade.purestorage.fb
 """
 
 EXAMPLES = r"""
 - name: Create a simple snapshot policy with no rules
-  purefb_policy:
+  purestorage.flashblade.purefb_policy:
     name: test_policy
     policy_type: snapshot
     fb_url: 10.10.10.2
     api_token: T-9f276a18-50ab-446e-8a0c-666a3529a1b6
 - name: Create a snapshot policy and connect to existing filesystems and filesystem replica links
-  purefb_policy:
+  purestorage.flashblade.purefb_policy:
     name: test_policy_with_members
     policy_type: snapshot
     filesystem:
@@ -300,7 +306,7 @@ EXAMPLES = r"""
     fb_url: 10.10.10.2
     api_token: T-9f276a18-50ab-446e-8a0c-666a3529a1b6
 - name: Create a snapshot policy with rules
-  purefb_policy:
+  purestorage.flashblade.purefb_policy:
     name: test_policy2
     policy_type: snapshot
     at: 11AM
@@ -310,21 +316,21 @@ EXAMPLES = r"""
     fb_url: 10.10.10.2
     api_token: T-9f276a18-50ab-446e-8a0c-666a3529a1b6
 - name: Delete a snapshot policy
-  purefb_policy:
+  purestorage.flashblade.purefb_policy:
     name: test_policy
     policy_type: snapshot
     state: absent
     fb_url: 10.10.10.2
     api_token: T-9f276a18-50ab-446e-8a0c-666a3529a1b6
 - name: Create an empty object store access policy
-  purefb_policy:
+  purestorage.flashblade.purefb_policy:
     name: test_os_policy
     account: test
     policy_type: access
     fb_url: 10.10.10.2
     api_token: T-9f276a18-50ab-446e-8a0c-666a3529a1b6
 - name: Create an empty object store access policy and assign user
-  purefb_policy:
+  purestorage.flashblade.purefb_policy:
     name: test_os_policy
     account: test
     policy_type: access
@@ -332,7 +338,7 @@ EXAMPLES = r"""
     fb_url: 10.10.10.2
     api_token: T-9f276a18-50ab-446e-8a0c-666a3529a1b6
 - name: Create a object store access policy with simple rule
-  purefb_policy:
+  purestorage.flashblade.purefb_policy:
     name: test_os_policy_rule
     policy_type: access
     account: test
@@ -342,13 +348,13 @@ EXAMPLES = r"""
     fb_url: 10.10.10.2
     api_token: T-9f276a18-50ab-446e-8a0c-666a3529a1b6
 - name: Create an empty NFS export policy
-  purefb_policy:
+  purestorage.flashblade.purefb_policy:
     name: test_nfs_export
     policy_type: nfs
     fb_url: 10.10.10.2
     api_token: T-9f276a18-50ab-446e-8a0c-666a3529a1b6
 - name: Create an NFS export policy with a client rule
-  purefb_policy:
+  purestorage.flashblade.purefb_policy:
     name: test_nfs_export
     policy_type: nfs
     atime: true
@@ -359,7 +365,7 @@ EXAMPLES = r"""
     fb_url: 10.10.10.2
     api_token: T-9f276a18-50ab-446e-8a0c-666a3529a1b6
 - name: Create a new rule for an existing NFS export policy
-  purefb_policy:
+  purestorage.flashblade.purefb_policy:
     name: test_nfs_export
     policy_type: nfs
     atime: true
@@ -369,7 +375,7 @@ EXAMPLES = r"""
     fb_url: 10.10.10.2
     api_token: T-9f276a18-50ab-446e-8a0c-666a3529a1b6
 - name: Delete a client rule from an NFS export policy
-  purefb_policy:
+  purestorage.flashblade.purefb_policy:
     name: test_nfs_export
     client: "10.0.1.0/24"
     policy_type: nfs
@@ -377,14 +383,14 @@ EXAMPLES = r"""
     fb_url: 10.10.10.2
     api_token: T-9f276a18-50ab-446e-8a0c-666a3529a1b6
 - name: Delete an NFS export policy and all associated rules
-  purefb_policy:
+  purestorage.flashblade.purefb_policy:
     name: test_nfs_export
     state: absent
     policy_type: nfs
     fb_url: 10.10.10.2
     api_token: T-9f276a18-50ab-446e-8a0c-666a3529a1b6
 - name: Delete a rule from an object store access policy
-  purefb_policy:
+  purestorage.flashblade.purefb_policy:
     name: test_os_policy_rule
     account: test
     policy_type: access
@@ -393,7 +399,7 @@ EXAMPLES = r"""
     fb_url: 10.10.10.2
     api_token: T-9f276a18-50ab-446e-8a0c-666a3529a1b6
 - name: Delete a user from an object store access policy
-  purefb_policy:
+  purestorage.flashblade.purefb_policy:
     name: test_os_policy_rule
     account: test
     user: fred
@@ -402,7 +408,7 @@ EXAMPLES = r"""
     fb_url: 10.10.10.2
     api_token: T-9f276a18-50ab-446e-8a0c-666a3529a1b6
 - name: Delete an object store access policy with attached users (USE WITH CAUTION)
-  purefb_policy:
+  purestorage.flashblade.purefb_policy:
     name: test_os_policy_rule
     account: test
     policy_type: access
@@ -411,7 +417,7 @@ EXAMPLES = r"""
     fb_url: 10.10.10.2
     api_token: T-9f276a18-50ab-446e-8a0c-666a3529a1b6
 - name: Delete an object store access policy with no attached users
-  purefb_policy:
+  purestorage.flashblade.purefb_policy:
     name: test_os_policy_rule
     account: test
     policy_type: access
@@ -419,7 +425,7 @@ EXAMPLES = r"""
     fb_url: 10.10.10.2
     api_token: T-9f276a18-50ab-446e-8a0c-666a3529a1b6
 - name: Copy an object store access policy rule to another exisitng policy
-  purefb_policy:
+  purestorage.flashblade.purefb_policy:
     name: test_os_policy_rule
     policy_type: access
     account: test
@@ -428,6 +434,13 @@ EXAMPLES = r"""
     state: copy
     fb_url: 10.10.10.2
     api_token: T-9f276a18-50ab-446e-8a0c-666a3529a1b6
+- name:  Rename an NFS Export Policy
+  purestorage.flashblade.purefb_policy:
+    name: old_name
+    policy_type: nfs
+    rename: new_name
+    fb_url: 10.10.10.2
+    api_token: T-9f276a18-50ab-446e-8a0c-666a3529a1b6
 """
 
 RETURN = r"""
@@ -474,6 +487,7 @@ from ansible_collections.purestorage.flashblade.plugins.module_utils.purefb impo
 MIN_REQUIRED_API_VERSION = "1.9"
 ACCESS_POLICY_API_VERSION = "2.2"
 NFS_POLICY_API_VERSION = "2.3"
+NFS_RENAME_API_VERSION = "2.4"
 
 
 def _convert_to_millisecs(hour):
@@ -630,6 +644,26 @@ def delete_nfs_policy(module, blade):
     module.exit_json(changed=changed)
 
 
+def rename_nfs_policy(module, blade):
+    """Rename NFS Export Policy"""
+
+    changed = True
+    if not module.check_mode:
+        res = blade.patch_nfs_export_policies(
+            names=[module.params["name"]],
+            policy=NfsExportPolicy(name=module.params["rename"]),
+        )
+        if res.status_code != 200:
+            module.fail_json(
+                msg="Failed to rename NFS export policy {0} to {1}. Error: {2}".format(
+                    module.params["name"],
+                    module.params["rename"],
+                    res.errors[0].message,
+                )
+            )
+        module.exit_json(changed=changed)
+
+
 def update_nfs_policy(module, blade):
     """Update NFS Export Policy Rule"""
 
@@ -703,7 +737,7 @@ def update_nfs_policy(module, blade):
                     changed = True
                     if not module.check_mode:
                         if module.params["before_rule"]:
-                            res = blade.post_object_store_access_policies_rules(
+                            res = blade.post_nfs_export_policies_rules(
                                 policy_names=[module.params["name"]],
                                 rule=rule,
                                 before_rule_name=(
@@ -891,7 +925,7 @@ def create_nfs_policy(module, blade):
                 secure=module.params["secure"],
                 security=module.params["security"],
             )
-            res = blade.post_object_store_access_policies_rules(
+            res = blade.post_nfs_export_policies_rules(
                 policy_names=[module.params["name"]],
                 rule=rule,
             )
@@ -1500,6 +1534,7 @@ def main():
             account=dict(type="str"),
             target=dict(type="str"),
             target_rule=dict(type="str"),
+            rename=dict(type="str"),
             rule=dict(type="str"),
             user=dict(type="str"),
             effect=dict(type="str", default="allow", choices=["allow"]),
@@ -1610,7 +1645,7 @@ def main():
                     )
                 )
         if policy and state == "present":
-            update_os_policy(module, blade, policy)
+            update_os_policy(module, blade)
         elif state == "present" and not policy:
             create_os_policy(module, blade)
         elif state == "absent" and policy:
@@ -1650,7 +1685,14 @@ def main():
             )[0]
         except AttributeError:
             policy = None
-        if policy and state == "present":
+        if module.params["rename"]:
+            try:
+                new_policy = list(
+                    blade.get_nfs_export_policies(names=[module.params["rename"]]).items
+                )[0]
+            except AttributeError:
+                new_policy = None
+        if policy and state == "present" and not module.params["rename"]:
             if module.params["before_rule"]:
                 res = blade.get_nfs_export_policies_rules(
                     policy_names=[module.params["name"]],
@@ -1665,7 +1707,11 @@ def main():
                         )
                     )
             update_nfs_policy(module, blade)
-        elif state == "present" and not policy:
+        elif (
+            state == "present" and module.params["rename"] and policy and not new_policy
+        ):
+            rename_nfs_policy(module, blade)
+        elif state == "present" and not policy and not module.params["rename"]:
             create_nfs_policy(module, blade)
         elif state == "absent" and policy:
             delete_nfs_policy(module, blade)
